Class: Google::Cloud::DiscoveryEngine::V1beta::AdvancedCompleteQueryResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb

Overview

Response message for CompletionService.AdvancedCompleteQuery method.

Defined Under Namespace

Classes: ContentSuggestion, PersonSuggestion, QuerySuggestion, RecentSearchSuggestion

Instance Attribute Summary collapse

Instance Attribute Details

#content_suggestions::Array<::Google::Cloud::DiscoveryEngine::V1beta::AdvancedCompleteQueryResponse::ContentSuggestion>

Returns Results of the matched content suggestions. The result list is ordered and the first result is the top suggestion.

Returns:



306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb', line 306

class AdvancedCompleteQueryResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Suggestions as search queries.
  # @!attribute [rw] suggestion
  #   @return [::String]
  #     The suggestion for the query.
  # @!attribute [rw] completable_field_paths
  #   @return [::Array<::String>]
  #     The unique document field paths that serve as the source of this
  #     suggestion if it was generated from completable fields.
  #
  #     This field is only populated for the document-completable model.
  # @!attribute [rw] data_store
  #   @return [::Array<::String>]
  #     The name of the dataStore that this suggestion belongs to.
  # @!attribute [rw] score
  #   @return [::Float]
  #     The score of each suggestion. The score is in the range of [0, 1].
  class QuerySuggestion
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Suggestions as people.
  # @!attribute [rw] suggestion
  #   @return [::String]
  #     The suggestion for the query.
  # @!attribute [rw] person_type
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::AdvancedCompleteQueryResponse::PersonSuggestion::PersonType]
  #     The type of the person.
  # @!attribute [rw] document
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Document]
  #     The document data snippet in the suggestion. Only a subset of fields is
  #     populated.
  # @!attribute [rw] data_store
  #   @return [::String]
  #     The name of the dataStore that this suggestion belongs to.
  # @!attribute [rw] score
  #   @return [::Float]
  #     The score of each suggestion. The score is in the range of [0, 1].
  # @!attribute [rw] display_photo_uri
  #   @return [::String]
  #     The photo uri of the person suggestion.
  # @!attribute [rw] destination_uri
  #   @return [::String]
  #     The destination uri of the person suggestion.
  class PersonSuggestion
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The type of the person based on the source.
    module PersonType
      # Default value.
      PERSON_TYPE_UNSPECIFIED = 0

      # The suggestion is from a GOOGLE_IDENTITY source.
      CLOUD_IDENTITY = 1

      # The suggestion is from a THIRD_PARTY_IDENTITY source.
      THIRD_PARTY_IDENTITY = 2
    end
  end

  # Suggestions as content.
  # @!attribute [rw] suggestion
  #   @return [::String]
  #     The suggestion for the query.
  # @!attribute [rw] content_type
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::AdvancedCompleteQueryResponse::ContentSuggestion::ContentType]
  #     The type of the content suggestion.
  # @!attribute [rw] document
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Document]
  #     The document data snippet in the suggestion. Only a subset of fields will
  #     be populated.
  # @!attribute [rw] data_store
  #   @return [::String]
  #     The name of the dataStore that this suggestion belongs to.
  # @!attribute [rw] score
  #   @return [::Float]
  #     The score of each suggestion. The score is in the range of [0, 1].
  # @!attribute [rw] icon_uri
  #   @return [::String]
  #     The icon uri of the content suggestion.
  # @!attribute [rw] destination_uri
  #   @return [::String]
  #     The destination uri of the content suggestion.
  class ContentSuggestion
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The type of the content returned for content suggestions.
    module ContentType
      # Default value.
      CONTENT_TYPE_UNSPECIFIED = 0

      # The suggestion is from a Google Workspace source.
      GOOGLE_WORKSPACE = 1

      # The suggestion is from a third party source.
      THIRD_PARTY = 2
    end
  end

  # Suggestions from recent search history.
  # @!attribute [rw] suggestion
  #   @return [::String]
  #     The suggestion for the query.
  # @!attribute [rw] recent_search_time
  #   @return [::Google::Protobuf::Timestamp]
  #     The time when this recent rearch happened.
  # @!attribute [rw] score
  #   @return [::Float]
  #     The score of each suggestion. The score is in the range of [0, 1].
  class RecentSearchSuggestion
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#people_suggestions::Array<::Google::Cloud::DiscoveryEngine::V1beta::AdvancedCompleteQueryResponse::PersonSuggestion>

Returns Results of the matched people suggestions. The result list is ordered and the first result is the top suggestion.

Returns:



306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb', line 306

class AdvancedCompleteQueryResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Suggestions as search queries.
  # @!attribute [rw] suggestion
  #   @return [::String]
  #     The suggestion for the query.
  # @!attribute [rw] completable_field_paths
  #   @return [::Array<::String>]
  #     The unique document field paths that serve as the source of this
  #     suggestion if it was generated from completable fields.
  #
  #     This field is only populated for the document-completable model.
  # @!attribute [rw] data_store
  #   @return [::Array<::String>]
  #     The name of the dataStore that this suggestion belongs to.
  # @!attribute [rw] score
  #   @return [::Float]
  #     The score of each suggestion. The score is in the range of [0, 1].
  class QuerySuggestion
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Suggestions as people.
  # @!attribute [rw] suggestion
  #   @return [::String]
  #     The suggestion for the query.
  # @!attribute [rw] person_type
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::AdvancedCompleteQueryResponse::PersonSuggestion::PersonType]
  #     The type of the person.
  # @!attribute [rw] document
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Document]
  #     The document data snippet in the suggestion. Only a subset of fields is
  #     populated.
  # @!attribute [rw] data_store
  #   @return [::String]
  #     The name of the dataStore that this suggestion belongs to.
  # @!attribute [rw] score
  #   @return [::Float]
  #     The score of each suggestion. The score is in the range of [0, 1].
  # @!attribute [rw] display_photo_uri
  #   @return [::String]
  #     The photo uri of the person suggestion.
  # @!attribute [rw] destination_uri
  #   @return [::String]
  #     The destination uri of the person suggestion.
  class PersonSuggestion
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The type of the person based on the source.
    module PersonType
      # Default value.
      PERSON_TYPE_UNSPECIFIED = 0

      # The suggestion is from a GOOGLE_IDENTITY source.
      CLOUD_IDENTITY = 1

      # The suggestion is from a THIRD_PARTY_IDENTITY source.
      THIRD_PARTY_IDENTITY = 2
    end
  end

  # Suggestions as content.
  # @!attribute [rw] suggestion
  #   @return [::String]
  #     The suggestion for the query.
  # @!attribute [rw] content_type
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::AdvancedCompleteQueryResponse::ContentSuggestion::ContentType]
  #     The type of the content suggestion.
  # @!attribute [rw] document
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Document]
  #     The document data snippet in the suggestion. Only a subset of fields will
  #     be populated.
  # @!attribute [rw] data_store
  #   @return [::String]
  #     The name of the dataStore that this suggestion belongs to.
  # @!attribute [rw] score
  #   @return [::Float]
  #     The score of each suggestion. The score is in the range of [0, 1].
  # @!attribute [rw] icon_uri
  #   @return [::String]
  #     The icon uri of the content suggestion.
  # @!attribute [rw] destination_uri
  #   @return [::String]
  #     The destination uri of the content suggestion.
  class ContentSuggestion
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The type of the content returned for content suggestions.
    module ContentType
      # Default value.
      CONTENT_TYPE_UNSPECIFIED = 0

      # The suggestion is from a Google Workspace source.
      GOOGLE_WORKSPACE = 1

      # The suggestion is from a third party source.
      THIRD_PARTY = 2
    end
  end

  # Suggestions from recent search history.
  # @!attribute [rw] suggestion
  #   @return [::String]
  #     The suggestion for the query.
  # @!attribute [rw] recent_search_time
  #   @return [::Google::Protobuf::Timestamp]
  #     The time when this recent rearch happened.
  # @!attribute [rw] score
  #   @return [::Float]
  #     The score of each suggestion. The score is in the range of [0, 1].
  class RecentSearchSuggestion
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#query_suggestions::Array<::Google::Cloud::DiscoveryEngine::V1beta::AdvancedCompleteQueryResponse::QuerySuggestion>

Returns Results of the matched query suggestions. The result list is ordered and the first result is a top suggestion.

Returns:



306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb', line 306

class AdvancedCompleteQueryResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Suggestions as search queries.
  # @!attribute [rw] suggestion
  #   @return [::String]
  #     The suggestion for the query.
  # @!attribute [rw] completable_field_paths
  #   @return [::Array<::String>]
  #     The unique document field paths that serve as the source of this
  #     suggestion if it was generated from completable fields.
  #
  #     This field is only populated for the document-completable model.
  # @!attribute [rw] data_store
  #   @return [::Array<::String>]
  #     The name of the dataStore that this suggestion belongs to.
  # @!attribute [rw] score
  #   @return [::Float]
  #     The score of each suggestion. The score is in the range of [0, 1].
  class QuerySuggestion
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Suggestions as people.
  # @!attribute [rw] suggestion
  #   @return [::String]
  #     The suggestion for the query.
  # @!attribute [rw] person_type
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::AdvancedCompleteQueryResponse::PersonSuggestion::PersonType]
  #     The type of the person.
  # @!attribute [rw] document
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Document]
  #     The document data snippet in the suggestion. Only a subset of fields is
  #     populated.
  # @!attribute [rw] data_store
  #   @return [::String]
  #     The name of the dataStore that this suggestion belongs to.
  # @!attribute [rw] score
  #   @return [::Float]
  #     The score of each suggestion. The score is in the range of [0, 1].
  # @!attribute [rw] display_photo_uri
  #   @return [::String]
  #     The photo uri of the person suggestion.
  # @!attribute [rw] destination_uri
  #   @return [::String]
  #     The destination uri of the person suggestion.
  class PersonSuggestion
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The type of the person based on the source.
    module PersonType
      # Default value.
      PERSON_TYPE_UNSPECIFIED = 0

      # The suggestion is from a GOOGLE_IDENTITY source.
      CLOUD_IDENTITY = 1

      # The suggestion is from a THIRD_PARTY_IDENTITY source.
      THIRD_PARTY_IDENTITY = 2
    end
  end

  # Suggestions as content.
  # @!attribute [rw] suggestion
  #   @return [::String]
  #     The suggestion for the query.
  # @!attribute [rw] content_type
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::AdvancedCompleteQueryResponse::ContentSuggestion::ContentType]
  #     The type of the content suggestion.
  # @!attribute [rw] document
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Document]
  #     The document data snippet in the suggestion. Only a subset of fields will
  #     be populated.
  # @!attribute [rw] data_store
  #   @return [::String]
  #     The name of the dataStore that this suggestion belongs to.
  # @!attribute [rw] score
  #   @return [::Float]
  #     The score of each suggestion. The score is in the range of [0, 1].
  # @!attribute [rw] icon_uri
  #   @return [::String]
  #     The icon uri of the content suggestion.
  # @!attribute [rw] destination_uri
  #   @return [::String]
  #     The destination uri of the content suggestion.
  class ContentSuggestion
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The type of the content returned for content suggestions.
    module ContentType
      # Default value.
      CONTENT_TYPE_UNSPECIFIED = 0

      # The suggestion is from a Google Workspace source.
      GOOGLE_WORKSPACE = 1

      # The suggestion is from a third party source.
      THIRD_PARTY = 2
    end
  end

  # Suggestions from recent search history.
  # @!attribute [rw] suggestion
  #   @return [::String]
  #     The suggestion for the query.
  # @!attribute [rw] recent_search_time
  #   @return [::Google::Protobuf::Timestamp]
  #     The time when this recent rearch happened.
  # @!attribute [rw] score
  #   @return [::Float]
  #     The score of each suggestion. The score is in the range of [0, 1].
  class RecentSearchSuggestion
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#recent_search_suggestions::Array<::Google::Cloud::DiscoveryEngine::V1beta::AdvancedCompleteQueryResponse::RecentSearchSuggestion>

Returns Results of the matched "recent search" suggestions. The result list is ordered and the first result is the top suggestion.

Returns:



306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb', line 306

class AdvancedCompleteQueryResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Suggestions as search queries.
  # @!attribute [rw] suggestion
  #   @return [::String]
  #     The suggestion for the query.
  # @!attribute [rw] completable_field_paths
  #   @return [::Array<::String>]
  #     The unique document field paths that serve as the source of this
  #     suggestion if it was generated from completable fields.
  #
  #     This field is only populated for the document-completable model.
  # @!attribute [rw] data_store
  #   @return [::Array<::String>]
  #     The name of the dataStore that this suggestion belongs to.
  # @!attribute [rw] score
  #   @return [::Float]
  #     The score of each suggestion. The score is in the range of [0, 1].
  class QuerySuggestion
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Suggestions as people.
  # @!attribute [rw] suggestion
  #   @return [::String]
  #     The suggestion for the query.
  # @!attribute [rw] person_type
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::AdvancedCompleteQueryResponse::PersonSuggestion::PersonType]
  #     The type of the person.
  # @!attribute [rw] document
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Document]
  #     The document data snippet in the suggestion. Only a subset of fields is
  #     populated.
  # @!attribute [rw] data_store
  #   @return [::String]
  #     The name of the dataStore that this suggestion belongs to.
  # @!attribute [rw] score
  #   @return [::Float]
  #     The score of each suggestion. The score is in the range of [0, 1].
  # @!attribute [rw] display_photo_uri
  #   @return [::String]
  #     The photo uri of the person suggestion.
  # @!attribute [rw] destination_uri
  #   @return [::String]
  #     The destination uri of the person suggestion.
  class PersonSuggestion
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The type of the person based on the source.
    module PersonType
      # Default value.
      PERSON_TYPE_UNSPECIFIED = 0

      # The suggestion is from a GOOGLE_IDENTITY source.
      CLOUD_IDENTITY = 1

      # The suggestion is from a THIRD_PARTY_IDENTITY source.
      THIRD_PARTY_IDENTITY = 2
    end
  end

  # Suggestions as content.
  # @!attribute [rw] suggestion
  #   @return [::String]
  #     The suggestion for the query.
  # @!attribute [rw] content_type
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::AdvancedCompleteQueryResponse::ContentSuggestion::ContentType]
  #     The type of the content suggestion.
  # @!attribute [rw] document
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Document]
  #     The document data snippet in the suggestion. Only a subset of fields will
  #     be populated.
  # @!attribute [rw] data_store
  #   @return [::String]
  #     The name of the dataStore that this suggestion belongs to.
  # @!attribute [rw] score
  #   @return [::Float]
  #     The score of each suggestion. The score is in the range of [0, 1].
  # @!attribute [rw] icon_uri
  #   @return [::String]
  #     The icon uri of the content suggestion.
  # @!attribute [rw] destination_uri
  #   @return [::String]
  #     The destination uri of the content suggestion.
  class ContentSuggestion
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The type of the content returned for content suggestions.
    module ContentType
      # Default value.
      CONTENT_TYPE_UNSPECIFIED = 0

      # The suggestion is from a Google Workspace source.
      GOOGLE_WORKSPACE = 1

      # The suggestion is from a third party source.
      THIRD_PARTY = 2
    end
  end

  # Suggestions from recent search history.
  # @!attribute [rw] suggestion
  #   @return [::String]
  #     The suggestion for the query.
  # @!attribute [rw] recent_search_time
  #   @return [::Google::Protobuf::Timestamp]
  #     The time when this recent rearch happened.
  # @!attribute [rw] score
  #   @return [::Float]
  #     The score of each suggestion. The score is in the range of [0, 1].
  class RecentSearchSuggestion
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#tail_match_triggered::Boolean

Returns True if the returned suggestions are all tail suggestions.

For tail matching to be triggered, include_tail_suggestions in the request must be true and there must be no suggestions that match the full query.

Returns:

  • (::Boolean)

    True if the returned suggestions are all tail suggestions.

    For tail matching to be triggered, include_tail_suggestions in the request must be true and there must be no suggestions that match the full query.



306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb', line 306

class AdvancedCompleteQueryResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Suggestions as search queries.
  # @!attribute [rw] suggestion
  #   @return [::String]
  #     The suggestion for the query.
  # @!attribute [rw] completable_field_paths
  #   @return [::Array<::String>]
  #     The unique document field paths that serve as the source of this
  #     suggestion if it was generated from completable fields.
  #
  #     This field is only populated for the document-completable model.
  # @!attribute [rw] data_store
  #   @return [::Array<::String>]
  #     The name of the dataStore that this suggestion belongs to.
  # @!attribute [rw] score
  #   @return [::Float]
  #     The score of each suggestion. The score is in the range of [0, 1].
  class QuerySuggestion
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Suggestions as people.
  # @!attribute [rw] suggestion
  #   @return [::String]
  #     The suggestion for the query.
  # @!attribute [rw] person_type
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::AdvancedCompleteQueryResponse::PersonSuggestion::PersonType]
  #     The type of the person.
  # @!attribute [rw] document
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Document]
  #     The document data snippet in the suggestion. Only a subset of fields is
  #     populated.
  # @!attribute [rw] data_store
  #   @return [::String]
  #     The name of the dataStore that this suggestion belongs to.
  # @!attribute [rw] score
  #   @return [::Float]
  #     The score of each suggestion. The score is in the range of [0, 1].
  # @!attribute [rw] display_photo_uri
  #   @return [::String]
  #     The photo uri of the person suggestion.
  # @!attribute [rw] destination_uri
  #   @return [::String]
  #     The destination uri of the person suggestion.
  class PersonSuggestion
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The type of the person based on the source.
    module PersonType
      # Default value.
      PERSON_TYPE_UNSPECIFIED = 0

      # The suggestion is from a GOOGLE_IDENTITY source.
      CLOUD_IDENTITY = 1

      # The suggestion is from a THIRD_PARTY_IDENTITY source.
      THIRD_PARTY_IDENTITY = 2
    end
  end

  # Suggestions as content.
  # @!attribute [rw] suggestion
  #   @return [::String]
  #     The suggestion for the query.
  # @!attribute [rw] content_type
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::AdvancedCompleteQueryResponse::ContentSuggestion::ContentType]
  #     The type of the content suggestion.
  # @!attribute [rw] document
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Document]
  #     The document data snippet in the suggestion. Only a subset of fields will
  #     be populated.
  # @!attribute [rw] data_store
  #   @return [::String]
  #     The name of the dataStore that this suggestion belongs to.
  # @!attribute [rw] score
  #   @return [::Float]
  #     The score of each suggestion. The score is in the range of [0, 1].
  # @!attribute [rw] icon_uri
  #   @return [::String]
  #     The icon uri of the content suggestion.
  # @!attribute [rw] destination_uri
  #   @return [::String]
  #     The destination uri of the content suggestion.
  class ContentSuggestion
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The type of the content returned for content suggestions.
    module ContentType
      # Default value.
      CONTENT_TYPE_UNSPECIFIED = 0

      # The suggestion is from a Google Workspace source.
      GOOGLE_WORKSPACE = 1

      # The suggestion is from a third party source.
      THIRD_PARTY = 2
    end
  end

  # Suggestions from recent search history.
  # @!attribute [rw] suggestion
  #   @return [::String]
  #     The suggestion for the query.
  # @!attribute [rw] recent_search_time
  #   @return [::Google::Protobuf::Timestamp]
  #     The time when this recent rearch happened.
  # @!attribute [rw] score
  #   @return [::Float]
  #     The score of each suggestion. The score is in the range of [0, 1].
  class RecentSearchSuggestion
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end