Class: Google::Cloud::DiscoveryEngine::V1beta::AdvancedCompleteQueryResponse::ContentSuggestion

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb

Overview

Suggestions as content.

Defined Under Namespace

Modules: ContentType

Instance Attribute Summary collapse

Instance Attribute Details

#content_type::Google::Cloud::DiscoveryEngine::V1beta::AdvancedCompleteQueryResponse::ContentSuggestion::ContentType

Returns The type of the content suggestion.



394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
# File 'proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb', line 394

class ContentSuggestion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the content returned for content suggestions.
  module ContentType
    # Default value.
    CONTENT_TYPE_UNSPECIFIED = 0

    # The suggestion is from a Google Workspace source.
    GOOGLE_WORKSPACE = 1

    # The suggestion is from a third party source.
    THIRD_PARTY = 2
  end
end

#data_store::String

Returns The name of the dataStore that this suggestion belongs to.

Returns:

  • (::String)

    The name of the dataStore that this suggestion belongs to.



394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
# File 'proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb', line 394

class ContentSuggestion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the content returned for content suggestions.
  module ContentType
    # Default value.
    CONTENT_TYPE_UNSPECIFIED = 0

    # The suggestion is from a Google Workspace source.
    GOOGLE_WORKSPACE = 1

    # The suggestion is from a third party source.
    THIRD_PARTY = 2
  end
end

#destination_uri::String

Returns The destination uri of the content suggestion.

Returns:

  • (::String)

    The destination uri of the content suggestion.



394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
# File 'proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb', line 394

class ContentSuggestion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the content returned for content suggestions.
  module ContentType
    # Default value.
    CONTENT_TYPE_UNSPECIFIED = 0

    # The suggestion is from a Google Workspace source.
    GOOGLE_WORKSPACE = 1

    # The suggestion is from a third party source.
    THIRD_PARTY = 2
  end
end

#document::Google::Cloud::DiscoveryEngine::V1beta::Document

Returns The document data snippet in the suggestion. Only a subset of fields will be populated.

Returns:



394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
# File 'proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb', line 394

class ContentSuggestion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the content returned for content suggestions.
  module ContentType
    # Default value.
    CONTENT_TYPE_UNSPECIFIED = 0

    # The suggestion is from a Google Workspace source.
    GOOGLE_WORKSPACE = 1

    # The suggestion is from a third party source.
    THIRD_PARTY = 2
  end
end

#icon_uri::String

Returns The icon uri of the content suggestion.

Returns:

  • (::String)

    The icon uri of the content suggestion.



394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
# File 'proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb', line 394

class ContentSuggestion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the content returned for content suggestions.
  module ContentType
    # Default value.
    CONTENT_TYPE_UNSPECIFIED = 0

    # The suggestion is from a Google Workspace source.
    GOOGLE_WORKSPACE = 1

    # The suggestion is from a third party source.
    THIRD_PARTY = 2
  end
end

#score::Float

Returns The score of each suggestion. The score is in the range of [0, 1].

Returns:

  • (::Float)

    The score of each suggestion. The score is in the range of [0, 1].



394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
# File 'proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb', line 394

class ContentSuggestion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the content returned for content suggestions.
  module ContentType
    # Default value.
    CONTENT_TYPE_UNSPECIFIED = 0

    # The suggestion is from a Google Workspace source.
    GOOGLE_WORKSPACE = 1

    # The suggestion is from a third party source.
    THIRD_PARTY = 2
  end
end

#suggestion::String

Returns The suggestion for the query.

Returns:

  • (::String)

    The suggestion for the query.



394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
# File 'proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb', line 394

class ContentSuggestion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the content returned for content suggestions.
  module ContentType
    # Default value.
    CONTENT_TYPE_UNSPECIFIED = 0

    # The suggestion is from a Google Workspace source.
    GOOGLE_WORKSPACE = 1

    # The suggestion is from a third party source.
    THIRD_PARTY = 2
  end
end