Class: Google::Cloud::DiscoveryEngine::V1beta::AdvancedCompleteQueryResponse::PersonSuggestion

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb

Overview

Suggestions as people.

Defined Under Namespace

Modules: PersonType

Instance Attribute Summary collapse

Instance Attribute Details

#data_store::String

Returns The name of the dataStore that this suggestion belongs to.

Returns:

  • (::String)

    The name of the dataStore that this suggestion belongs to.



354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
# File 'proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb', line 354

class PersonSuggestion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the person based on the source.
  module PersonType
    # Default value.
    PERSON_TYPE_UNSPECIFIED = 0

    # The suggestion is from a GOOGLE_IDENTITY source.
    CLOUD_IDENTITY = 1

    # The suggestion is from a THIRD_PARTY_IDENTITY source.
    THIRD_PARTY_IDENTITY = 2
  end
end

#destination_uri::String

Returns The destination uri of the person suggestion.

Returns:

  • (::String)

    The destination uri of the person suggestion.



354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
# File 'proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb', line 354

class PersonSuggestion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the person based on the source.
  module PersonType
    # Default value.
    PERSON_TYPE_UNSPECIFIED = 0

    # The suggestion is from a GOOGLE_IDENTITY source.
    CLOUD_IDENTITY = 1

    # The suggestion is from a THIRD_PARTY_IDENTITY source.
    THIRD_PARTY_IDENTITY = 2
  end
end

#display_photo_uri::String

Returns The photo uri of the person suggestion.

Returns:

  • (::String)

    The photo uri of the person suggestion.



354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
# File 'proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb', line 354

class PersonSuggestion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the person based on the source.
  module PersonType
    # Default value.
    PERSON_TYPE_UNSPECIFIED = 0

    # The suggestion is from a GOOGLE_IDENTITY source.
    CLOUD_IDENTITY = 1

    # The suggestion is from a THIRD_PARTY_IDENTITY source.
    THIRD_PARTY_IDENTITY = 2
  end
end

#document::Google::Cloud::DiscoveryEngine::V1beta::Document

Returns The document data snippet in the suggestion. Only a subset of fields is populated.

Returns:



354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
# File 'proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb', line 354

class PersonSuggestion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the person based on the source.
  module PersonType
    # Default value.
    PERSON_TYPE_UNSPECIFIED = 0

    # The suggestion is from a GOOGLE_IDENTITY source.
    CLOUD_IDENTITY = 1

    # The suggestion is from a THIRD_PARTY_IDENTITY source.
    THIRD_PARTY_IDENTITY = 2
  end
end

#person_type::Google::Cloud::DiscoveryEngine::V1beta::AdvancedCompleteQueryResponse::PersonSuggestion::PersonType

Returns The type of the person.



354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
# File 'proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb', line 354

class PersonSuggestion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the person based on the source.
  module PersonType
    # Default value.
    PERSON_TYPE_UNSPECIFIED = 0

    # The suggestion is from a GOOGLE_IDENTITY source.
    CLOUD_IDENTITY = 1

    # The suggestion is from a THIRD_PARTY_IDENTITY source.
    THIRD_PARTY_IDENTITY = 2
  end
end

#score::Float

Returns The score of each suggestion. The score is in the range of [0, 1].

Returns:

  • (::Float)

    The score of each suggestion. The score is in the range of [0, 1].



354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
# File 'proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb', line 354

class PersonSuggestion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the person based on the source.
  module PersonType
    # Default value.
    PERSON_TYPE_UNSPECIFIED = 0

    # The suggestion is from a GOOGLE_IDENTITY source.
    CLOUD_IDENTITY = 1

    # The suggestion is from a THIRD_PARTY_IDENTITY source.
    THIRD_PARTY_IDENTITY = 2
  end
end

#suggestion::String

Returns The suggestion for the query.

Returns:

  • (::String)

    The suggestion for the query.



354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
# File 'proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb', line 354

class PersonSuggestion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the person based on the source.
  module PersonType
    # Default value.
    PERSON_TYPE_UNSPECIFIED = 0

    # The suggestion is from a GOOGLE_IDENTITY source.
    CLOUD_IDENTITY = 1

    # The suggestion is from a THIRD_PARTY_IDENTITY source.
    THIRD_PARTY_IDENTITY = 2
  end
end