Class: Google::Cloud::DiscoveryEngine::V1beta::AgentGatewaySetting

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/agent_gateway_setting.rb

Overview

Agent Gateway setting, which may be attached to Gemini Enterprise resources for egress control of Gemini Enterprise agents to agents and tools outside of Gemini Enterprise.

Defined Under Namespace

Classes: AgentGatewayReference

Instance Attribute Summary collapse

Instance Attribute Details

#default_egress_agent_gateway::Google::Cloud::DiscoveryEngine::V1beta::AgentGatewaySetting::AgentGatewayReference

Returns Optional. The default egress agent gateway to use, when this setting is applied to a Gemini Enterprise resource.

The deployment mode must be GOOGLE_MANAGED, and the governed access path must be AGENT_TO_ANYWHERE.

Returns:



34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
# File 'proto_docs/google/cloud/discoveryengine/v1beta/agent_gateway_setting.rb', line 34

class AgentGatewaySetting
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Reference to an Agent Gateway resource.
  # @!attribute [rw] name
  #   @return [::String]
  #     Required. Immutable. The resource name of the agent gateway.
  #
  #     Expected format:
  #     `projects/{project_number}/locations/{location}/agentGateways/{agent_gateway}`.
  class AgentGatewayReference
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end