Class: Google::Cloud::DiscoveryEngine::V1beta::Answer::GroundingSupport

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/answer.rb

Overview

Grounding support for a claim in answer_text.

Instance Attribute Summary collapse

Instance Attribute Details

#end_index::Integer

Returns Required. End of the claim, exclusive.

Returns:

  • (::Integer)

    Required. End of the claim, exclusive.



129
130
131
132
# File 'proto_docs/google/cloud/discoveryengine/v1beta/answer.rb', line 129

class GroundingSupport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#grounding_check_required::Boolean

Indicates that this claim required grounding check. When the system decided this claim didn't require attribution/grounding check, this field is set to false. In that case, no grounding check was done for the claim and therefore grounding_score, sources is not returned.

Returns:

  • (::Boolean)

    Indicates that this claim required grounding check. When the system decided this claim didn't require attribution/grounding check, this field is set to false. In that case, no grounding check was done for the claim and therefore grounding_score, sources is not returned.



129
130
131
132
# File 'proto_docs/google/cloud/discoveryengine/v1beta/answer.rb', line 129

class GroundingSupport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#grounding_score::Float

Returns A score in the range of [0, 1] describing how grounded is a specific claim by the references. Higher value means that the claim is better supported by the reference chunks.

Returns:

  • (::Float)

    A score in the range of [0, 1] describing how grounded is a specific claim by the references. Higher value means that the claim is better supported by the reference chunks.



129
130
131
132
# File 'proto_docs/google/cloud/discoveryengine/v1beta/answer.rb', line 129

class GroundingSupport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#sources::Array<::Google::Cloud::DiscoveryEngine::V1beta::Answer::CitationSource>

Returns Optional. Citation sources for the claim.

Returns:



129
130
131
132
# File 'proto_docs/google/cloud/discoveryengine/v1beta/answer.rb', line 129

class GroundingSupport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#start_index::Integer

Returns Required. Index indicates the start of the claim, measured in bytes (UTF-8 unicode).

Returns:

  • (::Integer)

    Required. Index indicates the start of the claim, measured in bytes (UTF-8 unicode).



129
130
131
132
# File 'proto_docs/google/cloud/discoveryengine/v1beta/answer.rb', line 129

class GroundingSupport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end