Class: Google::Cloud::DiscoveryEngine::V1beta::Answer::Reference::UnstructuredDocumentInfo::ChunkContent

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/answer.rb

Overview

Chunk content.

Instance Attribute Summary collapse

Instance Attribute Details

#blob_attachment_indexes::Array<::Integer> (readonly)

Returns Output only. Stores indexes of blobattachments linked to this chunk.

Returns:

  • (::Array<::Integer>)

    Output only. Stores indexes of blobattachments linked to this chunk.



192
193
194
195
# File 'proto_docs/google/cloud/discoveryengine/v1beta/answer.rb', line 192

class ChunkContent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#content::String

Returns Chunk textual content.

Returns:

  • (::String)

    Chunk textual content.



192
193
194
195
# File 'proto_docs/google/cloud/discoveryengine/v1beta/answer.rb', line 192

class ChunkContent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_identifier::String

Returns Page identifier.

Returns:

  • (::String)

    Page identifier.



192
193
194
195
# File 'proto_docs/google/cloud/discoveryengine/v1beta/answer.rb', line 192

class ChunkContent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#relevance_score::Float

Returns The relevance of the chunk for a given query. Values range from 0.0 (completely irrelevant) to 1.0 (completely relevant). This value is for informational purpose only. It may change for the same query and chunk at any time due to a model retraining or change in implementation.

Returns:

  • (::Float)

    The relevance of the chunk for a given query. Values range from 0.0 (completely irrelevant) to 1.0 (completely relevant). This value is for informational purpose only. It may change for the same query and chunk at any time due to a model retraining or change in implementation.



192
193
194
195
# File 'proto_docs/google/cloud/discoveryengine/v1beta/answer.rb', line 192

class ChunkContent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end