Class: Google::Cloud::DiscoveryEngine::V1beta::Answer::Step

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/answer.rb

Overview

Step information.

Defined Under Namespace

Modules: State Classes: Action

Instance Attribute Summary collapse

Instance Attribute Details

#actions::Array<::Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::Action>

Returns Actions.



315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
# File 'proto_docs/google/cloud/discoveryengine/v1beta/answer.rb', line 315

class Step
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Action.
  # @!attribute [rw] search_action
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::Action::SearchAction]
  #     Search action.
  # @!attribute [rw] observation
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::Action::Observation]
  #     Observation.
  class Action
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Search action.
    # @!attribute [rw] query
    #   @return [::String]
    #     The query to search.
    class SearchAction
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Observation.
    # @!attribute [rw] search_results
    #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::Action::Observation::SearchResult>]
    #     Search results observed by the search action, it can be snippets info
    #     or chunk info, depending on the citation type set by the user.
    class Observation
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods

      # @!attribute [rw] document
      #   @return [::String]
      #     Document resource name.
      # @!attribute [rw] uri
      #   @return [::String]
      #     URI for the document.
      # @!attribute [rw] title
      #   @return [::String]
      #     Title.
      # @!attribute [rw] snippet_info
      #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::Action::Observation::SearchResult::SnippetInfo>]
      #     If citation_type is DOCUMENT_LEVEL_CITATION, populate document
      #     level snippets.
      # @!attribute [rw] chunk_info
      #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::Action::Observation::SearchResult::ChunkInfo>]
      #     If citation_type is CHUNK_LEVEL_CITATION and chunk mode is on,
      #     populate chunk info.
      # @!attribute [rw] struct_data
      #   @return [::Google::Protobuf::Struct]
      #     Data representation.
      #     The structured JSON data for the document.
      #     It's populated from the struct data from the Document, or the
      #     Chunk in search result.
      class SearchResult
        include ::Google::Protobuf::MessageExts
        extend ::Google::Protobuf::MessageExts::ClassMethods

        # Snippet information.
        # @!attribute [rw] snippet
        #   @return [::String]
        #     Snippet content.
        # @!attribute [rw] snippet_status
        #   @return [::String]
        #     Status of the snippet defined by the search team.
        class SnippetInfo
          include ::Google::Protobuf::MessageExts
          extend ::Google::Protobuf::MessageExts::ClassMethods
        end

        # Chunk information.
        # @!attribute [rw] chunk
        #   @return [::String]
        #     Chunk resource name.
        # @!attribute [rw] content
        #   @return [::String]
        #     Chunk textual content.
        # @!attribute [rw] relevance_score
        #   @return [::Float]
        #     The relevance of the chunk for a given query. Values range from
        #     0.0 (completely irrelevant) to 1.0 (completely relevant).
        #     This value is for informational purpose only. It may change for
        #     the same query and chunk at any time due to a model retraining or
        #     change in implementation.
        class ChunkInfo
          include ::Google::Protobuf::MessageExts
          extend ::Google::Protobuf::MessageExts::ClassMethods
        end
      end
    end
  end

  # Enumeration of the state of the step.
  module State
    # Unknown.
    STATE_UNSPECIFIED = 0

    # Step is currently in progress.
    IN_PROGRESS = 1

    # Step currently failed.
    FAILED = 2

    # Step has succeeded.
    SUCCEEDED = 3
  end
end

#description::String

Returns The description of the step.

Returns:

  • (::String)

    The description of the step.



315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
# File 'proto_docs/google/cloud/discoveryengine/v1beta/answer.rb', line 315

class Step
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Action.
  # @!attribute [rw] search_action
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::Action::SearchAction]
  #     Search action.
  # @!attribute [rw] observation
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::Action::Observation]
  #     Observation.
  class Action
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Search action.
    # @!attribute [rw] query
    #   @return [::String]
    #     The query to search.
    class SearchAction
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Observation.
    # @!attribute [rw] search_results
    #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::Action::Observation::SearchResult>]
    #     Search results observed by the search action, it can be snippets info
    #     or chunk info, depending on the citation type set by the user.
    class Observation
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods

      # @!attribute [rw] document
      #   @return [::String]
      #     Document resource name.
      # @!attribute [rw] uri
      #   @return [::String]
      #     URI for the document.
      # @!attribute [rw] title
      #   @return [::String]
      #     Title.
      # @!attribute [rw] snippet_info
      #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::Action::Observation::SearchResult::SnippetInfo>]
      #     If citation_type is DOCUMENT_LEVEL_CITATION, populate document
      #     level snippets.
      # @!attribute [rw] chunk_info
      #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::Action::Observation::SearchResult::ChunkInfo>]
      #     If citation_type is CHUNK_LEVEL_CITATION and chunk mode is on,
      #     populate chunk info.
      # @!attribute [rw] struct_data
      #   @return [::Google::Protobuf::Struct]
      #     Data representation.
      #     The structured JSON data for the document.
      #     It's populated from the struct data from the Document, or the
      #     Chunk in search result.
      class SearchResult
        include ::Google::Protobuf::MessageExts
        extend ::Google::Protobuf::MessageExts::ClassMethods

        # Snippet information.
        # @!attribute [rw] snippet
        #   @return [::String]
        #     Snippet content.
        # @!attribute [rw] snippet_status
        #   @return [::String]
        #     Status of the snippet defined by the search team.
        class SnippetInfo
          include ::Google::Protobuf::MessageExts
          extend ::Google::Protobuf::MessageExts::ClassMethods
        end

        # Chunk information.
        # @!attribute [rw] chunk
        #   @return [::String]
        #     Chunk resource name.
        # @!attribute [rw] content
        #   @return [::String]
        #     Chunk textual content.
        # @!attribute [rw] relevance_score
        #   @return [::Float]
        #     The relevance of the chunk for a given query. Values range from
        #     0.0 (completely irrelevant) to 1.0 (completely relevant).
        #     This value is for informational purpose only. It may change for
        #     the same query and chunk at any time due to a model retraining or
        #     change in implementation.
        class ChunkInfo
          include ::Google::Protobuf::MessageExts
          extend ::Google::Protobuf::MessageExts::ClassMethods
        end
      end
    end
  end

  # Enumeration of the state of the step.
  module State
    # Unknown.
    STATE_UNSPECIFIED = 0

    # Step is currently in progress.
    IN_PROGRESS = 1

    # Step currently failed.
    FAILED = 2

    # Step has succeeded.
    SUCCEEDED = 3
  end
end

#state::Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::State

Returns The state of the step.



315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
# File 'proto_docs/google/cloud/discoveryengine/v1beta/answer.rb', line 315

class Step
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Action.
  # @!attribute [rw] search_action
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::Action::SearchAction]
  #     Search action.
  # @!attribute [rw] observation
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::Action::Observation]
  #     Observation.
  class Action
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Search action.
    # @!attribute [rw] query
    #   @return [::String]
    #     The query to search.
    class SearchAction
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Observation.
    # @!attribute [rw] search_results
    #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::Action::Observation::SearchResult>]
    #     Search results observed by the search action, it can be snippets info
    #     or chunk info, depending on the citation type set by the user.
    class Observation
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods

      # @!attribute [rw] document
      #   @return [::String]
      #     Document resource name.
      # @!attribute [rw] uri
      #   @return [::String]
      #     URI for the document.
      # @!attribute [rw] title
      #   @return [::String]
      #     Title.
      # @!attribute [rw] snippet_info
      #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::Action::Observation::SearchResult::SnippetInfo>]
      #     If citation_type is DOCUMENT_LEVEL_CITATION, populate document
      #     level snippets.
      # @!attribute [rw] chunk_info
      #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::Action::Observation::SearchResult::ChunkInfo>]
      #     If citation_type is CHUNK_LEVEL_CITATION and chunk mode is on,
      #     populate chunk info.
      # @!attribute [rw] struct_data
      #   @return [::Google::Protobuf::Struct]
      #     Data representation.
      #     The structured JSON data for the document.
      #     It's populated from the struct data from the Document, or the
      #     Chunk in search result.
      class SearchResult
        include ::Google::Protobuf::MessageExts
        extend ::Google::Protobuf::MessageExts::ClassMethods

        # Snippet information.
        # @!attribute [rw] snippet
        #   @return [::String]
        #     Snippet content.
        # @!attribute [rw] snippet_status
        #   @return [::String]
        #     Status of the snippet defined by the search team.
        class SnippetInfo
          include ::Google::Protobuf::MessageExts
          extend ::Google::Protobuf::MessageExts::ClassMethods
        end

        # Chunk information.
        # @!attribute [rw] chunk
        #   @return [::String]
        #     Chunk resource name.
        # @!attribute [rw] content
        #   @return [::String]
        #     Chunk textual content.
        # @!attribute [rw] relevance_score
        #   @return [::Float]
        #     The relevance of the chunk for a given query. Values range from
        #     0.0 (completely irrelevant) to 1.0 (completely relevant).
        #     This value is for informational purpose only. It may change for
        #     the same query and chunk at any time due to a model retraining or
        #     change in implementation.
        class ChunkInfo
          include ::Google::Protobuf::MessageExts
          extend ::Google::Protobuf::MessageExts::ClassMethods
        end
      end
    end
  end

  # Enumeration of the state of the step.
  module State
    # Unknown.
    STATE_UNSPECIFIED = 0

    # Step is currently in progress.
    IN_PROGRESS = 1

    # Step currently failed.
    FAILED = 2

    # Step has succeeded.
    SUCCEEDED = 3
  end
end

#thought::String

Returns The thought of the step.

Returns:

  • (::String)

    The thought of the step.



315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
# File 'proto_docs/google/cloud/discoveryengine/v1beta/answer.rb', line 315

class Step
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Action.
  # @!attribute [rw] search_action
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::Action::SearchAction]
  #     Search action.
  # @!attribute [rw] observation
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::Action::Observation]
  #     Observation.
  class Action
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Search action.
    # @!attribute [rw] query
    #   @return [::String]
    #     The query to search.
    class SearchAction
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Observation.
    # @!attribute [rw] search_results
    #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::Action::Observation::SearchResult>]
    #     Search results observed by the search action, it can be snippets info
    #     or chunk info, depending on the citation type set by the user.
    class Observation
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods

      # @!attribute [rw] document
      #   @return [::String]
      #     Document resource name.
      # @!attribute [rw] uri
      #   @return [::String]
      #     URI for the document.
      # @!attribute [rw] title
      #   @return [::String]
      #     Title.
      # @!attribute [rw] snippet_info
      #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::Action::Observation::SearchResult::SnippetInfo>]
      #     If citation_type is DOCUMENT_LEVEL_CITATION, populate document
      #     level snippets.
      # @!attribute [rw] chunk_info
      #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::Action::Observation::SearchResult::ChunkInfo>]
      #     If citation_type is CHUNK_LEVEL_CITATION and chunk mode is on,
      #     populate chunk info.
      # @!attribute [rw] struct_data
      #   @return [::Google::Protobuf::Struct]
      #     Data representation.
      #     The structured JSON data for the document.
      #     It's populated from the struct data from the Document, or the
      #     Chunk in search result.
      class SearchResult
        include ::Google::Protobuf::MessageExts
        extend ::Google::Protobuf::MessageExts::ClassMethods

        # Snippet information.
        # @!attribute [rw] snippet
        #   @return [::String]
        #     Snippet content.
        # @!attribute [rw] snippet_status
        #   @return [::String]
        #     Status of the snippet defined by the search team.
        class SnippetInfo
          include ::Google::Protobuf::MessageExts
          extend ::Google::Protobuf::MessageExts::ClassMethods
        end

        # Chunk information.
        # @!attribute [rw] chunk
        #   @return [::String]
        #     Chunk resource name.
        # @!attribute [rw] content
        #   @return [::String]
        #     Chunk textual content.
        # @!attribute [rw] relevance_score
        #   @return [::Float]
        #     The relevance of the chunk for a given query. Values range from
        #     0.0 (completely irrelevant) to 1.0 (completely relevant).
        #     This value is for informational purpose only. It may change for
        #     the same query and chunk at any time due to a model retraining or
        #     change in implementation.
        class ChunkInfo
          include ::Google::Protobuf::MessageExts
          extend ::Google::Protobuf::MessageExts::ClassMethods
        end
      end
    end
  end

  # Enumeration of the state of the step.
  module State
    # Unknown.
    STATE_UNSPECIFIED = 0

    # Step is currently in progress.
    IN_PROGRESS = 1

    # Step currently failed.
    FAILED = 2

    # Step has succeeded.
    SUCCEEDED = 3
  end
end