Class: Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::Action::Observation::SearchResult

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/answer.rb

Defined Under Namespace

Classes: ChunkInfo, SnippetInfo

Instance Attribute Summary collapse

Instance Attribute Details

#chunk_info::Array<::Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::Action::Observation::SearchResult::ChunkInfo>

Returns If citation_type is CHUNK_LEVEL_CITATION and chunk mode is on, populate chunk info.

Returns:



371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'proto_docs/google/cloud/discoveryengine/v1beta/answer.rb', line 371

class SearchResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Snippet information.
  # @!attribute [rw] snippet
  #   @return [::String]
  #     Snippet content.
  # @!attribute [rw] snippet_status
  #   @return [::String]
  #     Status of the snippet defined by the search team.
  class SnippetInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Chunk information.
  # @!attribute [rw] chunk
  #   @return [::String]
  #     Chunk resource name.
  # @!attribute [rw] content
  #   @return [::String]
  #     Chunk textual content.
  # @!attribute [rw] relevance_score
  #   @return [::Float]
  #     The relevance of the chunk for a given query. Values range from
  #     0.0 (completely irrelevant) to 1.0 (completely relevant).
  #     This value is for informational purpose only. It may change for
  #     the same query and chunk at any time due to a model retraining or
  #     change in implementation.
  class ChunkInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#document::String

Returns Document resource name.

Returns:

  • (::String)

    Document resource name.



371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'proto_docs/google/cloud/discoveryengine/v1beta/answer.rb', line 371

class SearchResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Snippet information.
  # @!attribute [rw] snippet
  #   @return [::String]
  #     Snippet content.
  # @!attribute [rw] snippet_status
  #   @return [::String]
  #     Status of the snippet defined by the search team.
  class SnippetInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Chunk information.
  # @!attribute [rw] chunk
  #   @return [::String]
  #     Chunk resource name.
  # @!attribute [rw] content
  #   @return [::String]
  #     Chunk textual content.
  # @!attribute [rw] relevance_score
  #   @return [::Float]
  #     The relevance of the chunk for a given query. Values range from
  #     0.0 (completely irrelevant) to 1.0 (completely relevant).
  #     This value is for informational purpose only. It may change for
  #     the same query and chunk at any time due to a model retraining or
  #     change in implementation.
  class ChunkInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#snippet_info::Array<::Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::Action::Observation::SearchResult::SnippetInfo>

Returns If citation_type is DOCUMENT_LEVEL_CITATION, populate document level snippets.

Returns:



371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'proto_docs/google/cloud/discoveryengine/v1beta/answer.rb', line 371

class SearchResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Snippet information.
  # @!attribute [rw] snippet
  #   @return [::String]
  #     Snippet content.
  # @!attribute [rw] snippet_status
  #   @return [::String]
  #     Status of the snippet defined by the search team.
  class SnippetInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Chunk information.
  # @!attribute [rw] chunk
  #   @return [::String]
  #     Chunk resource name.
  # @!attribute [rw] content
  #   @return [::String]
  #     Chunk textual content.
  # @!attribute [rw] relevance_score
  #   @return [::Float]
  #     The relevance of the chunk for a given query. Values range from
  #     0.0 (completely irrelevant) to 1.0 (completely relevant).
  #     This value is for informational purpose only. It may change for
  #     the same query and chunk at any time due to a model retraining or
  #     change in implementation.
  class ChunkInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#struct_data::Google::Protobuf::Struct

Returns Data representation. The structured JSON data for the document. It's populated from the struct data from the Document, or the Chunk in search result.

Returns:

  • (::Google::Protobuf::Struct)

    Data representation. The structured JSON data for the document. It's populated from the struct data from the Document, or the Chunk in search result.



371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'proto_docs/google/cloud/discoveryengine/v1beta/answer.rb', line 371

class SearchResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Snippet information.
  # @!attribute [rw] snippet
  #   @return [::String]
  #     Snippet content.
  # @!attribute [rw] snippet_status
  #   @return [::String]
  #     Status of the snippet defined by the search team.
  class SnippetInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Chunk information.
  # @!attribute [rw] chunk
  #   @return [::String]
  #     Chunk resource name.
  # @!attribute [rw] content
  #   @return [::String]
  #     Chunk textual content.
  # @!attribute [rw] relevance_score
  #   @return [::Float]
  #     The relevance of the chunk for a given query. Values range from
  #     0.0 (completely irrelevant) to 1.0 (completely relevant).
  #     This value is for informational purpose only. It may change for
  #     the same query and chunk at any time due to a model retraining or
  #     change in implementation.
  class ChunkInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#title::String

Returns Title.

Returns:

  • (::String)

    Title.



371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'proto_docs/google/cloud/discoveryengine/v1beta/answer.rb', line 371

class SearchResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Snippet information.
  # @!attribute [rw] snippet
  #   @return [::String]
  #     Snippet content.
  # @!attribute [rw] snippet_status
  #   @return [::String]
  #     Status of the snippet defined by the search team.
  class SnippetInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Chunk information.
  # @!attribute [rw] chunk
  #   @return [::String]
  #     Chunk resource name.
  # @!attribute [rw] content
  #   @return [::String]
  #     Chunk textual content.
  # @!attribute [rw] relevance_score
  #   @return [::Float]
  #     The relevance of the chunk for a given query. Values range from
  #     0.0 (completely irrelevant) to 1.0 (completely relevant).
  #     This value is for informational purpose only. It may change for
  #     the same query and chunk at any time due to a model retraining or
  #     change in implementation.
  class ChunkInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#uri::String

Returns URI for the document.

Returns:

  • (::String)

    URI for the document.



371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'proto_docs/google/cloud/discoveryengine/v1beta/answer.rb', line 371

class SearchResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Snippet information.
  # @!attribute [rw] snippet
  #   @return [::String]
  #     Snippet content.
  # @!attribute [rw] snippet_status
  #   @return [::String]
  #     Status of the snippet defined by the search team.
  class SnippetInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Chunk information.
  # @!attribute [rw] chunk
  #   @return [::String]
  #     Chunk resource name.
  # @!attribute [rw] content
  #   @return [::String]
  #     Chunk textual content.
  # @!attribute [rw] relevance_score
  #   @return [::Float]
  #     The relevance of the chunk for a given query. Values range from
  #     0.0 (completely irrelevant) to 1.0 (completely relevant).
  #     This value is for informational purpose only. It may change for
  #     the same query and chunk at any time due to a model retraining or
  #     change in implementation.
  class ChunkInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end