Class: Google::Cloud::DiscoveryEngine::V1beta::AnswerQueryRequest::AnswerGenerationSpec::MultimodalSpec

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/conversational_search_service.rb

Overview

Multimodal specification: Will return an image from specified source. If multiple sources are specified, the pick is a quality based decision.

Defined Under Namespace

Modules: ImageSource

Instance Attribute Summary collapse

Instance Attribute Details

#image_source::Google::Cloud::DiscoveryEngine::V1beta::AnswerQueryRequest::AnswerGenerationSpec::MultimodalSpec::ImageSource

Returns Optional. Source of image returned in the answer.



507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
# File 'proto_docs/google/cloud/discoveryengine/v1beta/conversational_search_service.rb', line 507

class MultimodalSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the image source.
  module ImageSource
    # Unspecified image source (multimodal feature is disabled by default).
    IMAGE_SOURCE_UNSPECIFIED = 0

    # Behavior when service determines the pick from all available sources.
    ALL_AVAILABLE_SOURCES = 1

    # Includes image from corpus in the answer.
    CORPUS_IMAGE_ONLY = 2

    # Triggers figure generation in the answer.
    FIGURE_GENERATION_ONLY = 3
  end
end