Class: Google::Cloud::DiscoveryEngine::V1beta::AssistAnswer::CustomerPolicyEnforcementResult::BannedPhraseEnforcementResult

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb

Overview

Customer policy enforcement result for the banned phrase policy.

Instance Attribute Summary collapse

Instance Attribute Details

#banned_phrases::Array<::String>

Returns The banned phrases that were found in the query or the answer.

Returns:

  • (::Array<::String>)

    The banned phrases that were found in the query or the answer.



84
85
86
87
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb', line 84

class BannedPhraseEnforcementResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end