Class: Google::Cloud::DiscoveryEngine::V1beta::AssistAnswer::CustomerPolicyEnforcementResult::ModelArmorEnforcementResult

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb

Overview

Customer policy enforcement result for the Model Armor policy.

Instance Attribute Summary collapse

Instance Attribute Details

#error::Google::Rpc::Status

Returns The error returned by Model Armor if the policy enforcement failed for some reason.

Note: The following fields are mutually exclusive: error, model_armor_violation. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Rpc::Status)

    The error returned by Model Armor if the policy enforcement failed for some reason.

    Note: The following fields are mutually exclusive: error, model_armor_violation. If a field in that set is populated, all other fields in the set will automatically be cleared.



101
102
103
104
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb', line 101

class ModelArmorEnforcementResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#model_armor_violation::String

Returns The Model Armor violation that was found.

Note: The following fields are mutually exclusive: model_armor_violation, error. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    The Model Armor violation that was found.

    Note: The following fields are mutually exclusive: model_armor_violation, error. If a field in that set is populated, all other fields in the set will automatically be cleared.



101
102
103
104
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb', line 101

class ModelArmorEnforcementResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end