Class: Google::Cloud::DiscoveryEngine::V1beta::AssistAnswer::Reply
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::AssistAnswer::Reply
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb
Overview
One part of the multi-part response of the assist call.
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
The time when the reply was created.
-
#grounded_content ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::AssistantGroundedContent
Possibly grounded response text or media from the assistant.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp
Returns The time when the reply was created.
59 60 61 62 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb', line 59 class Reply include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#grounded_content ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::AssistantGroundedContent
Returns Possibly grounded response text or media from the assistant.
59 60 61 62 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb', line 59 class Reply include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |