Class: Google::Cloud::DiscoveryEngine::V1beta::Assistant::CustomerPolicy::ModelArmorConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/assistant.rb

Overview

Configuration for customer defined Model Armor templates to be used for sanitizing user prompts and assistant responses.

Defined Under Namespace

Modules: FailureMode

Instance Attribute Summary collapse

Instance Attribute Details

#failure_mode::Google::Cloud::DiscoveryEngine::V1beta::Assistant::CustomerPolicy::ModelArmorConfig::FailureMode

Returns Optional. Defines the failure mode for Model Armor sanitization.

Returns:



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assistant.rb', line 207

class ModelArmorConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Determines the behavior when Model Armor fails to process a request.
  module FailureMode
    # Unspecified failure mode, default behavior is `FAIL_CLOSED`.
    FAILURE_MODE_UNSPECIFIED = 0

    # In case of a Model Armor processing failure, the request is allowed
    # to proceed without any changes.
    FAIL_OPEN = 1

    # In case of a Model Armor processing failure, the request is rejected.
    FAIL_CLOSED = 2
  end
end

#response_template::String

Returns Optional. The resource name of the Model Armor template for sanitizing assistant responses. Format: projects/{project}/locations/{location}/templates/{template_id}

If not specified, no sanitization will be applied to the assistant response.

Returns:

  • (::String)

    Optional. The resource name of the Model Armor template for sanitizing assistant responses. Format: projects/{project}/locations/{location}/templates/{template_id}

    If not specified, no sanitization will be applied to the assistant response.



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assistant.rb', line 207

class ModelArmorConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Determines the behavior when Model Armor fails to process a request.
  module FailureMode
    # Unspecified failure mode, default behavior is `FAIL_CLOSED`.
    FAILURE_MODE_UNSPECIFIED = 0

    # In case of a Model Armor processing failure, the request is allowed
    # to proceed without any changes.
    FAIL_OPEN = 1

    # In case of a Model Armor processing failure, the request is rejected.
    FAIL_CLOSED = 2
  end
end

#user_prompt_template::String

Returns Optional. The resource name of the Model Armor template for sanitizing user prompts. Format: projects/{project}/locations/{location}/templates/{template_id}

If not specified, no sanitization will be applied to the user prompt.

Returns:

  • (::String)

    Optional. The resource name of the Model Armor template for sanitizing user prompts. Format: projects/{project}/locations/{location}/templates/{template_id}

    If not specified, no sanitization will be applied to the user prompt.



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assistant.rb', line 207

class ModelArmorConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Determines the behavior when Model Armor fails to process a request.
  module FailureMode
    # Unspecified failure mode, default behavior is `FAIL_CLOSED`.
    FAILURE_MODE_UNSPECIFIED = 0

    # In case of a Model Armor processing failure, the request is allowed
    # to proceed without any changes.
    FAIL_OPEN = 1

    # In case of a Model Armor processing failure, the request is rejected.
    FAIL_CLOSED = 2
  end
end