Module: Google::Cloud::DiscoveryEngine::V1beta::Assistant::CustomerPolicy::ModelArmorConfig::FailureMode

Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/assistant.rb

Overview

Determines the behavior when Model Armor fails to process a request.

Constant Summary collapse

FAILURE_MODE_UNSPECIFIED =

Unspecified failure mode, default behavior is FAIL_CLOSED.

0
FAIL_OPEN =

In case of a Model Armor processing failure, the request is allowed to proceed without any changes.

1
FAIL_CLOSED =

In case of a Model Armor processing failure, the request is rejected.

2