Class: Google::Cloud::DiscoveryEngine::V1beta::Assistant::GenerationConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/assistant.rb

Overview

Configuration for the generation of the assistant response.

Defined Under Namespace

Classes: SystemInstruction

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_model_ids::Array<::String>

Returns Optional. The list of models that are allowed to be used for assistant.

Returns:

  • (::Array<::String>)

    Optional. The list of models that are allowed to be used for assistant.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assistant.rb', line 102

class GenerationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # System instruction, also known as the prompt preamble for LLM calls.
  # @!attribute [rw] additional_system_instruction
  #   @return [::String]
  #     Optional. Additional system instruction that will be added to the
  #     default system instruction.
  class SystemInstruction
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#default_language::String

Returns The default language to use for the generation of the assistant response. Use an ISO 639-1 language code such as en. If not specified, the language will be automatically detected.

Returns:

  • (::String)

    The default language to use for the generation of the assistant response. Use an ISO 639-1 language code such as en. If not specified, the language will be automatically detected.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assistant.rb', line 102

class GenerationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # System instruction, also known as the prompt preamble for LLM calls.
  # @!attribute [rw] additional_system_instruction
  #   @return [::String]
  #     Optional. Additional system instruction that will be added to the
  #     default system instruction.
  class SystemInstruction
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#default_model_id::String

Returns Optional. The default model to use for assistant.

Returns:

  • (::String)

    Optional. The default model to use for assistant.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assistant.rb', line 102

class GenerationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # System instruction, also known as the prompt preamble for LLM calls.
  # @!attribute [rw] additional_system_instruction
  #   @return [::String]
  #     Optional. Additional system instruction that will be added to the
  #     default system instruction.
  class SystemInstruction
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#system_instruction::Google::Cloud::DiscoveryEngine::V1beta::Assistant::GenerationConfig::SystemInstruction

Returns System instruction, also known as the prompt preamble for LLM calls. See also https://cloud.google.com/vertex-ai/generative-ai/docs/learn/prompts/system-instructions.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assistant.rb', line 102

class GenerationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # System instruction, also known as the prompt preamble for LLM calls.
  # @!attribute [rw] additional_system_instruction
  #   @return [::String]
  #     Optional. Additional system instruction that will be added to the
  #     default system instruction.
  class SystemInstruction
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end