Class: Google::Cloud::DiscoveryEngine::V1beta::Assistant::GenerationConfig::SystemInstruction

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/assistant.rb

Overview

System instruction, also known as the prompt preamble for LLM calls.

Instance Attribute Summary collapse

Instance Attribute Details

#additional_system_instruction::String

Returns Optional. Additional system instruction that will be added to the default system instruction.

Returns:

  • (::String)

    Optional. Additional system instruction that will be added to the default system instruction.



111
112
113
114
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assistant.rb', line 111

class SystemInstruction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end