Class: Google::Cloud::DiscoveryEngine::V1beta::Assistant::ToolInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/assistant.rb

Overview

Information to identify a tool.

Instance Attribute Summary collapse

Instance Attribute Details

#tool_display_name::String

Returns The display name of the tool.

Returns:

  • (::String)

    The display name of the tool.



127
128
129
130
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assistant.rb', line 127

class ToolInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tool_name::String

Returns The name of the tool as defined by DataConnectorService.QueryAvailableActions. Note: it's using action in the DataConnectorService apis, but they are the same as the tool here.

Returns:

  • (::String)

    The name of the tool as defined by DataConnectorService.QueryAvailableActions. Note: it's using action in the DataConnectorService apis, but they are the same as the tool here.



127
128
129
130
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assistant.rb', line 127

class ToolInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end