Class: Google::Cloud::DiscoveryEngine::V1beta::AssistantContent

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb

Overview

Multi-modal content.

Defined Under Namespace

Classes: Blob, CodeExecutionResult, ExecutableCode, File

Instance Attribute Summary collapse

Instance Attribute Details

#code_execution_result::Google::Cloud::DiscoveryEngine::V1beta::AssistantContent::CodeExecutionResult

Returns Result of executing an ExecutableCode.

Note: The following fields are mutually exclusive: code_execution_result, text, inline_data, file, executable_code. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb', line 205

class AssistantContent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Inline blob.
  # @!attribute [rw] mime_type
  #   @return [::String]
  #     Required. The media type (MIME type) of the generated data.
  # @!attribute [rw] data
  #   @return [::String]
  #     Required. Raw bytes.
  class Blob
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A file, e.g., an audio summary.
  # @!attribute [rw] mime_type
  #   @return [::String]
  #     Required. The media type (MIME type) of the file.
  # @!attribute [rw] file_id
  #   @return [::String]
  #     Required. The file ID.
  class File
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Code generated by the model that is meant to be executed by the model.
  # @!attribute [rw] code
  #   @return [::String]
  #     Required. The code content. Currently only supports Python.
  class ExecutableCode
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Result of executing ExecutableCode.
  # @!attribute [rw] outcome
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::AssistantContent::CodeExecutionResult::Outcome]
  #     Required. Outcome of the code execution.
  # @!attribute [rw] output
  #   @return [::String]
  #     Optional. Contains stdout when code execution is successful, stderr or
  #     other description otherwise.
  class CodeExecutionResult
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Enumeration of possible outcomes of the code execution.
    module Outcome
      # Unspecified status. This value should not be used.
      OUTCOME_UNSPECIFIED = 0

      # Code execution completed successfully.
      OUTCOME_OK = 1

      # Code execution finished but with a failure. `stderr` should contain the
      # reason.
      OUTCOME_FAILED = 2

      # Code execution ran for too long, and was cancelled. There may or may
      # not be a partial output present.
      OUTCOME_DEADLINE_EXCEEDED = 3
    end
  end
end

#executable_code::Google::Cloud::DiscoveryEngine::V1beta::AssistantContent::ExecutableCode

Returns Code generated by the model that is meant to be executed.

Note: The following fields are mutually exclusive: executable_code, text, inline_data, file, code_execution_result. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb', line 205

class AssistantContent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Inline blob.
  # @!attribute [rw] mime_type
  #   @return [::String]
  #     Required. The media type (MIME type) of the generated data.
  # @!attribute [rw] data
  #   @return [::String]
  #     Required. Raw bytes.
  class Blob
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A file, e.g., an audio summary.
  # @!attribute [rw] mime_type
  #   @return [::String]
  #     Required. The media type (MIME type) of the file.
  # @!attribute [rw] file_id
  #   @return [::String]
  #     Required. The file ID.
  class File
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Code generated by the model that is meant to be executed by the model.
  # @!attribute [rw] code
  #   @return [::String]
  #     Required. The code content. Currently only supports Python.
  class ExecutableCode
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Result of executing ExecutableCode.
  # @!attribute [rw] outcome
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::AssistantContent::CodeExecutionResult::Outcome]
  #     Required. Outcome of the code execution.
  # @!attribute [rw] output
  #   @return [::String]
  #     Optional. Contains stdout when code execution is successful, stderr or
  #     other description otherwise.
  class CodeExecutionResult
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Enumeration of possible outcomes of the code execution.
    module Outcome
      # Unspecified status. This value should not be used.
      OUTCOME_UNSPECIFIED = 0

      # Code execution completed successfully.
      OUTCOME_OK = 1

      # Code execution finished but with a failure. `stderr` should contain the
      # reason.
      OUTCOME_FAILED = 2

      # Code execution ran for too long, and was cancelled. There may or may
      # not be a partial output present.
      OUTCOME_DEADLINE_EXCEEDED = 3
    end
  end
end

#file::Google::Cloud::DiscoveryEngine::V1beta::AssistantContent::File

Returns A file, e.g., an audio summary.

Note: The following fields are mutually exclusive: file, text, inline_data, executable_code, code_execution_result. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb', line 205

class AssistantContent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Inline blob.
  # @!attribute [rw] mime_type
  #   @return [::String]
  #     Required. The media type (MIME type) of the generated data.
  # @!attribute [rw] data
  #   @return [::String]
  #     Required. Raw bytes.
  class Blob
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A file, e.g., an audio summary.
  # @!attribute [rw] mime_type
  #   @return [::String]
  #     Required. The media type (MIME type) of the file.
  # @!attribute [rw] file_id
  #   @return [::String]
  #     Required. The file ID.
  class File
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Code generated by the model that is meant to be executed by the model.
  # @!attribute [rw] code
  #   @return [::String]
  #     Required. The code content. Currently only supports Python.
  class ExecutableCode
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Result of executing ExecutableCode.
  # @!attribute [rw] outcome
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::AssistantContent::CodeExecutionResult::Outcome]
  #     Required. Outcome of the code execution.
  # @!attribute [rw] output
  #   @return [::String]
  #     Optional. Contains stdout when code execution is successful, stderr or
  #     other description otherwise.
  class CodeExecutionResult
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Enumeration of possible outcomes of the code execution.
    module Outcome
      # Unspecified status. This value should not be used.
      OUTCOME_UNSPECIFIED = 0

      # Code execution completed successfully.
      OUTCOME_OK = 1

      # Code execution finished but with a failure. `stderr` should contain the
      # reason.
      OUTCOME_FAILED = 2

      # Code execution ran for too long, and was cancelled. There may or may
      # not be a partial output present.
      OUTCOME_DEADLINE_EXCEEDED = 3
    end
  end
end

#inline_data::Google::Cloud::DiscoveryEngine::V1beta::AssistantContent::Blob

Returns Inline binary data.

Note: The following fields are mutually exclusive: inline_data, text, file, executable_code, code_execution_result. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb', line 205

class AssistantContent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Inline blob.
  # @!attribute [rw] mime_type
  #   @return [::String]
  #     Required. The media type (MIME type) of the generated data.
  # @!attribute [rw] data
  #   @return [::String]
  #     Required. Raw bytes.
  class Blob
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A file, e.g., an audio summary.
  # @!attribute [rw] mime_type
  #   @return [::String]
  #     Required. The media type (MIME type) of the file.
  # @!attribute [rw] file_id
  #   @return [::String]
  #     Required. The file ID.
  class File
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Code generated by the model that is meant to be executed by the model.
  # @!attribute [rw] code
  #   @return [::String]
  #     Required. The code content. Currently only supports Python.
  class ExecutableCode
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Result of executing ExecutableCode.
  # @!attribute [rw] outcome
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::AssistantContent::CodeExecutionResult::Outcome]
  #     Required. Outcome of the code execution.
  # @!attribute [rw] output
  #   @return [::String]
  #     Optional. Contains stdout when code execution is successful, stderr or
  #     other description otherwise.
  class CodeExecutionResult
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Enumeration of possible outcomes of the code execution.
    module Outcome
      # Unspecified status. This value should not be used.
      OUTCOME_UNSPECIFIED = 0

      # Code execution completed successfully.
      OUTCOME_OK = 1

      # Code execution finished but with a failure. `stderr` should contain the
      # reason.
      OUTCOME_FAILED = 2

      # Code execution ran for too long, and was cancelled. There may or may
      # not be a partial output present.
      OUTCOME_DEADLINE_EXCEEDED = 3
    end
  end
end

#role::String

Returns The producer of the content. Can be "model" or "user".

Returns:

  • (::String)

    The producer of the content. Can be "model" or "user".



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb', line 205

class AssistantContent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Inline blob.
  # @!attribute [rw] mime_type
  #   @return [::String]
  #     Required. The media type (MIME type) of the generated data.
  # @!attribute [rw] data
  #   @return [::String]
  #     Required. Raw bytes.
  class Blob
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A file, e.g., an audio summary.
  # @!attribute [rw] mime_type
  #   @return [::String]
  #     Required. The media type (MIME type) of the file.
  # @!attribute [rw] file_id
  #   @return [::String]
  #     Required. The file ID.
  class File
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Code generated by the model that is meant to be executed by the model.
  # @!attribute [rw] code
  #   @return [::String]
  #     Required. The code content. Currently only supports Python.
  class ExecutableCode
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Result of executing ExecutableCode.
  # @!attribute [rw] outcome
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::AssistantContent::CodeExecutionResult::Outcome]
  #     Required. Outcome of the code execution.
  # @!attribute [rw] output
  #   @return [::String]
  #     Optional. Contains stdout when code execution is successful, stderr or
  #     other description otherwise.
  class CodeExecutionResult
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Enumeration of possible outcomes of the code execution.
    module Outcome
      # Unspecified status. This value should not be used.
      OUTCOME_UNSPECIFIED = 0

      # Code execution completed successfully.
      OUTCOME_OK = 1

      # Code execution finished but with a failure. `stderr` should contain the
      # reason.
      OUTCOME_FAILED = 2

      # Code execution ran for too long, and was cancelled. There may or may
      # not be a partial output present.
      OUTCOME_DEADLINE_EXCEEDED = 3
    end
  end
end

#text::String

Returns Inline text.

Note: The following fields are mutually exclusive: text, inline_data, file, executable_code, code_execution_result. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Inline text.

    Note: The following fields are mutually exclusive: text, inline_data, file, executable_code, code_execution_result. If a field in that set is populated, all other fields in the set will automatically be cleared.



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb', line 205

class AssistantContent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Inline blob.
  # @!attribute [rw] mime_type
  #   @return [::String]
  #     Required. The media type (MIME type) of the generated data.
  # @!attribute [rw] data
  #   @return [::String]
  #     Required. Raw bytes.
  class Blob
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A file, e.g., an audio summary.
  # @!attribute [rw] mime_type
  #   @return [::String]
  #     Required. The media type (MIME type) of the file.
  # @!attribute [rw] file_id
  #   @return [::String]
  #     Required. The file ID.
  class File
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Code generated by the model that is meant to be executed by the model.
  # @!attribute [rw] code
  #   @return [::String]
  #     Required. The code content. Currently only supports Python.
  class ExecutableCode
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Result of executing ExecutableCode.
  # @!attribute [rw] outcome
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::AssistantContent::CodeExecutionResult::Outcome]
  #     Required. Outcome of the code execution.
  # @!attribute [rw] output
  #   @return [::String]
  #     Optional. Contains stdout when code execution is successful, stderr or
  #     other description otherwise.
  class CodeExecutionResult
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Enumeration of possible outcomes of the code execution.
    module Outcome
      # Unspecified status. This value should not be used.
      OUTCOME_UNSPECIFIED = 0

      # Code execution completed successfully.
      OUTCOME_OK = 1

      # Code execution finished but with a failure. `stderr` should contain the
      # reason.
      OUTCOME_FAILED = 2

      # Code execution ran for too long, and was cancelled. There may or may
      # not be a partial output present.
      OUTCOME_DEADLINE_EXCEEDED = 3
    end
  end
end

#thought::Boolean

Returns Optional. Indicates if the part is thought from the model.

Returns:

  • (::Boolean)

    Optional. Indicates if the part is thought from the model.



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb', line 205

class AssistantContent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Inline blob.
  # @!attribute [rw] mime_type
  #   @return [::String]
  #     Required. The media type (MIME type) of the generated data.
  # @!attribute [rw] data
  #   @return [::String]
  #     Required. Raw bytes.
  class Blob
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # A file, e.g., an audio summary.
  # @!attribute [rw] mime_type
  #   @return [::String]
  #     Required. The media type (MIME type) of the file.
  # @!attribute [rw] file_id
  #   @return [::String]
  #     Required. The file ID.
  class File
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Code generated by the model that is meant to be executed by the model.
  # @!attribute [rw] code
  #   @return [::String]
  #     Required. The code content. Currently only supports Python.
  class ExecutableCode
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Result of executing ExecutableCode.
  # @!attribute [rw] outcome
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::AssistantContent::CodeExecutionResult::Outcome]
  #     Required. Outcome of the code execution.
  # @!attribute [rw] output
  #   @return [::String]
  #     Optional. Contains stdout when code execution is successful, stderr or
  #     other description otherwise.
  class CodeExecutionResult
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Enumeration of possible outcomes of the code execution.
    module Outcome
      # Unspecified status. This value should not be used.
      OUTCOME_UNSPECIFIED = 0

      # Code execution completed successfully.
      OUTCOME_OK = 1

      # Code execution finished but with a failure. `stderr` should contain the
      # reason.
      OUTCOME_FAILED = 2

      # Code execution ran for too long, and was cancelled. There may or may
      # not be a partial output present.
      OUTCOME_DEADLINE_EXCEEDED = 3
    end
  end
end