Class: Google::Cloud::DiscoveryEngine::V1beta::AssistantContent::CodeExecutionResult

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb

Overview

Result of executing ExecutableCode.

Defined Under Namespace

Modules: Outcome

Instance Attribute Summary collapse

Instance Attribute Details

#outcome::Google::Cloud::DiscoveryEngine::V1beta::AssistantContent::CodeExecutionResult::Outcome

Returns Required. Outcome of the code execution.



250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb', line 250

class CodeExecutionResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enumeration of possible outcomes of the code execution.
  module Outcome
    # Unspecified status. This value should not be used.
    OUTCOME_UNSPECIFIED = 0

    # Code execution completed successfully.
    OUTCOME_OK = 1

    # Code execution finished but with a failure. `stderr` should contain the
    # reason.
    OUTCOME_FAILED = 2

    # Code execution ran for too long, and was cancelled. There may or may
    # not be a partial output present.
    OUTCOME_DEADLINE_EXCEEDED = 3
  end
end

#output::String

Returns Optional. Contains stdout when code execution is successful, stderr or other description otherwise.

Returns:

  • (::String)

    Optional. Contains stdout when code execution is successful, stderr or other description otherwise.



250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb', line 250

class CodeExecutionResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enumeration of possible outcomes of the code execution.
  module Outcome
    # Unspecified status. This value should not be used.
    OUTCOME_UNSPECIFIED = 0

    # Code execution completed successfully.
    OUTCOME_OK = 1

    # Code execution finished but with a failure. `stderr` should contain the
    # reason.
    OUTCOME_FAILED = 2

    # Code execution ran for too long, and was cancelled. There may or may
    # not be a partial output present.
    OUTCOME_DEADLINE_EXCEEDED = 3
  end
end