Class: Google::Cloud::DiscoveryEngine::V1beta::AssistantGroundedContent::TextGroundingMetadata::VisualSegment

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb

Overview

Grounding information for a visual segment.

Instance Attribute Summary collapse

Instance Attribute Details

#content_id::String

Returns The content id of the visual segment. In order to display the citation of the visual element, this content_id needs to match with the grounded_content.content_metadata.content_id field.

Returns:

  • (::String)

    The content id of the visual segment. In order to display the citation of the visual element, this content_id needs to match with the grounded_content.content_metadata.content_id field.



337
338
339
340
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb', line 337

class VisualSegment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#reference_indices::Array<::Integer>

Returns References for the visual segment.

Returns:

  • (::Array<::Integer>)

    References for the visual segment.



337
338
339
340
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb', line 337

class VisualSegment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end