Class: Google::Cloud::DiscoveryEngine::V1beta::AssistantService::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/discovery_engine/v1beta/assistant_service/client.rb

Overview

Client for the AssistantService service.

Service for managing Assistant configuration and assisting users.

Defined Under Namespace

Classes: Configuration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#assistant_path, #data_store_path, #engine_path, #session_path, #template_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new AssistantService client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::DiscoveryEngine::V1beta::AssistantService::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::DiscoveryEngine::V1beta::AssistantService::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the AssistantService client.

Yield Parameters:



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/google/cloud/discovery_engine/v1beta/assistant_service/client.rb', line 141

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/cloud/discoveryengine/v1beta/assistant_service_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @assistant_service_stub = ::Gapic::ServiceStub.new(
    ::Google::Cloud::DiscoveryEngine::V1beta::AssistantService::Stub,
    credentials: credentials,
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors,
    channel_pool_config: @config.channel_pool,
    logger: @config.logger
  )

  @assistant_service_stub.stub_logger&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end

  @location_client = Google::Cloud::Location::Locations::Client.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @assistant_service_stub.endpoint
    config.universe_domain = @assistant_service_stub.universe_domain
    config.logger = @assistant_service_stub.logger if config.respond_to? :logger=
  end
end

Instance Attribute Details

#location_clientGoogle::Cloud::Location::Locations::Client (readonly)

Get the associated client for mix-in of the Locations.

Returns:

  • (Google::Cloud::Location::Locations::Client)


205
206
207
# File 'lib/google/cloud/discovery_engine/v1beta/assistant_service/client.rb', line 205

def location_client
  @location_client
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the AssistantService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all AssistantService clients
::Google::Cloud::DiscoveryEngine::V1beta::AssistantService::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/google/cloud/discovery_engine/v1beta/assistant_service/client.rb', line 63

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "DiscoveryEngine", "V1beta"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.timeout = 30.0
    default_config.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.stream_assist.timeout = 300.0
    default_config.rpcs.stream_assist.retry_policy = {
      initial_delay: 1.0, max_delay: 30.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.create_assistant.timeout = 30.0

    default_config.rpcs.delete_assistant.timeout = 30.0

    default_config.rpcs.update_assistant.timeout = 30.0

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the AssistantService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



111
112
113
114
# File 'lib/google/cloud/discovery_engine/v1beta/assistant_service/client.rb', line 111

def configure
  yield @config if block_given?
  @config
end

#create_assistant(request, options = nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Assistant #create_assistant(parent: nil, assistant: nil, assistant_id: nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Assistant

Creates an Assistant.

Examples:

Basic example

require "google/cloud/discovery_engine/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::DiscoveryEngine::V1beta::AssistantService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::DiscoveryEngine::V1beta::CreateAssistantRequest.new

# Call the create_assistant method.
result = client.create_assistant request

# The returned object is of type Google::Cloud::DiscoveryEngine::V1beta::Assistant.
p result

Overloads:

  • #create_assistant(request, options = nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Assistant

    Pass arguments to create_assistant via a request object, either of type CreateAssistantRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::DiscoveryEngine::V1beta::CreateAssistantRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #create_assistant(parent: nil, assistant: nil, assistant_id: nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Assistant

    Pass arguments to create_assistant via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent resource name. Format: projects/{project}/locations/{location}/collections/{collection}/engines/{engine}

    • assistant (::Google::Cloud::DiscoveryEngine::V1beta::Assistant, ::Hash) (defaults to: nil)

      Required. The Assistant to create.

    • assistant_id (::String) (defaults to: nil)

      Required. The ID to use for the Assistant, which will become the final component of the Assistant's resource name.

      This field must conform to RFC-1034 with a length limit of 63 characters.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'lib/google/cloud/discovery_engine/v1beta/assistant_service/client.rb', line 386

def create_assistant request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::DiscoveryEngine::V1beta::CreateAssistantRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_assistant..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::DiscoveryEngine::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.create_assistant.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_assistant.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @assistant_service_stub.call_rpc :create_assistant, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#delete_assistant(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_assistant(name: nil) ⇒ ::Google::Protobuf::Empty

Deletes an Assistant.

Examples:

Basic example

require "google/cloud/discovery_engine/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::DiscoveryEngine::V1beta::AssistantService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::DiscoveryEngine::V1beta::DeleteAssistantRequest.new

# Call the delete_assistant method.
result = client.delete_assistant request

# The returned object is of type Google::Protobuf::Empty.
p result

Overloads:

  • #delete_assistant(request, options = nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_assistant via a request object, either of type DeleteAssistantRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::DiscoveryEngine::V1beta::DeleteAssistantRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #delete_assistant(name: nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_assistant via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. Resource name of Assistant. Format: projects/{project}/locations/{location}/collections/{collection}/engines/{engine}/assistants/{assistant}

      If the caller does not have permission to delete the Assistant, regardless of whether or not it exists, a PERMISSION_DENIED error is returned.

      If the Assistant to delete does not exist, a NOT_FOUND error is returned.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
# File 'lib/google/cloud/discovery_engine/v1beta/assistant_service/client.rb', line 480

def delete_assistant request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::DiscoveryEngine::V1beta::DeleteAssistantRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_assistant..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::DiscoveryEngine::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.delete_assistant.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_assistant.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @assistant_service_stub.call_rpc :delete_assistant, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_assistant(request, options = nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Assistant #get_assistant(name: nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Assistant

Gets an Assistant.

Examples:

Basic example

require "google/cloud/discovery_engine/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::DiscoveryEngine::V1beta::AssistantService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::DiscoveryEngine::V1beta::GetAssistantRequest.new

# Call the get_assistant method.
result = client.get_assistant request

# The returned object is of type Google::Cloud::DiscoveryEngine::V1beta::Assistant.
p result

Overloads:

  • #get_assistant(request, options = nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Assistant

    Pass arguments to get_assistant via a request object, either of type GetAssistantRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::DiscoveryEngine::V1beta::GetAssistantRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_assistant(name: nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Assistant

    Pass arguments to get_assistant via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. Resource name of Assistant. Format: projects/{project}/locations/{location}/collections/{collection}/engines/{engine}/assistants/{assistant}

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
# File 'lib/google/cloud/discovery_engine/v1beta/assistant_service/client.rb', line 668

def get_assistant request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::DiscoveryEngine::V1beta::GetAssistantRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_assistant..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::DiscoveryEngine::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_assistant.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_assistant.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @assistant_service_stub.call_rpc :get_assistant, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_assistants(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::DiscoveryEngine::V1beta::Assistant> #list_assistants(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::DiscoveryEngine::V1beta::Assistant>

Lists all Assistants under an Engine.

Examples:

Basic example

require "google/cloud/discovery_engine/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::DiscoveryEngine::V1beta::AssistantService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::DiscoveryEngine::V1beta::ListAssistantsRequest.new

# Call the list_assistants method.
result = client.list_assistants request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::DiscoveryEngine::V1beta::Assistant.
  p item
end

Overloads:

  • #list_assistants(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::DiscoveryEngine::V1beta::Assistant>

    Pass arguments to list_assistants via a request object, either of type ListAssistantsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::DiscoveryEngine::V1beta::ListAssistantsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #list_assistants(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::DiscoveryEngine::V1beta::Assistant>

    Pass arguments to list_assistants via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent resource name. Format: projects/{project}/locations/{location}/collections/{collection}/engines/{engine}

    • page_size (::Integer) (defaults to: nil)

      Maximum number of Assistants to return. If unspecified, defaults to 100. The maximum allowed value is 1000; anything above that will be coerced down to 1000.

    • page_token (::String) (defaults to: nil)

      A page token ListAssistantsResponse.next_page_token, received from a previous AssistantService.ListAssistants call. Provide this to retrieve the subsequent page.

      When paginating, all other parameters provided to ListAssistants must match the call that provided the page token.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
# File 'lib/google/cloud/discovery_engine/v1beta/assistant_service/client.rb', line 775

def list_assistants request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::DiscoveryEngine::V1beta::ListAssistantsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_assistants..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::DiscoveryEngine::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_assistants.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_assistants.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @assistant_service_stub.call_rpc :list_assistants, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @assistant_service_stub, :list_assistants, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


212
213
214
# File 'lib/google/cloud/discovery_engine/v1beta/assistant_service/client.rb', line 212

def logger
  @assistant_service_stub.logger
end

#stream_assist(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::DiscoveryEngine::V1beta::StreamAssistResponse> #stream_assist(name: nil, query: nil, session: nil, user_metadata: nil, tools_spec: nil, generation_spec: nil) ⇒ ::Enumerable<::Google::Cloud::DiscoveryEngine::V1beta::StreamAssistResponse>

Assists the user with a query in a streaming fashion.

Examples:

Basic example

require "google/cloud/discovery_engine/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::DiscoveryEngine::V1beta::AssistantService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::DiscoveryEngine::V1beta::StreamAssistRequest.new

# Call the stream_assist method to start streaming.
output = client.stream_assist request

# The returned object is a streamed enumerable yielding elements of type
# ::Google::Cloud::DiscoveryEngine::V1beta::StreamAssistResponse
output.each do |current_response|
  p current_response
end

Overloads:

  • #stream_assist(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::DiscoveryEngine::V1beta::StreamAssistResponse>

    Pass arguments to stream_assist via a request object, either of type StreamAssistRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::DiscoveryEngine::V1beta::StreamAssistRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #stream_assist(name: nil, query: nil, session: nil, user_metadata: nil, tools_spec: nil, generation_spec: nil) ⇒ ::Enumerable<::Google::Cloud::DiscoveryEngine::V1beta::StreamAssistResponse>

    Pass arguments to stream_assist via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The resource name of the Assistant. Format: projects/{project}/locations/{location}/collections/{collection}/engines/{engine}/assistants/{assistant}

    • query (::Google::Cloud::DiscoveryEngine::V1beta::Query, ::Hash) (defaults to: nil)

      Optional. Current user query.

      Empty query is only supported if file_ids are provided. In this case, the answer will be generated based on those context files.

    • session (::String) (defaults to: nil)

      Optional. The session to use for the request. If specified, the assistant has access to the session history, and the query and the answer are stored there.

      If - is specified as the session ID, or it is left empty, then a new session is created with an automatically generated ID.

      Format: projects/{project}/locations/{location}/collections/{collection}/engines/{engine}/sessions/{session}

    • user_metadata (::Google::Cloud::DiscoveryEngine::V1beta::AssistUserMetadata, ::Hash) (defaults to: nil)

      Optional. Information about the user initiating the query.

    • tools_spec (::Google::Cloud::DiscoveryEngine::V1beta::StreamAssistRequest::ToolsSpec, ::Hash) (defaults to: nil)

      Optional. Specification of tools that are used to serve the request.

    • generation_spec (::Google::Cloud::DiscoveryEngine::V1beta::StreamAssistRequest::GenerationSpec, ::Hash) (defaults to: nil)

      Optional. Specification of the generation configuration for the request.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/google/cloud/discovery_engine/v1beta/assistant_service/client.rb', line 288

def stream_assist request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::DiscoveryEngine::V1beta::StreamAssistRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.stream_assist..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::DiscoveryEngine::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.stream_assist.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.stream_assist.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @assistant_service_stub.call_rpc :stream_assist, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


121
122
123
# File 'lib/google/cloud/discovery_engine/v1beta/assistant_service/client.rb', line 121

def universe_domain
  @assistant_service_stub.universe_domain
end

#update_assistant(request, options = nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Assistant #update_assistant(assistant: nil, update_mask: nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Assistant

Updates an Assistant

Examples:

Basic example

require "google/cloud/discovery_engine/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::DiscoveryEngine::V1beta::AssistantService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::DiscoveryEngine::V1beta::UpdateAssistantRequest.new

# Call the update_assistant method.
result = client.update_assistant request

# The returned object is of type Google::Cloud::DiscoveryEngine::V1beta::Assistant.
p result

Overloads:

  • #update_assistant(request, options = nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Assistant

    Pass arguments to update_assistant via a request object, either of type UpdateAssistantRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::DiscoveryEngine::V1beta::UpdateAssistantRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #update_assistant(assistant: nil, update_mask: nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Assistant

    Pass arguments to update_assistant via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • assistant (::Google::Cloud::DiscoveryEngine::V1beta::Assistant, ::Hash) (defaults to: nil)

      Required. The Assistant to update.

      The Assistant's name field is used to identify the Assistant to update. Format: projects/{project}/locations/{location}/collections/{collection}/engines/{engine}/assistants/{assistant}

      If the caller does not have permission to update the Assistant, regardless of whether or not it exists, a PERMISSION_DENIED error is returned.

      If the Assistant to update does not exist, a NOT_FOUND error is returned.

    • update_mask (::Google::Protobuf::FieldMask, ::Hash) (defaults to: nil)

      The list of fields to update.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
# File 'lib/google/cloud/discovery_engine/v1beta/assistant_service/client.rb', line 581

def update_assistant request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::DiscoveryEngine::V1beta::UpdateAssistantRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_assistant..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::DiscoveryEngine::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.assistant&.name
    header_params["assistant.name"] = request.assistant.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.update_assistant.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_assistant.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @assistant_service_stub.call_rpc :update_assistant, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end