Class: Google::Cloud::DiscoveryEngine::V1beta::AssistantService::Rest::Client
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::AssistantService::Rest::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/discovery_engine/v1beta/assistant_service/rest/client.rb
Overview
REST client for the AssistantService service.
Service for managing Assistant configuration and assisting users.
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#location_client ⇒ Google::Cloud::Location::Locations::Rest::Client
readonly
Get the associated client for mix-in of the Locations.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the AssistantService Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the AssistantService Client instance.
-
#create_assistant(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Assistant
Creates an Assistant.
-
#delete_assistant(request, options = nil) {|result, operation| ... } ⇒ ::Google::Protobuf::Empty
Deletes an Assistant.
-
#get_assistant(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Assistant
Gets an Assistant.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new AssistantService REST client object.
- #list_assistants(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::DiscoveryEngine::V1beta::Assistant>
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#stream_assist(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::DiscoveryEngine::V1beta::StreamAssistResponse>
Assists the user with a query in a streaming fashion.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_assistant(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Assistant
Updates an Assistant.
Methods included from Paths
#assistant_path, #data_store_path, #engine_path, #session_path, #template_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new AssistantService REST client object.
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/google/cloud/discovery_engine/v1beta/assistant_service/rest/client.rb', line 143 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @assistant_service_stub = ::Google::Cloud::DiscoveryEngine::V1beta::AssistantService::Rest::ServiceStub.new( endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, credentials: credentials, logger: @config.logger ) @assistant_service_stub.logger(stub: true)&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end @location_client = Google::Cloud::Location::Locations::Rest::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @assistant_service_stub.endpoint config.universe_domain = @assistant_service_stub.universe_domain config.logger = @assistant_service_stub.logger if config.respond_to? :logger= end end |
Instance Attribute Details
#location_client ⇒ Google::Cloud::Location::Locations::Rest::Client (readonly)
Get the associated client for mix-in of the Locations.
198 199 200 |
# File 'lib/google/cloud/discovery_engine/v1beta/assistant_service/rest/client.rb', line 198 def location_client @location_client end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the AssistantService Client class.
See Configuration for a description of the configuration fields.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/google/cloud/discovery_engine/v1beta/assistant_service/rest/client.rb', line 65 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "DiscoveryEngine", "V1beta"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.timeout = 30.0 default_config.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.stream_assist.timeout = 300.0 default_config.rpcs.stream_assist.retry_policy = { initial_delay: 1.0, max_delay: 30.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.create_assistant.timeout = 30.0 default_config.rpcs.delete_assistant.timeout = 30.0 default_config.rpcs.update_assistant.timeout = 30.0 default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the AssistantService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
113 114 115 116 |
# File 'lib/google/cloud/discovery_engine/v1beta/assistant_service/rest/client.rb', line 113 def configure yield @config if block_given? @config end |
#create_assistant(request, options = nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Assistant #create_assistant(parent: nil, assistant: nil, assistant_id: nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Assistant
Creates an Assistant.
373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 |
# File 'lib/google/cloud/discovery_engine/v1beta/assistant_service/rest/client.rb', line 373 def create_assistant request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::DiscoveryEngine::V1beta::CreateAssistantRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_assistant..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::DiscoveryEngine::V1beta::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.create_assistant.timeout, metadata: , retry_policy: @config.rpcs.create_assistant.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @assistant_service_stub.create_assistant request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_assistant(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_assistant(name: nil) ⇒ ::Google::Protobuf::Empty
Deletes an Assistant.
460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'lib/google/cloud/discovery_engine/v1beta/assistant_service/rest/client.rb', line 460 def delete_assistant request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::DiscoveryEngine::V1beta::DeleteAssistantRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_assistant..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::DiscoveryEngine::V1beta::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.delete_assistant.timeout, metadata: , retry_policy: @config.rpcs.delete_assistant.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @assistant_service_stub.delete_assistant request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get_assistant(request, options = nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Assistant #get_assistant(name: nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Assistant
Gets an Assistant.
634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 |
# File 'lib/google/cloud/discovery_engine/v1beta/assistant_service/rest/client.rb', line 634 def get_assistant request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::DiscoveryEngine::V1beta::GetAssistantRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_assistant..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::DiscoveryEngine::V1beta::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_assistant.timeout, metadata: , retry_policy: @config.rpcs.get_assistant.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @assistant_service_stub.get_assistant request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#list_assistants(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::DiscoveryEngine::V1beta::Assistant> #list_assistants(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::DiscoveryEngine::V1beta::Assistant>
734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 |
# File 'lib/google/cloud/discovery_engine/v1beta/assistant_service/rest/client.rb', line 734 def list_assistants request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::DiscoveryEngine::V1beta::ListAssistantsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_assistants..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::DiscoveryEngine::V1beta::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_assistants.timeout, metadata: , retry_policy: @config.rpcs.list_assistants.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @assistant_service_stub.list_assistants request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @assistant_service_stub, :list_assistants, "assistants", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
205 206 207 |
# File 'lib/google/cloud/discovery_engine/v1beta/assistant_service/rest/client.rb', line 205 def logger @assistant_service_stub.logger end |
#stream_assist(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::DiscoveryEngine::V1beta::StreamAssistResponse> #stream_assist(name: nil, query: nil, session: nil, user_metadata: nil, tools_spec: nil, generation_spec: nil) ⇒ ::Enumerable<::Google::Cloud::DiscoveryEngine::V1beta::StreamAssistResponse>
Assists the user with a query in a streaming fashion.
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/google/cloud/discovery_engine/v1beta/assistant_service/rest/client.rb', line 276 def stream_assist request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::DiscoveryEngine::V1beta::StreamAssistRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.stream_assist..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::DiscoveryEngine::V1beta::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.stream_assist.timeout, metadata: , retry_policy: @config.rpcs.stream_assist.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy ::Gapic::Rest::ServerStream.new( ::Google::Cloud::DiscoveryEngine::V1beta::StreamAssistResponse, ::Gapic::Rest::ThreadedEnumerator.new do |in_q, out_q| @assistant_service_stub.stream_assist request, do |chunk| in_q.deq out_q.enq chunk end end ) rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#universe_domain ⇒ String
The effective universe domain
123 124 125 |
# File 'lib/google/cloud/discovery_engine/v1beta/assistant_service/rest/client.rb', line 123 def universe_domain @assistant_service_stub.universe_domain end |
#update_assistant(request, options = nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Assistant #update_assistant(assistant: nil, update_mask: nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Assistant
Updates an Assistant
554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 |
# File 'lib/google/cloud/discovery_engine/v1beta/assistant_service/rest/client.rb', line 554 def update_assistant request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::DiscoveryEngine::V1beta::UpdateAssistantRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_assistant..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::DiscoveryEngine::V1beta::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.update_assistant.timeout, metadata: , retry_policy: @config.rpcs.update_assistant.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @assistant_service_stub.update_assistant request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |