Class: Google::Cloud::DiscoveryEngine::V1beta::BatchUpdateUserLicensesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/user_license_service.rb

Overview

Request message for UserLicenseService.BatchUpdateUserLicenses method.

Defined Under Namespace

Classes: InlineSource

Instance Attribute Summary collapse

Instance Attribute Details

#delete_unassigned_user_licenses::Boolean

Returns Optional. If true, if user licenses removed associated license config, the user license will be deleted. By default which is false, the user license will be updated to unassigned state.

Returns:

  • (::Boolean)

    Optional. If true, if user licenses removed associated license config, the user license will be deleted. By default which is false, the user license will be updated to unassigned state.



144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'proto_docs/google/cloud/discoveryengine/v1beta/user_license_service.rb', line 144

class BatchUpdateUserLicensesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The inline source for the input config for BatchUpdateUserLicenses
  # method.
  # @!attribute [rw] user_licenses
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::UserLicense>]
  #     Required. A list of user licenses to update. Each user license
  #     must have a valid
  #     {::Google::Cloud::DiscoveryEngine::V1beta::UserLicense#user_principal UserLicense.user_principal}.
  # @!attribute [rw] update_mask
  #   @return [::Google::Protobuf::FieldMask]
  #     Optional. The list of fields to update.
  class InlineSource
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#inline_source::Google::Cloud::DiscoveryEngine::V1beta::BatchUpdateUserLicensesRequest::InlineSource

Returns The inline source for the input content for document embeddings.

Returns:



144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'proto_docs/google/cloud/discoveryengine/v1beta/user_license_service.rb', line 144

class BatchUpdateUserLicensesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The inline source for the input config for BatchUpdateUserLicenses
  # method.
  # @!attribute [rw] user_licenses
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::UserLicense>]
  #     Required. A list of user licenses to update. Each user license
  #     must have a valid
  #     {::Google::Cloud::DiscoveryEngine::V1beta::UserLicense#user_principal UserLicense.user_principal}.
  # @!attribute [rw] update_mask
  #   @return [::Google::Protobuf::FieldMask]
  #     Optional. The list of fields to update.
  class InlineSource
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#parent::String

Returns Required. The parent UserStore resource name, format: projects/{project}/locations/{location}/userStores/{user_store_id}.

Returns:

  • (::String)

    Required. The parent UserStore resource name, format: projects/{project}/locations/{location}/userStores/{user_store_id}.



144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'proto_docs/google/cloud/discoveryengine/v1beta/user_license_service.rb', line 144

class BatchUpdateUserLicensesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The inline source for the input config for BatchUpdateUserLicenses
  # method.
  # @!attribute [rw] user_licenses
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::UserLicense>]
  #     Required. A list of user licenses to update. Each user license
  #     must have a valid
  #     {::Google::Cloud::DiscoveryEngine::V1beta::UserLicense#user_principal UserLicense.user_principal}.
  # @!attribute [rw] update_mask
  #   @return [::Google::Protobuf::FieldMask]
  #     Optional. The list of fields to update.
  class InlineSource
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end