Class: Google::Cloud::DiscoveryEngine::V1beta::Chunk::AnnotationMetadata
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::Chunk::AnnotationMetadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/chunk.rb
Overview
The annotation metadata includes structured content in the current chunk.
Instance Attribute Summary collapse
-
#image_id ⇒ ::String
readonly
Output only.
-
#structured_content ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Chunk::StructuredContent
readonly
Output only.
Instance Attribute Details
#image_id ⇒ ::String (readonly)
Returns Output only. Image id is provided if the structured content is based on an image.
155 156 157 158 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/chunk.rb', line 155 class AnnotationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#structured_content ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Chunk::StructuredContent (readonly)
Returns Output only. The structured content information.
155 156 157 158 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/chunk.rb', line 155 class AnnotationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |