Class: Google::Cloud::DiscoveryEngine::V1beta::Citation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb

Overview

Source attributions for content.

Defined Under Namespace

Modules: PhishBlockThreshold

Instance Attribute Summary collapse

Instance Attribute Details

#end_index::Integer (readonly)

Returns Output only. End index into the content.

Returns:

  • (::Integer)

    Output only. End index into the content.



693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 693

class Citation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # These are available confidence level user can set to block malicious urls
  # with chosen confidence and above. For understanding different confidence of
  # webrisk, please refer to
  # https://cloud.google.com/web-risk/docs/reference/rpc/google.cloud.webrisk.v1eap1#confidencelevel
  module PhishBlockThreshold
    # Defaults to unspecified.
    PHISH_BLOCK_THRESHOLD_UNSPECIFIED = 0

    # Blocks Low and above confidence URL that is risky.
    BLOCK_LOW_AND_ABOVE = 30

    # Blocks Medium and above confidence URL that is risky.
    BLOCK_MEDIUM_AND_ABOVE = 40

    # Blocks High and above confidence URL that is risky.
    BLOCK_HIGH_AND_ABOVE = 50

    # Blocks Higher and above confidence URL that is risky.
    BLOCK_HIGHER_AND_ABOVE = 55

    # Blocks Very high and above confidence URL that is risky.
    BLOCK_VERY_HIGH_AND_ABOVE = 60

    # Blocks Extremely high confidence URL that is risky.
    BLOCK_ONLY_EXTREMELY_HIGH = 100
  end
end

#license::String (readonly)

Returns Output only. License of the attribution.

Returns:

  • (::String)

    Output only. License of the attribution.



693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 693

class Citation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # These are available confidence level user can set to block malicious urls
  # with chosen confidence and above. For understanding different confidence of
  # webrisk, please refer to
  # https://cloud.google.com/web-risk/docs/reference/rpc/google.cloud.webrisk.v1eap1#confidencelevel
  module PhishBlockThreshold
    # Defaults to unspecified.
    PHISH_BLOCK_THRESHOLD_UNSPECIFIED = 0

    # Blocks Low and above confidence URL that is risky.
    BLOCK_LOW_AND_ABOVE = 30

    # Blocks Medium and above confidence URL that is risky.
    BLOCK_MEDIUM_AND_ABOVE = 40

    # Blocks High and above confidence URL that is risky.
    BLOCK_HIGH_AND_ABOVE = 50

    # Blocks Higher and above confidence URL that is risky.
    BLOCK_HIGHER_AND_ABOVE = 55

    # Blocks Very high and above confidence URL that is risky.
    BLOCK_VERY_HIGH_AND_ABOVE = 60

    # Blocks Extremely high confidence URL that is risky.
    BLOCK_ONLY_EXTREMELY_HIGH = 100
  end
end

#publication_date::Google::Type::Date (readonly)

Returns Output only. Publication date of the attribution.

Returns:



693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 693

class Citation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # These are available confidence level user can set to block malicious urls
  # with chosen confidence and above. For understanding different confidence of
  # webrisk, please refer to
  # https://cloud.google.com/web-risk/docs/reference/rpc/google.cloud.webrisk.v1eap1#confidencelevel
  module PhishBlockThreshold
    # Defaults to unspecified.
    PHISH_BLOCK_THRESHOLD_UNSPECIFIED = 0

    # Blocks Low and above confidence URL that is risky.
    BLOCK_LOW_AND_ABOVE = 30

    # Blocks Medium and above confidence URL that is risky.
    BLOCK_MEDIUM_AND_ABOVE = 40

    # Blocks High and above confidence URL that is risky.
    BLOCK_HIGH_AND_ABOVE = 50

    # Blocks Higher and above confidence URL that is risky.
    BLOCK_HIGHER_AND_ABOVE = 55

    # Blocks Very high and above confidence URL that is risky.
    BLOCK_VERY_HIGH_AND_ABOVE = 60

    # Blocks Extremely high confidence URL that is risky.
    BLOCK_ONLY_EXTREMELY_HIGH = 100
  end
end

#start_index::Integer (readonly)

Returns Output only. Start index into the content.

Returns:

  • (::Integer)

    Output only. Start index into the content.



693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 693

class Citation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # These are available confidence level user can set to block malicious urls
  # with chosen confidence and above. For understanding different confidence of
  # webrisk, please refer to
  # https://cloud.google.com/web-risk/docs/reference/rpc/google.cloud.webrisk.v1eap1#confidencelevel
  module PhishBlockThreshold
    # Defaults to unspecified.
    PHISH_BLOCK_THRESHOLD_UNSPECIFIED = 0

    # Blocks Low and above confidence URL that is risky.
    BLOCK_LOW_AND_ABOVE = 30

    # Blocks Medium and above confidence URL that is risky.
    BLOCK_MEDIUM_AND_ABOVE = 40

    # Blocks High and above confidence URL that is risky.
    BLOCK_HIGH_AND_ABOVE = 50

    # Blocks Higher and above confidence URL that is risky.
    BLOCK_HIGHER_AND_ABOVE = 55

    # Blocks Very high and above confidence URL that is risky.
    BLOCK_VERY_HIGH_AND_ABOVE = 60

    # Blocks Extremely high confidence URL that is risky.
    BLOCK_ONLY_EXTREMELY_HIGH = 100
  end
end

#title::String (readonly)

Returns Output only. Title of the attribution.

Returns:

  • (::String)

    Output only. Title of the attribution.



693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 693

class Citation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # These are available confidence level user can set to block malicious urls
  # with chosen confidence and above. For understanding different confidence of
  # webrisk, please refer to
  # https://cloud.google.com/web-risk/docs/reference/rpc/google.cloud.webrisk.v1eap1#confidencelevel
  module PhishBlockThreshold
    # Defaults to unspecified.
    PHISH_BLOCK_THRESHOLD_UNSPECIFIED = 0

    # Blocks Low and above confidence URL that is risky.
    BLOCK_LOW_AND_ABOVE = 30

    # Blocks Medium and above confidence URL that is risky.
    BLOCK_MEDIUM_AND_ABOVE = 40

    # Blocks High and above confidence URL that is risky.
    BLOCK_HIGH_AND_ABOVE = 50

    # Blocks Higher and above confidence URL that is risky.
    BLOCK_HIGHER_AND_ABOVE = 55

    # Blocks Very high and above confidence URL that is risky.
    BLOCK_VERY_HIGH_AND_ABOVE = 60

    # Blocks Extremely high confidence URL that is risky.
    BLOCK_ONLY_EXTREMELY_HIGH = 100
  end
end

#uri::String (readonly)

Returns Output only. Url reference of the attribution.

Returns:

  • (::String)

    Output only. Url reference of the attribution.



693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 693

class Citation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # These are available confidence level user can set to block malicious urls
  # with chosen confidence and above. For understanding different confidence of
  # webrisk, please refer to
  # https://cloud.google.com/web-risk/docs/reference/rpc/google.cloud.webrisk.v1eap1#confidencelevel
  module PhishBlockThreshold
    # Defaults to unspecified.
    PHISH_BLOCK_THRESHOLD_UNSPECIFIED = 0

    # Blocks Low and above confidence URL that is risky.
    BLOCK_LOW_AND_ABOVE = 30

    # Blocks Medium and above confidence URL that is risky.
    BLOCK_MEDIUM_AND_ABOVE = 40

    # Blocks High and above confidence URL that is risky.
    BLOCK_HIGH_AND_ABOVE = 50

    # Blocks Higher and above confidence URL that is risky.
    BLOCK_HIGHER_AND_ABOVE = 55

    # Blocks Very high and above confidence URL that is risky.
    BLOCK_VERY_HIGH_AND_ABOVE = 60

    # Blocks Extremely high confidence URL that is risky.
    BLOCK_ONLY_EXTREMELY_HIGH = 100
  end
end