Class: Google::Cloud::DiscoveryEngine::V1beta::CreateAssistantRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/assistant_service.rb

Overview

Request for the AssistantService.CreateAssistant method.

Instance Attribute Summary collapse

Instance Attribute Details

#assistant::Google::Cloud::DiscoveryEngine::V1beta::Assistant

Returns Required. The Assistant to create.

Returns:



252
253
254
255
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assistant_service.rb', line 252

class CreateAssistantRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#assistant_id::String

Returns Required. The ID to use for the Assistant, which will become the final component of the Assistant's resource name.

This field must conform to RFC-1034 with a length limit of 63 characters.

Returns:

  • (::String)

    Required. The ID to use for the Assistant, which will become the final component of the Assistant's resource name.

    This field must conform to RFC-1034 with a length limit of 63 characters.



252
253
254
255
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assistant_service.rb', line 252

class CreateAssistantRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent resource name. Format: projects/{project}/locations/{location}/collections/{collection}/engines/{engine}.

Returns:

  • (::String)

    Required. The parent resource name. Format: projects/{project}/locations/{location}/collections/{collection}/engines/{engine}



252
253
254
255
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assistant_service.rb', line 252

class CreateAssistantRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end