Class: Google::Cloud::DiscoveryEngine::V1beta::CreateLicenseConfigRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/license_config_service.rb

Overview

Request message for LicenseConfigService.CreateLicenseConfig method.

Instance Attribute Summary collapse

Instance Attribute Details

#license_config::Google::Cloud::DiscoveryEngine::V1beta::LicenseConfig

Returns Required. The LicenseConfig to create.



44
45
46
47
# File 'proto_docs/google/cloud/discoveryengine/v1beta/license_config_service.rb', line 44

class CreateLicenseConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#license_config_id::String

Returns Optional. The ID to use for the LicenseConfig, which will become the final component of the LicenseConfig's resource name. We are using the tier (product edition) name as the license config id such as search or search_and_assistant.

Returns:

  • (::String)

    Optional. The ID to use for the LicenseConfig, which will become the final component of the LicenseConfig's resource name. We are using the tier (product edition) name as the license config id such as search or search_and_assistant.



44
45
46
47
# File 'proto_docs/google/cloud/discoveryengine/v1beta/license_config_service.rb', line 44

class CreateLicenseConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent resource name, such as projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. The parent resource name, such as projects/{project}/locations/{location}.



44
45
46
47
# File 'proto_docs/google/cloud/discoveryengine/v1beta/license_config_service.rb', line 44

class CreateLicenseConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end