Class: Google::Cloud::DiscoveryEngine::V1beta::CreateServingConfigRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/serving_config_service.rb

Overview

Request for CreateServingConfig method.

Instance Attribute Summary collapse

Instance Attribute Details

#parent::String

Returns Required. Full resource name of parent. Format: projects/{project}/locations/{location}/collections/{collection}/engines/{engine}.

Returns:

  • (::String)

    Required. Full resource name of parent. Format: projects/{project}/locations/{location}/collections/{collection}/engines/{engine}



39
40
41
42
# File 'proto_docs/google/cloud/discoveryengine/v1beta/serving_config_service.rb', line 39

class CreateServingConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#serving_config::Google::Cloud::DiscoveryEngine::V1beta::ServingConfig

Returns Required. The ServingConfig to create.

Returns:



39
40
41
42
# File 'proto_docs/google/cloud/discoveryengine/v1beta/serving_config_service.rb', line 39

class CreateServingConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#serving_config_id::String

Returns Required. The ID to use for the ServingConfig, which will become the final component of the ServingConfig's resource name.

This value should be 4-63 characters, and valid characters are /[a-zA-Z0-9][a-zA-Z0-9_-]+/.

Returns:

  • (::String)

    Required. The ID to use for the ServingConfig, which will become the final component of the ServingConfig's resource name.

    This value should be 4-63 characters, and valid characters are /[a-zA-Z0-9][a-zA-Z0-9_-]+/.



39
40
41
42
# File 'proto_docs/google/cloud/discoveryengine/v1beta/serving_config_service.rb', line 39

class CreateServingConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end