Class: Google::Cloud::DiscoveryEngine::V1beta::CreateSessionRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/conversational_search_service.rb

Overview

Request for CreateSession method.

Instance Attribute Summary collapse

Instance Attribute Details

#parent::String

Returns Required. Full resource name of parent data store. Format: projects/{project}/locations/{location}/collections/{collection}/dataStores/{data_store_id}.

Returns:

  • (::String)

    Required. Full resource name of parent data store. Format: projects/{project}/locations/{location}/collections/{collection}/dataStores/{data_store_id}



917
918
919
920
# File 'proto_docs/google/cloud/discoveryengine/v1beta/conversational_search_service.rb', line 917

class CreateSessionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#session::Google::Cloud::DiscoveryEngine::V1beta::Session

Returns Required. The session to create.

Returns:



917
918
919
920
# File 'proto_docs/google/cloud/discoveryengine/v1beta/conversational_search_service.rb', line 917

class CreateSessionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#session_id::String

Returns Optional. The ID to use for the session, which will become the final component of the session's resource name.

This value should be 1-63 characters, and valid characters are /[a-z0-9][a-z0-9-]{0,61}[a-z0-9]/. If not specified, a unique ID will be generated.

Returns:

  • (::String)

    Optional. The ID to use for the session, which will become the final component of the session's resource name.

    This value should be 1-63 characters, and valid characters are /[a-z0-9][a-z0-9-]{0,61}[a-z0-9]/. If not specified, a unique ID will be generated.



917
918
919
920
# File 'proto_docs/google/cloud/discoveryengine/v1beta/conversational_search_service.rb', line 917

class CreateSessionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end