Class: Google::Cloud::DiscoveryEngine::V1beta::DataStore::FederatedSearchConfig::AlloyDbConfig::AlloyDbConnectionConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/data_store.rb

Overview

Configuration for connecting to AlloyDB.

Defined Under Namespace

Modules: AuthMode

Instance Attribute Summary collapse

Instance Attribute Details

#auth_mode::Google::Cloud::DiscoveryEngine::V1beta::DataStore::FederatedSearchConfig::AlloyDbConfig::AlloyDbConnectionConfig::AuthMode

Returns Optional. Auth mode.



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'proto_docs/google/cloud/discoveryengine/v1beta/data_store.rb', line 266

class AlloyDbConnectionConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Auth mode.
  module AuthMode
    AUTH_MODE_UNSPECIFIED = 0

    # Uses P4SA when VAIS talks to AlloyDB.
    AUTH_MODE_SERVICE_ACCOUNT = 1

    # Uses EUC when VAIS talks to AlloyDB.
    AUTH_MODE_END_USER_ACCOUNT = 2
  end
end

#database::String

Returns Required. The AlloyDB database to connect to.

Returns:

  • (::String)

    Required. The AlloyDB database to connect to.



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'proto_docs/google/cloud/discoveryengine/v1beta/data_store.rb', line 266

class AlloyDbConnectionConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Auth mode.
  module AuthMode
    AUTH_MODE_UNSPECIFIED = 0

    # Uses P4SA when VAIS talks to AlloyDB.
    AUTH_MODE_SERVICE_ACCOUNT = 1

    # Uses EUC when VAIS talks to AlloyDB.
    AUTH_MODE_END_USER_ACCOUNT = 2
  end
end

#enable_psvs::Boolean

Returns Optional. If true, enable PSVS for AlloyDB.

Returns:

  • (::Boolean)

    Optional. If true, enable PSVS for AlloyDB.



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'proto_docs/google/cloud/discoveryengine/v1beta/data_store.rb', line 266

class AlloyDbConnectionConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Auth mode.
  module AuthMode
    AUTH_MODE_UNSPECIFIED = 0

    # Uses P4SA when VAIS talks to AlloyDB.
    AUTH_MODE_SERVICE_ACCOUNT = 1

    # Uses EUC when VAIS talks to AlloyDB.
    AUTH_MODE_END_USER_ACCOUNT = 2
  end
end

#instance::String

Returns Required. The AlloyDB instance to connect to.

Returns:

  • (::String)

    Required. The AlloyDB instance to connect to.



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'proto_docs/google/cloud/discoveryengine/v1beta/data_store.rb', line 266

class AlloyDbConnectionConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Auth mode.
  module AuthMode
    AUTH_MODE_UNSPECIFIED = 0

    # Uses P4SA when VAIS talks to AlloyDB.
    AUTH_MODE_SERVICE_ACCOUNT = 1

    # Uses EUC when VAIS talks to AlloyDB.
    AUTH_MODE_END_USER_ACCOUNT = 2
  end
end

#password::String

Returns Required. Database password.

If auth_mode = END_USER_ACCOUNT, it can be unset. In that case, the password will be inferred on the AlloyDB side, based on the authenticated user.

Returns:

  • (::String)

    Required. Database password.

    If auth_mode = END_USER_ACCOUNT, it can be unset. In that case, the password will be inferred on the AlloyDB side, based on the authenticated user.



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'proto_docs/google/cloud/discoveryengine/v1beta/data_store.rb', line 266

class AlloyDbConnectionConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Auth mode.
  module AuthMode
    AUTH_MODE_UNSPECIFIED = 0

    # Uses P4SA when VAIS talks to AlloyDB.
    AUTH_MODE_SERVICE_ACCOUNT = 1

    # Uses EUC when VAIS talks to AlloyDB.
    AUTH_MODE_END_USER_ACCOUNT = 2
  end
end

#user::String

Returns Required. Database user.

If auth_mode = END_USER_ACCOUNT, it can be unset. In that case, the user will be inferred on the AlloyDB side, based on the authenticated user.

Returns:

  • (::String)

    Required. Database user.

    If auth_mode = END_USER_ACCOUNT, it can be unset. In that case, the user will be inferred on the AlloyDB side, based on the authenticated user.



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'proto_docs/google/cloud/discoveryengine/v1beta/data_store.rb', line 266

class AlloyDbConnectionConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Auth mode.
  module AuthMode
    AUTH_MODE_UNSPECIFIED = 0

    # Uses P4SA when VAIS talks to AlloyDB.
    AUTH_MODE_SERVICE_ACCOUNT = 1

    # Uses EUC when VAIS talks to AlloyDB.
    AUTH_MODE_END_USER_ACCOUNT = 2
  end
end