Class: Google::Cloud::DiscoveryEngine::V1beta::DistributeLicenseConfigRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/license_config_service.rb

Overview

Request message for LicenseConfigService.DistributeLicenseConfig method.

Instance Attribute Summary collapse

Instance Attribute Details

#billing_account_license_config::String

Returns Required. Full resource name of [BillingAccountLicenseConfig][].

Format: billingAccounts/{billing_account}/billingAccountLicenseConfigs/{billing_account_license_config_id}.

Returns:

  • (::String)

    Required. Full resource name of [BillingAccountLicenseConfig][].

    Format: billingAccounts/{billing_account}/billingAccountLicenseConfigs/{billing_account_license_config_id}.



166
167
168
169
# File 'proto_docs/google/cloud/discoveryengine/v1beta/license_config_service.rb', line 166

class DistributeLicenseConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#license_config_id::String

Returns Optional. Distribute seats to this license config instead of creating a new one. If not specified, a new license config will be created from the billing account license config.

Returns:

  • (::String)

    Optional. Distribute seats to this license config instead of creating a new one. If not specified, a new license config will be created from the billing account license config.



166
167
168
169
# File 'proto_docs/google/cloud/discoveryengine/v1beta/license_config_service.rb', line 166

class DistributeLicenseConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#license_count::Integer

Returns Required. The number of licenses to distribute.

Returns:

  • (::Integer)

    Required. The number of licenses to distribute.



166
167
168
169
# File 'proto_docs/google/cloud/discoveryengine/v1beta/license_config_service.rb', line 166

class DistributeLicenseConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#location::String

Returns Required. The target GCP project region to distribute the license config to.

Returns:

  • (::String)

    Required. The target GCP project region to distribute the license config to.



166
167
168
169
# File 'proto_docs/google/cloud/discoveryengine/v1beta/license_config_service.rb', line 166

class DistributeLicenseConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project_number::Integer

Returns Required. The target GCP project number to distribute the license config to.

Returns:

  • (::Integer)

    Required. The target GCP project number to distribute the license config to.



166
167
168
169
# File 'proto_docs/google/cloud/discoveryengine/v1beta/license_config_service.rb', line 166

class DistributeLicenseConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end