Class: Google::Cloud::DiscoveryEngine::V1beta::Document::IndexStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/document.rb

Overview

Index status of the document.

Instance Attribute Summary collapse

Instance Attribute Details

#error_samples::Array<::Google::Rpc::Status>

Returns A sample of errors encountered while indexing the document. If this field is populated, the document is not indexed due to errors.

Returns:

  • (::Array<::Google::Rpc::Status>)

    A sample of errors encountered while indexing the document. If this field is populated, the document is not indexed due to errors.



242
243
244
245
# File 'proto_docs/google/cloud/discoveryengine/v1beta/document.rb', line 242

class IndexStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#index_time::Google::Protobuf::Timestamp

Returns The time when the document was indexed. If this field is populated, it means the document has been indexed. While documents typically become searchable within seconds of indexing, it can sometimes take up to a few hours.

Returns:

  • (::Google::Protobuf::Timestamp)

    The time when the document was indexed. If this field is populated, it means the document has been indexed. While documents typically become searchable within seconds of indexing, it can sometimes take up to a few hours.



242
243
244
245
# File 'proto_docs/google/cloud/discoveryengine/v1beta/document.rb', line 242

class IndexStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#pending_message::String

Returns Immutable. The message indicates the document index is in progress. If this field is populated, the document index is pending.

Returns:

  • (::String)

    Immutable. The message indicates the document index is in progress. If this field is populated, the document index is pending.



242
243
244
245
# File 'proto_docs/google/cloud/discoveryengine/v1beta/document.rb', line 242

class IndexStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end