Class: Google::Cloud::DiscoveryEngine::V1beta::DocumentProcessingConfig::ParsingConfig::LayoutParsingConfig
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::DocumentProcessingConfig::ParsingConfig::LayoutParsingConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/document_processing_config.rb
Overview
The layout parsing configurations for documents.
Instance Attribute Summary collapse
-
#enable_get_processed_document ⇒ ::Boolean
Optional.
-
#enable_image_annotation ⇒ ::Boolean
Optional.
-
#enable_llm_layout_parsing ⇒ ::Boolean
Optional.
-
#enable_table_annotation ⇒ ::Boolean
Optional.
-
#exclude_html_classes ⇒ ::Array<::String>
Optional.
-
#exclude_html_elements ⇒ ::Array<::String>
Optional.
-
#exclude_html_ids ⇒ ::Array<::String>
Optional.
-
#structured_content_types ⇒ ::Array<::String>
Optional.
Instance Attribute Details
#enable_get_processed_document ⇒ ::Boolean
Returns Optional. If true, the processed document will be made available for the GetProcessedDocument API.
165 166 167 168 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/document_processing_config.rb', line 165 class LayoutParsingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#enable_image_annotation ⇒ ::Boolean
Returns Optional. If true, the LLM based annotation is added to the image during parsing.
165 166 167 168 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/document_processing_config.rb', line 165 class LayoutParsingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#enable_llm_layout_parsing ⇒ ::Boolean
Returns Optional. If true, the pdf layout will be refined using an LLM.
165 166 167 168 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/document_processing_config.rb', line 165 class LayoutParsingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#enable_table_annotation ⇒ ::Boolean
Returns Optional. If true, the LLM based annotation is added to the table during parsing.
165 166 167 168 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/document_processing_config.rb', line 165 class LayoutParsingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#exclude_html_classes ⇒ ::Array<::String>
Returns Optional. List of HTML classes to exclude from the parsed content.
165 166 167 168 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/document_processing_config.rb', line 165 class LayoutParsingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#exclude_html_elements ⇒ ::Array<::String>
Returns Optional. List of HTML elements to exclude from the parsed content.
165 166 167 168 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/document_processing_config.rb', line 165 class LayoutParsingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#exclude_html_ids ⇒ ::Array<::String>
Returns Optional. List of HTML ids to exclude from the parsed content.
165 166 167 168 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/document_processing_config.rb', line 165 class LayoutParsingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#structured_content_types ⇒ ::Array<::String>
Returns Optional. Contains the required structure types to extract from the document. Supported values:
shareholder-structure.
165 166 167 168 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/document_processing_config.rb', line 165 class LayoutParsingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |