Class: Google::Cloud::DiscoveryEngine::V1beta::Engine::ChatEngineConfig
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::Engine::ChatEngineConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/engine.rb
Overview
Configurations for a Chat Engine.
Defined Under Namespace
Classes: AgentCreationConfig
Instance Attribute Summary collapse
-
#agent_creation_config ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Engine::ChatEngineConfig::AgentCreationConfig
The configurationt generate the Dialogflow agent that is associated to this Engine.
-
#allow_cross_region ⇒ ::Boolean
Optional.
-
#dialogflow_agent_to_link ⇒ ::String
The resource name of an exist Dialogflow agent to link to this Chat Engine.
Instance Attribute Details
#agent_creation_config ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Engine::ChatEngineConfig::AgentCreationConfig
Returns The configurationt generate the Dialogflow agent that is associated to this Engine.
Note that these configurations are one-time consumed by and passed to Dialogflow service. It means they cannot be retrieved using EngineService.GetEngine or EngineService.ListEngines API after engine creation.
395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/engine.rb', line 395 class ChatEngineConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configurations for generating a Dialogflow agent. # # Note that these configurations are one-time consumed by # and passed to Dialogflow service. It means they cannot be retrieved using # {::Google::Cloud::DiscoveryEngine::V1beta::EngineService::Client#get_engine EngineService.GetEngine} # or # {::Google::Cloud::DiscoveryEngine::V1beta::EngineService::Client#list_engines EngineService.ListEngines} # API after engine creation. # @!attribute [rw] business # @return [::String] # Name of the company, organization or other entity that the agent # represents. Used for knowledge connector LLM prompt and for knowledge # search. # @!attribute [rw] default_language_code # @return [::String] # Required. The default language of the agent as a language tag. # See [Language # Support](https://cloud.google.com/dialogflow/docs/reference/language) # for a list of the currently supported language codes. # @!attribute [rw] time_zone # @return [::String] # Required. The time zone of the agent from the [time zone # database](https://www.iana.org/time-zones), e.g., America/New_York, # Europe/Paris. # @!attribute [rw] location # @return [::String] # Agent location for Agent creation, supported values: global/us/eu. # If not provided, us Engine will create Agent using us-central-1 by # default; eu Engine will create Agent using eu-west-1 by default. class AgentCreationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#allow_cross_region ⇒ ::Boolean
Returns Optional. If the flag set to true, we allow the agent and engine are in different locations, otherwise the agent and engine are required to be in the same location. The flag is set to false by default.
Note that the allow_cross_region are one-time consumed by and
passed to
EngineService.CreateEngine.
It means they cannot be retrieved using
EngineService.GetEngine
or
EngineService.ListEngines
API after engine creation.
395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/engine.rb', line 395 class ChatEngineConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configurations for generating a Dialogflow agent. # # Note that these configurations are one-time consumed by # and passed to Dialogflow service. It means they cannot be retrieved using # {::Google::Cloud::DiscoveryEngine::V1beta::EngineService::Client#get_engine EngineService.GetEngine} # or # {::Google::Cloud::DiscoveryEngine::V1beta::EngineService::Client#list_engines EngineService.ListEngines} # API after engine creation. # @!attribute [rw] business # @return [::String] # Name of the company, organization or other entity that the agent # represents. Used for knowledge connector LLM prompt and for knowledge # search. # @!attribute [rw] default_language_code # @return [::String] # Required. The default language of the agent as a language tag. # See [Language # Support](https://cloud.google.com/dialogflow/docs/reference/language) # for a list of the currently supported language codes. # @!attribute [rw] time_zone # @return [::String] # Required. The time zone of the agent from the [time zone # database](https://www.iana.org/time-zones), e.g., America/New_York, # Europe/Paris. # @!attribute [rw] location # @return [::String] # Agent location for Agent creation, supported values: global/us/eu. # If not provided, us Engine will create Agent using us-central-1 by # default; eu Engine will create Agent using eu-west-1 by default. class AgentCreationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#dialogflow_agent_to_link ⇒ ::String
Returns The resource name of an exist Dialogflow agent to link to this Chat
Engine. Customers can either provide agent_creation_config to create
agent or provide an agent name that links the agent with the Chat engine.
Format: projects/<Project ID>/locations/<Location ID>/agents/<Agent
ID>.
Note that the dialogflow_agent_to_link are one-time consumed by and
passed to Dialogflow service. It means they cannot be retrieved using
EngineService.GetEngine
or
EngineService.ListEngines
API after engine creation. Use
ChatEngineMetadata.dialogflow_agent
for actual agent association after Engine is created.
395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/engine.rb', line 395 class ChatEngineConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configurations for generating a Dialogflow agent. # # Note that these configurations are one-time consumed by # and passed to Dialogflow service. It means they cannot be retrieved using # {::Google::Cloud::DiscoveryEngine::V1beta::EngineService::Client#get_engine EngineService.GetEngine} # or # {::Google::Cloud::DiscoveryEngine::V1beta::EngineService::Client#list_engines EngineService.ListEngines} # API after engine creation. # @!attribute [rw] business # @return [::String] # Name of the company, organization or other entity that the agent # represents. Used for knowledge connector LLM prompt and for knowledge # search. # @!attribute [rw] default_language_code # @return [::String] # Required. The default language of the agent as a language tag. # See [Language # Support](https://cloud.google.com/dialogflow/docs/reference/language) # for a list of the currently supported language codes. # @!attribute [rw] time_zone # @return [::String] # Required. The time zone of the agent from the [time zone # database](https://www.iana.org/time-zones), e.g., America/New_York, # Europe/Paris. # @!attribute [rw] location # @return [::String] # Agent location for Agent creation, supported values: global/us/eu. # If not provided, us Engine will create Agent using us-central-1 by # default; eu Engine will create Agent using eu-west-1 by default. class AgentCreationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |