Class: Google::Cloud::DiscoveryEngine::V1beta::Engine::MediaRecommendationEngineConfig::MostPopularFeatureConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/engine.rb

Overview

Feature configurations that are required for creating a Most Popular engine.

Instance Attribute Summary collapse

Instance Attribute Details

#time_window_days::Integer

Returns The time window of which the engine is queried at training and prediction time. Positive integers only. The value translates to the last X days of events. Currently required for the most-popular-items engine.

Returns:

  • (::Integer)

    The time window of which the engine is queried at training and prediction time. Positive integers only. The value translates to the last X days of events. Currently required for the most-popular-items engine.



334
335
336
337
# File 'proto_docs/google/cloud/discoveryengine/v1beta/engine.rb', line 334

class MostPopularFeatureConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end