Class: Google::Cloud::DiscoveryEngine::V1beta::Feedback

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/feedback.rb

Overview

Information about the user feedback. This information will be used for logging and metrics purpose.

Defined Under Namespace

Modules: FeedbackSource, FeedbackType, Reason Classes: ConversationInfo

Instance Attribute Summary collapse

Instance Attribute Details

#comment::String

Returns Optional. The additional user comment of the feedback if user gives a thumb down.

Returns:

  • (::String)

    Optional. The additional user comment of the feedback if user gives a thumb down.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'proto_docs/google/cloud/discoveryengine/v1beta/feedback.rb', line 54

class Feedback
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The conversation information such as the question index and session name.
  # @!attribute [rw] question_index
  #   @return [::Integer]
  #     The index of the user input within the conversation messages.
  # @!attribute [rw] session
  #   @return [::String]
  #     Name of the newly generated or continued session.
  # @!attribute [rw] query
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Query]
  #     Required. The user's search query.
  # @!attribute [rw] assist_token
  #   @return [::String]
  #     Optional. The token which could be used to fetch the assistant log.
  # @!attribute [rw] answer_query_token
  #   @return [::String]
  #     Optional. The token which could be used to fetch the answer log.
  class ConversationInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The type of the feedback user gives.
  module FeedbackType
    # Unspecified feedback type.
    FEEDBACK_TYPE_UNSPECIFIED = 0

    # The user gives a positive feedback.
    LIKE = 1

    # The user gives a negative feedback.
    DISLIKE = 2
  end

  # The reason why user gives a negative feedback.
  module Reason
    # Unspecified reason.
    REASON_UNSPECIFIED = 0

    # The response is inaccurate.
    INACCURATE_RESPONSE = 1

    # The response is not relevant.
    NOT_RELEVANT = 2

    # The response is incomprehensive.
    INCOMPREHENSIVE = 3

    # The response is offensive or unsafe.
    OFFENSIVE_OR_UNSAFE = 4

    # The response is not well-formatted.
    FORMAT_AND_STYLES = 6

    # The response is not well-associated with the query.
    BAD_CITATION = 7

    # The expected canvas was not generated for the response.
    CANVAS_NOT_GENERATED = 8

    # The generated canvas is of bad quality (e.g. inaccurate, incomplete,
    # poorly formatted).
    CANVAS_QUALITY_BAD = 9

    # Exporting the generated canvas failed (e.g. download or external
    # export action did not complete successfully).
    CANVAS_EXPORT_FAILED = 10
  end

  # Source of the feedback as per integration.
  module FeedbackSource
    # Unspecified feedback source.
    FEEDBACK_SOURCE_UNSPECIFIED = 0

    # Feedback source is Google Console.
    GOOGLE_CONSOLE = 1

    # Feedback source is Google Widget.
    GOOGLE_WIDGET = 2

    # Feedback source is Google Webapp.
    GOOGLE_WEBAPP = 3

    # Feedback source is Google AgentSpace Mobile app.
    GOOGLE_AGENTSPACE_MOBILE = 4
  end
end

#component_version::String

Returns Optional. The version of the component that this report is being sent from.

Returns:

  • (::String)

    Optional. The version of the component that this report is being sent from.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'proto_docs/google/cloud/discoveryengine/v1beta/feedback.rb', line 54

class Feedback
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The conversation information such as the question index and session name.
  # @!attribute [rw] question_index
  #   @return [::Integer]
  #     The index of the user input within the conversation messages.
  # @!attribute [rw] session
  #   @return [::String]
  #     Name of the newly generated or continued session.
  # @!attribute [rw] query
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Query]
  #     Required. The user's search query.
  # @!attribute [rw] assist_token
  #   @return [::String]
  #     Optional. The token which could be used to fetch the assistant log.
  # @!attribute [rw] answer_query_token
  #   @return [::String]
  #     Optional. The token which could be used to fetch the answer log.
  class ConversationInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The type of the feedback user gives.
  module FeedbackType
    # Unspecified feedback type.
    FEEDBACK_TYPE_UNSPECIFIED = 0

    # The user gives a positive feedback.
    LIKE = 1

    # The user gives a negative feedback.
    DISLIKE = 2
  end

  # The reason why user gives a negative feedback.
  module Reason
    # Unspecified reason.
    REASON_UNSPECIFIED = 0

    # The response is inaccurate.
    INACCURATE_RESPONSE = 1

    # The response is not relevant.
    NOT_RELEVANT = 2

    # The response is incomprehensive.
    INCOMPREHENSIVE = 3

    # The response is offensive or unsafe.
    OFFENSIVE_OR_UNSAFE = 4

    # The response is not well-formatted.
    FORMAT_AND_STYLES = 6

    # The response is not well-associated with the query.
    BAD_CITATION = 7

    # The expected canvas was not generated for the response.
    CANVAS_NOT_GENERATED = 8

    # The generated canvas is of bad quality (e.g. inaccurate, incomplete,
    # poorly formatted).
    CANVAS_QUALITY_BAD = 9

    # Exporting the generated canvas failed (e.g. download or external
    # export action did not complete successfully).
    CANVAS_EXPORT_FAILED = 10
  end

  # Source of the feedback as per integration.
  module FeedbackSource
    # Unspecified feedback source.
    FEEDBACK_SOURCE_UNSPECIFIED = 0

    # Feedback source is Google Console.
    GOOGLE_CONSOLE = 1

    # Feedback source is Google Widget.
    GOOGLE_WIDGET = 2

    # Feedback source is Google Webapp.
    GOOGLE_WEBAPP = 3

    # Feedback source is Google AgentSpace Mobile app.
    GOOGLE_AGENTSPACE_MOBILE = 4
  end
end

#conversation_info::Google::Cloud::DiscoveryEngine::V1beta::Feedback::ConversationInfo

Returns The related conversation information when user gives feedback.

Returns:



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'proto_docs/google/cloud/discoveryengine/v1beta/feedback.rb', line 54

class Feedback
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The conversation information such as the question index and session name.
  # @!attribute [rw] question_index
  #   @return [::Integer]
  #     The index of the user input within the conversation messages.
  # @!attribute [rw] session
  #   @return [::String]
  #     Name of the newly generated or continued session.
  # @!attribute [rw] query
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Query]
  #     Required. The user's search query.
  # @!attribute [rw] assist_token
  #   @return [::String]
  #     Optional. The token which could be used to fetch the assistant log.
  # @!attribute [rw] answer_query_token
  #   @return [::String]
  #     Optional. The token which could be used to fetch the answer log.
  class ConversationInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The type of the feedback user gives.
  module FeedbackType
    # Unspecified feedback type.
    FEEDBACK_TYPE_UNSPECIFIED = 0

    # The user gives a positive feedback.
    LIKE = 1

    # The user gives a negative feedback.
    DISLIKE = 2
  end

  # The reason why user gives a negative feedback.
  module Reason
    # Unspecified reason.
    REASON_UNSPECIFIED = 0

    # The response is inaccurate.
    INACCURATE_RESPONSE = 1

    # The response is not relevant.
    NOT_RELEVANT = 2

    # The response is incomprehensive.
    INCOMPREHENSIVE = 3

    # The response is offensive or unsafe.
    OFFENSIVE_OR_UNSAFE = 4

    # The response is not well-formatted.
    FORMAT_AND_STYLES = 6

    # The response is not well-associated with the query.
    BAD_CITATION = 7

    # The expected canvas was not generated for the response.
    CANVAS_NOT_GENERATED = 8

    # The generated canvas is of bad quality (e.g. inaccurate, incomplete,
    # poorly formatted).
    CANVAS_QUALITY_BAD = 9

    # Exporting the generated canvas failed (e.g. download or external
    # export action did not complete successfully).
    CANVAS_EXPORT_FAILED = 10
  end

  # Source of the feedback as per integration.
  module FeedbackSource
    # Unspecified feedback source.
    FEEDBACK_SOURCE_UNSPECIFIED = 0

    # Feedback source is Google Console.
    GOOGLE_CONSOLE = 1

    # Feedback source is Google Widget.
    GOOGLE_WIDGET = 2

    # Feedback source is Google Webapp.
    GOOGLE_WEBAPP = 3

    # Feedback source is Google AgentSpace Mobile app.
    GOOGLE_AGENTSPACE_MOBILE = 4
  end
end

#data_terms_accepted::Boolean

Returns Optional. Whether the customer accepted data use terms.

Returns:

  • (::Boolean)

    Optional. Whether the customer accepted data use terms.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'proto_docs/google/cloud/discoveryengine/v1beta/feedback.rb', line 54

class Feedback
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The conversation information such as the question index and session name.
  # @!attribute [rw] question_index
  #   @return [::Integer]
  #     The index of the user input within the conversation messages.
  # @!attribute [rw] session
  #   @return [::String]
  #     Name of the newly generated or continued session.
  # @!attribute [rw] query
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Query]
  #     Required. The user's search query.
  # @!attribute [rw] assist_token
  #   @return [::String]
  #     Optional. The token which could be used to fetch the assistant log.
  # @!attribute [rw] answer_query_token
  #   @return [::String]
  #     Optional. The token which could be used to fetch the answer log.
  class ConversationInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The type of the feedback user gives.
  module FeedbackType
    # Unspecified feedback type.
    FEEDBACK_TYPE_UNSPECIFIED = 0

    # The user gives a positive feedback.
    LIKE = 1

    # The user gives a negative feedback.
    DISLIKE = 2
  end

  # The reason why user gives a negative feedback.
  module Reason
    # Unspecified reason.
    REASON_UNSPECIFIED = 0

    # The response is inaccurate.
    INACCURATE_RESPONSE = 1

    # The response is not relevant.
    NOT_RELEVANT = 2

    # The response is incomprehensive.
    INCOMPREHENSIVE = 3

    # The response is offensive or unsafe.
    OFFENSIVE_OR_UNSAFE = 4

    # The response is not well-formatted.
    FORMAT_AND_STYLES = 6

    # The response is not well-associated with the query.
    BAD_CITATION = 7

    # The expected canvas was not generated for the response.
    CANVAS_NOT_GENERATED = 8

    # The generated canvas is of bad quality (e.g. inaccurate, incomplete,
    # poorly formatted).
    CANVAS_QUALITY_BAD = 9

    # Exporting the generated canvas failed (e.g. download or external
    # export action did not complete successfully).
    CANVAS_EXPORT_FAILED = 10
  end

  # Source of the feedback as per integration.
  module FeedbackSource
    # Unspecified feedback source.
    FEEDBACK_SOURCE_UNSPECIFIED = 0

    # Feedback source is Google Console.
    GOOGLE_CONSOLE = 1

    # Feedback source is Google Widget.
    GOOGLE_WIDGET = 2

    # Feedback source is Google Webapp.
    GOOGLE_WEBAPP = 3

    # Feedback source is Google AgentSpace Mobile app.
    GOOGLE_AGENTSPACE_MOBILE = 4
  end
end

#feedback_source::Google::Cloud::DiscoveryEngine::V1beta::Feedback::FeedbackSource

Returns Optional. The UI component the user feedback comes from, which could be GOOGLE_CONSOLE, GOOGLE_WIDGET, GOOGLE_WEBAPP.

Returns:



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'proto_docs/google/cloud/discoveryengine/v1beta/feedback.rb', line 54

class Feedback
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The conversation information such as the question index and session name.
  # @!attribute [rw] question_index
  #   @return [::Integer]
  #     The index of the user input within the conversation messages.
  # @!attribute [rw] session
  #   @return [::String]
  #     Name of the newly generated or continued session.
  # @!attribute [rw] query
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Query]
  #     Required. The user's search query.
  # @!attribute [rw] assist_token
  #   @return [::String]
  #     Optional. The token which could be used to fetch the assistant log.
  # @!attribute [rw] answer_query_token
  #   @return [::String]
  #     Optional. The token which could be used to fetch the answer log.
  class ConversationInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The type of the feedback user gives.
  module FeedbackType
    # Unspecified feedback type.
    FEEDBACK_TYPE_UNSPECIFIED = 0

    # The user gives a positive feedback.
    LIKE = 1

    # The user gives a negative feedback.
    DISLIKE = 2
  end

  # The reason why user gives a negative feedback.
  module Reason
    # Unspecified reason.
    REASON_UNSPECIFIED = 0

    # The response is inaccurate.
    INACCURATE_RESPONSE = 1

    # The response is not relevant.
    NOT_RELEVANT = 2

    # The response is incomprehensive.
    INCOMPREHENSIVE = 3

    # The response is offensive or unsafe.
    OFFENSIVE_OR_UNSAFE = 4

    # The response is not well-formatted.
    FORMAT_AND_STYLES = 6

    # The response is not well-associated with the query.
    BAD_CITATION = 7

    # The expected canvas was not generated for the response.
    CANVAS_NOT_GENERATED = 8

    # The generated canvas is of bad quality (e.g. inaccurate, incomplete,
    # poorly formatted).
    CANVAS_QUALITY_BAD = 9

    # Exporting the generated canvas failed (e.g. download or external
    # export action did not complete successfully).
    CANVAS_EXPORT_FAILED = 10
  end

  # Source of the feedback as per integration.
  module FeedbackSource
    # Unspecified feedback source.
    FEEDBACK_SOURCE_UNSPECIFIED = 0

    # Feedback source is Google Console.
    GOOGLE_CONSOLE = 1

    # Feedback source is Google Widget.
    GOOGLE_WIDGET = 2

    # Feedback source is Google Webapp.
    GOOGLE_WEBAPP = 3

    # Feedback source is Google AgentSpace Mobile app.
    GOOGLE_AGENTSPACE_MOBILE = 4
  end
end

#feedback_type::Google::Cloud::DiscoveryEngine::V1beta::Feedback::FeedbackType

Returns Required. Indicate whether the user gives a positive or negative feedback. If the user gives a negative feedback, there might be more feedback details.

Returns:



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'proto_docs/google/cloud/discoveryengine/v1beta/feedback.rb', line 54

class Feedback
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The conversation information such as the question index and session name.
  # @!attribute [rw] question_index
  #   @return [::Integer]
  #     The index of the user input within the conversation messages.
  # @!attribute [rw] session
  #   @return [::String]
  #     Name of the newly generated or continued session.
  # @!attribute [rw] query
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Query]
  #     Required. The user's search query.
  # @!attribute [rw] assist_token
  #   @return [::String]
  #     Optional. The token which could be used to fetch the assistant log.
  # @!attribute [rw] answer_query_token
  #   @return [::String]
  #     Optional. The token which could be used to fetch the answer log.
  class ConversationInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The type of the feedback user gives.
  module FeedbackType
    # Unspecified feedback type.
    FEEDBACK_TYPE_UNSPECIFIED = 0

    # The user gives a positive feedback.
    LIKE = 1

    # The user gives a negative feedback.
    DISLIKE = 2
  end

  # The reason why user gives a negative feedback.
  module Reason
    # Unspecified reason.
    REASON_UNSPECIFIED = 0

    # The response is inaccurate.
    INACCURATE_RESPONSE = 1

    # The response is not relevant.
    NOT_RELEVANT = 2

    # The response is incomprehensive.
    INCOMPREHENSIVE = 3

    # The response is offensive or unsafe.
    OFFENSIVE_OR_UNSAFE = 4

    # The response is not well-formatted.
    FORMAT_AND_STYLES = 6

    # The response is not well-associated with the query.
    BAD_CITATION = 7

    # The expected canvas was not generated for the response.
    CANVAS_NOT_GENERATED = 8

    # The generated canvas is of bad quality (e.g. inaccurate, incomplete,
    # poorly formatted).
    CANVAS_QUALITY_BAD = 9

    # Exporting the generated canvas failed (e.g. download or external
    # export action did not complete successfully).
    CANVAS_EXPORT_FAILED = 10
  end

  # Source of the feedback as per integration.
  module FeedbackSource
    # Unspecified feedback source.
    FEEDBACK_SOURCE_UNSPECIFIED = 0

    # Feedback source is Google Console.
    GOOGLE_CONSOLE = 1

    # Feedback source is Google Widget.
    GOOGLE_WIDGET = 2

    # Feedback source is Google Webapp.
    GOOGLE_WEBAPP = 3

    # Feedback source is Google AgentSpace Mobile app.
    GOOGLE_AGENTSPACE_MOBILE = 4
  end
end

#llm_model_version::String

Returns The version of the LLM model that was used to generate the response.

Returns:

  • (::String)

    The version of the LLM model that was used to generate the response.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'proto_docs/google/cloud/discoveryengine/v1beta/feedback.rb', line 54

class Feedback
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The conversation information such as the question index and session name.
  # @!attribute [rw] question_index
  #   @return [::Integer]
  #     The index of the user input within the conversation messages.
  # @!attribute [rw] session
  #   @return [::String]
  #     Name of the newly generated or continued session.
  # @!attribute [rw] query
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Query]
  #     Required. The user's search query.
  # @!attribute [rw] assist_token
  #   @return [::String]
  #     Optional. The token which could be used to fetch the assistant log.
  # @!attribute [rw] answer_query_token
  #   @return [::String]
  #     Optional. The token which could be used to fetch the answer log.
  class ConversationInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The type of the feedback user gives.
  module FeedbackType
    # Unspecified feedback type.
    FEEDBACK_TYPE_UNSPECIFIED = 0

    # The user gives a positive feedback.
    LIKE = 1

    # The user gives a negative feedback.
    DISLIKE = 2
  end

  # The reason why user gives a negative feedback.
  module Reason
    # Unspecified reason.
    REASON_UNSPECIFIED = 0

    # The response is inaccurate.
    INACCURATE_RESPONSE = 1

    # The response is not relevant.
    NOT_RELEVANT = 2

    # The response is incomprehensive.
    INCOMPREHENSIVE = 3

    # The response is offensive or unsafe.
    OFFENSIVE_OR_UNSAFE = 4

    # The response is not well-formatted.
    FORMAT_AND_STYLES = 6

    # The response is not well-associated with the query.
    BAD_CITATION = 7

    # The expected canvas was not generated for the response.
    CANVAS_NOT_GENERATED = 8

    # The generated canvas is of bad quality (e.g. inaccurate, incomplete,
    # poorly formatted).
    CANVAS_QUALITY_BAD = 9

    # Exporting the generated canvas failed (e.g. download or external
    # export action did not complete successfully).
    CANVAS_EXPORT_FAILED = 10
  end

  # Source of the feedback as per integration.
  module FeedbackSource
    # Unspecified feedback source.
    FEEDBACK_SOURCE_UNSPECIFIED = 0

    # Feedback source is Google Console.
    GOOGLE_CONSOLE = 1

    # Feedback source is Google Widget.
    GOOGLE_WIDGET = 2

    # Feedback source is Google Webapp.
    GOOGLE_WEBAPP = 3

    # Feedback source is Google AgentSpace Mobile app.
    GOOGLE_AGENTSPACE_MOBILE = 4
  end
end

#reasons::Array<::Google::Cloud::DiscoveryEngine::V1beta::Feedback::Reason>

Returns Optional. The reason if user gives a thumb down.

Returns:



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'proto_docs/google/cloud/discoveryengine/v1beta/feedback.rb', line 54

class Feedback
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The conversation information such as the question index and session name.
  # @!attribute [rw] question_index
  #   @return [::Integer]
  #     The index of the user input within the conversation messages.
  # @!attribute [rw] session
  #   @return [::String]
  #     Name of the newly generated or continued session.
  # @!attribute [rw] query
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Query]
  #     Required. The user's search query.
  # @!attribute [rw] assist_token
  #   @return [::String]
  #     Optional. The token which could be used to fetch the assistant log.
  # @!attribute [rw] answer_query_token
  #   @return [::String]
  #     Optional. The token which could be used to fetch the answer log.
  class ConversationInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The type of the feedback user gives.
  module FeedbackType
    # Unspecified feedback type.
    FEEDBACK_TYPE_UNSPECIFIED = 0

    # The user gives a positive feedback.
    LIKE = 1

    # The user gives a negative feedback.
    DISLIKE = 2
  end

  # The reason why user gives a negative feedback.
  module Reason
    # Unspecified reason.
    REASON_UNSPECIFIED = 0

    # The response is inaccurate.
    INACCURATE_RESPONSE = 1

    # The response is not relevant.
    NOT_RELEVANT = 2

    # The response is incomprehensive.
    INCOMPREHENSIVE = 3

    # The response is offensive or unsafe.
    OFFENSIVE_OR_UNSAFE = 4

    # The response is not well-formatted.
    FORMAT_AND_STYLES = 6

    # The response is not well-associated with the query.
    BAD_CITATION = 7

    # The expected canvas was not generated for the response.
    CANVAS_NOT_GENERATED = 8

    # The generated canvas is of bad quality (e.g. inaccurate, incomplete,
    # poorly formatted).
    CANVAS_QUALITY_BAD = 9

    # Exporting the generated canvas failed (e.g. download or external
    # export action did not complete successfully).
    CANVAS_EXPORT_FAILED = 10
  end

  # Source of the feedback as per integration.
  module FeedbackSource
    # Unspecified feedback source.
    FEEDBACK_SOURCE_UNSPECIFIED = 0

    # Feedback source is Google Console.
    GOOGLE_CONSOLE = 1

    # Feedback source is Google Widget.
    GOOGLE_WIDGET = 2

    # Feedback source is Google Webapp.
    GOOGLE_WEBAPP = 3

    # Feedback source is Google AgentSpace Mobile app.
    GOOGLE_AGENTSPACE_MOBILE = 4
  end
end