Module: Google::Cloud::DiscoveryEngine::V1beta::Feedback::Reason

Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/feedback.rb

Overview

The reason why user gives a negative feedback.

Constant Summary collapse

REASON_UNSPECIFIED =

Unspecified reason.

0
INACCURATE_RESPONSE =

The response is inaccurate.

1
NOT_RELEVANT =

The response is not relevant.

2
INCOMPREHENSIVE =

The response is incomprehensive.

3
OFFENSIVE_OR_UNSAFE =

The response is offensive or unsafe.

4
FORMAT_AND_STYLES =

The response is not well-formatted.

6
BAD_CITATION =

The response is not well-associated with the query.

7
CANVAS_NOT_GENERATED =

The expected canvas was not generated for the response.

8
CANVAS_QUALITY_BAD =

The generated canvas is of bad quality (e.g. inaccurate, incomplete, poorly formatted).

9
CANVAS_EXPORT_FAILED =

Exporting the generated canvas failed (e.g. download or external export action did not complete successfully).

10