Class: Google::Cloud::DiscoveryEngine::V1beta::FetchDomainVerificationStatusResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/site_search_engine_service.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token ⇒ ::String

Returns A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String) —

    A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



671
672
673
674
# File 'proto_docs/google/cloud/discoveryengine/v1beta/site_search_engine_service.rb', line 671

class FetchDomainVerificationStatusResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#target_sites ⇒ ::Array<::Google::Cloud::DiscoveryEngine::V1beta::TargetSite>

Returns List of TargetSites containing the site verification status.

Returns:



671
672
673
674
# File 'proto_docs/google/cloud/discoveryengine/v1beta/site_search_engine_service.rb', line 671

class FetchDomainVerificationStatusResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#total_size ⇒ ::Integer

Returns The total number of items matching the request. This will always be populated in the response.

Returns:

  • (::Integer) —

    The total number of items matching the request. This will always be populated in the response.



671
672
673
674
# File 'proto_docs/google/cloud/discoveryengine/v1beta/site_search_engine_service.rb', line 671

class FetchDomainVerificationStatusResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end