Class: Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentRequest::GenerationSpec

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb

Overview

Content generation specification.

Defined Under Namespace

Modules: ProvisionedThroughputSetting

Instance Attribute Summary collapse

Instance Attribute Details

#frequency_penalty::Float

Returns If specified, custom value for frequency penalty will be used.

Returns:

  • (::Float)

    If specified, custom value for frequency penalty will be used.



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 129

class GenerationSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Setting for provisioned throughput.
  module ProvisionedThroughputSetting
    # Default value. If the user has remaining provisioned throughput,
    # provisioned throughput will be used. Otherwise, pay as you go will be
    # used.
    PROVISIONED_THROUGHPUT_SETTING_UNSPECIFIED = 0

    # Only use provisioned throughput. If the user has no remaining
    # provisioned throughput, an error will be returned.
    PROVISIONED_THROUGHPUT_ONLY = 1

    # Disables provisioned throughput.
    PAY_AS_YOU_GO_ONLY = 2
  end
end

#language_code::String

Returns Language code for content. Use language tags defined by BCP47.

Returns:

  • (::String)

    Language code for content. Use language tags defined by BCP47.



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 129

class GenerationSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Setting for provisioned throughput.
  module ProvisionedThroughputSetting
    # Default value. If the user has remaining provisioned throughput,
    # provisioned throughput will be used. Otherwise, pay as you go will be
    # used.
    PROVISIONED_THROUGHPUT_SETTING_UNSPECIFIED = 0

    # Only use provisioned throughput. If the user has no remaining
    # provisioned throughput, an error will be returned.
    PROVISIONED_THROUGHPUT_ONLY = 1

    # Disables provisioned throughput.
    PAY_AS_YOU_GO_ONLY = 2
  end
end

#max_output_tokens::Integer

Returns If specified, custom value for max output tokens will be used.

Returns:

  • (::Integer)

    If specified, custom value for max output tokens will be used.



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 129

class GenerationSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Setting for provisioned throughput.
  module ProvisionedThroughputSetting
    # Default value. If the user has remaining provisioned throughput,
    # provisioned throughput will be used. Otherwise, pay as you go will be
    # used.
    PROVISIONED_THROUGHPUT_SETTING_UNSPECIFIED = 0

    # Only use provisioned throughput. If the user has no remaining
    # provisioned throughput, an error will be returned.
    PROVISIONED_THROUGHPUT_ONLY = 1

    # Disables provisioned throughput.
    PAY_AS_YOU_GO_ONLY = 2
  end
end

#model_id::String

Returns Specifies which Vertex model id to use for generation.

Returns:

  • (::String)

    Specifies which Vertex model id to use for generation.



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 129

class GenerationSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Setting for provisioned throughput.
  module ProvisionedThroughputSetting
    # Default value. If the user has remaining provisioned throughput,
    # provisioned throughput will be used. Otherwise, pay as you go will be
    # used.
    PROVISIONED_THROUGHPUT_SETTING_UNSPECIFIED = 0

    # Only use provisioned throughput. If the user has no remaining
    # provisioned throughput, an error will be returned.
    PROVISIONED_THROUGHPUT_ONLY = 1

    # Disables provisioned throughput.
    PAY_AS_YOU_GO_ONLY = 2
  end
end

#presence_penalty::Float

Returns If specified, custom value for presence penalty will be used.

Returns:

  • (::Float)

    If specified, custom value for presence penalty will be used.



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 129

class GenerationSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Setting for provisioned throughput.
  module ProvisionedThroughputSetting
    # Default value. If the user has remaining provisioned throughput,
    # provisioned throughput will be used. Otherwise, pay as you go will be
    # used.
    PROVISIONED_THROUGHPUT_SETTING_UNSPECIFIED = 0

    # Only use provisioned throughput. If the user has no remaining
    # provisioned throughput, an error will be returned.
    PROVISIONED_THROUGHPUT_ONLY = 1

    # Disables provisioned throughput.
    PAY_AS_YOU_GO_ONLY = 2
  end
end

#provisioned_throughput_setting::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentRequest::GenerationSpec::ProvisionedThroughputSetting

Returns Optional. Setting for provisioned throughput.



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 129

class GenerationSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Setting for provisioned throughput.
  module ProvisionedThroughputSetting
    # Default value. If the user has remaining provisioned throughput,
    # provisioned throughput will be used. Otherwise, pay as you go will be
    # used.
    PROVISIONED_THROUGHPUT_SETTING_UNSPECIFIED = 0

    # Only use provisioned throughput. If the user has no remaining
    # provisioned throughput, an error will be returned.
    PROVISIONED_THROUGHPUT_ONLY = 1

    # Disables provisioned throughput.
    PAY_AS_YOU_GO_ONLY = 2
  end
end

#seed::Integer

Returns If specified, custom value for the seed will be used.

Returns:

  • (::Integer)

    If specified, custom value for the seed will be used.



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 129

class GenerationSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Setting for provisioned throughput.
  module ProvisionedThroughputSetting
    # Default value. If the user has remaining provisioned throughput,
    # provisioned throughput will be used. Otherwise, pay as you go will be
    # used.
    PROVISIONED_THROUGHPUT_SETTING_UNSPECIFIED = 0

    # Only use provisioned throughput. If the user has no remaining
    # provisioned throughput, an error will be returned.
    PROVISIONED_THROUGHPUT_ONLY = 1

    # Disables provisioned throughput.
    PAY_AS_YOU_GO_ONLY = 2
  end
end

#temperature::Float

Returns If specified, custom value for the temperature will be used.

Returns:

  • (::Float)

    If specified, custom value for the temperature will be used.



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 129

class GenerationSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Setting for provisioned throughput.
  module ProvisionedThroughputSetting
    # Default value. If the user has remaining provisioned throughput,
    # provisioned throughput will be used. Otherwise, pay as you go will be
    # used.
    PROVISIONED_THROUGHPUT_SETTING_UNSPECIFIED = 0

    # Only use provisioned throughput. If the user has no remaining
    # provisioned throughput, an error will be returned.
    PROVISIONED_THROUGHPUT_ONLY = 1

    # Disables provisioned throughput.
    PAY_AS_YOU_GO_ONLY = 2
  end
end

#top_k::Integer

Returns If specified, custom value for top-k sampling will be used.

Returns:

  • (::Integer)

    If specified, custom value for top-k sampling will be used.



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 129

class GenerationSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Setting for provisioned throughput.
  module ProvisionedThroughputSetting
    # Default value. If the user has remaining provisioned throughput,
    # provisioned throughput will be used. Otherwise, pay as you go will be
    # used.
    PROVISIONED_THROUGHPUT_SETTING_UNSPECIFIED = 0

    # Only use provisioned throughput. If the user has no remaining
    # provisioned throughput, an error will be returned.
    PROVISIONED_THROUGHPUT_ONLY = 1

    # Disables provisioned throughput.
    PAY_AS_YOU_GO_ONLY = 2
  end
end

#top_p::Float

Returns If specified, custom value for nucleus sampling will be used.

Returns:

  • (::Float)

    If specified, custom value for nucleus sampling will be used.



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 129

class GenerationSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Setting for provisioned throughput.
  module ProvisionedThroughputSetting
    # Default value. If the user has remaining provisioned throughput,
    # provisioned throughput will be used. Otherwise, pay as you go will be
    # used.
    PROVISIONED_THROUGHPUT_SETTING_UNSPECIFIED = 0

    # Only use provisioned throughput. If the user has no remaining
    # provisioned throughput, an error will be returned.
    PROVISIONED_THROUGHPUT_ONLY = 1

    # Disables provisioned throughput.
    PAY_AS_YOU_GO_ONLY = 2
  end
end