Module: Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentRequest::GenerationSpec::ProvisionedThroughputSetting

Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb

Overview

Setting for provisioned throughput.

Constant Summary collapse

PROVISIONED_THROUGHPUT_SETTING_UNSPECIFIED =

Default value. If the user has remaining provisioned throughput, provisioned throughput will be used. Otherwise, pay as you go will be used.

0
PROVISIONED_THROUGHPUT_ONLY =

Only use provisioned throughput. If the user has no remaining provisioned throughput, an error will be returned.

1
PAY_AS_YOU_GO_ONLY =

Disables provisioned throughput.

2