Class: Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentRequest::GroundingSource::EnterpriseWebRetrievalSource

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb

Overview

Params for using enterprise web retrieval as grounding source.

Instance Attribute Summary collapse

Instance Attribute Details

#blocking_confidence::Google::Cloud::DiscoveryEngine::V1beta::Citation::PhishBlockThreshold

Returns Optional. Sites with confidence level chosen & above this value will be blocked from the search results.

Returns:



280
281
282
283
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 280

class EnterpriseWebRetrievalSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#exclude_domains::Array<::String>

Returns Optional. List of domains to be excluded from the search results.

Returns:

  • (::Array<::String>)

    Optional. List of domains to be excluded from the search results.



280
281
282
283
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 280

class EnterpriseWebRetrievalSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end