Class: Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentRequest::GroundingSource::GoogleSearchSource

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb

Overview

Google Search config parameters.

Instance Attribute Summary collapse

Instance Attribute Details

#blocking_confidence::Google::Cloud::DiscoveryEngine::V1beta::Citation::PhishBlockThreshold

Returns Optional. Sites with confidence level chosen & above this value will be blocked from the search results.

Returns:



267
268
269
270
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 267

class GoogleSearchSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#dynamic_retrieval_config::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentRequest::DynamicRetrievalConfiguration

Returns Optional. Specifies the dynamic retrieval configuration for the given source.

Returns:



267
268
269
270
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 267

class GoogleSearchSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#exclude_domains::Array<::String>

Returns Optional. List of domains to be excluded from the search results.

Returns:

  • (::Array<::String>)

    Optional. List of domains to be excluded from the search results.



267
268
269
270
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 267

class GoogleSearchSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end