Class: Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentRequest::GroundingSource::InlineSource

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb

Overview

Message to be used for grounding based on inline content.

Defined Under Namespace

Classes: AttributesEntry

Instance Attribute Summary collapse

Instance Attribute Details

#attributes::Google::Protobuf::Map{::String => ::String}

Returns Attributes associated with the content.

Common attributes include source (indicating where the content was sourced from) and author (indicating the author of the content).

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Attributes associated with the content.

    Common attributes include source (indicating where the content was sourced from) and author (indicating the author of the content).



215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 215

class InlineSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#grounding_facts::Array<::Google::Cloud::DiscoveryEngine::V1beta::GroundingFact>

Returns List of facts to be used for grounding.

Returns:



215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 215

class InlineSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end