Class: Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb

Overview

Citation for the generated content.

Defined Under Namespace

Classes: DynamicRetrievalMetadata, DynamicRetrievalPredictorMetadata, GroundingSupport, ImageMetadata, RetrievalMetadata, SearchEntryPoint, VideoMetadata

Instance Attribute Summary collapse

Instance Attribute Details

#grounding_support::Array<::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::GroundingSupport>

Returns GroundingSupport across all claims in the answer candidate. An support to a fact indicates that the claim is supported by the fact.

Returns:



358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 358

class GroundingMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes the metadata associated with a retrieval step.
  # @!attribute [rw] source
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::RetrievalMetadata::Source]
  #     Describes the source to which the metadata is referring to.
  # @!attribute [rw] dynamic_retrieval_metadata
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::DynamicRetrievalMetadata]
  #     Metadata for dynamic retrieval.
  class RetrievalMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Describes the source to which the metadata is associated to.
    module Source
      # Unspecified source.
      SOURCE_UNSPECIFIED = 0

      # Vertex AI search.
      VERTEX_AI_SEARCH = 1

      # Google Search.
      GOOGLE_SEARCH = 3

      # User inline provided content.
      INLINE_CONTENT = 2

      # Google Maps.
      GOOGLE_MAPS = 4
    end
  end

  # Describes the metadata about dynamic retrieval.
  # @!attribute [rw] predictor_metadata
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::DynamicRetrievalPredictorMetadata]
  #     Metadata for the dynamic retrieval predictor.
  class DynamicRetrievalMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Describes the metadata about the dynamic retrieval predictor.
  # @!attribute [rw] version
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::DynamicRetrievalPredictorMetadata::Version]
  #     The version of the predictor which was used in dynamic retrieval.
  # @!attribute [rw] prediction
  #   @return [::Float]
  #     The value of the predictor. This should be between [0, 1] where
  #     a value of 0 means that the query would not benefit from grounding,
  #     while a value of 1.0 means that the query would benefit the most.
  #     In between values allow to differentiate between different usefulness
  #     scores for grounding.
  class DynamicRetrievalPredictorMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The version of the predictor which was used in dynamic retrieval.
    module Version
      # Unspecified version, should never be used.
      VERSION_UNSPECIFIED = 0

      # The V1 model which is evaluating each source independently.
      V1_INDEPENDENT = 1
    end
  end

  # Google search entry point.
  # @!attribute [rw] rendered_content
  #   @return [::String]
  #     Web content snippet that can be embedded in a web page or an app
  #     webview.
  # @!attribute [rw] sdk_blob
  #   @return [::String]
  #     Base64 encoded JSON representing array of <search term, search url>
  #     tuple.
  class SearchEntryPoint
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Grounding info for a claim in the candidate and its support.
  # @!attribute [rw] claim_text
  #   @return [::String]
  #     Text for the claim in the candidate. Always provided when a
  #     support is found.
  # @!attribute [rw] support_chunk_indices
  #   @return [::Array<::Integer>]
  #     A list of indices (into 'support_chunks') specifying the
  #     citations associated with the claim. For instance [1,3,4] means
  #     that support_chunks[1], support_chunks[3],
  #     support_chunks[4] are the chunks attributed to the claim.
  # @!attribute [rw] support_score
  #   @return [::Float]
  #     A score in the range of [0, 1] describing how grounded is a specific
  #     claim in the support chunks indicated.
  #     Higher value means that the claim is better supported by the chunks.
  class GroundingSupport
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Metadata about an image from the web search.
  # @!attribute [rw] image
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::ImageMetadata::Image]
  #     Metadata about the full size image.
  # @!attribute [rw] thumbnail
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::ImageMetadata::Image]
  #     Metadata about the thumbnail.
  # @!attribute [rw] source
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::ImageMetadata::WebsiteInfo]
  #     The details about the website that the image is from.
  class ImageMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Metadata about the website that the image is from.
    # @!attribute [rw] uri
    #   @return [::String]
    #     The url of the website.
    # @!attribute [rw] title
    #   @return [::String]
    #     The title of the website.
    # @!attribute [rw] site_display_name
    #   @return [::String]
    #     The display name of the website.
    class WebsiteInfo
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Metadata about the image.
    # @!attribute [rw] uri
    #   @return [::String]
    #     The url of the image.
    # @!attribute [rw] width
    #   @return [::Integer]
    #     The width of the image in pixels.
    # @!attribute [rw] height
    #   @return [::Integer]
    #     The height of the image in pixels.
    class Image
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # Metadata about a video from the web search.
  # @!attribute [rw] youtube_external_id
  #   @return [::String]
  #     The external id of the video.
  class VideoMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#images::Array<::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::ImageMetadata>

Returns Images from the web search.



358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 358

class GroundingMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes the metadata associated with a retrieval step.
  # @!attribute [rw] source
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::RetrievalMetadata::Source]
  #     Describes the source to which the metadata is referring to.
  # @!attribute [rw] dynamic_retrieval_metadata
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::DynamicRetrievalMetadata]
  #     Metadata for dynamic retrieval.
  class RetrievalMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Describes the source to which the metadata is associated to.
    module Source
      # Unspecified source.
      SOURCE_UNSPECIFIED = 0

      # Vertex AI search.
      VERTEX_AI_SEARCH = 1

      # Google Search.
      GOOGLE_SEARCH = 3

      # User inline provided content.
      INLINE_CONTENT = 2

      # Google Maps.
      GOOGLE_MAPS = 4
    end
  end

  # Describes the metadata about dynamic retrieval.
  # @!attribute [rw] predictor_metadata
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::DynamicRetrievalPredictorMetadata]
  #     Metadata for the dynamic retrieval predictor.
  class DynamicRetrievalMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Describes the metadata about the dynamic retrieval predictor.
  # @!attribute [rw] version
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::DynamicRetrievalPredictorMetadata::Version]
  #     The version of the predictor which was used in dynamic retrieval.
  # @!attribute [rw] prediction
  #   @return [::Float]
  #     The value of the predictor. This should be between [0, 1] where
  #     a value of 0 means that the query would not benefit from grounding,
  #     while a value of 1.0 means that the query would benefit the most.
  #     In between values allow to differentiate between different usefulness
  #     scores for grounding.
  class DynamicRetrievalPredictorMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The version of the predictor which was used in dynamic retrieval.
    module Version
      # Unspecified version, should never be used.
      VERSION_UNSPECIFIED = 0

      # The V1 model which is evaluating each source independently.
      V1_INDEPENDENT = 1
    end
  end

  # Google search entry point.
  # @!attribute [rw] rendered_content
  #   @return [::String]
  #     Web content snippet that can be embedded in a web page or an app
  #     webview.
  # @!attribute [rw] sdk_blob
  #   @return [::String]
  #     Base64 encoded JSON representing array of <search term, search url>
  #     tuple.
  class SearchEntryPoint
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Grounding info for a claim in the candidate and its support.
  # @!attribute [rw] claim_text
  #   @return [::String]
  #     Text for the claim in the candidate. Always provided when a
  #     support is found.
  # @!attribute [rw] support_chunk_indices
  #   @return [::Array<::Integer>]
  #     A list of indices (into 'support_chunks') specifying the
  #     citations associated with the claim. For instance [1,3,4] means
  #     that support_chunks[1], support_chunks[3],
  #     support_chunks[4] are the chunks attributed to the claim.
  # @!attribute [rw] support_score
  #   @return [::Float]
  #     A score in the range of [0, 1] describing how grounded is a specific
  #     claim in the support chunks indicated.
  #     Higher value means that the claim is better supported by the chunks.
  class GroundingSupport
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Metadata about an image from the web search.
  # @!attribute [rw] image
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::ImageMetadata::Image]
  #     Metadata about the full size image.
  # @!attribute [rw] thumbnail
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::ImageMetadata::Image]
  #     Metadata about the thumbnail.
  # @!attribute [rw] source
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::ImageMetadata::WebsiteInfo]
  #     The details about the website that the image is from.
  class ImageMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Metadata about the website that the image is from.
    # @!attribute [rw] uri
    #   @return [::String]
    #     The url of the website.
    # @!attribute [rw] title
    #   @return [::String]
    #     The title of the website.
    # @!attribute [rw] site_display_name
    #   @return [::String]
    #     The display name of the website.
    class WebsiteInfo
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Metadata about the image.
    # @!attribute [rw] uri
    #   @return [::String]
    #     The url of the image.
    # @!attribute [rw] width
    #   @return [::Integer]
    #     The width of the image in pixels.
    # @!attribute [rw] height
    #   @return [::Integer]
    #     The height of the image in pixels.
    class Image
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # Metadata about a video from the web search.
  # @!attribute [rw] youtube_external_id
  #   @return [::String]
  #     The external id of the video.
  class VideoMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#retrieval_metadata::Array<::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::RetrievalMetadata>

Returns Retrieval metadata to provide an understanding in the retrieval steps performed by the model. There can be multiple such messages which can correspond to different parts of the retrieval. This is a mechanism used to ensure transparency to our users.

Returns:



358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 358

class GroundingMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes the metadata associated with a retrieval step.
  # @!attribute [rw] source
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::RetrievalMetadata::Source]
  #     Describes the source to which the metadata is referring to.
  # @!attribute [rw] dynamic_retrieval_metadata
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::DynamicRetrievalMetadata]
  #     Metadata for dynamic retrieval.
  class RetrievalMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Describes the source to which the metadata is associated to.
    module Source
      # Unspecified source.
      SOURCE_UNSPECIFIED = 0

      # Vertex AI search.
      VERTEX_AI_SEARCH = 1

      # Google Search.
      GOOGLE_SEARCH = 3

      # User inline provided content.
      INLINE_CONTENT = 2

      # Google Maps.
      GOOGLE_MAPS = 4
    end
  end

  # Describes the metadata about dynamic retrieval.
  # @!attribute [rw] predictor_metadata
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::DynamicRetrievalPredictorMetadata]
  #     Metadata for the dynamic retrieval predictor.
  class DynamicRetrievalMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Describes the metadata about the dynamic retrieval predictor.
  # @!attribute [rw] version
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::DynamicRetrievalPredictorMetadata::Version]
  #     The version of the predictor which was used in dynamic retrieval.
  # @!attribute [rw] prediction
  #   @return [::Float]
  #     The value of the predictor. This should be between [0, 1] where
  #     a value of 0 means that the query would not benefit from grounding,
  #     while a value of 1.0 means that the query would benefit the most.
  #     In between values allow to differentiate between different usefulness
  #     scores for grounding.
  class DynamicRetrievalPredictorMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The version of the predictor which was used in dynamic retrieval.
    module Version
      # Unspecified version, should never be used.
      VERSION_UNSPECIFIED = 0

      # The V1 model which is evaluating each source independently.
      V1_INDEPENDENT = 1
    end
  end

  # Google search entry point.
  # @!attribute [rw] rendered_content
  #   @return [::String]
  #     Web content snippet that can be embedded in a web page or an app
  #     webview.
  # @!attribute [rw] sdk_blob
  #   @return [::String]
  #     Base64 encoded JSON representing array of <search term, search url>
  #     tuple.
  class SearchEntryPoint
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Grounding info for a claim in the candidate and its support.
  # @!attribute [rw] claim_text
  #   @return [::String]
  #     Text for the claim in the candidate. Always provided when a
  #     support is found.
  # @!attribute [rw] support_chunk_indices
  #   @return [::Array<::Integer>]
  #     A list of indices (into 'support_chunks') specifying the
  #     citations associated with the claim. For instance [1,3,4] means
  #     that support_chunks[1], support_chunks[3],
  #     support_chunks[4] are the chunks attributed to the claim.
  # @!attribute [rw] support_score
  #   @return [::Float]
  #     A score in the range of [0, 1] describing how grounded is a specific
  #     claim in the support chunks indicated.
  #     Higher value means that the claim is better supported by the chunks.
  class GroundingSupport
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Metadata about an image from the web search.
  # @!attribute [rw] image
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::ImageMetadata::Image]
  #     Metadata about the full size image.
  # @!attribute [rw] thumbnail
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::ImageMetadata::Image]
  #     Metadata about the thumbnail.
  # @!attribute [rw] source
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::ImageMetadata::WebsiteInfo]
  #     The details about the website that the image is from.
  class ImageMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Metadata about the website that the image is from.
    # @!attribute [rw] uri
    #   @return [::String]
    #     The url of the website.
    # @!attribute [rw] title
    #   @return [::String]
    #     The title of the website.
    # @!attribute [rw] site_display_name
    #   @return [::String]
    #     The display name of the website.
    class WebsiteInfo
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Metadata about the image.
    # @!attribute [rw] uri
    #   @return [::String]
    #     The url of the image.
    # @!attribute [rw] width
    #   @return [::Integer]
    #     The width of the image in pixels.
    # @!attribute [rw] height
    #   @return [::Integer]
    #     The height of the image in pixels.
    class Image
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # Metadata about a video from the web search.
  # @!attribute [rw] youtube_external_id
  #   @return [::String]
  #     The external id of the video.
  class VideoMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#search_entry_point::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::SearchEntryPoint

Returns Google search entry for the following-up web searches.



358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 358

class GroundingMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes the metadata associated with a retrieval step.
  # @!attribute [rw] source
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::RetrievalMetadata::Source]
  #     Describes the source to which the metadata is referring to.
  # @!attribute [rw] dynamic_retrieval_metadata
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::DynamicRetrievalMetadata]
  #     Metadata for dynamic retrieval.
  class RetrievalMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Describes the source to which the metadata is associated to.
    module Source
      # Unspecified source.
      SOURCE_UNSPECIFIED = 0

      # Vertex AI search.
      VERTEX_AI_SEARCH = 1

      # Google Search.
      GOOGLE_SEARCH = 3

      # User inline provided content.
      INLINE_CONTENT = 2

      # Google Maps.
      GOOGLE_MAPS = 4
    end
  end

  # Describes the metadata about dynamic retrieval.
  # @!attribute [rw] predictor_metadata
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::DynamicRetrievalPredictorMetadata]
  #     Metadata for the dynamic retrieval predictor.
  class DynamicRetrievalMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Describes the metadata about the dynamic retrieval predictor.
  # @!attribute [rw] version
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::DynamicRetrievalPredictorMetadata::Version]
  #     The version of the predictor which was used in dynamic retrieval.
  # @!attribute [rw] prediction
  #   @return [::Float]
  #     The value of the predictor. This should be between [0, 1] where
  #     a value of 0 means that the query would not benefit from grounding,
  #     while a value of 1.0 means that the query would benefit the most.
  #     In between values allow to differentiate between different usefulness
  #     scores for grounding.
  class DynamicRetrievalPredictorMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The version of the predictor which was used in dynamic retrieval.
    module Version
      # Unspecified version, should never be used.
      VERSION_UNSPECIFIED = 0

      # The V1 model which is evaluating each source independently.
      V1_INDEPENDENT = 1
    end
  end

  # Google search entry point.
  # @!attribute [rw] rendered_content
  #   @return [::String]
  #     Web content snippet that can be embedded in a web page or an app
  #     webview.
  # @!attribute [rw] sdk_blob
  #   @return [::String]
  #     Base64 encoded JSON representing array of <search term, search url>
  #     tuple.
  class SearchEntryPoint
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Grounding info for a claim in the candidate and its support.
  # @!attribute [rw] claim_text
  #   @return [::String]
  #     Text for the claim in the candidate. Always provided when a
  #     support is found.
  # @!attribute [rw] support_chunk_indices
  #   @return [::Array<::Integer>]
  #     A list of indices (into 'support_chunks') specifying the
  #     citations associated with the claim. For instance [1,3,4] means
  #     that support_chunks[1], support_chunks[3],
  #     support_chunks[4] are the chunks attributed to the claim.
  # @!attribute [rw] support_score
  #   @return [::Float]
  #     A score in the range of [0, 1] describing how grounded is a specific
  #     claim in the support chunks indicated.
  #     Higher value means that the claim is better supported by the chunks.
  class GroundingSupport
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Metadata about an image from the web search.
  # @!attribute [rw] image
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::ImageMetadata::Image]
  #     Metadata about the full size image.
  # @!attribute [rw] thumbnail
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::ImageMetadata::Image]
  #     Metadata about the thumbnail.
  # @!attribute [rw] source
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::ImageMetadata::WebsiteInfo]
  #     The details about the website that the image is from.
  class ImageMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Metadata about the website that the image is from.
    # @!attribute [rw] uri
    #   @return [::String]
    #     The url of the website.
    # @!attribute [rw] title
    #   @return [::String]
    #     The title of the website.
    # @!attribute [rw] site_display_name
    #   @return [::String]
    #     The display name of the website.
    class WebsiteInfo
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Metadata about the image.
    # @!attribute [rw] uri
    #   @return [::String]
    #     The url of the image.
    # @!attribute [rw] width
    #   @return [::Integer]
    #     The width of the image in pixels.
    # @!attribute [rw] height
    #   @return [::Integer]
    #     The height of the image in pixels.
    class Image
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # Metadata about a video from the web search.
  # @!attribute [rw] youtube_external_id
  #   @return [::String]
  #     The external id of the video.
  class VideoMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#support_chunks::Array<::Google::Cloud::DiscoveryEngine::V1beta::FactChunk>

Returns List of chunks to be attributed across all claims in the candidate. These are derived from the grounding sources supplied in the request.

Returns:



358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 358

class GroundingMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes the metadata associated with a retrieval step.
  # @!attribute [rw] source
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::RetrievalMetadata::Source]
  #     Describes the source to which the metadata is referring to.
  # @!attribute [rw] dynamic_retrieval_metadata
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::DynamicRetrievalMetadata]
  #     Metadata for dynamic retrieval.
  class RetrievalMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Describes the source to which the metadata is associated to.
    module Source
      # Unspecified source.
      SOURCE_UNSPECIFIED = 0

      # Vertex AI search.
      VERTEX_AI_SEARCH = 1

      # Google Search.
      GOOGLE_SEARCH = 3

      # User inline provided content.
      INLINE_CONTENT = 2

      # Google Maps.
      GOOGLE_MAPS = 4
    end
  end

  # Describes the metadata about dynamic retrieval.
  # @!attribute [rw] predictor_metadata
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::DynamicRetrievalPredictorMetadata]
  #     Metadata for the dynamic retrieval predictor.
  class DynamicRetrievalMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Describes the metadata about the dynamic retrieval predictor.
  # @!attribute [rw] version
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::DynamicRetrievalPredictorMetadata::Version]
  #     The version of the predictor which was used in dynamic retrieval.
  # @!attribute [rw] prediction
  #   @return [::Float]
  #     The value of the predictor. This should be between [0, 1] where
  #     a value of 0 means that the query would not benefit from grounding,
  #     while a value of 1.0 means that the query would benefit the most.
  #     In between values allow to differentiate between different usefulness
  #     scores for grounding.
  class DynamicRetrievalPredictorMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The version of the predictor which was used in dynamic retrieval.
    module Version
      # Unspecified version, should never be used.
      VERSION_UNSPECIFIED = 0

      # The V1 model which is evaluating each source independently.
      V1_INDEPENDENT = 1
    end
  end

  # Google search entry point.
  # @!attribute [rw] rendered_content
  #   @return [::String]
  #     Web content snippet that can be embedded in a web page or an app
  #     webview.
  # @!attribute [rw] sdk_blob
  #   @return [::String]
  #     Base64 encoded JSON representing array of <search term, search url>
  #     tuple.
  class SearchEntryPoint
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Grounding info for a claim in the candidate and its support.
  # @!attribute [rw] claim_text
  #   @return [::String]
  #     Text for the claim in the candidate. Always provided when a
  #     support is found.
  # @!attribute [rw] support_chunk_indices
  #   @return [::Array<::Integer>]
  #     A list of indices (into 'support_chunks') specifying the
  #     citations associated with the claim. For instance [1,3,4] means
  #     that support_chunks[1], support_chunks[3],
  #     support_chunks[4] are the chunks attributed to the claim.
  # @!attribute [rw] support_score
  #   @return [::Float]
  #     A score in the range of [0, 1] describing how grounded is a specific
  #     claim in the support chunks indicated.
  #     Higher value means that the claim is better supported by the chunks.
  class GroundingSupport
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Metadata about an image from the web search.
  # @!attribute [rw] image
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::ImageMetadata::Image]
  #     Metadata about the full size image.
  # @!attribute [rw] thumbnail
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::ImageMetadata::Image]
  #     Metadata about the thumbnail.
  # @!attribute [rw] source
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::ImageMetadata::WebsiteInfo]
  #     The details about the website that the image is from.
  class ImageMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Metadata about the website that the image is from.
    # @!attribute [rw] uri
    #   @return [::String]
    #     The url of the website.
    # @!attribute [rw] title
    #   @return [::String]
    #     The title of the website.
    # @!attribute [rw] site_display_name
    #   @return [::String]
    #     The display name of the website.
    class WebsiteInfo
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Metadata about the image.
    # @!attribute [rw] uri
    #   @return [::String]
    #     The url of the image.
    # @!attribute [rw] width
    #   @return [::Integer]
    #     The width of the image in pixels.
    # @!attribute [rw] height
    #   @return [::Integer]
    #     The height of the image in pixels.
    class Image
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # Metadata about a video from the web search.
  # @!attribute [rw] youtube_external_id
  #   @return [::String]
  #     The external id of the video.
  class VideoMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#videos::Array<::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::VideoMetadata>

Returns Videos from the web search.



358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 358

class GroundingMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes the metadata associated with a retrieval step.
  # @!attribute [rw] source
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::RetrievalMetadata::Source]
  #     Describes the source to which the metadata is referring to.
  # @!attribute [rw] dynamic_retrieval_metadata
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::DynamicRetrievalMetadata]
  #     Metadata for dynamic retrieval.
  class RetrievalMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Describes the source to which the metadata is associated to.
    module Source
      # Unspecified source.
      SOURCE_UNSPECIFIED = 0

      # Vertex AI search.
      VERTEX_AI_SEARCH = 1

      # Google Search.
      GOOGLE_SEARCH = 3

      # User inline provided content.
      INLINE_CONTENT = 2

      # Google Maps.
      GOOGLE_MAPS = 4
    end
  end

  # Describes the metadata about dynamic retrieval.
  # @!attribute [rw] predictor_metadata
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::DynamicRetrievalPredictorMetadata]
  #     Metadata for the dynamic retrieval predictor.
  class DynamicRetrievalMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Describes the metadata about the dynamic retrieval predictor.
  # @!attribute [rw] version
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::DynamicRetrievalPredictorMetadata::Version]
  #     The version of the predictor which was used in dynamic retrieval.
  # @!attribute [rw] prediction
  #   @return [::Float]
  #     The value of the predictor. This should be between [0, 1] where
  #     a value of 0 means that the query would not benefit from grounding,
  #     while a value of 1.0 means that the query would benefit the most.
  #     In between values allow to differentiate between different usefulness
  #     scores for grounding.
  class DynamicRetrievalPredictorMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The version of the predictor which was used in dynamic retrieval.
    module Version
      # Unspecified version, should never be used.
      VERSION_UNSPECIFIED = 0

      # The V1 model which is evaluating each source independently.
      V1_INDEPENDENT = 1
    end
  end

  # Google search entry point.
  # @!attribute [rw] rendered_content
  #   @return [::String]
  #     Web content snippet that can be embedded in a web page or an app
  #     webview.
  # @!attribute [rw] sdk_blob
  #   @return [::String]
  #     Base64 encoded JSON representing array of <search term, search url>
  #     tuple.
  class SearchEntryPoint
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Grounding info for a claim in the candidate and its support.
  # @!attribute [rw] claim_text
  #   @return [::String]
  #     Text for the claim in the candidate. Always provided when a
  #     support is found.
  # @!attribute [rw] support_chunk_indices
  #   @return [::Array<::Integer>]
  #     A list of indices (into 'support_chunks') specifying the
  #     citations associated with the claim. For instance [1,3,4] means
  #     that support_chunks[1], support_chunks[3],
  #     support_chunks[4] are the chunks attributed to the claim.
  # @!attribute [rw] support_score
  #   @return [::Float]
  #     A score in the range of [0, 1] describing how grounded is a specific
  #     claim in the support chunks indicated.
  #     Higher value means that the claim is better supported by the chunks.
  class GroundingSupport
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Metadata about an image from the web search.
  # @!attribute [rw] image
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::ImageMetadata::Image]
  #     Metadata about the full size image.
  # @!attribute [rw] thumbnail
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::ImageMetadata::Image]
  #     Metadata about the thumbnail.
  # @!attribute [rw] source
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::ImageMetadata::WebsiteInfo]
  #     The details about the website that the image is from.
  class ImageMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Metadata about the website that the image is from.
    # @!attribute [rw] uri
    #   @return [::String]
    #     The url of the website.
    # @!attribute [rw] title
    #   @return [::String]
    #     The title of the website.
    # @!attribute [rw] site_display_name
    #   @return [::String]
    #     The display name of the website.
    class WebsiteInfo
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Metadata about the image.
    # @!attribute [rw] uri
    #   @return [::String]
    #     The url of the image.
    # @!attribute [rw] width
    #   @return [::Integer]
    #     The width of the image in pixels.
    # @!attribute [rw] height
    #   @return [::Integer]
    #     The height of the image in pixels.
    class Image
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # Metadata about a video from the web search.
  # @!attribute [rw] youtube_external_id
  #   @return [::String]
  #     The external id of the video.
  class VideoMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#web_search_queries::Array<::String>

Returns Web search queries for the following-up web search.

Returns:

  • (::Array<::String>)

    Web search queries for the following-up web search.



358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 358

class GroundingMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes the metadata associated with a retrieval step.
  # @!attribute [rw] source
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::RetrievalMetadata::Source]
  #     Describes the source to which the metadata is referring to.
  # @!attribute [rw] dynamic_retrieval_metadata
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::DynamicRetrievalMetadata]
  #     Metadata for dynamic retrieval.
  class RetrievalMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Describes the source to which the metadata is associated to.
    module Source
      # Unspecified source.
      SOURCE_UNSPECIFIED = 0

      # Vertex AI search.
      VERTEX_AI_SEARCH = 1

      # Google Search.
      GOOGLE_SEARCH = 3

      # User inline provided content.
      INLINE_CONTENT = 2

      # Google Maps.
      GOOGLE_MAPS = 4
    end
  end

  # Describes the metadata about dynamic retrieval.
  # @!attribute [rw] predictor_metadata
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::DynamicRetrievalPredictorMetadata]
  #     Metadata for the dynamic retrieval predictor.
  class DynamicRetrievalMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Describes the metadata about the dynamic retrieval predictor.
  # @!attribute [rw] version
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::DynamicRetrievalPredictorMetadata::Version]
  #     The version of the predictor which was used in dynamic retrieval.
  # @!attribute [rw] prediction
  #   @return [::Float]
  #     The value of the predictor. This should be between [0, 1] where
  #     a value of 0 means that the query would not benefit from grounding,
  #     while a value of 1.0 means that the query would benefit the most.
  #     In between values allow to differentiate between different usefulness
  #     scores for grounding.
  class DynamicRetrievalPredictorMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The version of the predictor which was used in dynamic retrieval.
    module Version
      # Unspecified version, should never be used.
      VERSION_UNSPECIFIED = 0

      # The V1 model which is evaluating each source independently.
      V1_INDEPENDENT = 1
    end
  end

  # Google search entry point.
  # @!attribute [rw] rendered_content
  #   @return [::String]
  #     Web content snippet that can be embedded in a web page or an app
  #     webview.
  # @!attribute [rw] sdk_blob
  #   @return [::String]
  #     Base64 encoded JSON representing array of <search term, search url>
  #     tuple.
  class SearchEntryPoint
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Grounding info for a claim in the candidate and its support.
  # @!attribute [rw] claim_text
  #   @return [::String]
  #     Text for the claim in the candidate. Always provided when a
  #     support is found.
  # @!attribute [rw] support_chunk_indices
  #   @return [::Array<::Integer>]
  #     A list of indices (into 'support_chunks') specifying the
  #     citations associated with the claim. For instance [1,3,4] means
  #     that support_chunks[1], support_chunks[3],
  #     support_chunks[4] are the chunks attributed to the claim.
  # @!attribute [rw] support_score
  #   @return [::Float]
  #     A score in the range of [0, 1] describing how grounded is a specific
  #     claim in the support chunks indicated.
  #     Higher value means that the claim is better supported by the chunks.
  class GroundingSupport
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Metadata about an image from the web search.
  # @!attribute [rw] image
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::ImageMetadata::Image]
  #     Metadata about the full size image.
  # @!attribute [rw] thumbnail
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::ImageMetadata::Image]
  #     Metadata about the thumbnail.
  # @!attribute [rw] source
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::ImageMetadata::WebsiteInfo]
  #     The details about the website that the image is from.
  class ImageMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Metadata about the website that the image is from.
    # @!attribute [rw] uri
    #   @return [::String]
    #     The url of the website.
    # @!attribute [rw] title
    #   @return [::String]
    #     The title of the website.
    # @!attribute [rw] site_display_name
    #   @return [::String]
    #     The display name of the website.
    class WebsiteInfo
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Metadata about the image.
    # @!attribute [rw] uri
    #   @return [::String]
    #     The url of the image.
    # @!attribute [rw] width
    #   @return [::Integer]
    #     The width of the image in pixels.
    # @!attribute [rw] height
    #   @return [::Integer]
    #     The height of the image in pixels.
    class Image
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # Metadata about a video from the web search.
  # @!attribute [rw] youtube_external_id
  #   @return [::String]
  #     The external id of the video.
  class VideoMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end