Class: Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::ImageMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb

Overview

Metadata about an image from the web search.

Defined Under Namespace

Classes: Image, WebsiteInfo

Instance Attribute Summary collapse

Instance Attribute Details

#image::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::ImageMetadata::Image

Returns Metadata about the full size image.



471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 471

class ImageMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Metadata about the website that the image is from.
  # @!attribute [rw] uri
  #   @return [::String]
  #     The url of the website.
  # @!attribute [rw] title
  #   @return [::String]
  #     The title of the website.
  # @!attribute [rw] site_display_name
  #   @return [::String]
  #     The display name of the website.
  class WebsiteInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Metadata about the image.
  # @!attribute [rw] uri
  #   @return [::String]
  #     The url of the image.
  # @!attribute [rw] width
  #   @return [::Integer]
  #     The width of the image in pixels.
  # @!attribute [rw] height
  #   @return [::Integer]
  #     The height of the image in pixels.
  class Image
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#source::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::ImageMetadata::WebsiteInfo

Returns The details about the website that the image is from.



471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 471

class ImageMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Metadata about the website that the image is from.
  # @!attribute [rw] uri
  #   @return [::String]
  #     The url of the website.
  # @!attribute [rw] title
  #   @return [::String]
  #     The title of the website.
  # @!attribute [rw] site_display_name
  #   @return [::String]
  #     The display name of the website.
  class WebsiteInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Metadata about the image.
  # @!attribute [rw] uri
  #   @return [::String]
  #     The url of the image.
  # @!attribute [rw] width
  #   @return [::Integer]
  #     The width of the image in pixels.
  # @!attribute [rw] height
  #   @return [::Integer]
  #     The height of the image in pixels.
  class Image
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#thumbnail::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::ImageMetadata::Image

Returns Metadata about the thumbnail.



471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 471

class ImageMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Metadata about the website that the image is from.
  # @!attribute [rw] uri
  #   @return [::String]
  #     The url of the website.
  # @!attribute [rw] title
  #   @return [::String]
  #     The title of the website.
  # @!attribute [rw] site_display_name
  #   @return [::String]
  #     The display name of the website.
  class WebsiteInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Metadata about the image.
  # @!attribute [rw] uri
  #   @return [::String]
  #     The url of the image.
  # @!attribute [rw] width
  #   @return [::Integer]
  #     The width of the image in pixels.
  # @!attribute [rw] height
  #   @return [::Integer]
  #     The height of the image in pixels.
  class Image
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end