Class: Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::RetrievalMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb

Overview

Describes the metadata associated with a retrieval step.

Defined Under Namespace

Modules: Source

Instance Attribute Summary collapse

Instance Attribute Details

#dynamic_retrieval_metadata::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::DynamicRetrievalMetadata

Returns Metadata for dynamic retrieval.



369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 369

class RetrievalMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes the source to which the metadata is associated to.
  module Source
    # Unspecified source.
    SOURCE_UNSPECIFIED = 0

    # Vertex AI search.
    VERTEX_AI_SEARCH = 1

    # Google Search.
    GOOGLE_SEARCH = 3

    # User inline provided content.
    INLINE_CONTENT = 2

    # Google Maps.
    GOOGLE_MAPS = 4
  end
end

#source::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentResponse::Candidate::GroundingMetadata::RetrievalMetadata::Source

Returns Describes the source to which the metadata is referring to.



369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 369

class RetrievalMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes the source to which the metadata is associated to.
  module Source
    # Unspecified source.
    SOURCE_UNSPECIFIED = 0

    # Vertex AI search.
    VERTEX_AI_SEARCH = 1

    # Google Search.
    GOOGLE_SEARCH = 3

    # User inline provided content.
    INLINE_CONTENT = 2

    # Google Maps.
    GOOGLE_MAPS = 4
  end
end