Class: Google::Cloud::DiscoveryEngine::V1beta::GetAclConfigRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/acl_config_service.rb

Overview

Request message for GetAclConfigRequest method.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. Resource name of AclConfig, such as projects/*/locations/*/aclConfig.

If the caller does not have permission to access the AclConfig, regardless of whether or not it exists, a PERMISSION_DENIED error is returned.

Returns:

  • (::String)

    Required. Resource name of AclConfig, such as projects/*/locations/*/aclConfig.

    If the caller does not have permission to access the AclConfig, regardless of whether or not it exists, a PERMISSION_DENIED error is returned.



34
35
36
37
# File 'proto_docs/google/cloud/discoveryengine/v1beta/acl_config_service.rb', line 34

class GetAclConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end