Class: Google::Cloud::DiscoveryEngine::V1beta::GetLicenseConfigRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/license_config_service.rb

Overview

Request message for LicenseConfigService.GetLicenseConfig method.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Required. Full resource name of LicenseConfig, such as projects/{project}/locations/{location}/licenseConfigs/*.

If the caller does not have permission to access the LicenseConfig, regardless of whether or not it exists, a PERMISSION_DENIED error is returned.

If the requested LicenseConfig does not exist, a NOT_FOUND error is returned.

Returns:

  • (::String)

    Required. Full resource name of LicenseConfig, such as projects/{project}/locations/{location}/licenseConfigs/*.

    If the caller does not have permission to access the LicenseConfig, regardless of whether or not it exists, a PERMISSION_DENIED error is returned.

    If the requested LicenseConfig does not exist, a NOT_FOUND error is returned.



87
88
89
90
# File 'proto_docs/google/cloud/discoveryengine/v1beta/license_config_service.rb', line 87

class GetLicenseConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end