Class: Google::Cloud::DiscoveryEngine::V1beta::LicenseConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/license_config.rb

Overview

Information about users' licenses.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#auto_renew::Boolean

Returns Optional. Whether the license config should be auto renewed when it reaches the end date.

Returns:

  • (::Boolean)

    Optional. Whether the license config should be auto renewed when it reaches the end date.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'proto_docs/google/cloud/discoveryengine/v1beta/license_config.rb', line 67

class LicenseConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # License config state enumeration.
  module State
    # Default value. The license config does not exist.
    STATE_UNSPECIFIED = 0

    # The license config is effective and being used.
    ACTIVE = 1

    # The license config has expired.
    EXPIRED = 2

    # The license config has not started yet, and its start date is in the
    # future.
    NOT_STARTED = 3

    # This is when a sub license config has returned all its seats back to
    # BillingAccountLicenseConfig that it belongs to.
    # Similar to EXPIRED.
    WITHDRAWN = 4

    # The license config is terminated earlier than the expiration date and it
    # is deactivating. The customer will still have access in this state. It
    # will be converted to EXPIRED after the deactivating period ends (14 days)
    # or when the end date is reached, whichever comes first.
    DEACTIVATING = 5
  end
end

#early_terminated::Boolean (readonly)

Returns Output only. Indication of whether the subscription is terminated earlier than the expiration date. This is usually terminated by pipeline once the subscription gets terminated from subsv3.

Returns:

  • (::Boolean)

    Output only. Indication of whether the subscription is terminated earlier than the expiration date. This is usually terminated by pipeline once the subscription gets terminated from subsv3.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'proto_docs/google/cloud/discoveryengine/v1beta/license_config.rb', line 67

class LicenseConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # License config state enumeration.
  module State
    # Default value. The license config does not exist.
    STATE_UNSPECIFIED = 0

    # The license config is effective and being used.
    ACTIVE = 1

    # The license config has expired.
    EXPIRED = 2

    # The license config has not started yet, and its start date is in the
    # future.
    NOT_STARTED = 3

    # This is when a sub license config has returned all its seats back to
    # BillingAccountLicenseConfig that it belongs to.
    # Similar to EXPIRED.
    WITHDRAWN = 4

    # The license config is terminated earlier than the expiration date and it
    # is deactivating. The customer will still have access in this state. It
    # will be converted to EXPIRED after the deactivating period ends (14 days)
    # or when the end date is reached, whichever comes first.
    DEACTIVATING = 5
  end
end

#early_termination_date::Google::Type::Date (readonly)

Returns Output only. The date when the subscription is terminated earlier than the expiration date.

Returns:

  • (::Google::Type::Date)

    Output only. The date when the subscription is terminated earlier than the expiration date.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'proto_docs/google/cloud/discoveryengine/v1beta/license_config.rb', line 67

class LicenseConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # License config state enumeration.
  module State
    # Default value. The license config does not exist.
    STATE_UNSPECIFIED = 0

    # The license config is effective and being used.
    ACTIVE = 1

    # The license config has expired.
    EXPIRED = 2

    # The license config has not started yet, and its start date is in the
    # future.
    NOT_STARTED = 3

    # This is when a sub license config has returned all its seats back to
    # BillingAccountLicenseConfig that it belongs to.
    # Similar to EXPIRED.
    WITHDRAWN = 4

    # The license config is terminated earlier than the expiration date and it
    # is deactivating. The customer will still have access in this state. It
    # will be converted to EXPIRED after the deactivating period ends (14 days)
    # or when the end date is reached, whichever comes first.
    DEACTIVATING = 5
  end
end

#end_date::Google::Type::Date

Returns Optional. The planed end date.

Returns:



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'proto_docs/google/cloud/discoveryengine/v1beta/license_config.rb', line 67

class LicenseConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # License config state enumeration.
  module State
    # Default value. The license config does not exist.
    STATE_UNSPECIFIED = 0

    # The license config is effective and being used.
    ACTIVE = 1

    # The license config has expired.
    EXPIRED = 2

    # The license config has not started yet, and its start date is in the
    # future.
    NOT_STARTED = 3

    # This is when a sub license config has returned all its seats back to
    # BillingAccountLicenseConfig that it belongs to.
    # Similar to EXPIRED.
    WITHDRAWN = 4

    # The license config is terminated earlier than the expiration date and it
    # is deactivating. The customer will still have access in this state. It
    # will be converted to EXPIRED after the deactivating period ends (14 days)
    # or when the end date is reached, whichever comes first.
    DEACTIVATING = 5
  end
end

#free_trial::Boolean

Returns Optional. Whether the license config is for free trial.

Returns:

  • (::Boolean)

    Optional. Whether the license config is for free trial.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'proto_docs/google/cloud/discoveryengine/v1beta/license_config.rb', line 67

class LicenseConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # License config state enumeration.
  module State
    # Default value. The license config does not exist.
    STATE_UNSPECIFIED = 0

    # The license config is effective and being used.
    ACTIVE = 1

    # The license config has expired.
    EXPIRED = 2

    # The license config has not started yet, and its start date is in the
    # future.
    NOT_STARTED = 3

    # This is when a sub license config has returned all its seats back to
    # BillingAccountLicenseConfig that it belongs to.
    # Similar to EXPIRED.
    WITHDRAWN = 4

    # The license config is terminated earlier than the expiration date and it
    # is deactivating. The customer will still have access in this state. It
    # will be converted to EXPIRED after the deactivating period ends (14 days)
    # or when the end date is reached, whichever comes first.
    DEACTIVATING = 5
  end
end

#gemini_bundle::Boolean (readonly)

Returns Output only. Whether the license config is for Gemini bundle.

Returns:

  • (::Boolean)

    Output only. Whether the license config is for Gemini bundle.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'proto_docs/google/cloud/discoveryengine/v1beta/license_config.rb', line 67

class LicenseConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # License config state enumeration.
  module State
    # Default value. The license config does not exist.
    STATE_UNSPECIFIED = 0

    # The license config is effective and being used.
    ACTIVE = 1

    # The license config has expired.
    EXPIRED = 2

    # The license config has not started yet, and its start date is in the
    # future.
    NOT_STARTED = 3

    # This is when a sub license config has returned all its seats back to
    # BillingAccountLicenseConfig that it belongs to.
    # Similar to EXPIRED.
    WITHDRAWN = 4

    # The license config is terminated earlier than the expiration date and it
    # is deactivating. The customer will still have access in this state. It
    # will be converted to EXPIRED after the deactivating period ends (14 days)
    # or when the end date is reached, whichever comes first.
    DEACTIVATING = 5
  end
end

#license_count::Integer

Returns Required. Number of licenses purchased.

Returns:

  • (::Integer)

    Required. Number of licenses purchased.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'proto_docs/google/cloud/discoveryengine/v1beta/license_config.rb', line 67

class LicenseConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # License config state enumeration.
  module State
    # Default value. The license config does not exist.
    STATE_UNSPECIFIED = 0

    # The license config is effective and being used.
    ACTIVE = 1

    # The license config has expired.
    EXPIRED = 2

    # The license config has not started yet, and its start date is in the
    # future.
    NOT_STARTED = 3

    # This is when a sub license config has returned all its seats back to
    # BillingAccountLicenseConfig that it belongs to.
    # Similar to EXPIRED.
    WITHDRAWN = 4

    # The license config is terminated earlier than the expiration date and it
    # is deactivating. The customer will still have access in this state. It
    # will be converted to EXPIRED after the deactivating period ends (14 days)
    # or when the end date is reached, whichever comes first.
    DEACTIVATING = 5
  end
end

#name::String

Returns Immutable. Identifier. The fully qualified resource name of the license config. Format: projects/{project}/locations/{location}/licenseConfigs/{license_config}.

Returns:

  • (::String)

    Immutable. Identifier. The fully qualified resource name of the license config. Format: projects/{project}/locations/{location}/licenseConfigs/{license_config}



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'proto_docs/google/cloud/discoveryengine/v1beta/license_config.rb', line 67

class LicenseConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # License config state enumeration.
  module State
    # Default value. The license config does not exist.
    STATE_UNSPECIFIED = 0

    # The license config is effective and being used.
    ACTIVE = 1

    # The license config has expired.
    EXPIRED = 2

    # The license config has not started yet, and its start date is in the
    # future.
    NOT_STARTED = 3

    # This is when a sub license config has returned all its seats back to
    # BillingAccountLicenseConfig that it belongs to.
    # Similar to EXPIRED.
    WITHDRAWN = 4

    # The license config is terminated earlier than the expiration date and it
    # is deactivating. The customer will still have access in this state. It
    # will be converted to EXPIRED after the deactivating period ends (14 days)
    # or when the end date is reached, whichever comes first.
    DEACTIVATING = 5
  end
end

#start_date::Google::Type::Date

Returns Required. The start date.

Returns:



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'proto_docs/google/cloud/discoveryengine/v1beta/license_config.rb', line 67

class LicenseConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # License config state enumeration.
  module State
    # Default value. The license config does not exist.
    STATE_UNSPECIFIED = 0

    # The license config is effective and being used.
    ACTIVE = 1

    # The license config has expired.
    EXPIRED = 2

    # The license config has not started yet, and its start date is in the
    # future.
    NOT_STARTED = 3

    # This is when a sub license config has returned all its seats back to
    # BillingAccountLicenseConfig that it belongs to.
    # Similar to EXPIRED.
    WITHDRAWN = 4

    # The license config is terminated earlier than the expiration date and it
    # is deactivating. The customer will still have access in this state. It
    # will be converted to EXPIRED after the deactivating period ends (14 days)
    # or when the end date is reached, whichever comes first.
    DEACTIVATING = 5
  end
end

#state::Google::Cloud::DiscoveryEngine::V1beta::LicenseConfig::State (readonly)

Returns Output only. The state of the license config.

Returns:



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'proto_docs/google/cloud/discoveryengine/v1beta/license_config.rb', line 67

class LicenseConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # License config state enumeration.
  module State
    # Default value. The license config does not exist.
    STATE_UNSPECIFIED = 0

    # The license config is effective and being used.
    ACTIVE = 1

    # The license config has expired.
    EXPIRED = 2

    # The license config has not started yet, and its start date is in the
    # future.
    NOT_STARTED = 3

    # This is when a sub license config has returned all its seats back to
    # BillingAccountLicenseConfig that it belongs to.
    # Similar to EXPIRED.
    WITHDRAWN = 4

    # The license config is terminated earlier than the expiration date and it
    # is deactivating. The customer will still have access in this state. It
    # will be converted to EXPIRED after the deactivating period ends (14 days)
    # or when the end date is reached, whichever comes first.
    DEACTIVATING = 5
  end
end

#subscription_term::Google::Cloud::DiscoveryEngine::V1beta::SubscriptionTerm

Returns Required. Subscription term.

Returns:



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'proto_docs/google/cloud/discoveryengine/v1beta/license_config.rb', line 67

class LicenseConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # License config state enumeration.
  module State
    # Default value. The license config does not exist.
    STATE_UNSPECIFIED = 0

    # The license config is effective and being used.
    ACTIVE = 1

    # The license config has expired.
    EXPIRED = 2

    # The license config has not started yet, and its start date is in the
    # future.
    NOT_STARTED = 3

    # This is when a sub license config has returned all its seats back to
    # BillingAccountLicenseConfig that it belongs to.
    # Similar to EXPIRED.
    WITHDRAWN = 4

    # The license config is terminated earlier than the expiration date and it
    # is deactivating. The customer will still have access in this state. It
    # will be converted to EXPIRED after the deactivating period ends (14 days)
    # or when the end date is reached, whichever comes first.
    DEACTIVATING = 5
  end
end

#subscription_tier::Google::Cloud::DiscoveryEngine::V1beta::SubscriptionTier

Returns Required. Subscription tier information for the license config.

Returns:



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'proto_docs/google/cloud/discoveryengine/v1beta/license_config.rb', line 67

class LicenseConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # License config state enumeration.
  module State
    # Default value. The license config does not exist.
    STATE_UNSPECIFIED = 0

    # The license config is effective and being used.
    ACTIVE = 1

    # The license config has expired.
    EXPIRED = 2

    # The license config has not started yet, and its start date is in the
    # future.
    NOT_STARTED = 3

    # This is when a sub license config has returned all its seats back to
    # BillingAccountLicenseConfig that it belongs to.
    # Similar to EXPIRED.
    WITHDRAWN = 4

    # The license config is terminated earlier than the expiration date and it
    # is deactivating. The customer will still have access in this state. It
    # will be converted to EXPIRED after the deactivating period ends (14 days)
    # or when the end date is reached, whichever comes first.
    DEACTIVATING = 5
  end
end