Module: Google::Cloud::DiscoveryEngine::V1beta::LicenseConfig::State
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/license_config.rb
Overview
License config state enumeration.
Constant Summary collapse
- STATE_UNSPECIFIED =
Default value. The license config does not exist.
0- ACTIVE =
The license config is effective and being used.
1- EXPIRED =
The license config has expired.
2- NOT_STARTED =
The license config has not started yet, and its start date is in the future.
3- WITHDRAWN =
This is when a sub license config has returned all its seats back to BillingAccountLicenseConfig that it belongs to. Similar to EXPIRED.
4- DEACTIVATING =
The license config is terminated earlier than the expiration date and it is deactivating. The customer will still have access in this state. It will be converted to EXPIRED after the deactivating period ends (14 days) or when the end date is reached, whichever comes first.
5