Class: Google::Cloud::DiscoveryEngine::V1beta::LicenseConfigService::Rest::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/discovery_engine/v1beta/license_config_service/rest/client.rb

Overview

REST client for the LicenseConfigService service.

Service for managing license config related resources.

Defined Under Namespace

Classes: Configuration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#billing_account_license_config_path, #license_config_path, #location_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new LicenseConfigService REST client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::DiscoveryEngine::V1beta::LicenseConfigService::Rest::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::DiscoveryEngine::V1beta::LicenseConfigService::Rest::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the LicenseConfigService client.

Yield Parameters:



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/google/cloud/discovery_engine/v1beta/license_config_service/rest/client.rb', line 127

def initialize
  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end

  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @license_config_service_stub = ::Google::Cloud::DiscoveryEngine::V1beta::LicenseConfigService::Rest::ServiceStub.new(
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    credentials: credentials,
    logger: @config.logger
  )

  @license_config_service_stub.logger(stub: true)&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end

  @location_client = Google::Cloud::Location::Locations::Rest::Client.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @license_config_service_stub.endpoint
    config.universe_domain = @license_config_service_stub.universe_domain
    config.logger = @license_config_service_stub.logger if config.respond_to? :logger=
  end
end

Instance Attribute Details

#location_clientGoogle::Cloud::Location::Locations::Rest::Client (readonly)

Get the associated client for mix-in of the Locations.

Returns:

  • (Google::Cloud::Location::Locations::Rest::Client)


182
183
184
# File 'lib/google/cloud/discovery_engine/v1beta/license_config_service/rest/client.rb', line 182

def location_client
  @location_client
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the LicenseConfigService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all LicenseConfigService clients
::Google::Cloud::DiscoveryEngine::V1beta::LicenseConfigService::Rest::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/google/cloud/discovery_engine/v1beta/license_config_service/rest/client.rb', line 65

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "DiscoveryEngine", "V1beta"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the LicenseConfigService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



97
98
99
100
# File 'lib/google/cloud/discovery_engine/v1beta/license_config_service/rest/client.rb', line 97

def configure
  yield @config if block_given?
  @config
end

#create_license_config(request, options = nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::LicenseConfig #create_license_config(parent: nil, license_config: nil, license_config_id: nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::LicenseConfig

Creates a LicenseConfig This method should only be used for creating NotebookLm licenses or Gemini Enterprise free trial licenses.

Examples:

Basic example

require "google/cloud/discovery_engine/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::DiscoveryEngine::V1beta::LicenseConfigService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::DiscoveryEngine::V1beta::CreateLicenseConfigRequest.new

# Call the create_license_config method.
result = client.create_license_config request

# The returned object is of type Google::Cloud::DiscoveryEngine::V1beta::LicenseConfig.
p result

Overloads:

  • #create_license_config(request, options = nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::LicenseConfig

    Pass arguments to create_license_config via a request object, either of type CreateLicenseConfigRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::DiscoveryEngine::V1beta::CreateLicenseConfigRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #create_license_config(parent: nil, license_config: nil, license_config_id: nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::LicenseConfig

    Pass arguments to create_license_config via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent resource name, such as projects/{project}/locations/{location}.

    • license_config (::Google::Cloud::DiscoveryEngine::V1beta::LicenseConfig, ::Hash) (defaults to: nil)

      Required. The LicenseConfig to create.

    • license_config_id (::String) (defaults to: nil)

      Optional. The ID to use for the LicenseConfig, which will become the final component of the LicenseConfig's resource name. We are using the tier (product edition) name as the license config id such as search or search_and_assistant.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/google/cloud/discovery_engine/v1beta/license_config_service/rest/client.rb', line 253

def create_license_config request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::DiscoveryEngine::V1beta::CreateLicenseConfigRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_license_config..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::DiscoveryEngine::V1beta::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.create_license_config.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_license_config.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @license_config_service_stub.create_license_config request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#distribute_license_config(request, options = nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::DistributeLicenseConfigResponse #distribute_license_config(billing_account_license_config: nil, project_number: nil, location: nil, license_count: nil, license_config_id: nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::DistributeLicenseConfigResponse

Distributes a LicenseConfig from billing account level to project level.

Examples:

Basic example

require "google/cloud/discovery_engine/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::DiscoveryEngine::V1beta::LicenseConfigService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::DiscoveryEngine::V1beta::DistributeLicenseConfigRequest.new

# Call the distribute_license_config method.
result = client.distribute_license_config request

# The returned object is of type Google::Cloud::DiscoveryEngine::V1beta::DistributeLicenseConfigResponse.
p result

Overloads:

  • #distribute_license_config(request, options = nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::DistributeLicenseConfigResponse

    Pass arguments to distribute_license_config via a request object, either of type DistributeLicenseConfigRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::DiscoveryEngine::V1beta::DistributeLicenseConfigRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #distribute_license_config(billing_account_license_config: nil, project_number: nil, location: nil, license_count: nil, license_config_id: nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::DistributeLicenseConfigResponse

    Pass arguments to distribute_license_config via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • billing_account_license_config (::String) (defaults to: nil)

      Required. Full resource name of [BillingAccountLicenseConfig][].

      Format: billingAccounts/{billing_account}/billingAccountLicenseConfigs/{billing_account_license_config_id}.

    • project_number (::Integer) (defaults to: nil)

      Required. The target GCP project number to distribute the license config to.

    • location (::String) (defaults to: nil)

      Required. The target GCP project region to distribute the license config to.

    • license_count (::Integer) (defaults to: nil)

      Required. The number of licenses to distribute.

    • license_config_id (::String) (defaults to: nil)

      Optional. Distribute seats to this license config instead of creating a new one. If not specified, a new license config will be created from the billing account license config.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
# File 'lib/google/cloud/discovery_engine/v1beta/license_config_service/rest/client.rb', line 631

def distribute_license_config request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::DiscoveryEngine::V1beta::DistributeLicenseConfigRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.distribute_license_config..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::DiscoveryEngine::V1beta::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.distribute_license_config.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.distribute_license_config.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @license_config_service_stub.distribute_license_config request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_license_config(request, options = nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::LicenseConfig #get_license_config(name: nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::LicenseConfig

Gets a LicenseConfig.

Examples:

Basic example

require "google/cloud/discovery_engine/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::DiscoveryEngine::V1beta::LicenseConfigService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::DiscoveryEngine::V1beta::GetLicenseConfigRequest.new

# Call the get_license_config method.
result = client.get_license_config request

# The returned object is of type Google::Cloud::DiscoveryEngine::V1beta::LicenseConfig.
p result

Overloads:

  • #get_license_config(request, options = nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::LicenseConfig

    Pass arguments to get_license_config via a request object, either of type GetLicenseConfigRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::DiscoveryEngine::V1beta::GetLicenseConfigRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_license_config(name: nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::LicenseConfig

    Pass arguments to get_license_config via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. Full resource name of LicenseConfig, such as projects/{project}/locations/{location}/licenseConfigs/*.

      If the caller does not have permission to access the LicenseConfig, regardless of whether or not it exists, a PERMISSION_DENIED error is returned.

      If the requested LicenseConfig does not exist, a NOT_FOUND error is returned.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
# File 'lib/google/cloud/discovery_engine/v1beta/license_config_service/rest/client.rb', line 430

def get_license_config request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::DiscoveryEngine::V1beta::GetLicenseConfigRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_license_config..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::DiscoveryEngine::V1beta::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_license_config.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_license_config.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @license_config_service_stub.get_license_config request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_license_configs(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::DiscoveryEngine::V1beta::LicenseConfig> #list_license_configs(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::DiscoveryEngine::V1beta::LicenseConfig>

Lists all the LicenseConfigs associated with the project.

Examples:

Basic example

require "google/cloud/discovery_engine/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::DiscoveryEngine::V1beta::LicenseConfigService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::DiscoveryEngine::V1beta::ListLicenseConfigsRequest.new

# Call the list_license_configs method.
result = client.list_license_configs request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::DiscoveryEngine::V1beta::LicenseConfig.
  p item
end

Overloads:

  • #list_license_configs(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::DiscoveryEngine::V1beta::LicenseConfig>

    Pass arguments to list_license_configs via a request object, either of type Google::Cloud::DiscoveryEngine::V1beta::ListLicenseConfigsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::DiscoveryEngine::V1beta::ListLicenseConfigsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_license_configs(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::DiscoveryEngine::V1beta::LicenseConfig>

    Pass arguments to list_license_configs via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent branch resource name, such as projects/{project}/locations/{location}.

    • page_size (::Integer) (defaults to: nil)

      Optional. Not supported.

    • page_token (::String) (defaults to: nil)

      Optional. Not supported.

    • filter (::String) (defaults to: nil)

      Optional. The filter to apply to the list results.

      The supported fields are:

      • subscription_tier
      • state

      Examples:

      • subscription_tier=SUBSCRIPTION_TIER_SEARCH,state=ACTIVE - Lists all active search license configs.
      • state=ACTIVE - Lists all active license configs.

      The filter string should be a comma-separated list of field=value pairs.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
# File 'lib/google/cloud/discovery_engine/v1beta/license_config_service/rest/client.rb', line 534

def list_license_configs request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::DiscoveryEngine::V1beta::ListLicenseConfigsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_license_configs..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::DiscoveryEngine::V1beta::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_license_configs.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_license_configs.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @license_config_service_stub.list_license_configs request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @license_config_service_stub, :list_license_configs, "license_configs", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


189
190
191
# File 'lib/google/cloud/discovery_engine/v1beta/license_config_service/rest/client.rb', line 189

def logger
  @license_config_service_stub.logger
end

#retract_license_config(request, options = nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::RetractLicenseConfigResponse #retract_license_config(billing_account_license_config: nil, license_config: nil, full_retract: nil, license_count: nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::RetractLicenseConfigResponse

This method is called from the billing account side to retract the LicenseConfig from the given project back to the billing account.

Examples:

Basic example

require "google/cloud/discovery_engine/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::DiscoveryEngine::V1beta::LicenseConfigService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::DiscoveryEngine::V1beta::RetractLicenseConfigRequest.new

# Call the retract_license_config method.
result = client.retract_license_config request

# The returned object is of type Google::Cloud::DiscoveryEngine::V1beta::RetractLicenseConfigResponse.
p result

Overloads:

  • #retract_license_config(request, options = nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::RetractLicenseConfigResponse

    Pass arguments to retract_license_config via a request object, either of type RetractLicenseConfigRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::DiscoveryEngine::V1beta::RetractLicenseConfigRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #retract_license_config(billing_account_license_config: nil, license_config: nil, full_retract: nil, license_count: nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::RetractLicenseConfigResponse

    Pass arguments to retract_license_config via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • billing_account_license_config (::String) (defaults to: nil)

      Required. Full resource name of [BillingAccountLicenseConfig][].

      Format: billingAccounts/{billing_account}/billingAccountLicenseConfigs/{billing_account_license_config_id}.

    • license_config (::String) (defaults to: nil)

      Required. Full resource name of LicenseConfig.

      Format: projects/{project}/locations/{location}/licenseConfigs/{license_config_id}.

    • full_retract (::Boolean) (defaults to: nil)

      Optional. If set to true, retract the entire license config. Otherwise, retract the specified license count.

    • license_count (::Integer) (defaults to: nil)

      Optional. The number of licenses to retract. Only used when full_retract is false.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
# File 'lib/google/cloud/discovery_engine/v1beta/license_config_service/rest/client.rb', line 726

def retract_license_config request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::DiscoveryEngine::V1beta::RetractLicenseConfigRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.retract_license_config..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::DiscoveryEngine::V1beta::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.retract_license_config.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.retract_license_config.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @license_config_service_stub.retract_license_config request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


107
108
109
# File 'lib/google/cloud/discovery_engine/v1beta/license_config_service/rest/client.rb', line 107

def universe_domain
  @license_config_service_stub.universe_domain
end

#update_license_config(request, options = nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::LicenseConfig #update_license_config(license_config: nil, update_mask: nil) ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::LicenseConfig

Updates the LicenseConfig

Examples:

Basic example

require "google/cloud/discovery_engine/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::DiscoveryEngine::V1beta::LicenseConfigService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::DiscoveryEngine::V1beta::UpdateLicenseConfigRequest.new

# Call the update_license_config method.
result = client.update_license_config request

# The returned object is of type Google::Cloud::DiscoveryEngine::V1beta::LicenseConfig.
p result

Overloads:

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/google/cloud/discovery_engine/v1beta/license_config_service/rest/client.rb', line 341

def update_license_config request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::DiscoveryEngine::V1beta::UpdateLicenseConfigRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_license_config..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::DiscoveryEngine::V1beta::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.update_license_config.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_license_config.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @license_config_service_stub.update_license_config request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end