Class: Google::Cloud::DiscoveryEngine::V1beta::ListIdentityMappingStoresRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/identity_mapping_store_service.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Maximum number of IdentityMappingStores to return. If unspecified, defaults to 100. The maximum allowed value is 1000. Values above 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    Maximum number of IdentityMappingStores to return. If unspecified, defaults to 100. The maximum allowed value is 1000. Values above 1000 will be coerced to 1000.



225
226
227
228
# File 'proto_docs/google/cloud/discoveryengine/v1beta/identity_mapping_store_service.rb', line 225

class ListIdentityMappingStoresRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns A page token, received from a previous ListIdentityMappingStores call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to ListIdentityMappingStores must match the call that provided the page token.

Returns:

  • (::String)

    A page token, received from a previous ListIdentityMappingStores call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to ListIdentityMappingStores must match the call that provided the page token.



225
226
227
228
# File 'proto_docs/google/cloud/discoveryengine/v1beta/identity_mapping_store_service.rb', line 225

class ListIdentityMappingStoresRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent of the Identity Mapping Stores to list. Format: projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. The parent of the Identity Mapping Stores to list. Format: projects/{project}/locations/{location}.



225
226
227
228
# File 'proto_docs/google/cloud/discoveryengine/v1beta/identity_mapping_store_service.rb', line 225

class ListIdentityMappingStoresRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end