Class: Google::Cloud::DiscoveryEngine::V1beta::ListIdentityMappingsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::ListIdentityMappingsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/identity_mapping_store_service.rb
Overview
Request message for IdentityMappingStoreService.ListIdentityMappings
Instance Attribute Summary collapse
-
#identity_mapping_store ⇒ ::String
Required.
-
#page_size ⇒ ::Integer
Maximum number of IdentityMappings to return.
-
#page_token ⇒ ::String
A page token, received from a previous
ListIdentityMappingscall.
Instance Attribute Details
#identity_mapping_store ⇒ ::String
Returns Required. The name of the Identity Mapping Store to list Identity Mapping
Entries in. Format:
projects/{project}/locations/{location}/identityMappingStores/{identityMappingStore}.
186 187 188 189 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/identity_mapping_store_service.rb', line 186 class ListIdentityMappingsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Maximum number of IdentityMappings to return. If unspecified, defaults to 2000. The maximum allowed value is 10000. Values above 10000 will be coerced to 10000.
186 187 188 189 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/identity_mapping_store_service.rb', line 186 class ListIdentityMappingsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns A page token, received from a previous ListIdentityMappings call.
Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to
ListIdentityMappings must match the call that provided the page
token.
186 187 188 189 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/identity_mapping_store_service.rb', line 186 class ListIdentityMappingsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |