Class: Google::Cloud::DiscoveryEngine::V1beta::ListIdentityMappingsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/identity_mapping_store_service.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#identity_mapping_entries::Array<::Google::Cloud::DiscoveryEngine::V1beta::IdentityMappingEntry>

Returns The Identity Mapping Entries.

Returns:



200
201
202
203
# File 'proto_docs/google/cloud/discoveryengine/v1beta/identity_mapping_store_service.rb', line 200

class ListIdentityMappingsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



200
201
202
203
# File 'proto_docs/google/cloud/discoveryengine/v1beta/identity_mapping_store_service.rb', line 200

class ListIdentityMappingsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end