Class: Google::Cloud::DiscoveryEngine::V1beta::ListSessionsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/conversational_search_service.rb

Overview

Request for ListSessions method.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns A comma-separated list of fields to filter by, in EBNF grammar.

The supported fields are:

  • user_pseudo_id
  • state
  • display_name
  • starred
  • is_pinned
  • labels
  • create_time
  • update_time
  • collaborative_project

Examples:

  • user_pseudo_id = some_id
  • display_name = "some_name"
  • starred = true
  • is_pinned=true AND (NOT labels:hidden)
  • create_time > "1970-01-01T12:00:00Z"
  • collaborative_project = "projects/123/locations/global/collections/default_collection/engines/" "default_engine/collaborative_projects/cp1".

Returns:

  • (::String)

    A comma-separated list of fields to filter by, in EBNF grammar.

    The supported fields are:

    • user_pseudo_id
    • state
    • display_name
    • starred
    • is_pinned
    • labels
    • create_time
    • update_time
    • collaborative_project

    Examples:

    • user_pseudo_id = some_id
    • display_name = "some_name"
    • starred = true
    • is_pinned=true AND (NOT labels:hidden)
    • create_time > "1970-01-01T12:00:00Z"
    • collaborative_project = "projects/123/locations/global/collections/default_collection/engines/" "default_engine/collaborative_projects/cp1"


1022
1023
1024
1025
# File 'proto_docs/google/cloud/discoveryengine/v1beta/conversational_search_service.rb', line 1022

class ListSessionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns A comma-separated list of fields to order by, sorted in ascending order. Use "desc" after a field name for descending.

Supported fields:

  • update_time
  • create_time
  • session_name
  • is_pinned
  • display_name

Example:

  • update_time desc
  • create_time
  • is_pinned desc,update_time desc: list sessions by is_pinned first, then by update_time.

Returns:

  • (::String)

    A comma-separated list of fields to order by, sorted in ascending order. Use "desc" after a field name for descending.

    Supported fields:

    • update_time
    • create_time
    • session_name
    • is_pinned
    • display_name

    Example:

    • update_time desc
    • create_time
    • is_pinned desc,update_time desc: list sessions by is_pinned first, then by update_time.


1022
1023
1024
1025
# File 'proto_docs/google/cloud/discoveryengine/v1beta/conversational_search_service.rb', line 1022

class ListSessionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Maximum number of results to return. If unspecified, defaults to 50. Max allowed value is 1000.

Returns:

  • (::Integer)

    Maximum number of results to return. If unspecified, defaults to 50. Max allowed value is 1000.



1022
1023
1024
1025
# File 'proto_docs/google/cloud/discoveryengine/v1beta/conversational_search_service.rb', line 1022

class ListSessionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns A page token, received from a previous ListSessions call. Provide this to retrieve the subsequent page.

Returns:

  • (::String)

    A page token, received from a previous ListSessions call. Provide this to retrieve the subsequent page.



1022
1023
1024
1025
# File 'proto_docs/google/cloud/discoveryengine/v1beta/conversational_search_service.rb', line 1022

class ListSessionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The data store resource name. Format: projects/{project}/locations/{location}/collections/{collection}/dataStores/{data_store_id}.

Returns:

  • (::String)

    Required. The data store resource name. Format: projects/{project}/locations/{location}/collections/{collection}/dataStores/{data_store_id}



1022
1023
1024
1025
# File 'proto_docs/google/cloud/discoveryengine/v1beta/conversational_search_service.rb', line 1022

class ListSessionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end