Class: Google::Cloud::DiscoveryEngine::V1beta::ListUserLicensesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/user_license_service.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Filter for the list request.

Supported fields:

  • license_assignment_state
  • user_principal * Examples:

  • license_assignment_state = ASSIGNED to list assigned user licenses.

  • license_assignment_state = NO_LICENSE to list not licensed users.

  • license_assignment_state = NO_LICENSE_ATTEMPTED_LOGIN to list users who attempted login but no license assigned.

  • license_assignment_state != NO_LICENSE_ATTEMPTED_LOGIN to filter out users who attempted login but no license assigned.

  • user_principal = user1@example.com to list user license for user1@example.com.

Returns:

  • (::String)

    Optional. Filter for the list request.

    Supported fields:

    • license_assignment_state
    • user_principal * Examples:

    • license_assignment_state = ASSIGNED to list assigned user licenses.

    • license_assignment_state = NO_LICENSE to list not licensed users.

    • license_assignment_state = NO_LICENSE_ATTEMPTED_LOGIN to list users who attempted login but no license assigned.

    • license_assignment_state != NO_LICENSE_ATTEMPTED_LOGIN to filter out users who attempted login but no license assigned.

    • user_principal = user1@example.com to list user license for user1@example.com.



83
84
85
86
# File 'proto_docs/google/cloud/discoveryengine/v1beta/user_license_service.rb', line 83

class ListUserLicensesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Optional. The order in which the UserLicenses are listed. The value must be a comma-separated list of fields. Default sorting order is ascending. To specify descending order for a field, append a " desc" suffix. Redundant space characters in the syntax are insignificant.

Supported fields (only user_principal is supported for now):

  • user_principal

If not set, the default ordering is by user_principal.

Examples:

  • user_principal to order by user_principal in ascending order.
  • user_principal desc to order by user_principal in descending order.

Returns:

  • (::String)

    Optional. The order in which the UserLicenses are listed. The value must be a comma-separated list of fields. Default sorting order is ascending. To specify descending order for a field, append a " desc" suffix. Redundant space characters in the syntax are insignificant.

    Supported fields (only user_principal is supported for now):

    • user_principal

    If not set, the default ordering is by user_principal.

    Examples:

    • user_principal to order by user_principal in ascending order.
    • user_principal desc to order by user_principal in descending order.


83
84
85
86
# File 'proto_docs/google/cloud/discoveryengine/v1beta/user_license_service.rb', line 83

class ListUserLicensesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. Requested page size. Server may return fewer items than requested. If unspecified, defaults to 10. The maximum value is 50; values above 50 will be coerced to 50.

If this field is negative, an INVALID_ARGUMENT error is returned.

Returns:

  • (::Integer)

    Optional. Requested page size. Server may return fewer items than requested. If unspecified, defaults to 10. The maximum value is 50; values above 50 will be coerced to 50.

    If this field is negative, an INVALID_ARGUMENT error is returned.



83
84
85
86
# File 'proto_docs/google/cloud/discoveryengine/v1beta/user_license_service.rb', line 83

class ListUserLicensesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous ListUserLicenses call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to ListUserLicenses must match the call that provided the page token.

Returns:

  • (::String)

    Optional. A page token, received from a previous ListUserLicenses call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to ListUserLicenses must match the call that provided the page token.



83
84
85
86
# File 'proto_docs/google/cloud/discoveryengine/v1beta/user_license_service.rb', line 83

class ListUserLicensesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent UserStore resource name, format: projects/{project}/locations/{location}/userStores/{user_store_id}.

Returns:

  • (::String)

    Required. The parent UserStore resource name, format: projects/{project}/locations/{location}/userStores/{user_store_id}.



83
84
85
86
# File 'proto_docs/google/cloud/discoveryengine/v1beta/user_license_service.rb', line 83

class ListUserLicensesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end