Class: Google::Cloud::DiscoveryEngine::V1beta::Project::CustomerProvidedConfig::NotebooklmConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/project.rb

Overview

Configuration for NotebookLM.

Defined Under Namespace

Classes: DataProtectionPolicy, ModelArmorConfig

Instance Attribute Summary collapse

Instance Attribute Details

#data_protection_policy::Google::Cloud::DiscoveryEngine::V1beta::Project::CustomerProvidedConfig::NotebooklmConfig::DataProtectionPolicy

Returns Optional. Specifies the data protection policy for NotebookLM.

Returns:



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'proto_docs/google/cloud/discoveryengine/v1beta/project.rb', line 123

class NotebooklmConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for customer defined Model Armor templates to be used for
  # sanitizing user prompts and LLM responses.
  # @!attribute [rw] user_prompt_template
  #   @return [::String]
  #     Optional. The resource name of the Model Armor Template for
  #     sanitizing user prompts. Format:
  #     projects/\\{project}/locations/\\{location}/templates/\\{template_id}
  #     If not specified, no sanitization will be applied to the user prompt.
  # @!attribute [rw] response_template
  #   @return [::String]
  #     Optional. The resource name of the Model Armor Template for
  #     sanitizing LLM responses. Format:
  #     projects/\\{project}/locations/\\{location}/templates/\\{template_id}
  #     If not specified, no sanitization will be applied to the LLM
  #     response.
  class ModelArmorConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Data protection policy config for NotebookLM.
  # @!attribute [rw] sensitive_data_protection_policy
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Project::CustomerProvidedConfig::NotebooklmConfig::DataProtectionPolicy::SensitiveDataProtectionPolicy]
  #     Optional. The sensitive data protection policy.
  class DataProtectionPolicy
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Specifies a Sensitive Data Protection
    # (https://cloud.google.com/sensitive-data-protection/docs/sensitive-data-protection-overview)
    # policy.
    # @!attribute [rw] policy
    #   @return [::String]
    #     Optional. The Sensitive Data Protection policy resource name.
    class SensitiveDataProtectionPolicy
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#model_armor_config::Google::Cloud::DiscoveryEngine::V1beta::Project::CustomerProvidedConfig::NotebooklmConfig::ModelArmorConfig

Returns Model Armor configuration to be used for sanitizing user prompts and LLM responses.

Returns:



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'proto_docs/google/cloud/discoveryengine/v1beta/project.rb', line 123

class NotebooklmConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for customer defined Model Armor templates to be used for
  # sanitizing user prompts and LLM responses.
  # @!attribute [rw] user_prompt_template
  #   @return [::String]
  #     Optional. The resource name of the Model Armor Template for
  #     sanitizing user prompts. Format:
  #     projects/\\{project}/locations/\\{location}/templates/\\{template_id}
  #     If not specified, no sanitization will be applied to the user prompt.
  # @!attribute [rw] response_template
  #   @return [::String]
  #     Optional. The resource name of the Model Armor Template for
  #     sanitizing LLM responses. Format:
  #     projects/\\{project}/locations/\\{location}/templates/\\{template_id}
  #     If not specified, no sanitization will be applied to the LLM
  #     response.
  class ModelArmorConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Data protection policy config for NotebookLM.
  # @!attribute [rw] sensitive_data_protection_policy
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Project::CustomerProvidedConfig::NotebooklmConfig::DataProtectionPolicy::SensitiveDataProtectionPolicy]
  #     Optional. The sensitive data protection policy.
  class DataProtectionPolicy
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Specifies a Sensitive Data Protection
    # (https://cloud.google.com/sensitive-data-protection/docs/sensitive-data-protection-overview)
    # policy.
    # @!attribute [rw] policy
    #   @return [::String]
    #     Optional. The Sensitive Data Protection policy resource name.
    class SensitiveDataProtectionPolicy
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#observability_config::Google::Cloud::DiscoveryEngine::V1beta::ObservabilityConfig

Returns Optional. Observability config for NotebookLM.

Returns:



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'proto_docs/google/cloud/discoveryengine/v1beta/project.rb', line 123

class NotebooklmConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for customer defined Model Armor templates to be used for
  # sanitizing user prompts and LLM responses.
  # @!attribute [rw] user_prompt_template
  #   @return [::String]
  #     Optional. The resource name of the Model Armor Template for
  #     sanitizing user prompts. Format:
  #     projects/\\{project}/locations/\\{location}/templates/\\{template_id}
  #     If not specified, no sanitization will be applied to the user prompt.
  # @!attribute [rw] response_template
  #   @return [::String]
  #     Optional. The resource name of the Model Armor Template for
  #     sanitizing LLM responses. Format:
  #     projects/\\{project}/locations/\\{location}/templates/\\{template_id}
  #     If not specified, no sanitization will be applied to the LLM
  #     response.
  class ModelArmorConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Data protection policy config for NotebookLM.
  # @!attribute [rw] sensitive_data_protection_policy
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Project::CustomerProvidedConfig::NotebooklmConfig::DataProtectionPolicy::SensitiveDataProtectionPolicy]
  #     Optional. The sensitive data protection policy.
  class DataProtectionPolicy
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Specifies a Sensitive Data Protection
    # (https://cloud.google.com/sensitive-data-protection/docs/sensitive-data-protection-overview)
    # policy.
    # @!attribute [rw] policy
    #   @return [::String]
    #     Optional. The Sensitive Data Protection policy resource name.
    class SensitiveDataProtectionPolicy
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#opt_out_notebook_sharing::Boolean

Returns Optional. Whether to disable the notebook sharing feature for the project. Default to false if not specified.

Returns:

  • (::Boolean)

    Optional. Whether to disable the notebook sharing feature for the project. Default to false if not specified.



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'proto_docs/google/cloud/discoveryengine/v1beta/project.rb', line 123

class NotebooklmConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for customer defined Model Armor templates to be used for
  # sanitizing user prompts and LLM responses.
  # @!attribute [rw] user_prompt_template
  #   @return [::String]
  #     Optional. The resource name of the Model Armor Template for
  #     sanitizing user prompts. Format:
  #     projects/\\{project}/locations/\\{location}/templates/\\{template_id}
  #     If not specified, no sanitization will be applied to the user prompt.
  # @!attribute [rw] response_template
  #   @return [::String]
  #     Optional. The resource name of the Model Armor Template for
  #     sanitizing LLM responses. Format:
  #     projects/\\{project}/locations/\\{location}/templates/\\{template_id}
  #     If not specified, no sanitization will be applied to the LLM
  #     response.
  class ModelArmorConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Data protection policy config for NotebookLM.
  # @!attribute [rw] sensitive_data_protection_policy
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Project::CustomerProvidedConfig::NotebooklmConfig::DataProtectionPolicy::SensitiveDataProtectionPolicy]
  #     Optional. The sensitive data protection policy.
  class DataProtectionPolicy
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Specifies a Sensitive Data Protection
    # (https://cloud.google.com/sensitive-data-protection/docs/sensitive-data-protection-overview)
    # policy.
    # @!attribute [rw] policy
    #   @return [::String]
    #     Optional. The Sensitive Data Protection policy resource name.
    class SensitiveDataProtectionPolicy
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end