Class: Google::Cloud::DiscoveryEngine::V1beta::Project::CustomerProvidedConfig::NotebooklmConfig::ModelArmorConfig
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::Project::CustomerProvidedConfig::NotebooklmConfig::ModelArmorConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/project.rb
Overview
Configuration for customer defined Model Armor templates to be used for sanitizing user prompts and LLM responses.
Instance Attribute Summary collapse
-
#response_template ⇒ ::String
Optional.
-
#user_prompt_template ⇒ ::String
Optional.
Instance Attribute Details
#response_template ⇒ ::String
Returns Optional. The resource name of the Model Armor Template for sanitizing LLM responses. Format: projects/{project}/locations/{location}/templates/{template_id} If not specified, no sanitization will be applied to the LLM response.
142 143 144 145 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/project.rb', line 142 class ModelArmorConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#user_prompt_template ⇒ ::String
Returns Optional. The resource name of the Model Armor Template for sanitizing user prompts. Format: projects/{project}/locations/{location}/templates/{template_id} If not specified, no sanitization will be applied to the user prompt.
142 143 144 145 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/project.rb', line 142 class ModelArmorConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |