Class: Google::Cloud::DiscoveryEngine::V1beta::ProvisionProjectRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/project_service.rb

Overview

Request for ProjectService.ProvisionProject method.

Defined Under Namespace

Classes: SaasParams

Instance Attribute Summary collapse

Instance Attribute Details

#accept_data_use_terms::Boolean

Returns Required. Set to true to specify that caller has read and would like to give consent to the Terms for data use.

Returns:

  • (::Boolean)

    Required. Set to true to specify that caller has read and would like to give consent to the Terms for data use.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'proto_docs/google/cloud/discoveryengine/v1beta/project_service.rb', line 47

class ProvisionProjectRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Parameters for Agentspace.
  # @!attribute [rw] accept_biz_qos
  #   @return [::Boolean]
  #     Optional. Set to `true` to specify that caller has read and would like to
  #     give consent to the [Terms for Agent Space quality of service].
  # @!attribute [rw] is_biz
  #   @return [::Boolean]
  #     Optional. Indicates if the current request is for Biz edition (= true) or
  #     not
  #     (= false).
  class SaasParams
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#data_use_terms_version::String

Returns Required. The version of the Terms for data use that caller has read and would like to give consent to.

Acceptable version is 2022-11-23, and this may change over time.

Returns:

  • (::String)

    Required. The version of the Terms for data use that caller has read and would like to give consent to.

    Acceptable version is 2022-11-23, and this may change over time.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'proto_docs/google/cloud/discoveryengine/v1beta/project_service.rb', line 47

class ProvisionProjectRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Parameters for Agentspace.
  # @!attribute [rw] accept_biz_qos
  #   @return [::Boolean]
  #     Optional. Set to `true` to specify that caller has read and would like to
  #     give consent to the [Terms for Agent Space quality of service].
  # @!attribute [rw] is_biz
  #   @return [::Boolean]
  #     Optional. Indicates if the current request is for Biz edition (= true) or
  #     not
  #     (= false).
  class SaasParams
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String

Returns Required. Full resource name of a Project, such as projects/{project_id_or_number}.

Returns:

  • (::String)

    Required. Full resource name of a Project, such as projects/{project_id_or_number}.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'proto_docs/google/cloud/discoveryengine/v1beta/project_service.rb', line 47

class ProvisionProjectRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Parameters for Agentspace.
  # @!attribute [rw] accept_biz_qos
  #   @return [::Boolean]
  #     Optional. Set to `true` to specify that caller has read and would like to
  #     give consent to the [Terms for Agent Space quality of service].
  # @!attribute [rw] is_biz
  #   @return [::Boolean]
  #     Optional. Indicates if the current request is for Biz edition (= true) or
  #     not
  #     (= false).
  class SaasParams
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#saas_params::Google::Cloud::DiscoveryEngine::V1beta::ProvisionProjectRequest::SaasParams

Returns Optional. Parameters for Agentspace.

Returns:



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'proto_docs/google/cloud/discoveryengine/v1beta/project_service.rb', line 47

class ProvisionProjectRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Parameters for Agentspace.
  # @!attribute [rw] accept_biz_qos
  #   @return [::Boolean]
  #     Optional. Set to `true` to specify that caller has read and would like to
  #     give consent to the [Terms for Agent Space quality of service].
  # @!attribute [rw] is_biz
  #   @return [::Boolean]
  #     Optional. Indicates if the current request is for Biz edition (= true) or
  #     not
  #     (= false).
  class SaasParams
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end