Class: Google::Cloud::DiscoveryEngine::V1beta::ProvisionProjectRequest::SaasParams

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/project_service.rb

Overview

Parameters for Agentspace.

Instance Attribute Summary collapse

Instance Attribute Details

#accept_biz_qos::Boolean

Returns Optional. Set to true to specify that caller has read and would like to give consent to the [Terms for Agent Space quality of service].

Returns:

  • (::Boolean)

    Optional. Set to true to specify that caller has read and would like to give consent to the [Terms for Agent Space quality of service].



61
62
63
64
# File 'proto_docs/google/cloud/discoveryengine/v1beta/project_service.rb', line 61

class SaasParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#is_biz::Boolean

Returns Optional. Indicates if the current request is for Biz edition (= true) or not (= false).

Returns:

  • (::Boolean)

    Optional. Indicates if the current request is for Biz edition (= true) or not (= false).



61
62
63
64
# File 'proto_docs/google/cloud/discoveryengine/v1beta/project_service.rb', line 61

class SaasParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end