Class: Google::Cloud::DiscoveryEngine::V1beta::RankingRecord
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::RankingRecord
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/rank_service.rb
Overview
Record message for RankService.Rank method.
Instance Attribute Summary collapse
-
#content ⇒ ::String
The content of the record.
-
#id ⇒ ::String
The unique ID to represent the record.
-
#score ⇒ ::Float
The score of this record based on the given query and selected model.
-
#title ⇒ ::String
The title of the record.
Instance Attribute Details
#content ⇒ ::String
49 50 51 52 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/rank_service.rb', line 49 class RankingRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#id ⇒ ::String
Returns The unique ID to represent the record.
49 50 51 52 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/rank_service.rb', line 49 class RankingRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#score ⇒ ::Float
Returns The score of this record based on the given query and selected model. The score will be rounded to 4 decimal places. If the score is close to 0, it will be rounded to 0.00001 to avoid returning unset.
49 50 51 52 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/rank_service.rb', line 49 class RankingRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#title ⇒ ::String
49 50 51 52 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/rank_service.rb', line 49 class RankingRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |