Class: Google::Cloud::DiscoveryEngine::V1beta::RetractLicenseConfigRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/license_config_service.rb

Overview

Request message for LicenseConfigService.RetractLicenseConfig method.

Instance Attribute Summary collapse

Instance Attribute Details

#billing_account_license_config::String

Returns Required. Full resource name of [BillingAccountLicenseConfig][].

Format: billingAccounts/{billing_account}/billingAccountLicenseConfigs/{billing_account_license_config_id}.

Returns:

  • (::String)

    Required. Full resource name of [BillingAccountLicenseConfig][].

    Format: billingAccounts/{billing_account}/billingAccountLicenseConfigs/{billing_account_license_config_id}.



206
207
208
209
# File 'proto_docs/google/cloud/discoveryengine/v1beta/license_config_service.rb', line 206

class RetractLicenseConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#full_retract::Boolean

Returns Optional. If set to true, retract the entire license config. Otherwise, retract the specified license count.

Returns:

  • (::Boolean)

    Optional. If set to true, retract the entire license config. Otherwise, retract the specified license count.



206
207
208
209
# File 'proto_docs/google/cloud/discoveryengine/v1beta/license_config_service.rb', line 206

class RetractLicenseConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#license_config::String

Returns Required. Full resource name of LicenseConfig.

Format: projects/{project}/locations/{location}/licenseConfigs/{license_config_id}.

Returns:

  • (::String)

    Required. Full resource name of LicenseConfig.

    Format: projects/{project}/locations/{location}/licenseConfigs/{license_config_id}.



206
207
208
209
# File 'proto_docs/google/cloud/discoveryengine/v1beta/license_config_service.rb', line 206

class RetractLicenseConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#license_count::Integer

Returns Optional. The number of licenses to retract. Only used when full_retract is false.

Returns:

  • (::Integer)

    Optional. The number of licenses to retract. Only used when full_retract is false.



206
207
208
209
# File 'proto_docs/google/cloud/discoveryengine/v1beta/license_config_service.rb', line 206

class RetractLicenseConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end