Class: Google::Cloud::DiscoveryEngine::V1beta::SearchLinkPromotion

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/common.rb

Overview

Promotion proto includes uri and other helping information to display the promotion.

Instance Attribute Summary collapse

Instance Attribute Details

#description::String

Returns Optional. The Promotion description. Maximum length: 200 characters.

Returns:

  • (::String)

    Optional. The Promotion description. Maximum length: 200 characters.



280
281
282
283
# File 'proto_docs/google/cloud/discoveryengine/v1beta/common.rb', line 280

class SearchLinkPromotion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#document::String

Returns Optional. The Document the user wants to promote. For site search, leave unset and only populate uri. Can be set along with uri.

Returns:

  • (::String)

    Optional. The Document the user wants to promote. For site search, leave unset and only populate uri. Can be set along with uri.



280
281
282
283
# File 'proto_docs/google/cloud/discoveryengine/v1beta/common.rb', line 280

class SearchLinkPromotion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#enabled::Boolean

Returns Optional. The enabled promotion will be returned for any serving configs associated with the parent of the control this promotion is attached to.

This flag is used for basic site search only.

Returns:

  • (::Boolean)

    Optional. The enabled promotion will be returned for any serving configs associated with the parent of the control this promotion is attached to.

    This flag is used for basic site search only.



280
281
282
283
# File 'proto_docs/google/cloud/discoveryengine/v1beta/common.rb', line 280

class SearchLinkPromotion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#image_uri::String

Returns Optional. The promotion thumbnail image url.

Returns:

  • (::String)

    Optional. The promotion thumbnail image url.



280
281
282
283
# File 'proto_docs/google/cloud/discoveryengine/v1beta/common.rb', line 280

class SearchLinkPromotion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#title::String

Returns Required. The title of the promotion. Maximum length: 160 characters.

Returns:

  • (::String)

    Required. The title of the promotion. Maximum length: 160 characters.



280
281
282
283
# File 'proto_docs/google/cloud/discoveryengine/v1beta/common.rb', line 280

class SearchLinkPromotion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#uri::String

Returns Optional. The URL for the page the user wants to promote. Must be set for site search. For other verticals, this is optional.

Returns:

  • (::String)

    Optional. The URL for the page the user wants to promote. Must be set for site search. For other verticals, this is optional.



280
281
282
283
# File 'proto_docs/google/cloud/discoveryengine/v1beta/common.rb', line 280

class SearchLinkPromotion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end