Class: Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::ContentSearchSpec::SummarySpec

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb

Overview

A specification for configuring a summary returned in a search response.

Defined Under Namespace

Classes: ModelPromptSpec, ModelSpec, MultiModalSpec

Instance Attribute Summary collapse

Instance Attribute Details

#ignore_adversarial_query::Boolean

Returns Specifies whether to filter out adversarial queries. The default value is false.

Google employs search-query classification to detect adversarial queries. No summary is returned if the search query is classified as an adversarial query. For example, a user might ask a question regarding negative comments about the company or submit a query designed to generate unsafe, policy-violating output. If this field is set to true, we skip generating summaries for adversarial queries and return fallback messages instead.

Returns:

  • (::Boolean)

    Specifies whether to filter out adversarial queries. The default value is false.

    Google employs search-query classification to detect adversarial queries. No summary is returned if the search query is classified as an adversarial query. For example, a user might ask a question regarding negative comments about the company or submit a query designed to generate unsafe, policy-violating output. If this field is set to true, we skip generating summaries for adversarial queries and return fallback messages instead.



1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1021

class SummarySpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Multimodal specification: Will return an image from specified source.
  # If multiple sources are specified, the pick is a quality based
  # decision.
  # @!attribute [rw] image_source
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::ContentSearchSpec::SummarySpec::MultiModalSpec::ImageSource]
  #     Optional. Source of image returned in the answer.
  class MultiModalSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Specifies the image source.
    module ImageSource
      # Unspecified image source (multimodal feature is disabled by
      # default).
      IMAGE_SOURCE_UNSPECIFIED = 0

      # Behavior when service determines the pick from all available
      # sources.
      ALL_AVAILABLE_SOURCES = 1

      # Includes image from corpus in the answer.
      CORPUS_IMAGE_ONLY = 2

      # Triggers figure generation in the answer.
      FIGURE_GENERATION_ONLY = 3
    end
  end

  # Specification of the prompt to use with the model.
  # @!attribute [rw] preamble
  #   @return [::String]
  #     Text at the beginning of the prompt that instructs the assistant.
  #     Examples are available in the user guide.
  class ModelPromptSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Specification of the model.
  # @!attribute [rw] version
  #   @return [::String]
  #     The model version used to generate the summary.
  #
  #     Supported values are:
  #
  #     * `stable`: string. Default value when no value is specified. Uses a
  #        generally available, fine-tuned model. For more information, see
  #        [Answer generation model versions and
  #        lifecycle](https://cloud.google.com/generative-ai-app-builder/docs/answer-generation-models).
  #     * `preview`: string. (Public preview) Uses a preview model. For more
  #        information, see
  #        [Answer generation model versions and
  #        lifecycle](https://cloud.google.com/generative-ai-app-builder/docs/answer-generation-models).
  class ModelSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#ignore_jail_breaking_query::Boolean

Returns Optional. Specifies whether to filter out jail-breaking queries. The default value is false.

Google employs search-query classification to detect jail-breaking queries. No summary is returned if the search query is classified as a jail-breaking query. A user might add instructions to the query to change the tone, style, language, content of the answer, or ask the model to act as a different entity, e.g. "Reply in the tone of a competing company's CEO". If this field is set to true, we skip generating summaries for jail-breaking queries and return fallback messages instead.

Returns:

  • (::Boolean)

    Optional. Specifies whether to filter out jail-breaking queries. The default value is false.

    Google employs search-query classification to detect jail-breaking queries. No summary is returned if the search query is classified as a jail-breaking query. A user might add instructions to the query to change the tone, style, language, content of the answer, or ask the model to act as a different entity, e.g. "Reply in the tone of a competing company's CEO". If this field is set to true, we skip generating summaries for jail-breaking queries and return fallback messages instead.



1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1021

class SummarySpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Multimodal specification: Will return an image from specified source.
  # If multiple sources are specified, the pick is a quality based
  # decision.
  # @!attribute [rw] image_source
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::ContentSearchSpec::SummarySpec::MultiModalSpec::ImageSource]
  #     Optional. Source of image returned in the answer.
  class MultiModalSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Specifies the image source.
    module ImageSource
      # Unspecified image source (multimodal feature is disabled by
      # default).
      IMAGE_SOURCE_UNSPECIFIED = 0

      # Behavior when service determines the pick from all available
      # sources.
      ALL_AVAILABLE_SOURCES = 1

      # Includes image from corpus in the answer.
      CORPUS_IMAGE_ONLY = 2

      # Triggers figure generation in the answer.
      FIGURE_GENERATION_ONLY = 3
    end
  end

  # Specification of the prompt to use with the model.
  # @!attribute [rw] preamble
  #   @return [::String]
  #     Text at the beginning of the prompt that instructs the assistant.
  #     Examples are available in the user guide.
  class ModelPromptSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Specification of the model.
  # @!attribute [rw] version
  #   @return [::String]
  #     The model version used to generate the summary.
  #
  #     Supported values are:
  #
  #     * `stable`: string. Default value when no value is specified. Uses a
  #        generally available, fine-tuned model. For more information, see
  #        [Answer generation model versions and
  #        lifecycle](https://cloud.google.com/generative-ai-app-builder/docs/answer-generation-models).
  #     * `preview`: string. (Public preview) Uses a preview model. For more
  #        information, see
  #        [Answer generation model versions and
  #        lifecycle](https://cloud.google.com/generative-ai-app-builder/docs/answer-generation-models).
  class ModelSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#ignore_low_relevant_content::Boolean

Returns Specifies whether to filter out queries that have low relevance. The default value is false.

If this field is set to false, all search results are used regardless of relevance to generate answers. If set to true, only queries with high relevance search results will generate answers.

Returns:

  • (::Boolean)

    Specifies whether to filter out queries that have low relevance. The default value is false.

    If this field is set to false, all search results are used regardless of relevance to generate answers. If set to true, only queries with high relevance search results will generate answers.



1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1021

class SummarySpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Multimodal specification: Will return an image from specified source.
  # If multiple sources are specified, the pick is a quality based
  # decision.
  # @!attribute [rw] image_source
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::ContentSearchSpec::SummarySpec::MultiModalSpec::ImageSource]
  #     Optional. Source of image returned in the answer.
  class MultiModalSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Specifies the image source.
    module ImageSource
      # Unspecified image source (multimodal feature is disabled by
      # default).
      IMAGE_SOURCE_UNSPECIFIED = 0

      # Behavior when service determines the pick from all available
      # sources.
      ALL_AVAILABLE_SOURCES = 1

      # Includes image from corpus in the answer.
      CORPUS_IMAGE_ONLY = 2

      # Triggers figure generation in the answer.
      FIGURE_GENERATION_ONLY = 3
    end
  end

  # Specification of the prompt to use with the model.
  # @!attribute [rw] preamble
  #   @return [::String]
  #     Text at the beginning of the prompt that instructs the assistant.
  #     Examples are available in the user guide.
  class ModelPromptSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Specification of the model.
  # @!attribute [rw] version
  #   @return [::String]
  #     The model version used to generate the summary.
  #
  #     Supported values are:
  #
  #     * `stable`: string. Default value when no value is specified. Uses a
  #        generally available, fine-tuned model. For more information, see
  #        [Answer generation model versions and
  #        lifecycle](https://cloud.google.com/generative-ai-app-builder/docs/answer-generation-models).
  #     * `preview`: string. (Public preview) Uses a preview model. For more
  #        information, see
  #        [Answer generation model versions and
  #        lifecycle](https://cloud.google.com/generative-ai-app-builder/docs/answer-generation-models).
  class ModelSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#ignore_non_summary_seeking_query::Boolean

Returns Specifies whether to filter out queries that are not summary-seeking. The default value is false.

Google employs search-query classification to detect summary-seeking queries. No summary is returned if the search query is classified as a non-summary seeking query. For example, why is the sky blue and Who is the best soccer player in the world? are summary-seeking queries, but SFO airport and world cup 2026 are not. They are most likely navigational queries. If this field is set to true, we skip generating summaries for non-summary seeking queries and return fallback messages instead.

Returns:

  • (::Boolean)

    Specifies whether to filter out queries that are not summary-seeking. The default value is false.

    Google employs search-query classification to detect summary-seeking queries. No summary is returned if the search query is classified as a non-summary seeking query. For example, why is the sky blue and Who is the best soccer player in the world? are summary-seeking queries, but SFO airport and world cup 2026 are not. They are most likely navigational queries. If this field is set to true, we skip generating summaries for non-summary seeking queries and return fallback messages instead.



1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1021

class SummarySpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Multimodal specification: Will return an image from specified source.
  # If multiple sources are specified, the pick is a quality based
  # decision.
  # @!attribute [rw] image_source
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::ContentSearchSpec::SummarySpec::MultiModalSpec::ImageSource]
  #     Optional. Source of image returned in the answer.
  class MultiModalSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Specifies the image source.
    module ImageSource
      # Unspecified image source (multimodal feature is disabled by
      # default).
      IMAGE_SOURCE_UNSPECIFIED = 0

      # Behavior when service determines the pick from all available
      # sources.
      ALL_AVAILABLE_SOURCES = 1

      # Includes image from corpus in the answer.
      CORPUS_IMAGE_ONLY = 2

      # Triggers figure generation in the answer.
      FIGURE_GENERATION_ONLY = 3
    end
  end

  # Specification of the prompt to use with the model.
  # @!attribute [rw] preamble
  #   @return [::String]
  #     Text at the beginning of the prompt that instructs the assistant.
  #     Examples are available in the user guide.
  class ModelPromptSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Specification of the model.
  # @!attribute [rw] version
  #   @return [::String]
  #     The model version used to generate the summary.
  #
  #     Supported values are:
  #
  #     * `stable`: string. Default value when no value is specified. Uses a
  #        generally available, fine-tuned model. For more information, see
  #        [Answer generation model versions and
  #        lifecycle](https://cloud.google.com/generative-ai-app-builder/docs/answer-generation-models).
  #     * `preview`: string. (Public preview) Uses a preview model. For more
  #        information, see
  #        [Answer generation model versions and
  #        lifecycle](https://cloud.google.com/generative-ai-app-builder/docs/answer-generation-models).
  class ModelSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#include_citations::Boolean

Returns Specifies whether to include citations in the summary. The default value is false.

When this field is set to true, summaries include in-line citation numbers.

Example summary including citations:

BigQuery is Google Cloud's fully managed and completely serverless enterprise data warehouse [1]. BigQuery supports all data types, works across clouds, and has built-in machine learning and business intelligence, all within a unified platform [2, 3].

The citation numbers refer to the returned search results and are 1-indexed. For example, [1] means that the sentence is attributed to the first search result. [2, 3] means that the sentence is attributed to both the second and third search results.

Returns:

  • (::Boolean)

    Specifies whether to include citations in the summary. The default value is false.

    When this field is set to true, summaries include in-line citation numbers.

    Example summary including citations:

    BigQuery is Google Cloud's fully managed and completely serverless enterprise data warehouse [1]. BigQuery supports all data types, works across clouds, and has built-in machine learning and business intelligence, all within a unified platform [2, 3].

    The citation numbers refer to the returned search results and are 1-indexed. For example, [1] means that the sentence is attributed to the first search result. [2, 3] means that the sentence is attributed to both the second and third search results.



1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1021

class SummarySpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Multimodal specification: Will return an image from specified source.
  # If multiple sources are specified, the pick is a quality based
  # decision.
  # @!attribute [rw] image_source
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::ContentSearchSpec::SummarySpec::MultiModalSpec::ImageSource]
  #     Optional. Source of image returned in the answer.
  class MultiModalSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Specifies the image source.
    module ImageSource
      # Unspecified image source (multimodal feature is disabled by
      # default).
      IMAGE_SOURCE_UNSPECIFIED = 0

      # Behavior when service determines the pick from all available
      # sources.
      ALL_AVAILABLE_SOURCES = 1

      # Includes image from corpus in the answer.
      CORPUS_IMAGE_ONLY = 2

      # Triggers figure generation in the answer.
      FIGURE_GENERATION_ONLY = 3
    end
  end

  # Specification of the prompt to use with the model.
  # @!attribute [rw] preamble
  #   @return [::String]
  #     Text at the beginning of the prompt that instructs the assistant.
  #     Examples are available in the user guide.
  class ModelPromptSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Specification of the model.
  # @!attribute [rw] version
  #   @return [::String]
  #     The model version used to generate the summary.
  #
  #     Supported values are:
  #
  #     * `stable`: string. Default value when no value is specified. Uses a
  #        generally available, fine-tuned model. For more information, see
  #        [Answer generation model versions and
  #        lifecycle](https://cloud.google.com/generative-ai-app-builder/docs/answer-generation-models).
  #     * `preview`: string. (Public preview) Uses a preview model. For more
  #        information, see
  #        [Answer generation model versions and
  #        lifecycle](https://cloud.google.com/generative-ai-app-builder/docs/answer-generation-models).
  class ModelSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#language_code::String

Returns Language code for Summary. Use language tags defined by BCP47. Note: This is an experimental feature.

Returns:

  • (::String)

    Language code for Summary. Use language tags defined by BCP47. Note: This is an experimental feature.



1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1021

class SummarySpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Multimodal specification: Will return an image from specified source.
  # If multiple sources are specified, the pick is a quality based
  # decision.
  # @!attribute [rw] image_source
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::ContentSearchSpec::SummarySpec::MultiModalSpec::ImageSource]
  #     Optional. Source of image returned in the answer.
  class MultiModalSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Specifies the image source.
    module ImageSource
      # Unspecified image source (multimodal feature is disabled by
      # default).
      IMAGE_SOURCE_UNSPECIFIED = 0

      # Behavior when service determines the pick from all available
      # sources.
      ALL_AVAILABLE_SOURCES = 1

      # Includes image from corpus in the answer.
      CORPUS_IMAGE_ONLY = 2

      # Triggers figure generation in the answer.
      FIGURE_GENERATION_ONLY = 3
    end
  end

  # Specification of the prompt to use with the model.
  # @!attribute [rw] preamble
  #   @return [::String]
  #     Text at the beginning of the prompt that instructs the assistant.
  #     Examples are available in the user guide.
  class ModelPromptSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Specification of the model.
  # @!attribute [rw] version
  #   @return [::String]
  #     The model version used to generate the summary.
  #
  #     Supported values are:
  #
  #     * `stable`: string. Default value when no value is specified. Uses a
  #        generally available, fine-tuned model. For more information, see
  #        [Answer generation model versions and
  #        lifecycle](https://cloud.google.com/generative-ai-app-builder/docs/answer-generation-models).
  #     * `preview`: string. (Public preview) Uses a preview model. For more
  #        information, see
  #        [Answer generation model versions and
  #        lifecycle](https://cloud.google.com/generative-ai-app-builder/docs/answer-generation-models).
  class ModelSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#model_prompt_spec::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::ContentSearchSpec::SummarySpec::ModelPromptSpec

Returns If specified, the spec will be used to modify the prompt provided to the LLM.

Returns:



1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1021

class SummarySpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Multimodal specification: Will return an image from specified source.
  # If multiple sources are specified, the pick is a quality based
  # decision.
  # @!attribute [rw] image_source
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::ContentSearchSpec::SummarySpec::MultiModalSpec::ImageSource]
  #     Optional. Source of image returned in the answer.
  class MultiModalSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Specifies the image source.
    module ImageSource
      # Unspecified image source (multimodal feature is disabled by
      # default).
      IMAGE_SOURCE_UNSPECIFIED = 0

      # Behavior when service determines the pick from all available
      # sources.
      ALL_AVAILABLE_SOURCES = 1

      # Includes image from corpus in the answer.
      CORPUS_IMAGE_ONLY = 2

      # Triggers figure generation in the answer.
      FIGURE_GENERATION_ONLY = 3
    end
  end

  # Specification of the prompt to use with the model.
  # @!attribute [rw] preamble
  #   @return [::String]
  #     Text at the beginning of the prompt that instructs the assistant.
  #     Examples are available in the user guide.
  class ModelPromptSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Specification of the model.
  # @!attribute [rw] version
  #   @return [::String]
  #     The model version used to generate the summary.
  #
  #     Supported values are:
  #
  #     * `stable`: string. Default value when no value is specified. Uses a
  #        generally available, fine-tuned model. For more information, see
  #        [Answer generation model versions and
  #        lifecycle](https://cloud.google.com/generative-ai-app-builder/docs/answer-generation-models).
  #     * `preview`: string. (Public preview) Uses a preview model. For more
  #        information, see
  #        [Answer generation model versions and
  #        lifecycle](https://cloud.google.com/generative-ai-app-builder/docs/answer-generation-models).
  class ModelSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#model_spec::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::ContentSearchSpec::SummarySpec::ModelSpec

Returns If specified, the spec will be used to modify the model specification provided to the LLM.

Returns:



1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1021

class SummarySpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Multimodal specification: Will return an image from specified source.
  # If multiple sources are specified, the pick is a quality based
  # decision.
  # @!attribute [rw] image_source
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::ContentSearchSpec::SummarySpec::MultiModalSpec::ImageSource]
  #     Optional. Source of image returned in the answer.
  class MultiModalSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Specifies the image source.
    module ImageSource
      # Unspecified image source (multimodal feature is disabled by
      # default).
      IMAGE_SOURCE_UNSPECIFIED = 0

      # Behavior when service determines the pick from all available
      # sources.
      ALL_AVAILABLE_SOURCES = 1

      # Includes image from corpus in the answer.
      CORPUS_IMAGE_ONLY = 2

      # Triggers figure generation in the answer.
      FIGURE_GENERATION_ONLY = 3
    end
  end

  # Specification of the prompt to use with the model.
  # @!attribute [rw] preamble
  #   @return [::String]
  #     Text at the beginning of the prompt that instructs the assistant.
  #     Examples are available in the user guide.
  class ModelPromptSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Specification of the model.
  # @!attribute [rw] version
  #   @return [::String]
  #     The model version used to generate the summary.
  #
  #     Supported values are:
  #
  #     * `stable`: string. Default value when no value is specified. Uses a
  #        generally available, fine-tuned model. For more information, see
  #        [Answer generation model versions and
  #        lifecycle](https://cloud.google.com/generative-ai-app-builder/docs/answer-generation-models).
  #     * `preview`: string. (Public preview) Uses a preview model. For more
  #        information, see
  #        [Answer generation model versions and
  #        lifecycle](https://cloud.google.com/generative-ai-app-builder/docs/answer-generation-models).
  class ModelSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#multimodal_spec::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::ContentSearchSpec::SummarySpec::MultiModalSpec

Returns Optional. Multimodal specification.



1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1021

class SummarySpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Multimodal specification: Will return an image from specified source.
  # If multiple sources are specified, the pick is a quality based
  # decision.
  # @!attribute [rw] image_source
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::ContentSearchSpec::SummarySpec::MultiModalSpec::ImageSource]
  #     Optional. Source of image returned in the answer.
  class MultiModalSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Specifies the image source.
    module ImageSource
      # Unspecified image source (multimodal feature is disabled by
      # default).
      IMAGE_SOURCE_UNSPECIFIED = 0

      # Behavior when service determines the pick from all available
      # sources.
      ALL_AVAILABLE_SOURCES = 1

      # Includes image from corpus in the answer.
      CORPUS_IMAGE_ONLY = 2

      # Triggers figure generation in the answer.
      FIGURE_GENERATION_ONLY = 3
    end
  end

  # Specification of the prompt to use with the model.
  # @!attribute [rw] preamble
  #   @return [::String]
  #     Text at the beginning of the prompt that instructs the assistant.
  #     Examples are available in the user guide.
  class ModelPromptSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Specification of the model.
  # @!attribute [rw] version
  #   @return [::String]
  #     The model version used to generate the summary.
  #
  #     Supported values are:
  #
  #     * `stable`: string. Default value when no value is specified. Uses a
  #        generally available, fine-tuned model. For more information, see
  #        [Answer generation model versions and
  #        lifecycle](https://cloud.google.com/generative-ai-app-builder/docs/answer-generation-models).
  #     * `preview`: string. (Public preview) Uses a preview model. For more
  #        information, see
  #        [Answer generation model versions and
  #        lifecycle](https://cloud.google.com/generative-ai-app-builder/docs/answer-generation-models).
  class ModelSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#summary_result_count::Integer

Returns The number of top results to generate the summary from. If the number of results returned is less than summaryResultCount, the summary is generated from all of the results.

At most 10 results for documents mode, or 50 for chunks mode, can be used to generate a summary. The chunks mode is used when SearchRequest.ContentSearchSpec.search_result_mode is set to CHUNKS.

Returns:

  • (::Integer)

    The number of top results to generate the summary from. If the number of results returned is less than summaryResultCount, the summary is generated from all of the results.

    At most 10 results for documents mode, or 50 for chunks mode, can be used to generate a summary. The chunks mode is used when SearchRequest.ContentSearchSpec.search_result_mode is set to CHUNKS.



1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1021

class SummarySpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Multimodal specification: Will return an image from specified source.
  # If multiple sources are specified, the pick is a quality based
  # decision.
  # @!attribute [rw] image_source
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::ContentSearchSpec::SummarySpec::MultiModalSpec::ImageSource]
  #     Optional. Source of image returned in the answer.
  class MultiModalSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Specifies the image source.
    module ImageSource
      # Unspecified image source (multimodal feature is disabled by
      # default).
      IMAGE_SOURCE_UNSPECIFIED = 0

      # Behavior when service determines the pick from all available
      # sources.
      ALL_AVAILABLE_SOURCES = 1

      # Includes image from corpus in the answer.
      CORPUS_IMAGE_ONLY = 2

      # Triggers figure generation in the answer.
      FIGURE_GENERATION_ONLY = 3
    end
  end

  # Specification of the prompt to use with the model.
  # @!attribute [rw] preamble
  #   @return [::String]
  #     Text at the beginning of the prompt that instructs the assistant.
  #     Examples are available in the user guide.
  class ModelPromptSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Specification of the model.
  # @!attribute [rw] version
  #   @return [::String]
  #     The model version used to generate the summary.
  #
  #     Supported values are:
  #
  #     * `stable`: string. Default value when no value is specified. Uses a
  #        generally available, fine-tuned model. For more information, see
  #        [Answer generation model versions and
  #        lifecycle](https://cloud.google.com/generative-ai-app-builder/docs/answer-generation-models).
  #     * `preview`: string. (Public preview) Uses a preview model. For more
  #        information, see
  #        [Answer generation model versions and
  #        lifecycle](https://cloud.google.com/generative-ai-app-builder/docs/answer-generation-models).
  class ModelSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#use_semantic_chunks::Boolean

Returns If true, answer will be generated from most relevant chunks from top search results. This feature will improve summary quality. Note that with this feature enabled, not all top search results will be referenced and included in the reference list, so the citation source index only points to the search results listed in the reference list.

Returns:

  • (::Boolean)

    If true, answer will be generated from most relevant chunks from top search results. This feature will improve summary quality. Note that with this feature enabled, not all top search results will be referenced and included in the reference list, so the citation source index only points to the search results listed in the reference list.



1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1021

class SummarySpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Multimodal specification: Will return an image from specified source.
  # If multiple sources are specified, the pick is a quality based
  # decision.
  # @!attribute [rw] image_source
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::ContentSearchSpec::SummarySpec::MultiModalSpec::ImageSource]
  #     Optional. Source of image returned in the answer.
  class MultiModalSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Specifies the image source.
    module ImageSource
      # Unspecified image source (multimodal feature is disabled by
      # default).
      IMAGE_SOURCE_UNSPECIFIED = 0

      # Behavior when service determines the pick from all available
      # sources.
      ALL_AVAILABLE_SOURCES = 1

      # Includes image from corpus in the answer.
      CORPUS_IMAGE_ONLY = 2

      # Triggers figure generation in the answer.
      FIGURE_GENERATION_ONLY = 3
    end
  end

  # Specification of the prompt to use with the model.
  # @!attribute [rw] preamble
  #   @return [::String]
  #     Text at the beginning of the prompt that instructs the assistant.
  #     Examples are available in the user guide.
  class ModelPromptSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Specification of the model.
  # @!attribute [rw] version
  #   @return [::String]
  #     The model version used to generate the summary.
  #
  #     Supported values are:
  #
  #     * `stable`: string. Default value when no value is specified. Uses a
  #        generally available, fine-tuned model. For more information, see
  #        [Answer generation model versions and
  #        lifecycle](https://cloud.google.com/generative-ai-app-builder/docs/answer-generation-models).
  #     * `preview`: string. (Public preview) Uses a preview model. For more
  #        information, see
  #        [Answer generation model versions and
  #        lifecycle](https://cloud.google.com/generative-ai-app-builder/docs/answer-generation-models).
  class ModelSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end