Class: Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::DisplaySpec
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::DisplaySpec
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb
Overview
Specifies features for display, like match highlighting.
Defined Under Namespace
Modules: MatchHighlightingCondition
Instance Attribute Summary collapse
-
#match_highlighting_condition ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::DisplaySpec::MatchHighlightingCondition
The condition under which match highlighting should occur.
Instance Attribute Details
#match_highlighting_condition ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::DisplaySpec::MatchHighlightingCondition
Returns The condition under which match highlighting should occur.
1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1299 class DisplaySpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum describing under which condition match highlighting should occur. module MatchHighlightingCondition # Server behavior is the same as `MATCH_HIGHLIGHTING_DISABLED`. MATCH_HIGHLIGHTING_CONDITION_UNSPECIFIED = 0 # Disables match highlighting on all documents. MATCH_HIGHLIGHTING_DISABLED = 1 # Enables match highlighting on all documents. MATCH_HIGHLIGHTING_ENABLED = 2 end end |