Class: Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::FacetSpec

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb

Overview

A facet specification to perform faceted search.

Defined Under Namespace

Classes: FacetKey

Instance Attribute Summary collapse

Instance Attribute Details

#enable_dynamic_position::Boolean

Returns Enables dynamic position for this facet. If set to true, the position of this facet among all facets in the response is determined automatically. If dynamic facets are enabled, it is ordered together. If set to false, the position of this facet in the response is the same as in the request, and it is ranked before the facets with dynamic position enable and all dynamic facets.

For example, you may always want to have rating facet returned in the response, but it's not necessarily to always display the rating facet at the top. In that case, you can set enable_dynamic_position to true so that the position of rating facet in response is determined automatically.

Another example, assuming you have the following facets in the request:

  • "rating", enable_dynamic_position = true

  • "price", enable_dynamic_position = false

  • "brands", enable_dynamic_position = false

And also you have a dynamic facets enabled, which generates a facet gender. Then the final order of the facets in the response can be ("price", "brands", "rating", "gender") or ("price", "brands", "gender", "rating") depends on how API orders "gender" and "rating" facets. However, notice that "price" and "brands" are always ranked at first and second position because their enable_dynamic_position is false.

Returns:

  • (::Boolean)

    Enables dynamic position for this facet. If set to true, the position of this facet among all facets in the response is determined automatically. If dynamic facets are enabled, it is ordered together. If set to false, the position of this facet in the response is the same as in the request, and it is ranked before the facets with dynamic position enable and all dynamic facets.

    For example, you may always want to have rating facet returned in the response, but it's not necessarily to always display the rating facet at the top. In that case, you can set enable_dynamic_position to true so that the position of rating facet in response is determined automatically.

    Another example, assuming you have the following facets in the request:

    • "rating", enable_dynamic_position = true

    • "price", enable_dynamic_position = false

    • "brands", enable_dynamic_position = false

    And also you have a dynamic facets enabled, which generates a facet gender. Then the final order of the facets in the response can be ("price", "brands", "rating", "gender") or ("price", "brands", "gender", "rating") depends on how API orders "gender" and "rating" facets. However, notice that "price" and "brands" are always ranked at first and second position because their enable_dynamic_position is false.



607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 607

class FacetSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies how a facet is computed.
  # @!attribute [rw] key
  #   @return [::String]
  #     Required. Supported textual and numerical facet keys in
  #     {::Google::Cloud::DiscoveryEngine::V1beta::Document Document} object, over
  #     which the facet values are computed. Facet key is case-sensitive.
  # @!attribute [rw] intervals
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::Interval>]
  #     Set only if values should be bucketed into intervals. Must be set
  #     for facets with numerical values. Must not be set for facet with text
  #     values. Maximum number of intervals is 30.
  # @!attribute [rw] restricted_values
  #   @return [::Array<::String>]
  #     Only get facet for the given restricted values. Only supported on
  #     textual fields. For example, suppose "category" has three values
  #     "Action > 2022", "Action > 2021" and "Sci-Fi > 2022". If set
  #     "restricted_values" to "Action > 2022", the "category" facet only
  #     contains "Action > 2022". Only supported on textual fields. Maximum
  #     is 10.
  # @!attribute [rw] prefixes
  #   @return [::Array<::String>]
  #     Only get facet values that start with the given string prefix. For
  #     example, suppose "category" has three values "Action > 2022",
  #     "Action > 2021" and "Sci-Fi > 2022". If set "prefixes" to "Action", the
  #     "category" facet only contains "Action > 2022" and "Action > 2021".
  #     Only supported on textual fields. Maximum is 10.
  # @!attribute [rw] contains
  #   @return [::Array<::String>]
  #     Only get facet values that contain the given strings. For example,
  #     suppose "category" has three values "Action > 2022",
  #     "Action > 2021" and "Sci-Fi > 2022". If set "contains" to "2022", the
  #     "category" facet only contains "Action > 2022" and "Sci-Fi > 2022".
  #     Only supported on textual fields. Maximum is 10.
  # @!attribute [rw] case_insensitive
  #   @return [::Boolean]
  #     True to make facet keys case insensitive when getting faceting
  #     values with prefixes or contains; false otherwise.
  # @!attribute [rw] order_by
  #   @return [::String]
  #     The order in which documents are returned.
  #
  #     Allowed values are:
  #
  #     * "count desc", which means order by
  #     {::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Facet::FacetValue#count SearchResponse.Facet.values.count}
  #     descending.
  #
  #     * "value desc", which means order by
  #     {::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Facet::FacetValue#value SearchResponse.Facet.values.value}
  #     descending.
  #       Only applies to textual facets.
  #
  #     If not set, textual values are sorted in [natural
  #     order](https://en.wikipedia.org/wiki/Natural_sort_order); numerical
  #     intervals are sorted in the order given by
  #     {::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::FacetSpec::FacetKey#intervals FacetSpec.FacetKey.intervals}.
  class FacetKey
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#excluded_filter_keys::Array<::String>

List of keys to exclude when faceting.

By default, FacetKey.key is not excluded from the filter unless it is listed in this field.

Listing a facet key in this field allows its values to appear as facet results, even when they are filtered out of search results. Using this field does not affect what search results are returned.

For example, suppose there are 100 documents with the color facet "Red" and 200 documents with the color facet "Blue". A query containing the filter "color:ANY("Red")" and having "color" as FacetKey.key would by default return only "Red" documents in the search results, and also return "Red" with count 100 as the only color facet. Although there are also blue documents available, "Blue" would not be shown as an available facet value.

If "color" is listed in "excludedFilterKeys", then the query returns the facet values "Red" with count 100 and "Blue" with count 200, because the "color" key is now excluded from the filter. Because this field doesn't affect search results, the search results are still correctly filtered to return only "Red" documents.

A maximum of 100 values are allowed. Otherwise, an INVALID_ARGUMENT error is returned.

Returns:

  • (::Array<::String>)

    List of keys to exclude when faceting.

    By default, FacetKey.key is not excluded from the filter unless it is listed in this field.

    Listing a facet key in this field allows its values to appear as facet results, even when they are filtered out of search results. Using this field does not affect what search results are returned.

    For example, suppose there are 100 documents with the color facet "Red" and 200 documents with the color facet "Blue". A query containing the filter "color:ANY("Red")" and having "color" as FacetKey.key would by default return only "Red" documents in the search results, and also return "Red" with count 100 as the only color facet. Although there are also blue documents available, "Blue" would not be shown as an available facet value.

    If "color" is listed in "excludedFilterKeys", then the query returns the facet values "Red" with count 100 and "Blue" with count 200, because the "color" key is now excluded from the filter. Because this field doesn't affect search results, the search results are still correctly filtered to return only "Red" documents.

    A maximum of 100 values are allowed. Otherwise, an INVALID_ARGUMENT error is returned.



607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 607

class FacetSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies how a facet is computed.
  # @!attribute [rw] key
  #   @return [::String]
  #     Required. Supported textual and numerical facet keys in
  #     {::Google::Cloud::DiscoveryEngine::V1beta::Document Document} object, over
  #     which the facet values are computed. Facet key is case-sensitive.
  # @!attribute [rw] intervals
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::Interval>]
  #     Set only if values should be bucketed into intervals. Must be set
  #     for facets with numerical values. Must not be set for facet with text
  #     values. Maximum number of intervals is 30.
  # @!attribute [rw] restricted_values
  #   @return [::Array<::String>]
  #     Only get facet for the given restricted values. Only supported on
  #     textual fields. For example, suppose "category" has three values
  #     "Action > 2022", "Action > 2021" and "Sci-Fi > 2022". If set
  #     "restricted_values" to "Action > 2022", the "category" facet only
  #     contains "Action > 2022". Only supported on textual fields. Maximum
  #     is 10.
  # @!attribute [rw] prefixes
  #   @return [::Array<::String>]
  #     Only get facet values that start with the given string prefix. For
  #     example, suppose "category" has three values "Action > 2022",
  #     "Action > 2021" and "Sci-Fi > 2022". If set "prefixes" to "Action", the
  #     "category" facet only contains "Action > 2022" and "Action > 2021".
  #     Only supported on textual fields. Maximum is 10.
  # @!attribute [rw] contains
  #   @return [::Array<::String>]
  #     Only get facet values that contain the given strings. For example,
  #     suppose "category" has three values "Action > 2022",
  #     "Action > 2021" and "Sci-Fi > 2022". If set "contains" to "2022", the
  #     "category" facet only contains "Action > 2022" and "Sci-Fi > 2022".
  #     Only supported on textual fields. Maximum is 10.
  # @!attribute [rw] case_insensitive
  #   @return [::Boolean]
  #     True to make facet keys case insensitive when getting faceting
  #     values with prefixes or contains; false otherwise.
  # @!attribute [rw] order_by
  #   @return [::String]
  #     The order in which documents are returned.
  #
  #     Allowed values are:
  #
  #     * "count desc", which means order by
  #     {::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Facet::FacetValue#count SearchResponse.Facet.values.count}
  #     descending.
  #
  #     * "value desc", which means order by
  #     {::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Facet::FacetValue#value SearchResponse.Facet.values.value}
  #     descending.
  #       Only applies to textual facets.
  #
  #     If not set, textual values are sorted in [natural
  #     order](https://en.wikipedia.org/wiki/Natural_sort_order); numerical
  #     intervals are sorted in the order given by
  #     {::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::FacetSpec::FacetKey#intervals FacetSpec.FacetKey.intervals}.
  class FacetKey
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#facet_key::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::FacetSpec::FacetKey

Returns Required. The facet key specification.

Returns:



607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 607

class FacetSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies how a facet is computed.
  # @!attribute [rw] key
  #   @return [::String]
  #     Required. Supported textual and numerical facet keys in
  #     {::Google::Cloud::DiscoveryEngine::V1beta::Document Document} object, over
  #     which the facet values are computed. Facet key is case-sensitive.
  # @!attribute [rw] intervals
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::Interval>]
  #     Set only if values should be bucketed into intervals. Must be set
  #     for facets with numerical values. Must not be set for facet with text
  #     values. Maximum number of intervals is 30.
  # @!attribute [rw] restricted_values
  #   @return [::Array<::String>]
  #     Only get facet for the given restricted values. Only supported on
  #     textual fields. For example, suppose "category" has three values
  #     "Action > 2022", "Action > 2021" and "Sci-Fi > 2022". If set
  #     "restricted_values" to "Action > 2022", the "category" facet only
  #     contains "Action > 2022". Only supported on textual fields. Maximum
  #     is 10.
  # @!attribute [rw] prefixes
  #   @return [::Array<::String>]
  #     Only get facet values that start with the given string prefix. For
  #     example, suppose "category" has three values "Action > 2022",
  #     "Action > 2021" and "Sci-Fi > 2022". If set "prefixes" to "Action", the
  #     "category" facet only contains "Action > 2022" and "Action > 2021".
  #     Only supported on textual fields. Maximum is 10.
  # @!attribute [rw] contains
  #   @return [::Array<::String>]
  #     Only get facet values that contain the given strings. For example,
  #     suppose "category" has three values "Action > 2022",
  #     "Action > 2021" and "Sci-Fi > 2022". If set "contains" to "2022", the
  #     "category" facet only contains "Action > 2022" and "Sci-Fi > 2022".
  #     Only supported on textual fields. Maximum is 10.
  # @!attribute [rw] case_insensitive
  #   @return [::Boolean]
  #     True to make facet keys case insensitive when getting faceting
  #     values with prefixes or contains; false otherwise.
  # @!attribute [rw] order_by
  #   @return [::String]
  #     The order in which documents are returned.
  #
  #     Allowed values are:
  #
  #     * "count desc", which means order by
  #     {::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Facet::FacetValue#count SearchResponse.Facet.values.count}
  #     descending.
  #
  #     * "value desc", which means order by
  #     {::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Facet::FacetValue#value SearchResponse.Facet.values.value}
  #     descending.
  #       Only applies to textual facets.
  #
  #     If not set, textual values are sorted in [natural
  #     order](https://en.wikipedia.org/wiki/Natural_sort_order); numerical
  #     intervals are sorted in the order given by
  #     {::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::FacetSpec::FacetKey#intervals FacetSpec.FacetKey.intervals}.
  class FacetKey
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#limit::Integer

Returns Maximum facet values that are returned for this facet. If unspecified, defaults to 20. The maximum allowed value is 300. Values above 300 are coerced to 300. For aggregation in healthcare search, when the [FacetKey.key] is "healthcare_aggregation_key", the limit will be overridden to 10,000 internally, regardless of the value set here.

If this field is negative, an INVALID_ARGUMENT is returned.

Returns:

  • (::Integer)

    Maximum facet values that are returned for this facet. If unspecified, defaults to 20. The maximum allowed value is 300. Values above 300 are coerced to 300. For aggregation in healthcare search, when the [FacetKey.key] is "healthcare_aggregation_key", the limit will be overridden to 10,000 internally, regardless of the value set here.

    If this field is negative, an INVALID_ARGUMENT is returned.



607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 607

class FacetSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies how a facet is computed.
  # @!attribute [rw] key
  #   @return [::String]
  #     Required. Supported textual and numerical facet keys in
  #     {::Google::Cloud::DiscoveryEngine::V1beta::Document Document} object, over
  #     which the facet values are computed. Facet key is case-sensitive.
  # @!attribute [rw] intervals
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::Interval>]
  #     Set only if values should be bucketed into intervals. Must be set
  #     for facets with numerical values. Must not be set for facet with text
  #     values. Maximum number of intervals is 30.
  # @!attribute [rw] restricted_values
  #   @return [::Array<::String>]
  #     Only get facet for the given restricted values. Only supported on
  #     textual fields. For example, suppose "category" has three values
  #     "Action > 2022", "Action > 2021" and "Sci-Fi > 2022". If set
  #     "restricted_values" to "Action > 2022", the "category" facet only
  #     contains "Action > 2022". Only supported on textual fields. Maximum
  #     is 10.
  # @!attribute [rw] prefixes
  #   @return [::Array<::String>]
  #     Only get facet values that start with the given string prefix. For
  #     example, suppose "category" has three values "Action > 2022",
  #     "Action > 2021" and "Sci-Fi > 2022". If set "prefixes" to "Action", the
  #     "category" facet only contains "Action > 2022" and "Action > 2021".
  #     Only supported on textual fields. Maximum is 10.
  # @!attribute [rw] contains
  #   @return [::Array<::String>]
  #     Only get facet values that contain the given strings. For example,
  #     suppose "category" has three values "Action > 2022",
  #     "Action > 2021" and "Sci-Fi > 2022". If set "contains" to "2022", the
  #     "category" facet only contains "Action > 2022" and "Sci-Fi > 2022".
  #     Only supported on textual fields. Maximum is 10.
  # @!attribute [rw] case_insensitive
  #   @return [::Boolean]
  #     True to make facet keys case insensitive when getting faceting
  #     values with prefixes or contains; false otherwise.
  # @!attribute [rw] order_by
  #   @return [::String]
  #     The order in which documents are returned.
  #
  #     Allowed values are:
  #
  #     * "count desc", which means order by
  #     {::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Facet::FacetValue#count SearchResponse.Facet.values.count}
  #     descending.
  #
  #     * "value desc", which means order by
  #     {::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Facet::FacetValue#value SearchResponse.Facet.values.value}
  #     descending.
  #       Only applies to textual facets.
  #
  #     If not set, textual values are sorted in [natural
  #     order](https://en.wikipedia.org/wiki/Natural_sort_order); numerical
  #     intervals are sorted in the order given by
  #     {::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::FacetSpec::FacetKey#intervals FacetSpec.FacetKey.intervals}.
  class FacetKey
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end