Class: Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::QueryExpansionSpec

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb

Overview

Specification to determine under which conditions query expansion should occur.

Defined Under Namespace

Modules: Condition

Instance Attribute Summary collapse

Instance Attribute Details

#condition::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::QueryExpansionSpec::Condition

Returns The condition under which query expansion should occur. Default to Condition.DISABLED.

Returns:



819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 819

class QueryExpansionSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum describing under which condition query expansion should occur.
  module Condition
    # Unspecified query expansion condition. In this case, server behavior
    # defaults to
    # {::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::QueryExpansionSpec::Condition::DISABLED Condition.DISABLED}.
    CONDITION_UNSPECIFIED = 0

    # Disabled query expansion. Only the exact search query is used, even if
    # {::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse#total_size SearchResponse.total_size}
    # is zero.
    DISABLED = 1

    # Automatic query expansion built by the Search API.
    AUTO = 2
  end
end

#pin_unexpanded_results::Boolean

Returns Whether to pin unexpanded results. If this field is set to true, unexpanded products are always at the top of the search results, followed by the expanded results.

Returns:

  • (::Boolean)

    Whether to pin unexpanded results. If this field is set to true, unexpanded products are always at the top of the search results, followed by the expanded results.



819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 819

class QueryExpansionSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum describing under which condition query expansion should occur.
  module Condition
    # Unspecified query expansion condition. In this case, server behavior
    # defaults to
    # {::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::QueryExpansionSpec::Condition::DISABLED Condition.DISABLED}.
    CONDITION_UNSPECIFIED = 0

    # Disabled query expansion. Only the exact search query is used, even if
    # {::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse#total_size SearchResponse.total_size}
    # is zero.
    DISABLED = 1

    # Automatic query expansion built by the Search API.
    AUTO = 2
  end
end