Class: Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::SessionSpec

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb

Overview

Session specification.

Instance Attribute Summary collapse

Instance Attribute Details

#query_id::String

Returns If set, the search result gets stored to the "turn" specified by this query ID.

Example: Let's say the session looks like this: session { name: ".../sessions/xxx" turns { query { text: "What is foo?" query_id: ".../questions/yyy" } answer: "Foo is ..." } turns { query { text: "How about bar then?" query_id: ".../questions/zzz" } } }

The user can call /search API with a request like this:

session: ".../sessions/xxx" session_spec { query_id: ".../questions/zzz" }

Then, the API stores the search result, associated with the last turn. The stored search result can be used by a subsequent /answer API call (with the session ID and the query ID specified). Also, it is possible to call /search and /answer in parallel with the same session ID & query ID.

Returns:

  • (::String)

    If set, the search result gets stored to the "turn" specified by this query ID.

    Example: Let's say the session looks like this: session { name: ".../sessions/xxx" turns { query { text: "What is foo?" query_id: ".../questions/yyy" } answer: "Foo is ..." } turns { query { text: "How about bar then?" query_id: ".../questions/zzz" } } }

    The user can call /search API with a request like this:

    session: ".../sessions/xxx" session_spec { query_id: ".../questions/zzz" }

    Then, the API stores the search result, associated with the last turn. The stored search result can be used by a subsequent /answer API call (with the session ID and the query ID specified). Also, it is possible to call /search and /answer in parallel with the same session ID & query ID.



1392
1393
1394
1395
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1392

class SessionSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#search_result_persistence_count::Integer

Returns The number of top search results to persist. The persisted search results can be used for the subsequent /answer api call.

This field is similar to the summary_result_count field in SearchRequest.ContentSearchSpec.SummarySpec.summary_result_count.

At most 10 results for documents mode, or 50 for chunks mode.

Returns:

  • (::Integer)

    The number of top search results to persist. The persisted search results can be used for the subsequent /answer api call.

    This field is similar to the summary_result_count field in SearchRequest.ContentSearchSpec.SummarySpec.summary_result_count.

    At most 10 results for documents mode, or 50 for chunks mode.



1392
1393
1394
1395
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1392

class SessionSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end