Class: Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::SearchResult::RankSignals
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::SearchResult::RankSignals
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb
Overview
A set of ranking signals.
Defined Under Namespace
Classes: CustomSignal
Instance Attribute Summary collapse
-
#boosting_factor ⇒ ::Float
Optional.
-
#custom_signals ⇒ ::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::SearchResult::RankSignals::CustomSignal>
Optional.
-
#default_rank ⇒ ::Float
Optional.
-
#document_age ⇒ ::Float
Optional.
-
#keyword_similarity_score ⇒ ::Float
Optional.
-
#pctr_rank ⇒ ::Float
Optional.
-
#precomputed_expression_values ⇒ ::Array<::Float>
Optional.
-
#relevance_score ⇒ ::Float
Optional.
-
#semantic_similarity_score ⇒ ::Float
Optional.
-
#topicality_rank ⇒ ::Float
Optional.
Instance Attribute Details
#boosting_factor ⇒ ::Float
Returns Optional. Combined custom boosts for a doc.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1708 class RankSignals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Custom clearbox signal represented by name and value pair. # @!attribute [rw] name # @return [::String] # Optional. Name of the signal. # @!attribute [rw] value # @return [::Float] # Optional. Float value representing the ranking signal (e.g. 1.25 for # BM25). class CustomSignal include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#custom_signals ⇒ ::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::SearchResult::RankSignals::CustomSignal>
Returns Optional. A list of custom clearbox signals.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1708 class RankSignals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Custom clearbox signal represented by name and value pair. # @!attribute [rw] name # @return [::String] # Optional. Name of the signal. # @!attribute [rw] value # @return [::Float] # Optional. Float value representing the ranking signal (e.g. 1.25 for # BM25). class CustomSignal include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#default_rank ⇒ ::Float
Returns Optional. The default rank of the result.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1708 class RankSignals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Custom clearbox signal represented by name and value pair. # @!attribute [rw] name # @return [::String] # Optional. Name of the signal. # @!attribute [rw] value # @return [::Float] # Optional. Float value representing the ranking signal (e.g. 1.25 for # BM25). class CustomSignal include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#document_age ⇒ ::Float
Returns Optional. Age of the document in hours.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1708 class RankSignals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Custom clearbox signal represented by name and value pair. # @!attribute [rw] name # @return [::String] # Optional. Name of the signal. # @!attribute [rw] value # @return [::Float] # Optional. Float value representing the ranking signal (e.g. 1.25 for # BM25). class CustomSignal include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#keyword_similarity_score ⇒ ::Float
Returns Optional. Keyword matching adjustment.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1708 class RankSignals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Custom clearbox signal represented by name and value pair. # @!attribute [rw] name # @return [::String] # Optional. Name of the signal. # @!attribute [rw] value # @return [::Float] # Optional. Float value representing the ranking signal (e.g. 1.25 for # BM25). class CustomSignal include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#pctr_rank ⇒ ::Float
Returns Optional. Predicted conversion rate adjustment as a rank.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1708 class RankSignals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Custom clearbox signal represented by name and value pair. # @!attribute [rw] name # @return [::String] # Optional. Name of the signal. # @!attribute [rw] value # @return [::Float] # Optional. Float value representing the ranking signal (e.g. 1.25 for # BM25). class CustomSignal include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#precomputed_expression_values ⇒ ::Array<::Float>
Returns Optional. A list of precomputed expression results for a given
document, in the same order as requested in
SearchRequest.custom_ranking_params.expressions_to_precompute.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1708 class RankSignals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Custom clearbox signal represented by name and value pair. # @!attribute [rw] name # @return [::String] # Optional. Name of the signal. # @!attribute [rw] value # @return [::Float] # Optional. Float value representing the ranking signal (e.g. 1.25 for # BM25). class CustomSignal include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#relevance_score ⇒ ::Float
Returns Optional. Semantic relevance adjustment.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1708 class RankSignals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Custom clearbox signal represented by name and value pair. # @!attribute [rw] name # @return [::String] # Optional. Name of the signal. # @!attribute [rw] value # @return [::Float] # Optional. Float value representing the ranking signal (e.g. 1.25 for # BM25). class CustomSignal include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#semantic_similarity_score ⇒ ::Float
Returns Optional. Semantic similarity adjustment.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1708 class RankSignals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Custom clearbox signal represented by name and value pair. # @!attribute [rw] name # @return [::String] # Optional. Name of the signal. # @!attribute [rw] value # @return [::Float] # Optional. Float value representing the ranking signal (e.g. 1.25 for # BM25). class CustomSignal include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#topicality_rank ⇒ ::Float
Returns Optional. Topicality adjustment as a rank.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1708 class RankSignals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Custom clearbox signal represented by name and value pair. # @!attribute [rw] name # @return [::String] # Optional. Name of the signal. # @!attribute [rw] value # @return [::Float] # Optional. Float value representing the ranking signal (e.g. 1.25 for # BM25). class CustomSignal include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |