Class: Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb

Overview

Summary of the top N search results specified by the summary spec.

Defined Under Namespace

Modules: SummarySkippedReason Classes: BlobAttachment, Citation, CitationMetadata, CitationSource, Reference, SafetyAttributes, SummaryWithMetadata

Instance Attribute Summary collapse

Instance Attribute Details

#safety_attributes::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::SafetyAttributes

Returns A collection of Safety Attribute categories and their associated confidence scores.

Returns:



1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
1944
1945
1946
1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
1991
1992
1993
1994
1995
1996
1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
2028
2029
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1813

class Summary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Safety Attribute categories and their associated confidence scores.
  # @!attribute [rw] categories
  #   @return [::Array<::String>]
  #     The display names of Safety Attribute categories associated with the
  #     generated content. Order matches the Scores.
  # @!attribute [rw] scores
  #   @return [::Array<::Float>]
  #     The confidence scores of the each category, higher
  #     value means higher confidence. Order matches the Categories.
  class SafetyAttributes
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Citation metadata.
  # @!attribute [rw] citations
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::Citation>]
  #     Citations for segments.
  class CitationMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Citation info for a segment.
  # @!attribute [rw] start_index
  #   @return [::Integer]
  #     Index indicates the start of the segment, measured in bytes/unicode.
  # @!attribute [rw] end_index
  #   @return [::Integer]
  #     End of the attributed segment, exclusive.
  # @!attribute [rw] sources
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::CitationSource>]
  #     Citation sources for the attributed segment.
  class Citation
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Citation source.
  # @!attribute [rw] reference_index
  #   @return [::Integer]
  #     Document reference index from SummaryWithMetadata.references.
  #     It is 0-indexed and the value will be zero if the reference_index is
  #     not set explicitly.
  class CitationSource
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Document reference.
  # @!attribute [rw] title
  #   @return [::String]
  #     Title of the document.
  # @!attribute [rw] document
  #   @return [::String]
  #     Required.
  #     {::Google::Cloud::DiscoveryEngine::V1beta::Document#name Document.name} of
  #     the document. Full resource name of the referenced document, in the
  #     format
  #     `projects/*/locations/*/collections/*/dataStores/*/branches/*/documents/*`.
  # @!attribute [rw] uri
  #   @return [::String]
  #     Cloud Storage or HTTP uri for the document.
  # @!attribute [rw] chunk_contents
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::Reference::ChunkContent>]
  #     List of cited chunk contents derived from document content.
  class Reference
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Chunk content.
    # @!attribute [rw] content
    #   @return [::String]
    #     Chunk textual content.
    # @!attribute [rw] page_identifier
    #   @return [::String]
    #     Page identifier.
    # @!attribute [r] blob_attachment_indexes
    #   @return [::Array<::Integer>]
    #     Output only. Stores indexes of blobattachments linked to this chunk.
    class ChunkContent
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # Stores binarydata attached to text answer, e.g. image, video, audio, etc.
  # @!attribute [r] data
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::BlobAttachment::Blob]
  #     Output only. The blob data.
  # @!attribute [r] attribution_type
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::BlobAttachment::AttributionType]
  #     Output only. The attribution type of the blob.
  class BlobAttachment
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Stores type and data of the blob.
    # @!attribute [r] mime_type
    #   @return [::String]
    #     Output only. The media type (MIME type) of the generated data.
    # @!attribute [r] data
    #   @return [::String]
    #     Output only. Raw bytes.
    class Blob
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Defines the attribution type of the blob.
    module AttributionType
      # Unspecified attribution type.
      ATTRIBUTION_TYPE_UNSPECIFIED = 0

      # The attachment data is from the corpus.
      CORPUS = 1

      # The attachment data is generated by the model through code
      # generation.
      GENERATED = 2
    end
  end

  # Summary with metadata information.
  # @!attribute [rw] summary
  #   @return [::String]
  #     Summary text with no citation information.
  # @!attribute [rw] citation_metadata
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::CitationMetadata]
  #     Citation metadata for given summary.
  # @!attribute [rw] references
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::Reference>]
  #     Document References.
  # @!attribute [r] blob_attachments
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::BlobAttachment>]
  #     Output only. Store multimodal data for answer enhancement.
  class SummaryWithMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # An Enum for summary-skipped reasons.
  module SummarySkippedReason
    # Default value. The summary skipped reason is not specified.
    SUMMARY_SKIPPED_REASON_UNSPECIFIED = 0

    # The adversarial query ignored case.
    #
    # Only used when
    # {::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::ContentSearchSpec::SummarySpec#ignore_adversarial_query SummarySpec.ignore_adversarial_query}
    # is set to `true`.
    ADVERSARIAL_QUERY_IGNORED = 1

    # The non-summary seeking query ignored case.
    #
    # Google skips the summary if the query is chit chat.
    # Only used when
    # {::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::ContentSearchSpec::SummarySpec#ignore_non_summary_seeking_query SummarySpec.ignore_non_summary_seeking_query}
    # is set to `true`.
    NON_SUMMARY_SEEKING_QUERY_IGNORED = 2

    # The out-of-domain query ignored case.
    #
    # Google skips the summary if there are no high-relevance search results.
    # For example, the data store contains facts about company A but the
    # user query is asking questions about company B.
    OUT_OF_DOMAIN_QUERY_IGNORED = 3

    # The potential policy violation case.
    #
    # Google skips the summary if there is a potential policy violation
    # detected. This includes content that may be violent or toxic.
    POTENTIAL_POLICY_VIOLATION = 4

    # The LLM addon not enabled case.
    #
    # Google skips the summary if the LLM addon is not enabled.
    LLM_ADDON_NOT_ENABLED = 5

    # The no relevant content case.
    #
    # Google skips the summary if there is no relevant content in the
    # retrieved search results.
    NO_RELEVANT_CONTENT = 6

    # The jail-breaking query ignored case.
    #
    # For example, "Reply in the tone of a competing company's CEO".
    # Only used when
    # [SearchRequest.ContentSearchSpec.SummarySpec.ignore_jail_breaking_query]
    # is set to `true`.
    JAIL_BREAKING_QUERY_IGNORED = 7

    # The customer policy violation case.
    #
    # Google skips the summary if there is a customer policy violation
    # detected. The policy is defined by the customer.
    CUSTOMER_POLICY_VIOLATION = 8

    # The non-answer seeking query ignored case.
    #
    # Google skips the summary if the query doesn't have clear intent.
    # Only used when
    # [SearchRequest.ContentSearchSpec.SummarySpec.ignore_non_answer_seeking_query]
    # is set to `true`.
    NON_SUMMARY_SEEKING_QUERY_IGNORED_V2 = 9

    # The time out case.
    #
    # Google skips the summary if the time out.
    TIME_OUT = 10
  end
end

#summary_skipped_reasons::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::SummarySkippedReason>

Returns Additional summary-skipped reasons. This provides the reason for ignored cases. If nothing is skipped, this field is not set.

Returns:



1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
1944
1945
1946
1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
1991
1992
1993
1994
1995
1996
1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
2028
2029
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1813

class Summary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Safety Attribute categories and their associated confidence scores.
  # @!attribute [rw] categories
  #   @return [::Array<::String>]
  #     The display names of Safety Attribute categories associated with the
  #     generated content. Order matches the Scores.
  # @!attribute [rw] scores
  #   @return [::Array<::Float>]
  #     The confidence scores of the each category, higher
  #     value means higher confidence. Order matches the Categories.
  class SafetyAttributes
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Citation metadata.
  # @!attribute [rw] citations
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::Citation>]
  #     Citations for segments.
  class CitationMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Citation info for a segment.
  # @!attribute [rw] start_index
  #   @return [::Integer]
  #     Index indicates the start of the segment, measured in bytes/unicode.
  # @!attribute [rw] end_index
  #   @return [::Integer]
  #     End of the attributed segment, exclusive.
  # @!attribute [rw] sources
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::CitationSource>]
  #     Citation sources for the attributed segment.
  class Citation
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Citation source.
  # @!attribute [rw] reference_index
  #   @return [::Integer]
  #     Document reference index from SummaryWithMetadata.references.
  #     It is 0-indexed and the value will be zero if the reference_index is
  #     not set explicitly.
  class CitationSource
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Document reference.
  # @!attribute [rw] title
  #   @return [::String]
  #     Title of the document.
  # @!attribute [rw] document
  #   @return [::String]
  #     Required.
  #     {::Google::Cloud::DiscoveryEngine::V1beta::Document#name Document.name} of
  #     the document. Full resource name of the referenced document, in the
  #     format
  #     `projects/*/locations/*/collections/*/dataStores/*/branches/*/documents/*`.
  # @!attribute [rw] uri
  #   @return [::String]
  #     Cloud Storage or HTTP uri for the document.
  # @!attribute [rw] chunk_contents
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::Reference::ChunkContent>]
  #     List of cited chunk contents derived from document content.
  class Reference
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Chunk content.
    # @!attribute [rw] content
    #   @return [::String]
    #     Chunk textual content.
    # @!attribute [rw] page_identifier
    #   @return [::String]
    #     Page identifier.
    # @!attribute [r] blob_attachment_indexes
    #   @return [::Array<::Integer>]
    #     Output only. Stores indexes of blobattachments linked to this chunk.
    class ChunkContent
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # Stores binarydata attached to text answer, e.g. image, video, audio, etc.
  # @!attribute [r] data
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::BlobAttachment::Blob]
  #     Output only. The blob data.
  # @!attribute [r] attribution_type
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::BlobAttachment::AttributionType]
  #     Output only. The attribution type of the blob.
  class BlobAttachment
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Stores type and data of the blob.
    # @!attribute [r] mime_type
    #   @return [::String]
    #     Output only. The media type (MIME type) of the generated data.
    # @!attribute [r] data
    #   @return [::String]
    #     Output only. Raw bytes.
    class Blob
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Defines the attribution type of the blob.
    module AttributionType
      # Unspecified attribution type.
      ATTRIBUTION_TYPE_UNSPECIFIED = 0

      # The attachment data is from the corpus.
      CORPUS = 1

      # The attachment data is generated by the model through code
      # generation.
      GENERATED = 2
    end
  end

  # Summary with metadata information.
  # @!attribute [rw] summary
  #   @return [::String]
  #     Summary text with no citation information.
  # @!attribute [rw] citation_metadata
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::CitationMetadata]
  #     Citation metadata for given summary.
  # @!attribute [rw] references
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::Reference>]
  #     Document References.
  # @!attribute [r] blob_attachments
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::BlobAttachment>]
  #     Output only. Store multimodal data for answer enhancement.
  class SummaryWithMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # An Enum for summary-skipped reasons.
  module SummarySkippedReason
    # Default value. The summary skipped reason is not specified.
    SUMMARY_SKIPPED_REASON_UNSPECIFIED = 0

    # The adversarial query ignored case.
    #
    # Only used when
    # {::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::ContentSearchSpec::SummarySpec#ignore_adversarial_query SummarySpec.ignore_adversarial_query}
    # is set to `true`.
    ADVERSARIAL_QUERY_IGNORED = 1

    # The non-summary seeking query ignored case.
    #
    # Google skips the summary if the query is chit chat.
    # Only used when
    # {::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::ContentSearchSpec::SummarySpec#ignore_non_summary_seeking_query SummarySpec.ignore_non_summary_seeking_query}
    # is set to `true`.
    NON_SUMMARY_SEEKING_QUERY_IGNORED = 2

    # The out-of-domain query ignored case.
    #
    # Google skips the summary if there are no high-relevance search results.
    # For example, the data store contains facts about company A but the
    # user query is asking questions about company B.
    OUT_OF_DOMAIN_QUERY_IGNORED = 3

    # The potential policy violation case.
    #
    # Google skips the summary if there is a potential policy violation
    # detected. This includes content that may be violent or toxic.
    POTENTIAL_POLICY_VIOLATION = 4

    # The LLM addon not enabled case.
    #
    # Google skips the summary if the LLM addon is not enabled.
    LLM_ADDON_NOT_ENABLED = 5

    # The no relevant content case.
    #
    # Google skips the summary if there is no relevant content in the
    # retrieved search results.
    NO_RELEVANT_CONTENT = 6

    # The jail-breaking query ignored case.
    #
    # For example, "Reply in the tone of a competing company's CEO".
    # Only used when
    # [SearchRequest.ContentSearchSpec.SummarySpec.ignore_jail_breaking_query]
    # is set to `true`.
    JAIL_BREAKING_QUERY_IGNORED = 7

    # The customer policy violation case.
    #
    # Google skips the summary if there is a customer policy violation
    # detected. The policy is defined by the customer.
    CUSTOMER_POLICY_VIOLATION = 8

    # The non-answer seeking query ignored case.
    #
    # Google skips the summary if the query doesn't have clear intent.
    # Only used when
    # [SearchRequest.ContentSearchSpec.SummarySpec.ignore_non_answer_seeking_query]
    # is set to `true`.
    NON_SUMMARY_SEEKING_QUERY_IGNORED_V2 = 9

    # The time out case.
    #
    # Google skips the summary if the time out.
    TIME_OUT = 10
  end
end

#summary_text::String

Returns The summary content.

Returns:

  • (::String)

    The summary content.



1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
1944
1945
1946
1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
1991
1992
1993
1994
1995
1996
1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
2028
2029
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1813

class Summary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Safety Attribute categories and their associated confidence scores.
  # @!attribute [rw] categories
  #   @return [::Array<::String>]
  #     The display names of Safety Attribute categories associated with the
  #     generated content. Order matches the Scores.
  # @!attribute [rw] scores
  #   @return [::Array<::Float>]
  #     The confidence scores of the each category, higher
  #     value means higher confidence. Order matches the Categories.
  class SafetyAttributes
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Citation metadata.
  # @!attribute [rw] citations
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::Citation>]
  #     Citations for segments.
  class CitationMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Citation info for a segment.
  # @!attribute [rw] start_index
  #   @return [::Integer]
  #     Index indicates the start of the segment, measured in bytes/unicode.
  # @!attribute [rw] end_index
  #   @return [::Integer]
  #     End of the attributed segment, exclusive.
  # @!attribute [rw] sources
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::CitationSource>]
  #     Citation sources for the attributed segment.
  class Citation
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Citation source.
  # @!attribute [rw] reference_index
  #   @return [::Integer]
  #     Document reference index from SummaryWithMetadata.references.
  #     It is 0-indexed and the value will be zero if the reference_index is
  #     not set explicitly.
  class CitationSource
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Document reference.
  # @!attribute [rw] title
  #   @return [::String]
  #     Title of the document.
  # @!attribute [rw] document
  #   @return [::String]
  #     Required.
  #     {::Google::Cloud::DiscoveryEngine::V1beta::Document#name Document.name} of
  #     the document. Full resource name of the referenced document, in the
  #     format
  #     `projects/*/locations/*/collections/*/dataStores/*/branches/*/documents/*`.
  # @!attribute [rw] uri
  #   @return [::String]
  #     Cloud Storage or HTTP uri for the document.
  # @!attribute [rw] chunk_contents
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::Reference::ChunkContent>]
  #     List of cited chunk contents derived from document content.
  class Reference
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Chunk content.
    # @!attribute [rw] content
    #   @return [::String]
    #     Chunk textual content.
    # @!attribute [rw] page_identifier
    #   @return [::String]
    #     Page identifier.
    # @!attribute [r] blob_attachment_indexes
    #   @return [::Array<::Integer>]
    #     Output only. Stores indexes of blobattachments linked to this chunk.
    class ChunkContent
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # Stores binarydata attached to text answer, e.g. image, video, audio, etc.
  # @!attribute [r] data
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::BlobAttachment::Blob]
  #     Output only. The blob data.
  # @!attribute [r] attribution_type
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::BlobAttachment::AttributionType]
  #     Output only. The attribution type of the blob.
  class BlobAttachment
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Stores type and data of the blob.
    # @!attribute [r] mime_type
    #   @return [::String]
    #     Output only. The media type (MIME type) of the generated data.
    # @!attribute [r] data
    #   @return [::String]
    #     Output only. Raw bytes.
    class Blob
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Defines the attribution type of the blob.
    module AttributionType
      # Unspecified attribution type.
      ATTRIBUTION_TYPE_UNSPECIFIED = 0

      # The attachment data is from the corpus.
      CORPUS = 1

      # The attachment data is generated by the model through code
      # generation.
      GENERATED = 2
    end
  end

  # Summary with metadata information.
  # @!attribute [rw] summary
  #   @return [::String]
  #     Summary text with no citation information.
  # @!attribute [rw] citation_metadata
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::CitationMetadata]
  #     Citation metadata for given summary.
  # @!attribute [rw] references
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::Reference>]
  #     Document References.
  # @!attribute [r] blob_attachments
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::BlobAttachment>]
  #     Output only. Store multimodal data for answer enhancement.
  class SummaryWithMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # An Enum for summary-skipped reasons.
  module SummarySkippedReason
    # Default value. The summary skipped reason is not specified.
    SUMMARY_SKIPPED_REASON_UNSPECIFIED = 0

    # The adversarial query ignored case.
    #
    # Only used when
    # {::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::ContentSearchSpec::SummarySpec#ignore_adversarial_query SummarySpec.ignore_adversarial_query}
    # is set to `true`.
    ADVERSARIAL_QUERY_IGNORED = 1

    # The non-summary seeking query ignored case.
    #
    # Google skips the summary if the query is chit chat.
    # Only used when
    # {::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::ContentSearchSpec::SummarySpec#ignore_non_summary_seeking_query SummarySpec.ignore_non_summary_seeking_query}
    # is set to `true`.
    NON_SUMMARY_SEEKING_QUERY_IGNORED = 2

    # The out-of-domain query ignored case.
    #
    # Google skips the summary if there are no high-relevance search results.
    # For example, the data store contains facts about company A but the
    # user query is asking questions about company B.
    OUT_OF_DOMAIN_QUERY_IGNORED = 3

    # The potential policy violation case.
    #
    # Google skips the summary if there is a potential policy violation
    # detected. This includes content that may be violent or toxic.
    POTENTIAL_POLICY_VIOLATION = 4

    # The LLM addon not enabled case.
    #
    # Google skips the summary if the LLM addon is not enabled.
    LLM_ADDON_NOT_ENABLED = 5

    # The no relevant content case.
    #
    # Google skips the summary if there is no relevant content in the
    # retrieved search results.
    NO_RELEVANT_CONTENT = 6

    # The jail-breaking query ignored case.
    #
    # For example, "Reply in the tone of a competing company's CEO".
    # Only used when
    # [SearchRequest.ContentSearchSpec.SummarySpec.ignore_jail_breaking_query]
    # is set to `true`.
    JAIL_BREAKING_QUERY_IGNORED = 7

    # The customer policy violation case.
    #
    # Google skips the summary if there is a customer policy violation
    # detected. The policy is defined by the customer.
    CUSTOMER_POLICY_VIOLATION = 8

    # The non-answer seeking query ignored case.
    #
    # Google skips the summary if the query doesn't have clear intent.
    # Only used when
    # [SearchRequest.ContentSearchSpec.SummarySpec.ignore_non_answer_seeking_query]
    # is set to `true`.
    NON_SUMMARY_SEEKING_QUERY_IGNORED_V2 = 9

    # The time out case.
    #
    # Google skips the summary if the time out.
    TIME_OUT = 10
  end
end

#summary_with_metadata::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::SummaryWithMetadata

Returns Summary with metadata information.



1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
1944
1945
1946
1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
1991
1992
1993
1994
1995
1996
1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
2028
2029
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1813

class Summary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Safety Attribute categories and their associated confidence scores.
  # @!attribute [rw] categories
  #   @return [::Array<::String>]
  #     The display names of Safety Attribute categories associated with the
  #     generated content. Order matches the Scores.
  # @!attribute [rw] scores
  #   @return [::Array<::Float>]
  #     The confidence scores of the each category, higher
  #     value means higher confidence. Order matches the Categories.
  class SafetyAttributes
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Citation metadata.
  # @!attribute [rw] citations
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::Citation>]
  #     Citations for segments.
  class CitationMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Citation info for a segment.
  # @!attribute [rw] start_index
  #   @return [::Integer]
  #     Index indicates the start of the segment, measured in bytes/unicode.
  # @!attribute [rw] end_index
  #   @return [::Integer]
  #     End of the attributed segment, exclusive.
  # @!attribute [rw] sources
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::CitationSource>]
  #     Citation sources for the attributed segment.
  class Citation
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Citation source.
  # @!attribute [rw] reference_index
  #   @return [::Integer]
  #     Document reference index from SummaryWithMetadata.references.
  #     It is 0-indexed and the value will be zero if the reference_index is
  #     not set explicitly.
  class CitationSource
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Document reference.
  # @!attribute [rw] title
  #   @return [::String]
  #     Title of the document.
  # @!attribute [rw] document
  #   @return [::String]
  #     Required.
  #     {::Google::Cloud::DiscoveryEngine::V1beta::Document#name Document.name} of
  #     the document. Full resource name of the referenced document, in the
  #     format
  #     `projects/*/locations/*/collections/*/dataStores/*/branches/*/documents/*`.
  # @!attribute [rw] uri
  #   @return [::String]
  #     Cloud Storage or HTTP uri for the document.
  # @!attribute [rw] chunk_contents
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::Reference::ChunkContent>]
  #     List of cited chunk contents derived from document content.
  class Reference
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Chunk content.
    # @!attribute [rw] content
    #   @return [::String]
    #     Chunk textual content.
    # @!attribute [rw] page_identifier
    #   @return [::String]
    #     Page identifier.
    # @!attribute [r] blob_attachment_indexes
    #   @return [::Array<::Integer>]
    #     Output only. Stores indexes of blobattachments linked to this chunk.
    class ChunkContent
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # Stores binarydata attached to text answer, e.g. image, video, audio, etc.
  # @!attribute [r] data
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::BlobAttachment::Blob]
  #     Output only. The blob data.
  # @!attribute [r] attribution_type
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::BlobAttachment::AttributionType]
  #     Output only. The attribution type of the blob.
  class BlobAttachment
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Stores type and data of the blob.
    # @!attribute [r] mime_type
    #   @return [::String]
    #     Output only. The media type (MIME type) of the generated data.
    # @!attribute [r] data
    #   @return [::String]
    #     Output only. Raw bytes.
    class Blob
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Defines the attribution type of the blob.
    module AttributionType
      # Unspecified attribution type.
      ATTRIBUTION_TYPE_UNSPECIFIED = 0

      # The attachment data is from the corpus.
      CORPUS = 1

      # The attachment data is generated by the model through code
      # generation.
      GENERATED = 2
    end
  end

  # Summary with metadata information.
  # @!attribute [rw] summary
  #   @return [::String]
  #     Summary text with no citation information.
  # @!attribute [rw] citation_metadata
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::CitationMetadata]
  #     Citation metadata for given summary.
  # @!attribute [rw] references
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::Reference>]
  #     Document References.
  # @!attribute [r] blob_attachments
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::BlobAttachment>]
  #     Output only. Store multimodal data for answer enhancement.
  class SummaryWithMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # An Enum for summary-skipped reasons.
  module SummarySkippedReason
    # Default value. The summary skipped reason is not specified.
    SUMMARY_SKIPPED_REASON_UNSPECIFIED = 0

    # The adversarial query ignored case.
    #
    # Only used when
    # {::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::ContentSearchSpec::SummarySpec#ignore_adversarial_query SummarySpec.ignore_adversarial_query}
    # is set to `true`.
    ADVERSARIAL_QUERY_IGNORED = 1

    # The non-summary seeking query ignored case.
    #
    # Google skips the summary if the query is chit chat.
    # Only used when
    # {::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::ContentSearchSpec::SummarySpec#ignore_non_summary_seeking_query SummarySpec.ignore_non_summary_seeking_query}
    # is set to `true`.
    NON_SUMMARY_SEEKING_QUERY_IGNORED = 2

    # The out-of-domain query ignored case.
    #
    # Google skips the summary if there are no high-relevance search results.
    # For example, the data store contains facts about company A but the
    # user query is asking questions about company B.
    OUT_OF_DOMAIN_QUERY_IGNORED = 3

    # The potential policy violation case.
    #
    # Google skips the summary if there is a potential policy violation
    # detected. This includes content that may be violent or toxic.
    POTENTIAL_POLICY_VIOLATION = 4

    # The LLM addon not enabled case.
    #
    # Google skips the summary if the LLM addon is not enabled.
    LLM_ADDON_NOT_ENABLED = 5

    # The no relevant content case.
    #
    # Google skips the summary if there is no relevant content in the
    # retrieved search results.
    NO_RELEVANT_CONTENT = 6

    # The jail-breaking query ignored case.
    #
    # For example, "Reply in the tone of a competing company's CEO".
    # Only used when
    # [SearchRequest.ContentSearchSpec.SummarySpec.ignore_jail_breaking_query]
    # is set to `true`.
    JAIL_BREAKING_QUERY_IGNORED = 7

    # The customer policy violation case.
    #
    # Google skips the summary if there is a customer policy violation
    # detected. The policy is defined by the customer.
    CUSTOMER_POLICY_VIOLATION = 8

    # The non-answer seeking query ignored case.
    #
    # Google skips the summary if the query doesn't have clear intent.
    # Only used when
    # [SearchRequest.ContentSearchSpec.SummarySpec.ignore_non_answer_seeking_query]
    # is set to `true`.
    NON_SUMMARY_SEEKING_QUERY_IGNORED_V2 = 9

    # The time out case.
    #
    # Google skips the summary if the time out.
    TIME_OUT = 10
  end
end