Class: Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::Reference

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb

Overview

Document reference.

Defined Under Namespace

Classes: ChunkContent

Instance Attribute Summary collapse

Instance Attribute Details

#chunk_contents::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::Reference::ChunkContent>

Returns List of cited chunk contents derived from document content.

Returns:



1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1883

class Reference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Chunk content.
  # @!attribute [rw] content
  #   @return [::String]
  #     Chunk textual content.
  # @!attribute [rw] page_identifier
  #   @return [::String]
  #     Page identifier.
  # @!attribute [r] blob_attachment_indexes
  #   @return [::Array<::Integer>]
  #     Output only. Stores indexes of blobattachments linked to this chunk.
  class ChunkContent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#document::String

Returns Required. Document.name of the document. Full resource name of the referenced document, in the format projects/*/locations/*/collections/*/dataStores/*/branches/*/documents/*.

Returns:

  • (::String)

    Required. Document.name of the document. Full resource name of the referenced document, in the format projects/*/locations/*/collections/*/dataStores/*/branches/*/documents/*.



1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1883

class Reference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Chunk content.
  # @!attribute [rw] content
  #   @return [::String]
  #     Chunk textual content.
  # @!attribute [rw] page_identifier
  #   @return [::String]
  #     Page identifier.
  # @!attribute [r] blob_attachment_indexes
  #   @return [::Array<::Integer>]
  #     Output only. Stores indexes of blobattachments linked to this chunk.
  class ChunkContent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#title::String

Returns Title of the document.

Returns:

  • (::String)

    Title of the document.



1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1883

class Reference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Chunk content.
  # @!attribute [rw] content
  #   @return [::String]
  #     Chunk textual content.
  # @!attribute [rw] page_identifier
  #   @return [::String]
  #     Page identifier.
  # @!attribute [r] blob_attachment_indexes
  #   @return [::Array<::Integer>]
  #     Output only. Stores indexes of blobattachments linked to this chunk.
  class ChunkContent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#uri::String

Returns Cloud Storage or HTTP uri for the document.

Returns:

  • (::String)

    Cloud Storage or HTTP uri for the document.



1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1883

class Reference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Chunk content.
  # @!attribute [rw] content
  #   @return [::String]
  #     Chunk textual content.
  # @!attribute [rw] page_identifier
  #   @return [::String]
  #     Page identifier.
  # @!attribute [r] blob_attachment_indexes
  #   @return [::Array<::Integer>]
  #     Output only. Stores indexes of blobattachments linked to this chunk.
  class ChunkContent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end