Class: Google::Cloud::DiscoveryEngine::V1beta::UpdateAssistantRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/assistant_service.rb

Overview

Request message for the AssistantService.UpdateAssistant method.

Instance Attribute Summary collapse

Instance Attribute Details

#assistant ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Assistant

Returns Required. The Assistant to update.

The Assistant's name field is used to identify the Assistant to update. Format: projects/{project}/locations/{location}/collections/{collection}/engines/{engine}/assistants/{assistant}

If the caller does not have permission to update the Assistant, regardless of whether or not it exists, a PERMISSION_DENIED error is returned.

If the Assistant to update does not exist, a NOT_FOUND error is returned.

Returns:

  • (::Google::Cloud::DiscoveryEngine::V1beta::Assistant) —

    Required. The Assistant to update.

    The Assistant's name field is used to identify the Assistant to update. Format: projects/{project}/locations/{location}/collections/{collection}/engines/{engine}/assistants/{assistant}

    If the caller does not have permission to update the Assistant, regardless of whether or not it exists, a PERMISSION_DENIED error is returned.

    If the Assistant to update does not exist, a NOT_FOUND error is returned.



386
387
388
389
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assistant_service.rb', line 386

class UpdateAssistantRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask ⇒ ::Google::Protobuf::FieldMask

Returns The list of fields to update.

Returns:



386
387
388
389
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assistant_service.rb', line 386

class UpdateAssistantRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end