Class: Google::Cloud::DiscoveryEngine::V1beta::UserInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/common.rb

Overview

Information of an end user.

Defined Under Namespace

Classes: PreciseLocation

Instance Attribute Summary collapse

Instance Attribute Details

#precise_location::Google::Cloud::DiscoveryEngine::V1beta::UserInfo::PreciseLocation

Returns Optional. Input only. Precise location of the user. It is used in Custom Ranking to calculate the distance between the user and the relevant documents.

Returns:



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'proto_docs/google/cloud/discoveryengine/v1beta/common.rb', line 119

class UserInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Precise location info with multiple representation options.
  # Currently only latitude and longitude point is supported.
  # @!attribute [rw] point
  #   @return [::Google::Type::LatLng]
  #     Optional. Location represented by a latitude/longitude point.
  #
  #     Note: The following fields are mutually exclusive: `point`, `address`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] address
  #   @return [::String]
  #     Optional. Location represented by a natural language address. Will
  #     later be geocoded and converted to either a point or a polygon.
  #
  #     Note: The following fields are mutually exclusive: `address`, `point`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class PreciseLocation
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#time_zone::String

Returns Optional. IANA time zone, e.g. Europe/Budapest.

Returns:

  • (::String)

    Optional. IANA time zone, e.g. Europe/Budapest.



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'proto_docs/google/cloud/discoveryengine/v1beta/common.rb', line 119

class UserInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Precise location info with multiple representation options.
  # Currently only latitude and longitude point is supported.
  # @!attribute [rw] point
  #   @return [::Google::Type::LatLng]
  #     Optional. Location represented by a latitude/longitude point.
  #
  #     Note: The following fields are mutually exclusive: `point`, `address`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] address
  #   @return [::String]
  #     Optional. Location represented by a natural language address. Will
  #     later be geocoded and converted to either a point or a polygon.
  #
  #     Note: The following fields are mutually exclusive: `address`, `point`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class PreciseLocation
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#user_agent::String

Returns User agent as included in the HTTP header.

The field must be a UTF-8 encoded string with a length limit of 1,000 characters. Otherwise, an INVALID_ARGUMENT error is returned.

This should not be set when using the client side event reporting with GTM or JavaScript tag in UserEventService.CollectUserEvent or if UserEvent.direct_user_request is set.

Returns:

  • (::String)

    User agent as included in the HTTP header.

    The field must be a UTF-8 encoded string with a length limit of 1,000 characters. Otherwise, an INVALID_ARGUMENT error is returned.

    This should not be set when using the client side event reporting with GTM or JavaScript tag in UserEventService.CollectUserEvent or if UserEvent.direct_user_request is set.



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'proto_docs/google/cloud/discoveryengine/v1beta/common.rb', line 119

class UserInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Precise location info with multiple representation options.
  # Currently only latitude and longitude point is supported.
  # @!attribute [rw] point
  #   @return [::Google::Type::LatLng]
  #     Optional. Location represented by a latitude/longitude point.
  #
  #     Note: The following fields are mutually exclusive: `point`, `address`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] address
  #   @return [::String]
  #     Optional. Location represented by a natural language address. Will
  #     later be geocoded and converted to either a point or a polygon.
  #
  #     Note: The following fields are mutually exclusive: `address`, `point`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class PreciseLocation
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#user_id::String

Returns Highly recommended for logged-in users. Unique identifier for logged-in user, such as a user name. Don't set for anonymous users.

Always use a hashed value for this ID.

Don't set the field to the same fixed ID for different users. This mixes the event history of those users together, which results in degraded model quality.

The field must be a UTF-8 encoded string with a length limit of 128 characters. Otherwise, an INVALID_ARGUMENT error is returned.

Represents an opaque ID to the Search API. The Search API doesn't interpret the value in any way. This field is used to associate events with a user across sessions if the events are being uploaded.

Returns:

  • (::String)

    Highly recommended for logged-in users. Unique identifier for logged-in user, such as a user name. Don't set for anonymous users.

    Always use a hashed value for this ID.

    Don't set the field to the same fixed ID for different users. This mixes the event history of those users together, which results in degraded model quality.

    The field must be a UTF-8 encoded string with a length limit of 128 characters. Otherwise, an INVALID_ARGUMENT error is returned.

    Represents an opaque ID to the Search API. The Search API doesn't interpret the value in any way. This field is used to associate events with a user across sessions if the events are being uploaded.



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'proto_docs/google/cloud/discoveryengine/v1beta/common.rb', line 119

class UserInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Precise location info with multiple representation options.
  # Currently only latitude and longitude point is supported.
  # @!attribute [rw] point
  #   @return [::Google::Type::LatLng]
  #     Optional. Location represented by a latitude/longitude point.
  #
  #     Note: The following fields are mutually exclusive: `point`, `address`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] address
  #   @return [::String]
  #     Optional. Location represented by a natural language address. Will
  #     later be geocoded and converted to either a point or a polygon.
  #
  #     Note: The following fields are mutually exclusive: `address`, `point`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class PreciseLocation
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end