Class: Google::Cloud::DiscoveryEngine::V1beta::UserInfo::PreciseLocation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/common.rb

Overview

Precise location info with multiple representation options. Currently only latitude and longitude point is supported.

Instance Attribute Summary collapse

Instance Attribute Details

#address::String

Returns Optional. Location represented by a natural language address. Will later be geocoded and converted to either a point or a polygon.

Note: The following fields are mutually exclusive: address, point. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Location represented by a natural language address. Will later be geocoded and converted to either a point or a polygon.

    Note: The following fields are mutually exclusive: address, point. If a field in that set is populated, all other fields in the set will automatically be cleared.



136
137
138
139
# File 'proto_docs/google/cloud/discoveryengine/v1beta/common.rb', line 136

class PreciseLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#point::Google::Type::LatLng

Returns Optional. Location represented by a latitude/longitude point.

Note: The following fields are mutually exclusive: point, address. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Type::LatLng)

    Optional. Location represented by a latitude/longitude point.

    Note: The following fields are mutually exclusive: point, address. If a field in that set is populated, all other fields in the set will automatically be cleared.



136
137
138
139
# File 'proto_docs/google/cloud/discoveryengine/v1beta/common.rb', line 136

class PreciseLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end