Class: Google::Cloud::DiscoveryEngine::V1beta::UserStore

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/user_store.rb

Overview

Configures metadata that is used for End User entities.

Instance Attribute Summary collapse

Instance Attribute Details

#default_license_config::String

Returns Optional. The default subscription LicenseConfig for the UserStore, if UserStore.enable_license_auto_register is true, new users will automatically register under the default subscription.

If default LicenseConfig doesn't have remaining license seats left, new users will not be assigned with license and will be blocked for Vertex AI Search features. This is used if license_assignment_tier_rules is not configured.

Returns:

  • (::String)

    Optional. The default subscription LicenseConfig for the UserStore, if UserStore.enable_license_auto_register is true, new users will automatically register under the default subscription.

    If default LicenseConfig doesn't have remaining license seats left, new users will not be assigned with license and will be blocked for Vertex AI Search features. This is used if license_assignment_tier_rules is not configured.



60
61
62
63
# File 'proto_docs/google/cloud/discoveryengine/v1beta/user_store.rb', line 60

class UserStore
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#display_name::String

Returns The display name of the User Store.

Returns:

  • (::String)

    The display name of the User Store.



60
61
62
63
# File 'proto_docs/google/cloud/discoveryengine/v1beta/user_store.rb', line 60

class UserStore
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#enable_expired_license_auto_update::Boolean

Returns Optional. Whether to enable license auto update for users in this User Store. If true, users with expired licenses will automatically be updated to use the default license config as long as the default license config has seats left.

Returns:

  • (::Boolean)

    Optional. Whether to enable license auto update for users in this User Store. If true, users with expired licenses will automatically be updated to use the default license config as long as the default license config has seats left.



60
61
62
63
# File 'proto_docs/google/cloud/discoveryengine/v1beta/user_store.rb', line 60

class UserStore
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#enable_license_auto_register::Boolean

Returns Optional. Whether to enable license auto register for users in this User Store. If true, new users will automatically register under the default license config as long as the default license config has seats left.

Returns:

  • (::Boolean)

    Optional. Whether to enable license auto register for users in this User Store. If true, new users will automatically register under the default license config as long as the default license config has seats left.



60
61
62
63
# File 'proto_docs/google/cloud/discoveryengine/v1beta/user_store.rb', line 60

class UserStore
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Immutable. The full resource name of the User Store, in the format of projects/{project}/locations/{location}/userStores/{user_store}.

This field must be a UTF-8 encoded string with a length limit of 1024 characters.

Returns:

  • (::String)

    Immutable. The full resource name of the User Store, in the format of projects/{project}/locations/{location}/userStores/{user_store}.

    This field must be a UTF-8 encoded string with a length limit of 1024 characters.



60
61
62
63
# File 'proto_docs/google/cloud/discoveryengine/v1beta/user_store.rb', line 60

class UserStore
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end