Class: Google::Type::Date

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/type/date.rb

Overview

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following:

  • A full date, with non-zero year, month, and day values.
  • A month and day, with a zero year (for example, an anniversary).
  • A year on its own, with a zero month and a zero day.
  • A year and month, with a zero day (for example, a credit card expiration date).

Related types:

Instance Attribute Summary collapse

Instance Attribute Details

#day::Integer

Returns Day of a month. Must be from 1 to 31 and valid for the year and month, or 0 to specify a year by itself or a year and month where the day isn't significant.

Returns:

  • (::Integer)

    Day of a month. Must be from 1 to 31 and valid for the year and month, or 0 to specify a year by itself or a year and month where the day isn't significant.



51
52
53
54
# File 'proto_docs/google/type/date.rb', line 51

class Date
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#month::Integer

Returns Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.

Returns:

  • (::Integer)

    Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.



51
52
53
54
# File 'proto_docs/google/type/date.rb', line 51

class Date
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#year::Integer

Returns Year of the date. Must be from 1 to 9999, or 0 to specify a date without a year.

Returns:

  • (::Integer)

    Year of the date. Must be from 1 to 9999, or 0 to specify a date without a year.



51
52
53
54
# File 'proto_docs/google/type/date.rb', line 51

class Date
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end