Class: Google::Cloud::DiscoveryEngine::V1beta::AdvancedCompleteQueryResponse::QuerySuggestion

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb

Overview

Suggestions as search queries.

Instance Attribute Summary collapse

Instance Attribute Details

#completable_field_paths::Array<::String>

Returns The unique document field paths that serve as the source of this suggestion if it was generated from completable fields.

This field is only populated for the document-completable model.

Returns:

  • (::Array<::String>)

    The unique document field paths that serve as the source of this suggestion if it was generated from completable fields.

    This field is only populated for the document-completable model.



326
327
328
329
# File 'proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb', line 326

class QuerySuggestion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#data_store::Array<::String>

Returns The name of the dataStore that this suggestion belongs to.

Returns:

  • (::Array<::String>)

    The name of the dataStore that this suggestion belongs to.



326
327
328
329
# File 'proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb', line 326

class QuerySuggestion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#score::Float

Returns The score of each suggestion. The score is in the range of [0, 1].

Returns:

  • (::Float)

    The score of each suggestion. The score is in the range of [0, 1].



326
327
328
329
# File 'proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb', line 326

class QuerySuggestion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#suggestion::String

Returns The suggestion for the query.

Returns:

  • (::String)

    The suggestion for the query.



326
327
328
329
# File 'proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb', line 326

class QuerySuggestion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end