Class: Google::Cloud::DiscoveryEngine::V1beta::Answer::BlobAttachment
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::Answer::BlobAttachment
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/answer.rb
Overview
Stores binarydata attached to text answer, e.g. image, video, audio, etc.
Defined Under Namespace
Modules: AttributionType Classes: Blob
Instance Attribute Summary collapse
-
#attribution_type ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Answer::BlobAttachment::AttributionType
readonly
Output only.
-
#data ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Answer::BlobAttachment::Blob
readonly
Output only.
Instance Attribute Details
#attribution_type ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Answer::BlobAttachment::AttributionType (readonly)
Returns Output only. The attribution type of the blob.
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/answer.rb', line 271 class BlobAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The media type and data of the blob. # @!attribute [r] mime_type # @return [::String] # Output only. The media type (MIME type) of the generated or retrieved # data. # @!attribute [r] data # @return [::String] # Output only. Raw bytes. class Blob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The source of the blob. module AttributionType # Unspecified attribution type. ATTRIBUTION_TYPE_UNSPECIFIED = 0 # The attachment data is from the corpus. CORPUS = 1 # The attachment data is generated by the model through code # generation. GENERATED = 2 end end |
#data ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Answer::BlobAttachment::Blob (readonly)
Returns Output only. The mime type and data of the blob.
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/answer.rb', line 271 class BlobAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The media type and data of the blob. # @!attribute [r] mime_type # @return [::String] # Output only. The media type (MIME type) of the generated or retrieved # data. # @!attribute [r] data # @return [::String] # Output only. Raw bytes. class Blob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The source of the blob. module AttributionType # Unspecified attribution type. ATTRIBUTION_TYPE_UNSPECIFIED = 0 # The attachment data is from the corpus. CORPUS = 1 # The attachment data is generated by the model through code # generation. GENERATED = 2 end end |