Class: Google::Cloud::DiscoveryEngine::V1beta::Answer::Reference::UnstructuredDocumentInfo
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::Answer::Reference::UnstructuredDocumentInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/answer.rb
Overview
Unstructured document information.
Defined Under Namespace
Classes: ChunkContent
Instance Attribute Summary collapse
-
#chunk_contents ⇒ ::Array<::Google::Cloud::DiscoveryEngine::V1beta::Answer::Reference::UnstructuredDocumentInfo::ChunkContent>
List of cited chunk contents derived from document content.
-
#document ⇒ ::String
Document resource name.
-
#struct_data ⇒ ::Google::Protobuf::Struct
The structured JSON metadata for the document.
-
#title ⇒ ::String
Title.
-
#uri ⇒ ::String
URI for the document.
Instance Attribute Details
#chunk_contents ⇒ ::Array<::Google::Cloud::DiscoveryEngine::V1beta::Answer::Reference::UnstructuredDocumentInfo::ChunkContent>
Returns List of cited chunk contents derived from document content.
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/answer.rb', line 171 class UnstructuredDocumentInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Chunk content. # @!attribute [rw] content # @return [::String] # Chunk textual content. # @!attribute [rw] page_identifier # @return [::String] # Page identifier. # @!attribute [rw] relevance_score # @return [::Float] # The relevance of the chunk for a given query. Values range from 0.0 # (completely irrelevant) to 1.0 (completely relevant). # This value is for informational purpose only. It may change for # the same query and chunk at any time due to a model retraining or # change in implementation. # @!attribute [r] blob_attachment_indexes # @return [::Array<::Integer>] # Output only. Stores indexes of blobattachments linked to this chunk. class ChunkContent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#document ⇒ ::String
Returns Document resource name.
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/answer.rb', line 171 class UnstructuredDocumentInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Chunk content. # @!attribute [rw] content # @return [::String] # Chunk textual content. # @!attribute [rw] page_identifier # @return [::String] # Page identifier. # @!attribute [rw] relevance_score # @return [::Float] # The relevance of the chunk for a given query. Values range from 0.0 # (completely irrelevant) to 1.0 (completely relevant). # This value is for informational purpose only. It may change for # the same query and chunk at any time due to a model retraining or # change in implementation. # @!attribute [r] blob_attachment_indexes # @return [::Array<::Integer>] # Output only. Stores indexes of blobattachments linked to this chunk. class ChunkContent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#struct_data ⇒ ::Google::Protobuf::Struct
Returns The structured JSON metadata for the document. It is populated from the struct data from the Chunk in search result.
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/answer.rb', line 171 class UnstructuredDocumentInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Chunk content. # @!attribute [rw] content # @return [::String] # Chunk textual content. # @!attribute [rw] page_identifier # @return [::String] # Page identifier. # @!attribute [rw] relevance_score # @return [::Float] # The relevance of the chunk for a given query. Values range from 0.0 # (completely irrelevant) to 1.0 (completely relevant). # This value is for informational purpose only. It may change for # the same query and chunk at any time due to a model retraining or # change in implementation. # @!attribute [r] blob_attachment_indexes # @return [::Array<::Integer>] # Output only. Stores indexes of blobattachments linked to this chunk. class ChunkContent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#title ⇒ ::String
Returns Title.
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/answer.rb', line 171 class UnstructuredDocumentInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Chunk content. # @!attribute [rw] content # @return [::String] # Chunk textual content. # @!attribute [rw] page_identifier # @return [::String] # Page identifier. # @!attribute [rw] relevance_score # @return [::Float] # The relevance of the chunk for a given query. Values range from 0.0 # (completely irrelevant) to 1.0 (completely relevant). # This value is for informational purpose only. It may change for # the same query and chunk at any time due to a model retraining or # change in implementation. # @!attribute [r] blob_attachment_indexes # @return [::Array<::Integer>] # Output only. Stores indexes of blobattachments linked to this chunk. class ChunkContent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#uri ⇒ ::String
Returns URI for the document.
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/answer.rb', line 171 class UnstructuredDocumentInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Chunk content. # @!attribute [rw] content # @return [::String] # Chunk textual content. # @!attribute [rw] page_identifier # @return [::String] # Page identifier. # @!attribute [rw] relevance_score # @return [::Float] # The relevance of the chunk for a given query. Values range from 0.0 # (completely irrelevant) to 1.0 (completely relevant). # This value is for informational purpose only. It may change for # the same query and chunk at any time due to a model retraining or # change in implementation. # @!attribute [r] blob_attachment_indexes # @return [::Array<::Integer>] # Output only. Stores indexes of blobattachments linked to this chunk. class ChunkContent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |