Class: Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::Action::Observation
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::Action::Observation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/answer.rb
Overview
Observation.
Defined Under Namespace
Classes: SearchResult
Instance Attribute Summary collapse
-
#search_results ⇒ ::Array<::Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::Action::Observation::SearchResult>
Search results observed by the search action, it can be snippets info or chunk info, depending on the citation type set by the user.
Instance Attribute Details
#search_results ⇒ ::Array<::Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::Action::Observation::SearchResult>
Returns Search results observed by the search action, it can be snippets info or chunk info, depending on the citation type set by the user.
344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/answer.rb', line 344 class Observation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] document # @return [::String] # Document resource name. # @!attribute [rw] uri # @return [::String] # URI for the document. # @!attribute [rw] title # @return [::String] # Title. # @!attribute [rw] snippet_info # @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::Action::Observation::SearchResult::SnippetInfo>] # If citation_type is DOCUMENT_LEVEL_CITATION, populate document # level snippets. # @!attribute [rw] chunk_info # @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::Answer::Step::Action::Observation::SearchResult::ChunkInfo>] # If citation_type is CHUNK_LEVEL_CITATION and chunk mode is on, # populate chunk info. # @!attribute [rw] struct_data # @return [::Google::Protobuf::Struct] # Data representation. # The structured JSON data for the document. # It's populated from the struct data from the Document, or the # Chunk in search result. class SearchResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Snippet information. # @!attribute [rw] snippet # @return [::String] # Snippet content. # @!attribute [rw] snippet_status # @return [::String] # Status of the snippet defined by the search team. class SnippetInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Chunk information. # @!attribute [rw] chunk # @return [::String] # Chunk resource name. # @!attribute [rw] content # @return [::String] # Chunk textual content. # @!attribute [rw] relevance_score # @return [::Float] # The relevance of the chunk for a given query. Values range from # 0.0 (completely irrelevant) to 1.0 (completely relevant). # This value is for informational purpose only. It may change for # the same query and chunk at any time due to a model retraining or # change in implementation. class ChunkInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |