Class: Google::Cloud::DiscoveryEngine::V1beta::AnswerGenerationSpec
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::AnswerGenerationSpec
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/serving_config.rb
Overview
The specification for answer generation.
Defined Under Namespace
Classes: UserDefinedClassifierSpec
Instance Attribute Summary collapse
Instance Attribute Details
#user_defined_classifier_spec ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::AnswerGenerationSpec::UserDefinedClassifierSpec
Returns Optional. The specification for user specified classifier spec.
287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/serving_config.rb', line 287 class AnswerGenerationSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The specification for user defined classifier. # @!attribute [rw] enable_user_defined_classifier # @return [::Boolean] # Optional. Whether or not to enable and include user defined classifier. # @!attribute [rw] preamble # @return [::String] # Optional. The preamble to be used for the user defined classifier. # @!attribute [rw] model_id # @return [::String] # Optional. The model id to be used for the user defined classifier. # @!attribute [rw] task_marker # @return [::String] # Optional. The task marker to be used for the user defined classifier. # @!attribute [rw] top_p # @return [::Float] # Optional. The top-p value to be used for the user defined classifier. # @!attribute [rw] top_k # @return [::Integer] # Optional. The top-k value to be used for the user defined classifier. # @!attribute [rw] temperature # @return [::Float] # Optional. The temperature value to be used for the user defined # classifier. # @!attribute [rw] seed # @return [::Integer] # Optional. The seed value to be used for the user defined classifier. class UserDefinedClassifierSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |