Class: Google::Cloud::DiscoveryEngine::V1beta::AssistAnswer::CustomerPolicyEnforcementResult::PolicyEnforcementResult
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::AssistAnswer::CustomerPolicyEnforcementResult::PolicyEnforcementResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb
Overview
Customer policy enforcement result for a single policy type.
Instance Attribute Summary collapse
-
#banned_phrase_enforcement_result ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::AssistAnswer::CustomerPolicyEnforcementResult::BannedPhraseEnforcementResult
The policy enforcement result for the banned phrase policy.
-
#model_armor_enforcement_result ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::AssistAnswer::CustomerPolicyEnforcementResult::ModelArmorEnforcementResult
The policy enforcement result for the Model Armor policy.
Instance Attribute Details
#banned_phrase_enforcement_result ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::AssistAnswer::CustomerPolicyEnforcementResult::BannedPhraseEnforcementResult
Returns The policy enforcement result for the banned phrase policy.
Note: The following fields are mutually exclusive: banned_phrase_enforcement_result, model_armor_enforcement_result. If a field in that set is populated, all other fields in the set will automatically be cleared.
117 118 119 120 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb', line 117 class PolicyEnforcementResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#model_armor_enforcement_result ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::AssistAnswer::CustomerPolicyEnforcementResult::ModelArmorEnforcementResult
Returns The policy enforcement result for the Model Armor policy.
Note: The following fields are mutually exclusive: model_armor_enforcement_result, banned_phrase_enforcement_result. If a field in that set is populated, all other fields in the set will automatically be cleared.
117 118 119 120 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb', line 117 class PolicyEnforcementResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |