Class: Google::Cloud::DiscoveryEngine::V1beta::AssistantGroundedContent::TextGroundingMetadata::Reference
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::AssistantGroundedContent::TextGroundingMetadata::Reference
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb
Overview
Referenced content and related document metadata.
Defined Under Namespace
Classes: DocumentMetadata
Instance Attribute Summary collapse
-
#code_snippet ⇒ ::String
Chunk of code snippet from the referenced document.
-
#content ⇒ ::String
Referenced text content.
-
#document_metadata ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::AssistantGroundedContent::TextGroundingMetadata::Reference::DocumentMetadata
Document metadata.
Instance Attribute Details
#code_snippet ⇒ ::String
Returns Chunk of code snippet from the referenced document.
352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb', line 352 class Reference include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Document metadata. # @!attribute [rw] language # @return [::Google::Cloud::DiscoveryEngine::V1beta::AssistantGroundedContent::TextGroundingMetadata::Reference::DocumentMetadata::Language] # @!attribute [rw] document # @return [::String] # Document resource name. # @!attribute [rw] uri # @return [::String] # URI for the document. It may contain a URL that redirects to the # actual website. # @!attribute [rw] title # @return [::String] # Title. # @!attribute [rw] page_identifier # @return [::String] # Page identifier. # @!attribute [rw] domain # @return [::String] # Domain name from the document URI. Note that the `uri` field may # contain a URL that redirects to the actual website, in which case # this will contain the domain name of the target site. # @!attribute [rw] mime_type # @return [::String] # The mime type of the document. # https://www.iana.org/assignments/media-types/media-types.xhtml. class DocumentMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Language of the referenced content. For now, it is only used for # code. module Language LANGUAGE_UNSPECIFIED = 0 PYTHON = 1 SQL = 2 end end end |
#content ⇒ ::String
Returns Referenced text content.
352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb', line 352 class Reference include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Document metadata. # @!attribute [rw] language # @return [::Google::Cloud::DiscoveryEngine::V1beta::AssistantGroundedContent::TextGroundingMetadata::Reference::DocumentMetadata::Language] # @!attribute [rw] document # @return [::String] # Document resource name. # @!attribute [rw] uri # @return [::String] # URI for the document. It may contain a URL that redirects to the # actual website. # @!attribute [rw] title # @return [::String] # Title. # @!attribute [rw] page_identifier # @return [::String] # Page identifier. # @!attribute [rw] domain # @return [::String] # Domain name from the document URI. Note that the `uri` field may # contain a URL that redirects to the actual website, in which case # this will contain the domain name of the target site. # @!attribute [rw] mime_type # @return [::String] # The mime type of the document. # https://www.iana.org/assignments/media-types/media-types.xhtml. class DocumentMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Language of the referenced content. For now, it is only used for # code. module Language LANGUAGE_UNSPECIFIED = 0 PYTHON = 1 SQL = 2 end end end |
#document_metadata ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::AssistantGroundedContent::TextGroundingMetadata::Reference::DocumentMetadata
Returns Document metadata.
352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb', line 352 class Reference include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Document metadata. # @!attribute [rw] language # @return [::Google::Cloud::DiscoveryEngine::V1beta::AssistantGroundedContent::TextGroundingMetadata::Reference::DocumentMetadata::Language] # @!attribute [rw] document # @return [::String] # Document resource name. # @!attribute [rw] uri # @return [::String] # URI for the document. It may contain a URL that redirects to the # actual website. # @!attribute [rw] title # @return [::String] # Title. # @!attribute [rw] page_identifier # @return [::String] # Page identifier. # @!attribute [rw] domain # @return [::String] # Domain name from the document URI. Note that the `uri` field may # contain a URL that redirects to the actual website, in which case # this will contain the domain name of the target site. # @!attribute [rw] mime_type # @return [::String] # The mime type of the document. # https://www.iana.org/assignments/media-types/media-types.xhtml. class DocumentMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Language of the referenced content. For now, it is only used for # code. module Language LANGUAGE_UNSPECIFIED = 0 PYTHON = 1 SQL = 2 end end end |