Class: Google::Cloud::DiscoveryEngine::V1beta::AssistantGroundedContent::TextGroundingMetadata::Reference::DocumentMetadata
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::AssistantGroundedContent::TextGroundingMetadata::Reference::DocumentMetadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb
Overview
Document metadata.
Defined Under Namespace
Modules: Language
Instance Attribute Summary collapse
-
#document ⇒ ::String
Document resource name.
-
#domain ⇒ ::String
Domain name from the document URI.
- #language ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::AssistantGroundedContent::TextGroundingMetadata::Reference::DocumentMetadata::Language
-
#mime_type ⇒ ::String
The mime type of the document.
-
#page_identifier ⇒ ::String
Page identifier.
-
#title ⇒ ::String
Title.
-
#uri ⇒ ::String
URI for the document.
Instance Attribute Details
#document ⇒ ::String
Returns Document resource name.
381 382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb', line 381 class DocumentMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Language of the referenced content. For now, it is only used for # code. module Language LANGUAGE_UNSPECIFIED = 0 PYTHON = 1 SQL = 2 end end |
#domain ⇒ ::String
Returns Domain name from the document URI. Note that the uri field may
contain a URL that redirects to the actual website, in which case
this will contain the domain name of the target site.
381 382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb', line 381 class DocumentMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Language of the referenced content. For now, it is only used for # code. module Language LANGUAGE_UNSPECIFIED = 0 PYTHON = 1 SQL = 2 end end |
#language ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::AssistantGroundedContent::TextGroundingMetadata::Reference::DocumentMetadata::Language
381 382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb', line 381 class DocumentMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Language of the referenced content. For now, it is only used for # code. module Language LANGUAGE_UNSPECIFIED = 0 PYTHON = 1 SQL = 2 end end |
#mime_type ⇒ ::String
Returns The mime type of the document. https://www.iana.org/assignments/media-types/media-types.xhtml.
381 382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb', line 381 class DocumentMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Language of the referenced content. For now, it is only used for # code. module Language LANGUAGE_UNSPECIFIED = 0 PYTHON = 1 SQL = 2 end end |
#page_identifier ⇒ ::String
Returns Page identifier.
381 382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb', line 381 class DocumentMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Language of the referenced content. For now, it is only used for # code. module Language LANGUAGE_UNSPECIFIED = 0 PYTHON = 1 SQL = 2 end end |
#title ⇒ ::String
Returns Title.
381 382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb', line 381 class DocumentMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Language of the referenced content. For now, it is only used for # code. module Language LANGUAGE_UNSPECIFIED = 0 PYTHON = 1 SQL = 2 end end |
#uri ⇒ ::String
Returns URI for the document. It may contain a URL that redirects to the actual website.
381 382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assist_answer.rb', line 381 class DocumentMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Language of the referenced content. For now, it is only used for # code. module Language LANGUAGE_UNSPECIFIED = 0 PYTHON = 1 SQL = 2 end end |