Class: Google::Cloud::DiscoveryEngine::V1beta::DataStore::FederatedSearchConfig
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::DataStore::FederatedSearchConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/data_store.rb
Overview
Stores information for federated search.
Defined Under Namespace
Classes: AlloyDbConfig, NotebooklmConfig, ThirdPartyOauthConfig
Instance Attribute Summary collapse
-
#alloy_db_config ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::DataStore::FederatedSearchConfig::AlloyDbConfig
AlloyDB config.
-
#notebooklm_config ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::DataStore::FederatedSearchConfig::NotebooklmConfig
NotebookLM config.
-
#third_party_oauth_config ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::DataStore::FederatedSearchConfig::ThirdPartyOauthConfig
Third Party OAuth config.
Instance Attribute Details
#alloy_db_config ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::DataStore::FederatedSearchConfig::AlloyDbConfig
Returns AlloyDB config. If set, this DataStore is connected to AlloyDB.
Note: The following fields are mutually exclusive: alloy_db_config, third_party_oauth_config, notebooklm_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/data_store.rb', line 220 class FederatedSearchConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Stores information for connecting to AlloyDB. # @!attribute [rw] alloydb_connection_config # @return [::Google::Cloud::DiscoveryEngine::V1beta::DataStore::FederatedSearchConfig::AlloyDbConfig::AlloyDbConnectionConfig] # Required. Configuration for connecting to AlloyDB. # @!attribute [rw] alloydb_ai_nl_config # @return [::Google::Cloud::DiscoveryEngine::V1beta::DataStore::FederatedSearchConfig::AlloyDbConfig::AlloyDbAiNaturalLanguageConfig] # Optional. Configuration for Magic. # @!attribute [rw] returned_fields # @return [::Array<::String>] # Optional. Fields to be returned in the search results. If empty, all # fields will be returned. class AlloyDbConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for connecting to AlloyDB. # @!attribute [rw] instance # @return [::String] # Required. The AlloyDB instance to connect to. # @!attribute [rw] database # @return [::String] # Required. The AlloyDB database to connect to. # @!attribute [rw] user # @return [::String] # Required. Database user. # # If auth_mode = END_USER_ACCOUNT, it can be unset. In that case, # the user will be inferred on the AlloyDB side, based on the # authenticated user. # @!attribute [rw] password # @return [::String] # Required. Database password. # # If auth_mode = END_USER_ACCOUNT, it can be unset. In that case, # the password will be inferred on the AlloyDB side, based on the # authenticated user. # @!attribute [rw] auth_mode # @return [::Google::Cloud::DiscoveryEngine::V1beta::DataStore::FederatedSearchConfig::AlloyDbConfig::AlloyDbConnectionConfig::AuthMode] # Optional. Auth mode. # @!attribute [rw] enable_psvs # @return [::Boolean] # Optional. If true, enable PSVS for AlloyDB. class AlloyDbConnectionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Auth mode. module AuthMode AUTH_MODE_UNSPECIFIED = 0 # Uses P4SA when VAIS talks to AlloyDB. AUTH_MODE_SERVICE_ACCOUNT = 1 # Uses EUC when VAIS talks to AlloyDB. AUTH_MODE_END_USER_ACCOUNT = 2 end end # Configuration for AlloyDB AI Natural Language. # @!attribute [rw] nl_config_id # @return [::String] # Optional. AlloyDb AI NL config id, i.e. the value that was used for # calling `SELECT alloydb_ai_nl.g_create_configuration(...)`. Can be # empty. class AlloyDbAiNaturalLanguageConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Stores information for third party applicationOAuth. # @!attribute [rw] app_name # @return [::String] # Optional. The type of the application. E.g., "jira", "box", etc. # @!attribute [rw] instance_name # @return [::String] # Optional. The instance name identifying the 3P app, e.g., # "vaissptbots-my". This is different from the instance_uri which is the # full URL of the 3P app e.g., "https://vaissptbots-my.sharepoint.com". class ThirdPartyOauthConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Config for connecting to NotebookLM Enterprise. # @!attribute [rw] search_config # @return [::String] # Required. Search config name. # # Format: projects/*/locations/global/notebookLmSearchConfigs/* class NotebooklmConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#notebooklm_config ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::DataStore::FederatedSearchConfig::NotebooklmConfig
Returns NotebookLM config. If set, this DataStore is connected to NotebookLM Enterprise.
Note: The following fields are mutually exclusive: notebooklm_config, alloy_db_config, third_party_oauth_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/data_store.rb', line 220 class FederatedSearchConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Stores information for connecting to AlloyDB. # @!attribute [rw] alloydb_connection_config # @return [::Google::Cloud::DiscoveryEngine::V1beta::DataStore::FederatedSearchConfig::AlloyDbConfig::AlloyDbConnectionConfig] # Required. Configuration for connecting to AlloyDB. # @!attribute [rw] alloydb_ai_nl_config # @return [::Google::Cloud::DiscoveryEngine::V1beta::DataStore::FederatedSearchConfig::AlloyDbConfig::AlloyDbAiNaturalLanguageConfig] # Optional. Configuration for Magic. # @!attribute [rw] returned_fields # @return [::Array<::String>] # Optional. Fields to be returned in the search results. If empty, all # fields will be returned. class AlloyDbConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for connecting to AlloyDB. # @!attribute [rw] instance # @return [::String] # Required. The AlloyDB instance to connect to. # @!attribute [rw] database # @return [::String] # Required. The AlloyDB database to connect to. # @!attribute [rw] user # @return [::String] # Required. Database user. # # If auth_mode = END_USER_ACCOUNT, it can be unset. In that case, # the user will be inferred on the AlloyDB side, based on the # authenticated user. # @!attribute [rw] password # @return [::String] # Required. Database password. # # If auth_mode = END_USER_ACCOUNT, it can be unset. In that case, # the password will be inferred on the AlloyDB side, based on the # authenticated user. # @!attribute [rw] auth_mode # @return [::Google::Cloud::DiscoveryEngine::V1beta::DataStore::FederatedSearchConfig::AlloyDbConfig::AlloyDbConnectionConfig::AuthMode] # Optional. Auth mode. # @!attribute [rw] enable_psvs # @return [::Boolean] # Optional. If true, enable PSVS for AlloyDB. class AlloyDbConnectionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Auth mode. module AuthMode AUTH_MODE_UNSPECIFIED = 0 # Uses P4SA when VAIS talks to AlloyDB. AUTH_MODE_SERVICE_ACCOUNT = 1 # Uses EUC when VAIS talks to AlloyDB. AUTH_MODE_END_USER_ACCOUNT = 2 end end # Configuration for AlloyDB AI Natural Language. # @!attribute [rw] nl_config_id # @return [::String] # Optional. AlloyDb AI NL config id, i.e. the value that was used for # calling `SELECT alloydb_ai_nl.g_create_configuration(...)`. Can be # empty. class AlloyDbAiNaturalLanguageConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Stores information for third party applicationOAuth. # @!attribute [rw] app_name # @return [::String] # Optional. The type of the application. E.g., "jira", "box", etc. # @!attribute [rw] instance_name # @return [::String] # Optional. The instance name identifying the 3P app, e.g., # "vaissptbots-my". This is different from the instance_uri which is the # full URL of the 3P app e.g., "https://vaissptbots-my.sharepoint.com". class ThirdPartyOauthConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Config for connecting to NotebookLM Enterprise. # @!attribute [rw] search_config # @return [::String] # Required. Search config name. # # Format: projects/*/locations/global/notebookLmSearchConfigs/* class NotebooklmConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#third_party_oauth_config ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::DataStore::FederatedSearchConfig::ThirdPartyOauthConfig
Returns Third Party OAuth config. If set, this DataStore is connected to a third party application.
Note: The following fields are mutually exclusive: third_party_oauth_config, alloy_db_config, notebooklm_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/data_store.rb', line 220 class FederatedSearchConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Stores information for connecting to AlloyDB. # @!attribute [rw] alloydb_connection_config # @return [::Google::Cloud::DiscoveryEngine::V1beta::DataStore::FederatedSearchConfig::AlloyDbConfig::AlloyDbConnectionConfig] # Required. Configuration for connecting to AlloyDB. # @!attribute [rw] alloydb_ai_nl_config # @return [::Google::Cloud::DiscoveryEngine::V1beta::DataStore::FederatedSearchConfig::AlloyDbConfig::AlloyDbAiNaturalLanguageConfig] # Optional. Configuration for Magic. # @!attribute [rw] returned_fields # @return [::Array<::String>] # Optional. Fields to be returned in the search results. If empty, all # fields will be returned. class AlloyDbConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for connecting to AlloyDB. # @!attribute [rw] instance # @return [::String] # Required. The AlloyDB instance to connect to. # @!attribute [rw] database # @return [::String] # Required. The AlloyDB database to connect to. # @!attribute [rw] user # @return [::String] # Required. Database user. # # If auth_mode = END_USER_ACCOUNT, it can be unset. In that case, # the user will be inferred on the AlloyDB side, based on the # authenticated user. # @!attribute [rw] password # @return [::String] # Required. Database password. # # If auth_mode = END_USER_ACCOUNT, it can be unset. In that case, # the password will be inferred on the AlloyDB side, based on the # authenticated user. # @!attribute [rw] auth_mode # @return [::Google::Cloud::DiscoveryEngine::V1beta::DataStore::FederatedSearchConfig::AlloyDbConfig::AlloyDbConnectionConfig::AuthMode] # Optional. Auth mode. # @!attribute [rw] enable_psvs # @return [::Boolean] # Optional. If true, enable PSVS for AlloyDB. class AlloyDbConnectionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Auth mode. module AuthMode AUTH_MODE_UNSPECIFIED = 0 # Uses P4SA when VAIS talks to AlloyDB. AUTH_MODE_SERVICE_ACCOUNT = 1 # Uses EUC when VAIS talks to AlloyDB. AUTH_MODE_END_USER_ACCOUNT = 2 end end # Configuration for AlloyDB AI Natural Language. # @!attribute [rw] nl_config_id # @return [::String] # Optional. AlloyDb AI NL config id, i.e. the value that was used for # calling `SELECT alloydb_ai_nl.g_create_configuration(...)`. Can be # empty. class AlloyDbAiNaturalLanguageConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Stores information for third party applicationOAuth. # @!attribute [rw] app_name # @return [::String] # Optional. The type of the application. E.g., "jira", "box", etc. # @!attribute [rw] instance_name # @return [::String] # Optional. The instance name identifying the 3P app, e.g., # "vaissptbots-my". This is different from the instance_uri which is the # full URL of the 3P app e.g., "https://vaissptbots-my.sharepoint.com". class ThirdPartyOauthConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Config for connecting to NotebookLM Enterprise. # @!attribute [rw] search_config # @return [::String] # Required. Search config name. # # Format: projects/*/locations/global/notebookLmSearchConfigs/* class NotebooklmConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |