Class: Google::Cloud::DiscoveryEngine::V1beta::DeleteAssistantRequest
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::DeleteAssistantRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/assistant_service.rb
Overview
Request message for the AssistantService.DeleteAssistant method.
Instance Attribute Summary collapse
-
#name ⇒ ::String
Required.
Instance Attribute Details
#name ⇒ ::String
Returns Required. Resource name of
Assistant. Format:
projects/{project}/locations/{location}/collections/{collection}/engines/{engine}/assistants/{assistant}
If the caller does not have permission to delete the Assistant, regardless of whether or not it exists, a PERMISSION_DENIED error is returned.
If the Assistant to delete does not exist, a NOT_FOUND error is returned.
272 273 274 275 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assistant_service.rb', line 272 class DeleteAssistantRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |