Class: Google::Cloud::DiscoveryEngine::V1beta::Engine::KnowledgeGraphConfig
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::Engine::KnowledgeGraphConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/engine.rb
Overview
Configuration message for the Knowledge Graph.
Defined Under Namespace
Classes: FeatureConfig
Instance Attribute Summary collapse
-
#cloud_knowledge_graph_types ⇒ ::Array<::String>
Specify entity types to support.
-
#enable_cloud_knowledge_graph ⇒ ::Boolean
Whether to enable the Cloud Knowledge Graph for the engine.
-
#enable_private_knowledge_graph ⇒ ::Boolean
Whether to enable the Private Knowledge Graph for the engine.
-
#feature_config ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Engine::KnowledgeGraphConfig::FeatureConfig
Optional.
-
#private_knowledge_graph_types ⇒ ::Array<::String>
Specify entity types to support.
Instance Attribute Details
#cloud_knowledge_graph_types ⇒ ::Array<::String>
Returns Specify entity types to support.
464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/engine.rb', line 464 class KnowledgeGraphConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Feature config for the Knowledge Graph. # @!attribute [rw] disable_private_kg_query_understanding # @return [::Boolean] # Whether to disable the private KG query understanding for the engine. # # Defaults to false if not specified. # @!attribute [rw] disable_private_kg_enrichment # @return [::Boolean] # Whether to disable the private KG enrichment for the engine. # # Defaults to false if not specified. # @!attribute [rw] disable_private_kg_auto_complete # @return [::Boolean] # Whether to disable the private KG auto complete for the engine. # # Defaults to false if not specified. # @!attribute [rw] disable_private_kg_query_ui_chips # @return [::Boolean] # Whether to disable the private KG for query UI chips. # # Defaults to false if not specified. class FeatureConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#enable_cloud_knowledge_graph ⇒ ::Boolean
Returns Whether to enable the Cloud Knowledge Graph for the engine.
Defaults to false if not specified.
464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/engine.rb', line 464 class KnowledgeGraphConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Feature config for the Knowledge Graph. # @!attribute [rw] disable_private_kg_query_understanding # @return [::Boolean] # Whether to disable the private KG query understanding for the engine. # # Defaults to false if not specified. # @!attribute [rw] disable_private_kg_enrichment # @return [::Boolean] # Whether to disable the private KG enrichment for the engine. # # Defaults to false if not specified. # @!attribute [rw] disable_private_kg_auto_complete # @return [::Boolean] # Whether to disable the private KG auto complete for the engine. # # Defaults to false if not specified. # @!attribute [rw] disable_private_kg_query_ui_chips # @return [::Boolean] # Whether to disable the private KG for query UI chips. # # Defaults to false if not specified. class FeatureConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#enable_private_knowledge_graph ⇒ ::Boolean
Returns Whether to enable the Private Knowledge Graph for the engine.
Defaults to false if not specified.
464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/engine.rb', line 464 class KnowledgeGraphConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Feature config for the Knowledge Graph. # @!attribute [rw] disable_private_kg_query_understanding # @return [::Boolean] # Whether to disable the private KG query understanding for the engine. # # Defaults to false if not specified. # @!attribute [rw] disable_private_kg_enrichment # @return [::Boolean] # Whether to disable the private KG enrichment for the engine. # # Defaults to false if not specified. # @!attribute [rw] disable_private_kg_auto_complete # @return [::Boolean] # Whether to disable the private KG auto complete for the engine. # # Defaults to false if not specified. # @!attribute [rw] disable_private_kg_query_ui_chips # @return [::Boolean] # Whether to disable the private KG for query UI chips. # # Defaults to false if not specified. class FeatureConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#feature_config ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Engine::KnowledgeGraphConfig::FeatureConfig
Returns Optional. Feature config for the Knowledge Graph.
464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/engine.rb', line 464 class KnowledgeGraphConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Feature config for the Knowledge Graph. # @!attribute [rw] disable_private_kg_query_understanding # @return [::Boolean] # Whether to disable the private KG query understanding for the engine. # # Defaults to false if not specified. # @!attribute [rw] disable_private_kg_enrichment # @return [::Boolean] # Whether to disable the private KG enrichment for the engine. # # Defaults to false if not specified. # @!attribute [rw] disable_private_kg_auto_complete # @return [::Boolean] # Whether to disable the private KG auto complete for the engine. # # Defaults to false if not specified. # @!attribute [rw] disable_private_kg_query_ui_chips # @return [::Boolean] # Whether to disable the private KG for query UI chips. # # Defaults to false if not specified. class FeatureConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#private_knowledge_graph_types ⇒ ::Array<::String>
Returns Specify entity types to support.
464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/engine.rb', line 464 class KnowledgeGraphConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Feature config for the Knowledge Graph. # @!attribute [rw] disable_private_kg_query_understanding # @return [::Boolean] # Whether to disable the private KG query understanding for the engine. # # Defaults to false if not specified. # @!attribute [rw] disable_private_kg_enrichment # @return [::Boolean] # Whether to disable the private KG enrichment for the engine. # # Defaults to false if not specified. # @!attribute [rw] disable_private_kg_auto_complete # @return [::Boolean] # Whether to disable the private KG auto complete for the engine. # # Defaults to false if not specified. # @!attribute [rw] disable_private_kg_query_ui_chips # @return [::Boolean] # Whether to disable the private KG for query UI chips. # # Defaults to false if not specified. class FeatureConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |