Module: Google::Cloud::DiscoveryEngine::V1beta::Engine::MarketplaceAgentVisibility
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/engine.rb
Overview
Represents which marketplace agents are visible to any users in agent gallery.
Constant Summary collapse
- MARKETPLACE_AGENT_VISIBILITY_UNSPECIFIED =
Defaults to
MARKETPLACE_AGENT_VISIBILITY_UNSPECIFIED. 0- SHOW_AVAILABLE_AGENTS_ONLY =
Only agents that are currently available for use by the user are visible.
1- SHOW_AGENTS_ALREADY_INTEGRATED =
Show marketplace agents that the user does not yet have access to but are integrated into the engine. This level also includes all agents visible with
SHOW_AVAILABLE_AGENTS_ONLY. 2- SHOW_AGENTS_ALREADY_PURCHASED =
Show all agents visible with
SHOW_AGENTS_ALREADY_INTEGRATED, plus agents that have already been purchased by the project/organization, even if they are not currently integrated into the engine. 3- SHOW_ALL_AGENTS =
All agents in the marketplace are visible, regardless of access or purchase status. This level encompasses all agents shown in the previous levels.
4