Class: Google::Cloud::DiscoveryEngine::V1beta::Engine::SearchEngineConfig
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::Engine::SearchEngineConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/engine.rb
Overview
Configurations for a Search Engine.
Instance Attribute Summary collapse
-
#required_subscription_tier ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::SubscriptionTier
Optional.
-
#search_add_ons ⇒ ::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchAddOn>
The add-on that this search engine enables.
-
#search_tier ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::SearchTier
The search feature tier of this engine.
Instance Attribute Details
#required_subscription_tier ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::SubscriptionTier
Returns Optional. The required subscription tier of this engine.
They cannot be modified after engine creation. If the required subscription tier is search, user with higher license tier like assist can still access the standalone app associated with this engine.
222 223 224 225 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/engine.rb', line 222 class SearchEngineConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#search_add_ons ⇒ ::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchAddOn>
Returns The add-on that this search engine enables.
222 223 224 225 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/engine.rb', line 222 class SearchEngineConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#search_tier ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::SearchTier
Returns The search feature tier of this engine.
Different tiers might have different pricing. To learn more, check the pricing documentation.
Defaults to SearchTier.SEARCH_TIER_STANDARD if not specified.
222 223 224 225 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/engine.rb', line 222 class SearchEngineConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |