Class: Google::Cloud::DiscoveryEngine::V1beta::Feedback::ConversationInfo
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::Feedback::ConversationInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/feedback.rb
Overview
The conversation information such as the question index and session name.
Instance Attribute Summary collapse
-
#answer_query_token ⇒ ::String
Optional.
-
#assist_token ⇒ ::String
Optional.
-
#query ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Query
Required.
-
#question_index ⇒ ::Integer
The index of the user input within the conversation messages.
-
#session ⇒ ::String
Name of the newly generated or continued session.
Instance Attribute Details
#answer_query_token ⇒ ::String
Returns Optional. The token which could be used to fetch the answer log.
74 75 76 77 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/feedback.rb', line 74 class ConversationInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#assist_token ⇒ ::String
Returns Optional. The token which could be used to fetch the assistant log.
74 75 76 77 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/feedback.rb', line 74 class ConversationInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#query ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Query
Returns Required. The user's search query.
74 75 76 77 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/feedback.rb', line 74 class ConversationInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#question_index ⇒ ::Integer
Returns The index of the user input within the conversation messages.
74 75 76 77 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/feedback.rb', line 74 class ConversationInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#session ⇒ ::String
Returns Name of the newly generated or continued session.
74 75 76 77 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/feedback.rb', line 74 class ConversationInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |