Class: Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentRequest::DynamicRetrievalConfiguration
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentRequest::DynamicRetrievalConfiguration
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb
Overview
Describes the options to customize dynamic retrieval.
Defined Under Namespace
Classes: DynamicRetrievalPredictor
Instance Attribute Summary collapse
-
#predictor ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentRequest::DynamicRetrievalConfiguration::DynamicRetrievalPredictor
Specification for the predictor for dynamic retrieval.
Instance Attribute Details
#predictor ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentRequest::DynamicRetrievalConfiguration::DynamicRetrievalPredictor
Returns Specification for the predictor for dynamic retrieval.
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 153 class DynamicRetrievalConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes the predictor settings for dynamic retrieval. # @!attribute [rw] version # @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentRequest::DynamicRetrievalConfiguration::DynamicRetrievalPredictor::Version] # The version of the predictor to be used in dynamic retrieval. # @!attribute [rw] threshold # @return [::Float] # The value of the threshold. If the predictor will predict a # value smaller than this, it would suppress grounding in the source. class DynamicRetrievalPredictor include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The version of the predictor to be used in dynamic retrieval. module Version # Automatically choose the best version of the retrieval predictor. VERSION_UNSPECIFIED = 0 # The V1 model which is evaluating each source independently. V1_INDEPENDENT = 1 end end end |