Class: Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentRequest::GroundingSource
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentRequest::GroundingSource
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb
Overview
Grounding source.
Defined Under Namespace
Classes: EnterpriseWebRetrievalSource, GoogleSearchSource, InlineSource, SearchSource
Instance Attribute Summary collapse
-
#enterprise_web_retrieval_source ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentRequest::GroundingSource::EnterpriseWebRetrievalSource
If set, grounding is performed with enterprise web retrieval.
-
#google_search_source ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentRequest::GroundingSource::GoogleSearchSource
If set, grounding is performed with Google Search.
-
#inline_source ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentRequest::GroundingSource::InlineSource
If set, grounding is performed with inline content.
-
#search_source ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentRequest::GroundingSource::SearchSource
If set, grounding is performed with Vertex AI Search.
Instance Attribute Details
#enterprise_web_retrieval_source ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentRequest::GroundingSource::EnterpriseWebRetrievalSource
Returns If set, grounding is performed with enterprise web retrieval.
Note: The following fields are mutually exclusive: enterprise_web_retrieval_source, inline_source, search_source, google_search_source. If a field in that set is populated, all other fields in the set will automatically be cleared.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 201 class GroundingSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Message to be used for grounding based on inline content. # @!attribute [rw] grounding_facts # @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::GroundingFact>] # List of facts to be used for grounding. # @!attribute [rw] attributes # @return [::Google::Protobuf::Map{::String => ::String}] # Attributes associated with the content. # # Common attributes include `source` (indicating where the content was # sourced from) and `author` (indicating the author of the content). class InlineSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Message to be used for grounding with Vertex AI Search. # @!attribute [rw] serving_config # @return [::String] # The resource name of the Engine to use. # # Format: # `projects/{project}/locations/{location}/collections/{collection_id}/engines/{engine_id}/servingConfigs/{serving_config_id}` # @!attribute [rw] max_result_count # @return [::Integer] # Number of search results to return. # # The default value is 10. The maximumm allowed value is 10. # @!attribute [rw] filter # @return [::String] # Filter expression to be applied to the search. # # The syntax is the same as # {::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest#filter SearchRequest.filter}. # @!attribute [rw] safe_search # @return [::Boolean] # If set, safe search is enabled in Vertex AI Search requests. class SearchSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Google Search config parameters. # @!attribute [rw] dynamic_retrieval_config # @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentRequest::DynamicRetrievalConfiguration] # Optional. Specifies the dynamic retrieval configuration for the given # source. # @!attribute [rw] exclude_domains # @return [::Array<::String>] # Optional. List of domains to be excluded from the search results. # @!attribute [rw] blocking_confidence # @return [::Google::Cloud::DiscoveryEngine::V1beta::Citation::PhishBlockThreshold] # Optional. Sites with confidence level chosen & above this value will be # blocked from the search results. class GoogleSearchSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Params for using enterprise web retrieval as grounding source. # @!attribute [rw] exclude_domains # @return [::Array<::String>] # Optional. List of domains to be excluded from the search results. # @!attribute [rw] blocking_confidence # @return [::Google::Cloud::DiscoveryEngine::V1beta::Citation::PhishBlockThreshold] # Optional. Sites with confidence level chosen & above this value will be # blocked from the search results. class EnterpriseWebRetrievalSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#google_search_source ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentRequest::GroundingSource::GoogleSearchSource
Returns If set, grounding is performed with Google Search.
Note: The following fields are mutually exclusive: google_search_source, inline_source, search_source, enterprise_web_retrieval_source. If a field in that set is populated, all other fields in the set will automatically be cleared.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 201 class GroundingSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Message to be used for grounding based on inline content. # @!attribute [rw] grounding_facts # @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::GroundingFact>] # List of facts to be used for grounding. # @!attribute [rw] attributes # @return [::Google::Protobuf::Map{::String => ::String}] # Attributes associated with the content. # # Common attributes include `source` (indicating where the content was # sourced from) and `author` (indicating the author of the content). class InlineSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Message to be used for grounding with Vertex AI Search. # @!attribute [rw] serving_config # @return [::String] # The resource name of the Engine to use. # # Format: # `projects/{project}/locations/{location}/collections/{collection_id}/engines/{engine_id}/servingConfigs/{serving_config_id}` # @!attribute [rw] max_result_count # @return [::Integer] # Number of search results to return. # # The default value is 10. The maximumm allowed value is 10. # @!attribute [rw] filter # @return [::String] # Filter expression to be applied to the search. # # The syntax is the same as # {::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest#filter SearchRequest.filter}. # @!attribute [rw] safe_search # @return [::Boolean] # If set, safe search is enabled in Vertex AI Search requests. class SearchSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Google Search config parameters. # @!attribute [rw] dynamic_retrieval_config # @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentRequest::DynamicRetrievalConfiguration] # Optional. Specifies the dynamic retrieval configuration for the given # source. # @!attribute [rw] exclude_domains # @return [::Array<::String>] # Optional. List of domains to be excluded from the search results. # @!attribute [rw] blocking_confidence # @return [::Google::Cloud::DiscoveryEngine::V1beta::Citation::PhishBlockThreshold] # Optional. Sites with confidence level chosen & above this value will be # blocked from the search results. class GoogleSearchSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Params for using enterprise web retrieval as grounding source. # @!attribute [rw] exclude_domains # @return [::Array<::String>] # Optional. List of domains to be excluded from the search results. # @!attribute [rw] blocking_confidence # @return [::Google::Cloud::DiscoveryEngine::V1beta::Citation::PhishBlockThreshold] # Optional. Sites with confidence level chosen & above this value will be # blocked from the search results. class EnterpriseWebRetrievalSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#inline_source ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentRequest::GroundingSource::InlineSource
Returns If set, grounding is performed with inline content.
Note: The following fields are mutually exclusive: inline_source, search_source, google_search_source, enterprise_web_retrieval_source. If a field in that set is populated, all other fields in the set will automatically be cleared.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 201 class GroundingSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Message to be used for grounding based on inline content. # @!attribute [rw] grounding_facts # @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::GroundingFact>] # List of facts to be used for grounding. # @!attribute [rw] attributes # @return [::Google::Protobuf::Map{::String => ::String}] # Attributes associated with the content. # # Common attributes include `source` (indicating where the content was # sourced from) and `author` (indicating the author of the content). class InlineSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Message to be used for grounding with Vertex AI Search. # @!attribute [rw] serving_config # @return [::String] # The resource name of the Engine to use. # # Format: # `projects/{project}/locations/{location}/collections/{collection_id}/engines/{engine_id}/servingConfigs/{serving_config_id}` # @!attribute [rw] max_result_count # @return [::Integer] # Number of search results to return. # # The default value is 10. The maximumm allowed value is 10. # @!attribute [rw] filter # @return [::String] # Filter expression to be applied to the search. # # The syntax is the same as # {::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest#filter SearchRequest.filter}. # @!attribute [rw] safe_search # @return [::Boolean] # If set, safe search is enabled in Vertex AI Search requests. class SearchSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Google Search config parameters. # @!attribute [rw] dynamic_retrieval_config # @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentRequest::DynamicRetrievalConfiguration] # Optional. Specifies the dynamic retrieval configuration for the given # source. # @!attribute [rw] exclude_domains # @return [::Array<::String>] # Optional. List of domains to be excluded from the search results. # @!attribute [rw] blocking_confidence # @return [::Google::Cloud::DiscoveryEngine::V1beta::Citation::PhishBlockThreshold] # Optional. Sites with confidence level chosen & above this value will be # blocked from the search results. class GoogleSearchSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Params for using enterprise web retrieval as grounding source. # @!attribute [rw] exclude_domains # @return [::Array<::String>] # Optional. List of domains to be excluded from the search results. # @!attribute [rw] blocking_confidence # @return [::Google::Cloud::DiscoveryEngine::V1beta::Citation::PhishBlockThreshold] # Optional. Sites with confidence level chosen & above this value will be # blocked from the search results. class EnterpriseWebRetrievalSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#search_source ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentRequest::GroundingSource::SearchSource
Returns If set, grounding is performed with Vertex AI Search.
Note: The following fields are mutually exclusive: search_source, inline_source, google_search_source, enterprise_web_retrieval_source. If a field in that set is populated, all other fields in the set will automatically be cleared.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/grounded_generation_service.rb', line 201 class GroundingSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Message to be used for grounding based on inline content. # @!attribute [rw] grounding_facts # @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::GroundingFact>] # List of facts to be used for grounding. # @!attribute [rw] attributes # @return [::Google::Protobuf::Map{::String => ::String}] # Attributes associated with the content. # # Common attributes include `source` (indicating where the content was # sourced from) and `author` (indicating the author of the content). class InlineSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Message to be used for grounding with Vertex AI Search. # @!attribute [rw] serving_config # @return [::String] # The resource name of the Engine to use. # # Format: # `projects/{project}/locations/{location}/collections/{collection_id}/engines/{engine_id}/servingConfigs/{serving_config_id}` # @!attribute [rw] max_result_count # @return [::Integer] # Number of search results to return. # # The default value is 10. The maximumm allowed value is 10. # @!attribute [rw] filter # @return [::String] # Filter expression to be applied to the search. # # The syntax is the same as # {::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest#filter SearchRequest.filter}. # @!attribute [rw] safe_search # @return [::Boolean] # If set, safe search is enabled in Vertex AI Search requests. class SearchSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Google Search config parameters. # @!attribute [rw] dynamic_retrieval_config # @return [::Google::Cloud::DiscoveryEngine::V1beta::GenerateGroundedContentRequest::DynamicRetrievalConfiguration] # Optional. Specifies the dynamic retrieval configuration for the given # source. # @!attribute [rw] exclude_domains # @return [::Array<::String>] # Optional. List of domains to be excluded from the search results. # @!attribute [rw] blocking_confidence # @return [::Google::Cloud::DiscoveryEngine::V1beta::Citation::PhishBlockThreshold] # Optional. Sites with confidence level chosen & above this value will be # blocked from the search results. class GoogleSearchSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Params for using enterprise web retrieval as grounding source. # @!attribute [rw] exclude_domains # @return [::Array<::String>] # Optional. List of domains to be excluded from the search results. # @!attribute [rw] blocking_confidence # @return [::Google::Cloud::DiscoveryEngine::V1beta::Citation::PhishBlockThreshold] # Optional. Sites with confidence level chosen & above this value will be # blocked from the search results. class EnterpriseWebRetrievalSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |