Class: Google::Cloud::DiscoveryEngine::V1beta::HealthcareFhirConfig
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::HealthcareFhirConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/common.rb
Overview
Config to data store for HEALTHCARE_FHIR vertical.
Instance Attribute Summary collapse
-
#enable_configurable_schema ⇒ ::Boolean
Whether to enable configurable schema for
HEALTHCARE_FHIRvertical. -
#enable_static_indexing_for_batch_ingestion ⇒ ::Boolean
Whether to enable static indexing for
HEALTHCARE_FHIRbatch ingestion. -
#initial_filter_groups ⇒ ::Array<::String>
Optional.
Instance Attribute Details
#enable_configurable_schema ⇒ ::Boolean
Returns Whether to enable configurable schema for HEALTHCARE_FHIR vertical.
If set to true, the predefined healthcare fhir schema can be extended
for more customized searching and filtering.
247 248 249 250 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/common.rb', line 247 class HealthcareFhirConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#enable_static_indexing_for_batch_ingestion ⇒ ::Boolean
Returns Whether to enable static indexing for HEALTHCARE_FHIR batch
ingestion.
If set to true, the batch ingestion will be processed in a static
indexing mode which is slower but more capable of handling larger
volume.
247 248 249 250 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/common.rb', line 247 class HealthcareFhirConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#initial_filter_groups ⇒ ::Array<::String>
Returns Optional. Names of the Group resources to use as a basis for the initial
patient filter, in format
projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/fhirStores/{fhir_store_id}/fhir/Group/{group_id}.
The filter group must be a FHIR resource name of
type Group, and the filter will be constructed from the direct members of
the group which are Patient resources.
247 248 249 250 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/common.rb', line 247 class HealthcareFhirConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |