Class: Google::Cloud::DiscoveryEngine::V1beta::Project::CustomerProvidedConfig
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::Project::CustomerProvidedConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/project.rb
Overview
Customer provided configurations.
Defined Under Namespace
Classes: NotebooklmConfig
Instance Attribute Summary collapse
Instance Attribute Details
#notebooklm_config ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Project::CustomerProvidedConfig::NotebooklmConfig
Returns Optional. Configuration for NotebookLM settings.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/project.rb', line 104 class CustomerProvidedConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for NotebookLM. # @!attribute [rw] model_armor_config # @return [::Google::Cloud::DiscoveryEngine::V1beta::Project::CustomerProvidedConfig::NotebooklmConfig::ModelArmorConfig] # Model Armor configuration to be used for sanitizing user prompts and # LLM responses. # @!attribute [rw] opt_out_notebook_sharing # @return [::Boolean] # Optional. Whether to disable the notebook sharing feature for the # project. Default to false if not specified. # @!attribute [rw] data_protection_policy # @return [::Google::Cloud::DiscoveryEngine::V1beta::Project::CustomerProvidedConfig::NotebooklmConfig::DataProtectionPolicy] # Optional. Specifies the data protection policy for NotebookLM. # @!attribute [rw] observability_config # @return [::Google::Cloud::DiscoveryEngine::V1beta::ObservabilityConfig] # Optional. Observability config for NotebookLM. class NotebooklmConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for customer defined Model Armor templates to be used for # sanitizing user prompts and LLM responses. # @!attribute [rw] user_prompt_template # @return [::String] # Optional. The resource name of the Model Armor Template for # sanitizing user prompts. Format: # projects/\\{project}/locations/\\{location}/templates/\\{template_id} # If not specified, no sanitization will be applied to the user prompt. # @!attribute [rw] response_template # @return [::String] # Optional. The resource name of the Model Armor Template for # sanitizing LLM responses. Format: # projects/\\{project}/locations/\\{location}/templates/\\{template_id} # If not specified, no sanitization will be applied to the LLM # response. class ModelArmorConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Data protection policy config for NotebookLM. # @!attribute [rw] sensitive_data_protection_policy # @return [::Google::Cloud::DiscoveryEngine::V1beta::Project::CustomerProvidedConfig::NotebooklmConfig::DataProtectionPolicy::SensitiveDataProtectionPolicy] # Optional. The sensitive data protection policy. class DataProtectionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies a Sensitive Data Protection # (https://cloud.google.com/sensitive-data-protection/docs/sensitive-data-protection-overview) # policy. # @!attribute [rw] policy # @return [::String] # Optional. The Sensitive Data Protection policy resource name. class SensitiveDataProtectionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end end |