Class: Google::Cloud::DiscoveryEngine::V1beta::RemoveSuggestionRequest
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::RemoveSuggestionRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb
Overview
Request message for CompletionService.RemoveSuggestion method.
Instance Attribute Summary collapse
-
#completion_config ⇒ ::String
Required.
-
#remove_all_search_history_suggestions ⇒ ::Boolean
Remove all search history suggestions for the user.
-
#remove_time ⇒ ::Google::Protobuf::Timestamp
Required.
-
#search_history_suggestion ⇒ ::String
The search history suggestion to be removed.
-
#user_info ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::UserInfo
Optional.
-
#user_pseudo_id ⇒ ::String
Required.
Instance Attribute Details
#completion_config ⇒ ::String
Returns Required. The completion_config of the parent engine resource name for
which the search history suggestion is to be removed, such as
projects/*/locations/global/collections/default_collection/engines/*/completionConfig.
472 473 474 475 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb', line 472 class RemoveSuggestionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#remove_all_search_history_suggestions ⇒ ::Boolean
Returns Remove all search history suggestions for the user.
Note: The following fields are mutually exclusive: remove_all_search_history_suggestions, search_history_suggestion. If a field in that set is populated, all other fields in the set will automatically be cleared.
472 473 474 475 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb', line 472 class RemoveSuggestionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#remove_time ⇒ ::Google::Protobuf::Timestamp
Returns Required. Time at which the suggestion was removed. If not set, the current time will be used.
472 473 474 475 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb', line 472 class RemoveSuggestionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#search_history_suggestion ⇒ ::String
Returns The search history suggestion to be removed.
Note: The following fields are mutually exclusive: search_history_suggestion, remove_all_search_history_suggestions. If a field in that set is populated, all other fields in the set will automatically be cleared.
472 473 474 475 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb', line 472 class RemoveSuggestionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#user_info ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::UserInfo
Returns Optional. Information about the end user.
This should be the same identifier information as UserEvent.user_info and SearchRequest.user_info.
472 473 474 475 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb', line 472 class RemoveSuggestionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#user_pseudo_id ⇒ ::String
Returns Required. A unique identifier for tracking visitors. For example, this could be implemented with an HTTP cookie, which should be able to uniquely identify a visitor on a single device. This unique identifier should not change if the visitor logs in or out of the website.
This field should NOT have a fixed value such as unknown_visitor.
This should be the same identifier as UserEvent.user_pseudo_id and SearchRequest.user_pseudo_id.
The field must be a UTF-8 encoded string with a length limit of 128.
472 473 474 475 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/completion_service.rb', line 472 class RemoveSuggestionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |