Class: Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::ContentSearchSpec::SummarySpec::MultiModalSpec
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::ContentSearchSpec::SummarySpec::MultiModalSpec
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb
Overview
Multimodal specification: Will return an image from specified source. If multiple sources are specified, the pick is a quality based decision.
Defined Under Namespace
Modules: ImageSource
Instance Attribute Summary collapse
Instance Attribute Details
#image_source ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::ContentSearchSpec::SummarySpec::MultiModalSpec::ImageSource
Returns Optional. Source of image returned in the answer.
1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1031 class MultiModalSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the image source. module ImageSource # Unspecified image source (multimodal feature is disabled by # default). IMAGE_SOURCE_UNSPECIFIED = 0 # Behavior when service determines the pick from all available # sources. ALL_AVAILABLE_SOURCES = 1 # Includes image from corpus in the answer. CORPUS_IMAGE_ONLY = 2 # Triggers figure generation in the answer. FIGURE_GENERATION_ONLY = 3 end end |