Class: Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::DataStoreSpec
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::DataStoreSpec
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb
Overview
A struct to define data stores to filter on in a search call and
configurations for those data stores. Otherwise, an INVALID_ARGUMENT
error is returned.
Instance Attribute Summary collapse
-
#boost_spec ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::BoostSpec
Optional.
-
#custom_search_operators ⇒ ::String
Optional.
-
#data_store ⇒ ::String
Required.
-
#filter ⇒ ::String
Optional.
-
#num_results ⇒ ::Integer
Optional.
Instance Attribute Details
#boost_spec ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::BoostSpec
Returns Optional. Boost specification to boost certain documents. For more information on boosting, see Boosting.
529 530 531 532 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 529 class DataStoreSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#custom_search_operators ⇒ ::String
Returns Optional. Custom search operators which if specified will be used to filter results from workspace data stores. For more information on custom search operators, see SearchOperators.
529 530 531 532 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 529 class DataStoreSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#data_store ⇒ ::String
Returns Required. Full resource name of
DataStore, such as
projects/{project}/locations/{location}/collections/{collection_id}/dataStores/{data_store_id}.
The path must include the project number, project id is not supported for
this field.
529 530 531 532 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 529 class DataStoreSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#filter ⇒ ::String
Returns Optional. Filter specification to filter documents in the data store specified by data_store field. For more information on filtering, see Filtering.
529 530 531 532 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 529 class DataStoreSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#num_results ⇒ ::Integer
Returns Optional. The maximum number of results to retrieve from this data store. If not specified, it will use the SearchRequest.num_results_per_data_store if provided, otherwise there is no limit. If both this field and SearchRequest.num_results_per_data_store are specified, this field will be used.
529 530 531 532 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 529 class DataStoreSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |