Class: Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::NaturalLanguageQueryUnderstandingSpec

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb

Overview

Specification to enable natural language understanding capabilities for search requests.

Defined Under Namespace

Modules: FilterExtractionCondition

Instance Attribute Summary collapse

Instance Attribute Details

#filter_extraction_condition::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::NaturalLanguageQueryUnderstandingSpec::FilterExtractionCondition

Returns The condition under which filter extraction should occur. Default to [Condition.DISABLED][].

Returns:



1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1081

class NaturalLanguageQueryUnderstandingSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum describing under which condition filter extraction should occur.
  module FilterExtractionCondition
    # Server behavior defaults to [Condition.DISABLED][].
    CONDITION_UNSPECIFIED = 0

    # Disables NL filter extraction.
    DISABLED = 1

    # Enables NL filter extraction.
    ENABLED = 2
  end
end

#geo_search_query_detection_field_names::Array<::String>

Returns Field names used for location-based filtering, where geolocation filters are detected in natural language search queries. Only valid when the FilterExtractionCondition is set to ENABLED.

If this field is set, it overrides the field names set in [ServingConfig.geo_search_query_detection_field_names][google.cloud.discoveryengine.v1beta.ServingConfig.geo_search_query_detection_field_names].

Returns:

  • (::Array<::String>)

    Field names used for location-based filtering, where geolocation filters are detected in natural language search queries. Only valid when the FilterExtractionCondition is set to ENABLED.

    If this field is set, it overrides the field names set in [ServingConfig.geo_search_query_detection_field_names][google.cloud.discoveryengine.v1beta.ServingConfig.geo_search_query_detection_field_names].



1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1081

class NaturalLanguageQueryUnderstandingSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum describing under which condition filter extraction should occur.
  module FilterExtractionCondition
    # Server behavior defaults to [Condition.DISABLED][].
    CONDITION_UNSPECIFIED = 0

    # Disables NL filter extraction.
    DISABLED = 1

    # Enables NL filter extraction.
    ENABLED = 2
  end
end