Class: Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::SpellCorrectionSpec
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::SpellCorrectionSpec
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb
Overview
The specification for query spell correction.
Defined Under Namespace
Modules: Mode
Instance Attribute Summary collapse
-
#mode ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::SpellCorrectionSpec::Mode
The mode under which spell correction replaces the original search query.
Instance Attribute Details
#mode ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::SpellCorrectionSpec::Mode
Returns The mode under which spell correction replaces the original search query. Defaults to Mode.AUTO.
746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 746 class SpellCorrectionSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum describing under which mode spell correction should occur. module Mode # Unspecified spell correction mode. In this case, server behavior # defaults to # {::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::SpellCorrectionSpec::Mode::AUTO Mode.AUTO}. MODE_UNSPECIFIED = 0 # Search API tries to find a spelling suggestion. If a suggestion is # found, it is put in the # {::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse#corrected_query SearchResponse.corrected_query}. # The spelling suggestion won't be used as the search query. SUGGESTION_ONLY = 1 # Automatic spell correction built by the Search API. Search will # be based on the corrected query if found. AUTO = 2 end end |