Class: Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Facet

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb

Overview

A facet result.

Defined Under Namespace

Classes: FacetValue

Instance Attribute Summary collapse

Instance Attribute Details

#dynamic_facet::Boolean

Returns Whether the facet is dynamically generated.

Returns:

  • (::Boolean)

    Whether the facet is dynamically generated.



1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1418

class Facet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A facet value which contains value names and their count.
  # @!attribute [rw] value
  #   @return [::String]
  #     Text value of a facet, such as "Black" for facet "colors".
  #
  #     Note: The following fields are mutually exclusive: `value`, `interval`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] interval
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Interval]
  #     Interval value for a facet, such as [10, 20) for facet "price". It
  #     matches
  #     {::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::FacetSpec::FacetKey#intervals SearchRequest.FacetSpec.FacetKey.intervals}.
  #
  #     Note: The following fields are mutually exclusive: `interval`, `value`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     Number of items that have this facet value.
  class FacetValue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#key::String

Returns The key for this facet. For example, "colors" or "price". It matches SearchRequest.FacetSpec.FacetKey.key.

Returns:



1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1418

class Facet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A facet value which contains value names and their count.
  # @!attribute [rw] value
  #   @return [::String]
  #     Text value of a facet, such as "Black" for facet "colors".
  #
  #     Note: The following fields are mutually exclusive: `value`, `interval`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] interval
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Interval]
  #     Interval value for a facet, such as [10, 20) for facet "price". It
  #     matches
  #     {::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::FacetSpec::FacetKey#intervals SearchRequest.FacetSpec.FacetKey.intervals}.
  #
  #     Note: The following fields are mutually exclusive: `interval`, `value`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     Number of items that have this facet value.
  class FacetValue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#values::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Facet::FacetValue>

Returns The facet values for this field.

Returns:



1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1418

class Facet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A facet value which contains value names and their count.
  # @!attribute [rw] value
  #   @return [::String]
  #     Text value of a facet, such as "Black" for facet "colors".
  #
  #     Note: The following fields are mutually exclusive: `value`, `interval`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] interval
  #   @return [::Google::Cloud::DiscoveryEngine::V1beta::Interval]
  #     Interval value for a facet, such as [10, 20) for facet "price". It
  #     matches
  #     {::Google::Cloud::DiscoveryEngine::V1beta::SearchRequest::FacetSpec::FacetKey#intervals SearchRequest.FacetSpec.FacetKey.intervals}.
  #
  #     Note: The following fields are mutually exclusive: `interval`, `value`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     Number of items that have this facet value.
  class FacetValue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end