Class: Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::SearchResult
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::SearchResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb
Overview
Represents the search results.
Defined Under Namespace
Classes: ModelScoresEntry, RankSignals
Instance Attribute Summary collapse
-
#chunk ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Chunk
The chunk data in the search response if the SearchRequest.ContentSearchSpec.search_result_mode is set to CHUNKS.
-
#document ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Document
The document data snippet in the search response.
-
#id ⇒ ::String
Document.id of the searched Document.
-
#model_scores ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::DiscoveryEngine::V1beta::DoubleList}
readonly
Output only.
-
#rank_signals ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::SearchResult::RankSignals
Optional.
Instance Attribute Details
#chunk ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Chunk
Returns The chunk data in the search response if the SearchRequest.ContentSearchSpec.search_result_mode is set to CHUNKS.
1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1671 class SearchResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A set of ranking signals. # @!attribute [rw] keyword_similarity_score # @return [::Float] # Optional. Keyword matching adjustment. # @!attribute [rw] relevance_score # @return [::Float] # Optional. Semantic relevance adjustment. # @!attribute [rw] semantic_similarity_score # @return [::Float] # Optional. Semantic similarity adjustment. # @!attribute [rw] pctr_rank # @return [::Float] # Optional. Predicted conversion rate adjustment as a rank. # @!attribute [rw] topicality_rank # @return [::Float] # Optional. Topicality adjustment as a rank. # @!attribute [rw] document_age # @return [::Float] # Optional. Age of the document in hours. # @!attribute [rw] boosting_factor # @return [::Float] # Optional. Combined custom boosts for a doc. # @!attribute [rw] default_rank # @return [::Float] # Optional. The default rank of the result. # @!attribute [rw] custom_signals # @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::SearchResult::RankSignals::CustomSignal>] # Optional. A list of custom clearbox signals. # @!attribute [rw] precomputed_expression_values # @return [::Array<::Float>] # Optional. A list of precomputed expression results for a given # document, in the same order as requested in # `SearchRequest.custom_ranking_params.expressions_to_precompute`. class RankSignals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Custom clearbox signal represented by name and value pair. # @!attribute [rw] name # @return [::String] # Optional. Name of the signal. # @!attribute [rw] value # @return [::Float] # Optional. Float value representing the ranking signal (e.g. 1.25 for # BM25). class CustomSignal include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::DiscoveryEngine::V1beta::DoubleList] class ModelScoresEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#document ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::Document
Returns The document data snippet in the search response. Only fields that are
marked as retrievable are populated.
1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1671 class SearchResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A set of ranking signals. # @!attribute [rw] keyword_similarity_score # @return [::Float] # Optional. Keyword matching adjustment. # @!attribute [rw] relevance_score # @return [::Float] # Optional. Semantic relevance adjustment. # @!attribute [rw] semantic_similarity_score # @return [::Float] # Optional. Semantic similarity adjustment. # @!attribute [rw] pctr_rank # @return [::Float] # Optional. Predicted conversion rate adjustment as a rank. # @!attribute [rw] topicality_rank # @return [::Float] # Optional. Topicality adjustment as a rank. # @!attribute [rw] document_age # @return [::Float] # Optional. Age of the document in hours. # @!attribute [rw] boosting_factor # @return [::Float] # Optional. Combined custom boosts for a doc. # @!attribute [rw] default_rank # @return [::Float] # Optional. The default rank of the result. # @!attribute [rw] custom_signals # @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::SearchResult::RankSignals::CustomSignal>] # Optional. A list of custom clearbox signals. # @!attribute [rw] precomputed_expression_values # @return [::Array<::Float>] # Optional. A list of precomputed expression results for a given # document, in the same order as requested in # `SearchRequest.custom_ranking_params.expressions_to_precompute`. class RankSignals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Custom clearbox signal represented by name and value pair. # @!attribute [rw] name # @return [::String] # Optional. Name of the signal. # @!attribute [rw] value # @return [::Float] # Optional. Float value representing the ranking signal (e.g. 1.25 for # BM25). class CustomSignal include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::DiscoveryEngine::V1beta::DoubleList] class ModelScoresEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#id ⇒ ::String
Returns Document.id of the searched Document.
1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1671 class SearchResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A set of ranking signals. # @!attribute [rw] keyword_similarity_score # @return [::Float] # Optional. Keyword matching adjustment. # @!attribute [rw] relevance_score # @return [::Float] # Optional. Semantic relevance adjustment. # @!attribute [rw] semantic_similarity_score # @return [::Float] # Optional. Semantic similarity adjustment. # @!attribute [rw] pctr_rank # @return [::Float] # Optional. Predicted conversion rate adjustment as a rank. # @!attribute [rw] topicality_rank # @return [::Float] # Optional. Topicality adjustment as a rank. # @!attribute [rw] document_age # @return [::Float] # Optional. Age of the document in hours. # @!attribute [rw] boosting_factor # @return [::Float] # Optional. Combined custom boosts for a doc. # @!attribute [rw] default_rank # @return [::Float] # Optional. The default rank of the result. # @!attribute [rw] custom_signals # @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::SearchResult::RankSignals::CustomSignal>] # Optional. A list of custom clearbox signals. # @!attribute [rw] precomputed_expression_values # @return [::Array<::Float>] # Optional. A list of precomputed expression results for a given # document, in the same order as requested in # `SearchRequest.custom_ranking_params.expressions_to_precompute`. class RankSignals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Custom clearbox signal represented by name and value pair. # @!attribute [rw] name # @return [::String] # Optional. Name of the signal. # @!attribute [rw] value # @return [::Float] # Optional. Float value representing the ranking signal (e.g. 1.25 for # BM25). class CustomSignal include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::DiscoveryEngine::V1beta::DoubleList] class ModelScoresEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#model_scores ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::DiscoveryEngine::V1beta::DoubleList} (readonly)
Returns Output only. Google provided available scores.
1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1671 class SearchResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A set of ranking signals. # @!attribute [rw] keyword_similarity_score # @return [::Float] # Optional. Keyword matching adjustment. # @!attribute [rw] relevance_score # @return [::Float] # Optional. Semantic relevance adjustment. # @!attribute [rw] semantic_similarity_score # @return [::Float] # Optional. Semantic similarity adjustment. # @!attribute [rw] pctr_rank # @return [::Float] # Optional. Predicted conversion rate adjustment as a rank. # @!attribute [rw] topicality_rank # @return [::Float] # Optional. Topicality adjustment as a rank. # @!attribute [rw] document_age # @return [::Float] # Optional. Age of the document in hours. # @!attribute [rw] boosting_factor # @return [::Float] # Optional. Combined custom boosts for a doc. # @!attribute [rw] default_rank # @return [::Float] # Optional. The default rank of the result. # @!attribute [rw] custom_signals # @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::SearchResult::RankSignals::CustomSignal>] # Optional. A list of custom clearbox signals. # @!attribute [rw] precomputed_expression_values # @return [::Array<::Float>] # Optional. A list of precomputed expression results for a given # document, in the same order as requested in # `SearchRequest.custom_ranking_params.expressions_to_precompute`. class RankSignals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Custom clearbox signal represented by name and value pair. # @!attribute [rw] name # @return [::String] # Optional. Name of the signal. # @!attribute [rw] value # @return [::Float] # Optional. Float value representing the ranking signal (e.g. 1.25 for # BM25). class CustomSignal include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::DiscoveryEngine::V1beta::DoubleList] class ModelScoresEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#rank_signals ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::SearchResult::RankSignals
Returns Optional. A set of ranking signals associated with the result.
1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1671 class SearchResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A set of ranking signals. # @!attribute [rw] keyword_similarity_score # @return [::Float] # Optional. Keyword matching adjustment. # @!attribute [rw] relevance_score # @return [::Float] # Optional. Semantic relevance adjustment. # @!attribute [rw] semantic_similarity_score # @return [::Float] # Optional. Semantic similarity adjustment. # @!attribute [rw] pctr_rank # @return [::Float] # Optional. Predicted conversion rate adjustment as a rank. # @!attribute [rw] topicality_rank # @return [::Float] # Optional. Topicality adjustment as a rank. # @!attribute [rw] document_age # @return [::Float] # Optional. Age of the document in hours. # @!attribute [rw] boosting_factor # @return [::Float] # Optional. Combined custom boosts for a doc. # @!attribute [rw] default_rank # @return [::Float] # Optional. The default rank of the result. # @!attribute [rw] custom_signals # @return [::Array<::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::SearchResult::RankSignals::CustomSignal>] # Optional. A list of custom clearbox signals. # @!attribute [rw] precomputed_expression_values # @return [::Array<::Float>] # Optional. A list of precomputed expression results for a given # document, in the same order as requested in # `SearchRequest.custom_ranking_params.expressions_to_precompute`. class RankSignals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Custom clearbox signal represented by name and value pair. # @!attribute [rw] name # @return [::String] # Optional. Name of the signal. # @!attribute [rw] value # @return [::Float] # Optional. Float value representing the ranking signal (e.g. 1.25 for # BM25). class CustomSignal include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::DiscoveryEngine::V1beta::DoubleList] class ModelScoresEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |