Class: Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::BlobAttachment
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::BlobAttachment
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb
Overview
Stores binarydata attached to text answer, e.g. image, video, audio, etc.
Defined Under Namespace
Modules: AttributionType Classes: Blob
Instance Attribute Summary collapse
-
#attribution_type ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::BlobAttachment::AttributionType
readonly
Output only.
-
#data ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::BlobAttachment::Blob
readonly
Output only.
Instance Attribute Details
#attribution_type ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::BlobAttachment::AttributionType (readonly)
Returns Output only. The attribution type of the blob.
1910 1911 1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 1924 1925 1926 1927 1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 1938 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1910 class BlobAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Stores type and data of the blob. # @!attribute [r] mime_type # @return [::String] # Output only. The media type (MIME type) of the generated data. # @!attribute [r] data # @return [::String] # Output only. Raw bytes. class Blob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the attribution type of the blob. module AttributionType # Unspecified attribution type. ATTRIBUTION_TYPE_UNSPECIFIED = 0 # The attachment data is from the corpus. CORPUS = 1 # The attachment data is generated by the model through code # generation. GENERATED = 2 end end |
#data ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::SearchResponse::Summary::BlobAttachment::Blob (readonly)
Returns Output only. The blob data.
1910 1911 1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 1924 1925 1926 1927 1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 1938 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/search_service.rb', line 1910 class BlobAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Stores type and data of the blob. # @!attribute [r] mime_type # @return [::String] # Output only. The media type (MIME type) of the generated data. # @!attribute [r] data # @return [::String] # Output only. Raw bytes. class Blob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the attribution type of the blob. module AttributionType # Unspecified attribution type. ATTRIBUTION_TYPE_UNSPECIFIED = 0 # The attachment data is from the corpus. CORPUS = 1 # The attachment data is generated by the model through code # generation. GENERATED = 2 end end |