Class: Google::Cloud::DiscoveryEngine::V1beta::StreamAssistResponse
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::StreamAssistResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/assistant_service.rb
Overview
Response for the AssistantService.StreamAssist method.
Defined Under Namespace
Classes: InvokedSkill, SessionInfo
Instance Attribute Summary collapse
-
#answer ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::AssistAnswer
Assist answer resource object containing parts of the assistant's final answer for the user's query.
-
#assist_token ⇒ ::String
A global unique ID that identifies the current pair of request and stream of responses.
-
#invocation_tools ⇒ ::Array<::String>
The tool names of the tools that were invoked.
-
#invoked_skills ⇒ ::Array<::Google::Cloud::DiscoveryEngine::V1beta::StreamAssistResponse::InvokedSkill>
The skills executed during the turn.
-
#session_info ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::StreamAssistResponse::SessionInfo
Session information.
Instance Attribute Details
#answer ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::AssistAnswer
Returns Assist answer resource object containing parts of the assistant's final answer for the user's query.
Not present if the current response doesn't add anything to previously sent AssistAnswer.replies.
Observe
AssistAnswer.state
to see if more parts are to be expected. While the state is IN_PROGRESS,
the
AssistAnswer.replies
field in each response will contain replies (reply fragments) to be
appended to the ones received in previous responses.
AssistAnswer.name
won't be filled.
If the state is SUCCEEDED, FAILED or SKIPPED, the response
is the last response and
AssistAnswer.name
will have a value.
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assistant_service.rb', line 202 class StreamAssistResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Information about the session. # @!attribute [rw] session # @return [::String] # Name of the newly generated or continued session. # # Format: # `projects/{project}/locations/{location}/collections/{collection}/engines/{engine}/sessions/{session}`. class SessionInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents a skill used during the assist call. # @!attribute [rw] name # @return [::String] # The resource name of the skill. # @!attribute [rw] display_name # @return [::String] # The display name of the skill. class InvokedSkill include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#assist_token ⇒ ::String
Returns A global unique ID that identifies the current pair of request and stream of responses. Used for feedback and support.
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assistant_service.rb', line 202 class StreamAssistResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Information about the session. # @!attribute [rw] session # @return [::String] # Name of the newly generated or continued session. # # Format: # `projects/{project}/locations/{location}/collections/{collection}/engines/{engine}/sessions/{session}`. class SessionInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents a skill used during the assist call. # @!attribute [rw] name # @return [::String] # The resource name of the skill. # @!attribute [rw] display_name # @return [::String] # The display name of the skill. class InvokedSkill include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#invocation_tools ⇒ ::Array<::String>
Returns The tool names of the tools that were invoked.
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assistant_service.rb', line 202 class StreamAssistResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Information about the session. # @!attribute [rw] session # @return [::String] # Name of the newly generated or continued session. # # Format: # `projects/{project}/locations/{location}/collections/{collection}/engines/{engine}/sessions/{session}`. class SessionInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents a skill used during the assist call. # @!attribute [rw] name # @return [::String] # The resource name of the skill. # @!attribute [rw] display_name # @return [::String] # The display name of the skill. class InvokedSkill include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#invoked_skills ⇒ ::Array<::Google::Cloud::DiscoveryEngine::V1beta::StreamAssistResponse::InvokedSkill>
Returns The skills executed during the turn.
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assistant_service.rb', line 202 class StreamAssistResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Information about the session. # @!attribute [rw] session # @return [::String] # Name of the newly generated or continued session. # # Format: # `projects/{project}/locations/{location}/collections/{collection}/engines/{engine}/sessions/{session}`. class SessionInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents a skill used during the assist call. # @!attribute [rw] name # @return [::String] # The resource name of the skill. # @!attribute [rw] display_name # @return [::String] # The display name of the skill. class InvokedSkill include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#session_info ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::StreamAssistResponse::SessionInfo
Returns Session information. Only included in the final StreamAssistResponse of the response stream.
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/assistant_service.rb', line 202 class StreamAssistResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Information about the session. # @!attribute [rw] session # @return [::String] # Name of the newly generated or continued session. # # Format: # `projects/{project}/locations/{location}/collections/{collection}/engines/{engine}/sessions/{session}`. class SessionInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents a skill used during the assist call. # @!attribute [rw] name # @return [::String] # The resource name of the skill. # @!attribute [rw] display_name # @return [::String] # The display name of the skill. class InvokedSkill include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |