Class: Google::Cloud::DiscoveryEngine::V1beta::WorkspaceConfig
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1beta::WorkspaceConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1beta/data_store.rb
Overview
Config to store data store type configuration for workspace data
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#dasher_customer_id ⇒ ::String
readonly
Output only.
-
#super_admin_email_address ⇒ ::String
Optional.
-
#super_admin_service_account ⇒ ::String
Optional.
-
#type ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::WorkspaceConfig::Type
The Google Workspace data source.
Instance Attribute Details
#dasher_customer_id ⇒ ::String (readonly)
Returns Output only. Obfuscated Dasher customer ID. Derived by the server from the project's GCP organization at data store creation time; any value supplied in the request payload is ignored.
436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/data_store.rb', line 436 class WorkspaceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of Workspace App supported by this DataStore module Type # Defaults to an unspecified Workspace type. TYPE_UNSPECIFIED = 0 # Workspace Data Store contains Drive data GOOGLE_DRIVE = 1 # Workspace Data Store contains Mail data GOOGLE_MAIL = 2 # Workspace Data Store contains Sites data GOOGLE_SITES = 3 # Workspace Data Store contains Calendar data GOOGLE_CALENDAR = 4 # Workspace Data Store contains Chat data GOOGLE_CHAT = 5 # Workspace Data Store contains Groups data GOOGLE_GROUPS = 6 # Workspace Data Store contains Keep data GOOGLE_KEEP = 7 # Workspace Data Store contains People data GOOGLE_PEOPLE = 8 end end |
#super_admin_email_address ⇒ ::String
Returns Optional. The super admin email address for the workspace that will be used for access token generation. For now we only use it for Native Google Drive connector data ingestion.
436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/data_store.rb', line 436 class WorkspaceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of Workspace App supported by this DataStore module Type # Defaults to an unspecified Workspace type. TYPE_UNSPECIFIED = 0 # Workspace Data Store contains Drive data GOOGLE_DRIVE = 1 # Workspace Data Store contains Mail data GOOGLE_MAIL = 2 # Workspace Data Store contains Sites data GOOGLE_SITES = 3 # Workspace Data Store contains Calendar data GOOGLE_CALENDAR = 4 # Workspace Data Store contains Chat data GOOGLE_CHAT = 5 # Workspace Data Store contains Groups data GOOGLE_GROUPS = 6 # Workspace Data Store contains Keep data GOOGLE_KEEP = 7 # Workspace Data Store contains People data GOOGLE_PEOPLE = 8 end end |
#super_admin_service_account ⇒ ::String
Returns Optional. The super admin service account for the workspace that will be used for access token generation. For now we only use it for Native Google Drive connector data ingestion.
436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/data_store.rb', line 436 class WorkspaceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of Workspace App supported by this DataStore module Type # Defaults to an unspecified Workspace type. TYPE_UNSPECIFIED = 0 # Workspace Data Store contains Drive data GOOGLE_DRIVE = 1 # Workspace Data Store contains Mail data GOOGLE_MAIL = 2 # Workspace Data Store contains Sites data GOOGLE_SITES = 3 # Workspace Data Store contains Calendar data GOOGLE_CALENDAR = 4 # Workspace Data Store contains Chat data GOOGLE_CHAT = 5 # Workspace Data Store contains Groups data GOOGLE_GROUPS = 6 # Workspace Data Store contains Keep data GOOGLE_KEEP = 7 # Workspace Data Store contains People data GOOGLE_PEOPLE = 8 end end |
#type ⇒ ::Google::Cloud::DiscoveryEngine::V1beta::WorkspaceConfig::Type
Returns The Google Workspace data source.
436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 |
# File 'proto_docs/google/cloud/discoveryengine/v1beta/data_store.rb', line 436 class WorkspaceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of Workspace App supported by this DataStore module Type # Defaults to an unspecified Workspace type. TYPE_UNSPECIFIED = 0 # Workspace Data Store contains Drive data GOOGLE_DRIVE = 1 # Workspace Data Store contains Mail data GOOGLE_MAIL = 2 # Workspace Data Store contains Sites data GOOGLE_SITES = 3 # Workspace Data Store contains Calendar data GOOGLE_CALENDAR = 4 # Workspace Data Store contains Chat data GOOGLE_CHAT = 5 # Workspace Data Store contains Groups data GOOGLE_GROUPS = 6 # Workspace Data Store contains Keep data GOOGLE_KEEP = 7 # Workspace Data Store contains People data GOOGLE_PEOPLE = 8 end end |